package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Action;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An action performed by a direct agent and indirect     participants upon a direct object. Optionally happens at a location     with the help of an inanimate instrument. The execution of the action     may produce a result. Specific action sub-type documentation specifies     the exact expectation of each argument/role.
 */
public class ActionImpl extends SchemaObjectImpl implements Action {


  private ThingImpl thing;

  /**
   * The direct performer or driver of the action (animate or inanimate). e.g. *John* wrote a book.
   */
  private List<Thing> agent = new LinkedList<Thing>();
  
  /**
   * When the Action was performed: end time. This is for actions that span a period of time. e.g. John wrote a book from January to *December*.
   */
  private List<Date> endTime = new LinkedList<Date>();
  
  /**
   * The object that helped the agent perform the action. e.g. John wrote a book with *a pen*.
   */
  private List<Thing> instrument = new LinkedList<Thing>();
  
  /**
   * The location of the event, organization or action.
   */
  private List<Thing> location = new LinkedList<Thing>();
  
  /**
   * The object upon the action is carried out, whose state is kept intact or changed. Also known as the semantic roles patient, affected or undergoer (which change their state) or theme (which doesn't). e.g. John read *a book*.
   */
  private List<Thing> object = new LinkedList<Thing>();
  
  /**
   * Other co-agents that participated in the action indirectly. e.g. John wrote a book with *Steve*.
   */
  private List<Thing> participant = new LinkedList<Thing>();
  
  /**
   * The result produced in the action. e.g. John wrote *a book*.
   */
  private List<Thing> result = new LinkedList<Thing>();
  
  /**
   * When a FoodEstablishmentReservation starts or an Action was performed: start time. This is for actions that span a period of time. e.g. John wrote a book from *January* to December.
   */
  private List<Date> startTime = new LinkedList<Date>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ActionImpl() {
    super("http://schema.org/Action");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this Action object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single agent property value for this Action object.
   *
   * @return The first agent property value.
   */
  public Thing getAgent() {
  	return this.agent.isEmpty() ? null : this.agent.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Action object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this Action object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single endTime property value for this Action object.
   *
   * @return The first endTime property value.
   */
  public Date getEndTime() {
  	return this.endTime.isEmpty() ? null : this.endTime.get(0);
  }
  
  /**
   * Get a single image property value for this Action object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single instrument property value for this Action object.
   *
   * @return The first instrument property value.
   */
  public Thing getInstrument() {
  	return this.instrument.isEmpty() ? null : this.instrument.get(0);
  }
  
  /**
   * Get a single location property value for this Action object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
  	return this.location.isEmpty() ? null : this.location.get(0);
  }
  
  /**
   * Get a single name property value for this Action object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single object property value for this Action object.
   *
   * @return The first object property value.
   */
  public Thing getObject() {
  	return this.object.isEmpty() ? null : this.object.get(0);
  }
  
  /**
   * Get a single participant property value for this Action object.
   *
   * @return The first participant property value.
   */
  public Thing getParticipant() {
  	return this.participant.isEmpty() ? null : this.participant.get(0);
  }
  
  /**
   * Get a single result property value for this Action object.
   *
   * @return The first result property value.
   */
  public Thing getResult() {
  	return this.result.isEmpty() ? null : this.result.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Action object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single startTime property value for this Action object.
   *
   * @return The first startTime property value.
   */
  public Date getStartTime() {
  	return this.startTime.isEmpty() ? null : this.startTime.get(0);
  }
  
  /**
   * Get a single url property value for this Action object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Action object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the agent property values for this Action object.
   *
   * @return A list of agent property values.
   */
  public List<Thing> getAgents() {
  	return this.agent;
  }
  
  /**
   * Get all the alternateName property values for this Action object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this Action object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the endTime property values for this Action object.
   *
   * @return A list of endTime property values.
   */
  public List<Date> getEndTimes() {
  	return this.endTime;
  }
  
  /**
   * Get all the image property values for this Action object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the instrument property values for this Action object.
   *
   * @return A list of instrument property values.
   */
  public List<Thing> getInstruments() {
  	return this.instrument;
  }
  
  /**
   * Get all the location property values for this Action object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
  	return this.location;
  }
  
  /**
   * Get all the name property values for this Action object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the object property values for this Action object.
   *
   * @return A list of object property values.
   */
  public List<Thing> getObjects() {
  	return this.object;
  }
  
  /**
   * Get all the participant property values for this Action object.
   *
   * @return A list of participant property values.
   */
  public List<Thing> getParticipants() {
  	return this.participant;
  }
  
  /**
   * Get all the result property values for this Action object.
   *
   * @return A list of result property values.
   */
  public List<Thing> getResults() {
  	return this.result;
  }
  
  /**
   * Get all the sameAs property values for this Action object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the startTime property values for this Action object.
   *
   * @return A list of startTime property values.
   */
  public List<Date> getStartTimes() {
  	return this.startTime;
  }
  
  /**
   * Get all the url property values for this Action object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Action object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the agent property value for this Action object; overwriting any existing values.
   *
   * @param agent The value to set.
   */
  public void setAgent(Thing agent) {
  	this.agent.clear();
  	this.agent.add(agent);
  }
  
  /**
   * Set the alternateName property value for this Action object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this Action object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the endTime property value for this Action object; overwriting any existing values.
   *
   * @param endTime The value to set.
   */
  public void setEndTime(Date endTime) {
  	this.endTime.clear();
  	this.endTime.add(endTime);
  }
  
  /**
   * Set the image property value for this Action object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the instrument property value for this Action object; overwriting any existing values.
   *
   * @param instrument The value to set.
   */
  public void setInstrument(Thing instrument) {
  	this.instrument.clear();
  	this.instrument.add(instrument);
  }
  
  /**
   * Set the location property value for this Action object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
  	this.location.clear();
  	this.location.add(location);
  }
  
  /**
   * Set the name property value for this Action object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the object property value for this Action object; overwriting any existing values.
   *
   * @param object The value to set.
   */
  public void setObject(Thing object) {
  	this.object.clear();
  	this.object.add(object);
  }
  
  /**
   * Set the participant property value for this Action object; overwriting any existing values.
   *
   * @param participant The value to set.
   */
  public void setParticipant(Thing participant) {
  	this.participant.clear();
  	this.participant.add(participant);
  }
  
  /**
   * Set the result property value for this Action object; overwriting any existing values.
   *
   * @param result The value to set.
   */
  public void setResult(Thing result) {
  	this.result.clear();
  	this.result.add(result);
  }
  
  /**
   * Set the sameAs property value for this Action object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the startTime property value for this Action object; overwriting any existing values.
   *
   * @param startTime The value to set.
   */
  public void setStartTime(Date startTime) {
  	this.startTime.clear();
  	this.startTime.add(startTime);
  }
  
  /**
   * Set the url property value for this Action object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Action object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the agent property values for this Action object; overwriting any existing values.
   *
   * @param agents The list of values to set.
   */
  public void setAgents(List<Thing> agents) {
  	this.agent = agents;
  }
  
  /**
   * Set the alternateName property values for this Action object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this Action object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the endTime property values for this Action object; overwriting any existing values.
   *
   * @param endTimes The list of values to set.
   */
  public void setEndTimes(List<Date> endTimes) {
  	this.endTime = endTimes;
  }
  
  /**
   * Set the image property values for this Action object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the instrument property values for this Action object; overwriting any existing values.
   *
   * @param instruments The list of values to set.
   */
  public void setInstruments(List<Thing> instruments) {
  	this.instrument = instruments;
  }
  
  /**
   * Set the location property values for this Action object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
  	this.location = locations;
  }
  
  /**
   * Set the name property values for this Action object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the object property values for this Action object; overwriting any existing values.
   *
   * @param objects The list of values to set.
   */
  public void setObjects(List<Thing> objects) {
  	this.object = objects;
  }
  
  /**
   * Set the participant property values for this Action object; overwriting any existing values.
   *
   * @param participants The list of values to set.
   */
  public void setParticipants(List<Thing> participants) {
  	this.participant = participants;
  }
  
  /**
   * Set the result property values for this Action object; overwriting any existing values.
   *
   * @param results The list of values to set.
   */
  public void setResults(List<Thing> results) {
  	this.result = results;
  }
  
  /**
   * Set the sameAs property values for this Action object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the startTime property values for this Action object; overwriting any existing values.
   *
   * @param startTimes The list of values to set.
   */
  public void setStartTimes(List<Date> startTimes) {
  	this.startTime = startTimes;
  }
  
  /**
   * Set the url property values for this Action object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Action object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a agent property value for this Action object; appending it to the list of existing values.
   *
   * @param agent The value to add.
   */
  public void addAgent(Thing agent) {
  	this.agent.add(agent);
  }
  
  /**
   * Adds a alternateName property value for this Action object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this Action object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a endTime property value for this Action object; appending it to the list of existing values.
   *
   * @param endTime The value to add.
   */
  public void addEndTime(Date endTime) {
  	this.endTime.add(endTime);
  }
  
  /**
   * Adds a image property value for this Action object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a instrument property value for this Action object; appending it to the list of existing values.
   *
   * @param instrument The value to add.
   */
  public void addInstrument(Thing instrument) {
  	this.instrument.add(instrument);
  }
  
  /**
   * Adds a location property value for this Action object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
  	this.location.add(location);
  }
  
  /**
   * Adds a name property value for this Action object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a object property value for this Action object; appending it to the list of existing values.
   *
   * @param object The value to add.
   */
  public void addObject(Thing object) {
  	this.object.add(object);
  }
  
  /**
   * Adds a participant property value for this Action object; appending it to the list of existing values.
   *
   * @param participant The value to add.
   */
  public void addParticipant(Thing participant) {
  	this.participant.add(participant);
  }
  
  /**
   * Adds a result property value for this Action object; appending it to the list of existing values.
   *
   * @param result The value to add.
   */
  public void addResult(Thing result) {
  	this.result.add(result);
  }
  
  /**
   * Adds a sameAs property value for this Action object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a startTime property value for this Action object; appending it to the list of existing values.
   *
   * @param startTime The value to add.
   */
  public void addStartTime(Date startTime) {
  	this.startTime.add(startTime);
  }
  
  /**
   * Adds a url property value for this Action object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}