package com.google.developers.schemas.impl;

import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateOffer;
import org.schema.AggregateRating;
import org.schema.BusinessEntityType;
import org.schema.BusinessFunction;
import org.schema.DeliveryMethod;
import org.schema.ItemAvailability;
import org.schema.Offer;
import org.schema.OfferItemCondition;
import org.schema.PaymentMethod;
import org.schema.Place;
import org.schema.PriceSpecification;
import org.schema.Product;
import org.schema.QuantitativeValue;
import org.schema.Review;
import org.schema.Thing;
import org.schema.TypeAndQuantityNode;
import org.schema.WarrantyPromise;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.
 */
public class AggregateOfferImpl extends SchemaObjectImpl implements AggregateOffer {


  private OfferImpl offer;
  private ThingImpl thing;

  /**
   * The highest price of all offers available.
   */
  private List<Thing> highPrice = new LinkedList<Thing>();
  
  /**
   * The lowest price of all offers available.
   */
  private List<Thing> lowPrice = new LinkedList<Thing>();
  
  /**
   * The number of offers for the product.
   */
  private List<Long> offerCount = new LinkedList<Long>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public AggregateOfferImpl() {
    super("http://schema.org/AggregateOffer");
    offer = new OfferImpl();
  }
  /**
   * Get a single acceptedPaymentMethod property value for this AggregateOffer object.
   *
   * @return The first acceptedPaymentMethod property value.
   */
  public PaymentMethod getAcceptedPaymentMethod() {
    return offer.getAcceptedPaymentMethod();
  }
  
  /**
   * Get a single addOn property value for this AggregateOffer object.
   *
   * @return The first addOn property value.
   */
  public Offer getAddOn() {
    return offer.getAddOn();
  }
  
  /**
   * Get a single additionalType property value for this AggregateOffer object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single advanceBookingRequirement property value for this AggregateOffer object.
   *
   * @return The first advanceBookingRequirement property value.
   */
  public QuantitativeValue getAdvanceBookingRequirement() {
    return offer.getAdvanceBookingRequirement();
  }
  
  /**
   * Get a single aggregateRating property value for this AggregateOffer object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
    return offer.getAggregateRating();
  }
  
  /**
   * Get a single alternateName property value for this AggregateOffer object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single availability property value for this AggregateOffer object.
   *
   * @return The first availability property value.
   */
  public ItemAvailability getAvailability() {
    return offer.getAvailability();
  }
  
  /**
   * Get a single availabilityEnds property value for this AggregateOffer object.
   *
   * @return The first availabilityEnds property value.
   */
  public Date getAvailabilityEnds() {
    return offer.getAvailabilityEnds();
  }
  
  /**
   * Get a single availabilityStarts property value for this AggregateOffer object.
   *
   * @return The first availabilityStarts property value.
   */
  public Date getAvailabilityStarts() {
    return offer.getAvailabilityStarts();
  }
  
  /**
   * Get a single availableAtOrFrom property value for this AggregateOffer object.
   *
   * @return The first availableAtOrFrom property value.
   */
  public Place getAvailableAtOrFrom() {
    return offer.getAvailableAtOrFrom();
  }
  
  /**
   * Get a single availableDeliveryMethod property value for this AggregateOffer object.
   *
   * @return The first availableDeliveryMethod property value.
   */
  public DeliveryMethod getAvailableDeliveryMethod() {
    return offer.getAvailableDeliveryMethod();
  }
  
  /**
   * Get a single businessFunction property value for this AggregateOffer object.
   *
   * @return The first businessFunction property value.
   */
  public BusinessFunction getBusinessFunction() {
    return offer.getBusinessFunction();
  }
  
  /**
   * Get a single category property value for this AggregateOffer object.
   *
   * @return The first category property value.
   */
  public Thing getCategory() {
    return offer.getCategory();
  }
  
  /**
   * Get a single deliveryLeadTime property value for this AggregateOffer object.
   *
   * @return The first deliveryLeadTime property value.
   */
  public QuantitativeValue getDeliveryLeadTime() {
    return offer.getDeliveryLeadTime();
  }
  
  /**
   * Get a single description property value for this AggregateOffer object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single eligibleCustomerType property value for this AggregateOffer object.
   *
   * @return The first eligibleCustomerType property value.
   */
  public BusinessEntityType getEligibleCustomerType() {
    return offer.getEligibleCustomerType();
  }
  
  /**
   * Get a single eligibleDuration property value for this AggregateOffer object.
   *
   * @return The first eligibleDuration property value.
   */
  public QuantitativeValue getEligibleDuration() {
    return offer.getEligibleDuration();
  }
  
  /**
   * Get a single eligibleQuantity property value for this AggregateOffer object.
   *
   * @return The first eligibleQuantity property value.
   */
  public QuantitativeValue getEligibleQuantity() {
    return offer.getEligibleQuantity();
  }
  
  /**
   * Get a single eligibleRegion property value for this AggregateOffer object.
   *
   * @return The first eligibleRegion property value.
   */
  public Thing getEligibleRegion() {
    return offer.getEligibleRegion();
  }
  
  /**
   * Get a single eligibleTransactionVolume property value for this AggregateOffer object.
   *
   * @return The first eligibleTransactionVolume property value.
   */
  public PriceSpecification getEligibleTransactionVolume() {
    return offer.getEligibleTransactionVolume();
  }
  
  /**
   * Get a single gtin13 property value for this AggregateOffer object.
   *
   * @return The first gtin13 property value.
   */
  public String getGtin13() {
    return offer.getGtin13();
  }
  
  /**
   * Get a single gtin14 property value for this AggregateOffer object.
   *
   * @return The first gtin14 property value.
   */
  public String getGtin14() {
    return offer.getGtin14();
  }
  
  /**
   * Get a single gtin8 property value for this AggregateOffer object.
   *
   * @return The first gtin8 property value.
   */
  public String getGtin8() {
    return offer.getGtin8();
  }
  
  /**
   * Get a single highPrice property value for this AggregateOffer object.
   *
   * @return The first highPrice property value.
   */
  public Thing getHighPrice() {
  	return this.highPrice.isEmpty() ? null : this.highPrice.get(0);
  }
  
  /**
   * Get a single image property value for this AggregateOffer object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single includesObject property value for this AggregateOffer object.
   *
   * @return The first includesObject property value.
   */
  public TypeAndQuantityNode getIncludesObject() {
    return offer.getIncludesObject();
  }
  
  /**
   * Get a single inventoryLevel property value for this AggregateOffer object.
   *
   * @return The first inventoryLevel property value.
   */
  public QuantitativeValue getInventoryLevel() {
    return offer.getInventoryLevel();
  }
  
  /**
   * Get a single itemCondition property value for this AggregateOffer object.
   *
   * @return The first itemCondition property value.
   */
  public OfferItemCondition getItemCondition() {
    return offer.getItemCondition();
  }
  
  /**
   * Get a single itemOffered property value for this AggregateOffer object.
   *
   * @return The first itemOffered property value.
   */
  public Product getItemOffered() {
    return offer.getItemOffered();
  }
  
  /**
   * Get a single lowPrice property value for this AggregateOffer object.
   *
   * @return The first lowPrice property value.
   */
  public Thing getLowPrice() {
  	return this.lowPrice.isEmpty() ? null : this.lowPrice.get(0);
  }
  
  /**
   * Get a single mpn property value for this AggregateOffer object.
   *
   * @return The first mpn property value.
   */
  public String getMpn() {
    return offer.getMpn();
  }
  
  /**
   * Get a single name property value for this AggregateOffer object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offerCount property value for this AggregateOffer object.
   *
   * @return The first offerCount property value.
   */
  public Long getOfferCount() {
  	return this.offerCount.isEmpty() ? null : this.offerCount.get(0);
  }
  
  /**
   * Get a single price property value for this AggregateOffer object.
   *
   * @return The first price property value.
   */
  public Thing getPrice() {
    return offer.getPrice();
  }
  
  /**
   * Get a single priceCurrency property value for this AggregateOffer object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency() {
    return offer.getPriceCurrency();
  }
  
  /**
   * Get a single priceSpecification property value for this AggregateOffer object.
   *
   * @return The first priceSpecification property value.
   */
  public PriceSpecification getPriceSpecification() {
    return offer.getPriceSpecification();
  }
  
  /**
   * Get a single priceValidUntil property value for this AggregateOffer object.
   *
   * @return The first priceValidUntil property value.
   */
  public Date getPriceValidUntil() {
    return offer.getPriceValidUntil();
  }
  
  /**
   * Get a single review property value for this AggregateOffer object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
    return offer.getReview();
  }
  
  /**
   * Get a single sameAs property value for this AggregateOffer object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seller property value for this AggregateOffer object.
   *
   * @return The first seller property value.
   */
  public Thing getSeller() {
    return offer.getSeller();
  }
  
  /**
   * Get a single serialNumber property value for this AggregateOffer object.
   *
   * @return The first serialNumber property value.
   */
  public String getSerialNumber() {
    return offer.getSerialNumber();
  }
  
  /**
   * Get a single sku property value for this AggregateOffer object.
   *
   * @return The first sku property value.
   */
  public String getSku() {
    return offer.getSku();
  }
  
  /**
   * Get a single url property value for this AggregateOffer object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single validFrom property value for this AggregateOffer object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom() {
    return offer.getValidFrom();
  }
  
  /**
   * Get a single validThrough property value for this AggregateOffer object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough() {
    return offer.getValidThrough();
  }
  
  /**
   * Get a single warranty property value for this AggregateOffer object.
   *
   * @return The first warranty property value.
   */
  public WarrantyPromise getWarranty() {
    return offer.getWarranty();
  }
  
  /**
   * Get all the acceptedPaymentMethod property values for this AggregateOffer object.
   *
   * @return A list of acceptedPaymentMethod property values.
   */
  public List<PaymentMethod> getAcceptedPaymentMethods() {
    return offer.getAcceptedPaymentMethods();
  }
  
  /**
   * Get all the addOn property values for this AggregateOffer object.
   *
   * @return A list of addOn property values.
   */
  public List<Offer> getAddsOn() {
    return offer.getAddsOn();
  }
  
  /**
   * Get all the additionalType property values for this AggregateOffer object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the advanceBookingRequirement property values for this AggregateOffer object.
   *
   * @return A list of advanceBookingRequirement property values.
   */
  public List<QuantitativeValue> getAdvanceBookingRequirements() {
    return offer.getAdvanceBookingRequirements();
  }
  
  /**
   * Get all the aggregateRating property values for this AggregateOffer object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
    return offer.getAggregateRatings();
  }
  
  /**
   * Get all the alternateName property values for this AggregateOffer object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the availability property values for this AggregateOffer object.
   *
   * @return A list of availability property values.
   */
  public List<ItemAvailability> getAvailabilities() {
    return offer.getAvailabilities();
  }
  
  /**
   * Get all the availabilityEnds property values for this AggregateOffer object.
   *
   * @return A list of availabilityEnds property values.
   */
  public List<Date> getAvailabilityEndss() {
    return offer.getAvailabilityEndss();
  }
  
  /**
   * Get all the availabilityStarts property values for this AggregateOffer object.
   *
   * @return A list of availabilityStarts property values.
   */
  public List<Date> getAvailabilityStartss() {
    return offer.getAvailabilityStartss();
  }
  
  /**
   * Get all the availableAtOrFrom property values for this AggregateOffer object.
   *
   * @return A list of availableAtOrFrom property values.
   */
  public List<Place> getAvailableAtOrFroms() {
    return offer.getAvailableAtOrFroms();
  }
  
  /**
   * Get all the availableDeliveryMethod property values for this AggregateOffer object.
   *
   * @return A list of availableDeliveryMethod property values.
   */
  public List<DeliveryMethod> getAvailableDeliveryMethods() {
    return offer.getAvailableDeliveryMethods();
  }
  
  /**
   * Get all the businessFunction property values for this AggregateOffer object.
   *
   * @return A list of businessFunction property values.
   */
  public List<BusinessFunction> getBusinessFunctions() {
    return offer.getBusinessFunctions();
  }
  
  /**
   * Get all the category property values for this AggregateOffer object.
   *
   * @return A list of category property values.
   */
  public List<Thing> getCategories() {
    return offer.getCategories();
  }
  
  /**
   * Get all the deliveryLeadTime property values for this AggregateOffer object.
   *
   * @return A list of deliveryLeadTime property values.
   */
  public List<QuantitativeValue> getDeliveryLeadTimes() {
    return offer.getDeliveryLeadTimes();
  }
  
  /**
   * Get all the description property values for this AggregateOffer object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the eligibleCustomerType property values for this AggregateOffer object.
   *
   * @return A list of eligibleCustomerType property values.
   */
  public List<BusinessEntityType> getEligibleCustomerTypes() {
    return offer.getEligibleCustomerTypes();
  }
  
  /**
   * Get all the eligibleDuration property values for this AggregateOffer object.
   *
   * @return A list of eligibleDuration property values.
   */
  public List<QuantitativeValue> getEligibleDurations() {
    return offer.getEligibleDurations();
  }
  
  /**
   * Get all the eligibleQuantity property values for this AggregateOffer object.
   *
   * @return A list of eligibleQuantity property values.
   */
  public List<QuantitativeValue> getEligibleQuantities() {
    return offer.getEligibleQuantities();
  }
  
  /**
   * Get all the eligibleRegion property values for this AggregateOffer object.
   *
   * @return A list of eligibleRegion property values.
   */
  public List<Thing> getEligibleRegions() {
    return offer.getEligibleRegions();
  }
  
  /**
   * Get all the eligibleTransactionVolume property values for this AggregateOffer object.
   *
   * @return A list of eligibleTransactionVolume property values.
   */
  public List<PriceSpecification> getEligibleTransactionVolumes() {
    return offer.getEligibleTransactionVolumes();
  }
  
  /**
   * Get all the gtin13 property values for this AggregateOffer object.
   *
   * @return A list of gtin13 property values.
   */
  public List<String> getGtin13s() {
    return offer.getGtin13s();
  }
  
  /**
   * Get all the gtin14 property values for this AggregateOffer object.
   *
   * @return A list of gtin14 property values.
   */
  public List<String> getGtin14s() {
    return offer.getGtin14s();
  }
  
  /**
   * Get all the gtin8 property values for this AggregateOffer object.
   *
   * @return A list of gtin8 property values.
   */
  public List<String> getGtin8s() {
    return offer.getGtin8s();
  }
  
  /**
   * Get all the highPrice property values for this AggregateOffer object.
   *
   * @return A list of highPrice property values.
   */
  public List<Thing> getHighPrices() {
  	return this.highPrice;
  }
  
  /**
   * Get all the image property values for this AggregateOffer object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the includesObject property values for this AggregateOffer object.
   *
   * @return A list of includesObject property values.
   */
  public List<TypeAndQuantityNode> getIncludesObjects() {
    return offer.getIncludesObjects();
  }
  
  /**
   * Get all the inventoryLevel property values for this AggregateOffer object.
   *
   * @return A list of inventoryLevel property values.
   */
  public List<QuantitativeValue> getInventoryLevels() {
    return offer.getInventoryLevels();
  }
  
  /**
   * Get all the itemCondition property values for this AggregateOffer object.
   *
   * @return A list of itemCondition property values.
   */
  public List<OfferItemCondition> getItemConditions() {
    return offer.getItemConditions();
  }
  
  /**
   * Get all the itemOffered property values for this AggregateOffer object.
   *
   * @return A list of itemOffered property values.
   */
  public List<Product> getItemOffereds() {
    return offer.getItemOffereds();
  }
  
  /**
   * Get all the lowPrice property values for this AggregateOffer object.
   *
   * @return A list of lowPrice property values.
   */
  public List<Thing> getLowPrices() {
  	return this.lowPrice;
  }
  
  /**
   * Get all the mpn property values for this AggregateOffer object.
   *
   * @return A list of mpn property values.
   */
  public List<String> getMpns() {
    return offer.getMpns();
  }
  
  /**
   * Get all the name property values for this AggregateOffer object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offerCount property values for this AggregateOffer object.
   *
   * @return A list of offerCount property values.
   */
  public List<Long> getOfferCounts() {
  	return this.offerCount;
  }
  
  /**
   * Get all the price property values for this AggregateOffer object.
   *
   * @return A list of price property values.
   */
  public List<Thing> getPrices() {
    return offer.getPrices();
  }
  
  /**
   * Get all the priceCurrency property values for this AggregateOffer object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies() {
    return offer.getPriceCurrencies();
  }
  
  /**
   * Get all the priceSpecification property values for this AggregateOffer object.
   *
   * @return A list of priceSpecification property values.
   */
  public List<PriceSpecification> getPriceSpecifications() {
    return offer.getPriceSpecifications();
  }
  
  /**
   * Get all the priceValidUntil property values for this AggregateOffer object.
   *
   * @return A list of priceValidUntil property values.
   */
  public List<Date> getPriceValidUntils() {
    return offer.getPriceValidUntils();
  }
  
  /**
   * Get all the review property values for this AggregateOffer object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
    return offer.getReviews();
  }
  
  /**
   * Get all the sameAs property values for this AggregateOffer object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seller property values for this AggregateOffer object.
   *
   * @return A list of seller property values.
   */
  public List<Thing> getSellers() {
    return offer.getSellers();
  }
  
  /**
   * Get all the serialNumber property values for this AggregateOffer object.
   *
   * @return A list of serialNumber property values.
   */
  public List<String> getSerialNumbers() {
    return offer.getSerialNumbers();
  }
  
  /**
   * Get all the sku property values for this AggregateOffer object.
   *
   * @return A list of sku property values.
   */
  public List<String> getSkus() {
    return offer.getSkus();
  }
  
  /**
   * Get all the url property values for this AggregateOffer object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the validFrom property values for this AggregateOffer object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms() {
    return offer.getValidFroms();
  }
  
  /**
   * Get all the validThrough property values for this AggregateOffer object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs() {
    return offer.getValidThroughs();
  }
  
  /**
   * Get all the warranty property values for this AggregateOffer object.
   *
   * @return A list of warranty property values.
   */
  public List<WarrantyPromise> getWarranties() {
    return offer.getWarranties();
  }
  
  /**
   * Set the acceptedPaymentMethod property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param acceptedPaymentMethod The value to set.
   */
  public void setAcceptedPaymentMethod(PaymentMethod acceptedPaymentMethod) {
    offer.setAcceptedPaymentMethod(acceptedPaymentMethod);
  }
  
  /**
   * Set the addOn property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param addOn The value to set.
   */
  public void setAddOn(Offer addOn) {
    offer.setAddOn(addOn);
  }
  
  /**
   * Set the additionalType property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the advanceBookingRequirement property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param advanceBookingRequirement The value to set.
   */
  public void setAdvanceBookingRequirement(QuantitativeValue advanceBookingRequirement) {
    offer.setAdvanceBookingRequirement(advanceBookingRequirement);
  }
  
  /**
   * Set the aggregateRating property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
    offer.setAggregateRating(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the availability property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param availability The value to set.
   */
  public void setAvailability(ItemAvailability availability) {
    offer.setAvailability(availability);
  }
  
  /**
   * Set the availabilityEnds property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param availabilityEnds The value to set.
   */
  public void setAvailabilityEnds(Date availabilityEnds) {
    offer.setAvailabilityEnds(availabilityEnds);
  }
  
  /**
   * Set the availabilityStarts property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param availabilityStarts The value to set.
   */
  public void setAvailabilityStarts(Date availabilityStarts) {
    offer.setAvailabilityStarts(availabilityStarts);
  }
  
  /**
   * Set the availableAtOrFrom property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param availableAtOrFrom The value to set.
   */
  public void setAvailableAtOrFrom(Place availableAtOrFrom) {
    offer.setAvailableAtOrFrom(availableAtOrFrom);
  }
  
  /**
   * Set the availableDeliveryMethod property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param availableDeliveryMethod The value to set.
   */
  public void setAvailableDeliveryMethod(DeliveryMethod availableDeliveryMethod) {
    offer.setAvailableDeliveryMethod(availableDeliveryMethod);
  }
  
  /**
   * Set the businessFunction property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param businessFunction The value to set.
   */
  public void setBusinessFunction(BusinessFunction businessFunction) {
    offer.setBusinessFunction(businessFunction);
  }
  
  /**
   * Set the category property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param category The value to set.
   */
  public void setCategory(Thing category) {
    offer.setCategory(category);
  }
  
  /**
   * Set the deliveryLeadTime property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param deliveryLeadTime The value to set.
   */
  public void setDeliveryLeadTime(QuantitativeValue deliveryLeadTime) {
    offer.setDeliveryLeadTime(deliveryLeadTime);
  }
  
  /**
   * Set the description property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the eligibleCustomerType property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleCustomerType The value to set.
   */
  public void setEligibleCustomerType(BusinessEntityType eligibleCustomerType) {
    offer.setEligibleCustomerType(eligibleCustomerType);
  }
  
  /**
   * Set the eligibleDuration property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleDuration The value to set.
   */
  public void setEligibleDuration(QuantitativeValue eligibleDuration) {
    offer.setEligibleDuration(eligibleDuration);
  }
  
  /**
   * Set the eligibleQuantity property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleQuantity The value to set.
   */
  public void setEligibleQuantity(QuantitativeValue eligibleQuantity) {
    offer.setEligibleQuantity(eligibleQuantity);
  }
  
  /**
   * Set the eligibleRegion property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleRegion The value to set.
   */
  public void setEligibleRegion(Thing eligibleRegion) {
    offer.setEligibleRegion(eligibleRegion);
  }
  
  /**
   * Set the eligibleTransactionVolume property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleTransactionVolume The value to set.
   */
  public void setEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
    offer.setEligibleTransactionVolume(eligibleTransactionVolume);
  }
  
  /**
   * Set the gtin13 property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param gtin13 The value to set.
   */
  public void setGtin13(String gtin13) {
    offer.setGtin13(gtin13);
  }
  
  /**
   * Set the gtin14 property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param gtin14 The value to set.
   */
  public void setGtin14(String gtin14) {
    offer.setGtin14(gtin14);
  }
  
  /**
   * Set the gtin8 property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param gtin8 The value to set.
   */
  public void setGtin8(String gtin8) {
    offer.setGtin8(gtin8);
  }
  
  /**
   * Set the highPrice property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param highPrice The value to set.
   */
  public void setHighPrice(Thing highPrice) {
  	this.highPrice.clear();
  	this.highPrice.add(highPrice);
  }
  
  /**
   * Set the image property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the includesObject property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param includesObject The value to set.
   */
  public void setIncludesObject(TypeAndQuantityNode includesObject) {
    offer.setIncludesObject(includesObject);
  }
  
  /**
   * Set the inventoryLevel property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param inventoryLevel The value to set.
   */
  public void setInventoryLevel(QuantitativeValue inventoryLevel) {
    offer.setInventoryLevel(inventoryLevel);
  }
  
  /**
   * Set the itemCondition property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param itemCondition The value to set.
   */
  public void setItemCondition(OfferItemCondition itemCondition) {
    offer.setItemCondition(itemCondition);
  }
  
  /**
   * Set the itemOffered property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param itemOffered The value to set.
   */
  public void setItemOffered(Product itemOffered) {
    offer.setItemOffered(itemOffered);
  }
  
  /**
   * Set the lowPrice property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param lowPrice The value to set.
   */
  public void setLowPrice(Thing lowPrice) {
  	this.lowPrice.clear();
  	this.lowPrice.add(lowPrice);
  }
  
  /**
   * Set the mpn property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param mpn The value to set.
   */
  public void setMpn(String mpn) {
    offer.setMpn(mpn);
  }
  
  /**
   * Set the name property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offerCount property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param offerCount The value to set.
   */
  public void setOfferCount(Long offerCount) {
  	this.offerCount.clear();
  	this.offerCount.add(offerCount);
  }
  
  /**
   * Set the price property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param price The value to set.
   */
  public void setPrice(Thing price) {
    offer.setPrice(price);
  }
  
  /**
   * Set the priceCurrency property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency) {
    offer.setPriceCurrency(priceCurrency);
  }
  
  /**
   * Set the priceSpecification property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param priceSpecification The value to set.
   */
  public void setPriceSpecification(PriceSpecification priceSpecification) {
    offer.setPriceSpecification(priceSpecification);
  }
  
  /**
   * Set the priceValidUntil property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param priceValidUntil The value to set.
   */
  public void setPriceValidUntil(Date priceValidUntil) {
    offer.setPriceValidUntil(priceValidUntil);
  }
  
  /**
   * Set the review property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
    offer.setReview(review);
  }
  
  /**
   * Set the sameAs property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seller property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param seller The value to set.
   */
  public void setSeller(Thing seller) {
    offer.setSeller(seller);
  }
  
  /**
   * Set the serialNumber property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param serialNumber The value to set.
   */
  public void setSerialNumber(String serialNumber) {
    offer.setSerialNumber(serialNumber);
  }
  
  /**
   * Set the sku property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param sku The value to set.
   */
  public void setSku(String sku) {
    offer.setSku(sku);
  }
  
  /**
   * Set the url property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the validFrom property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom) {
    offer.setValidFrom(validFrom);
  }
  
  /**
   * Set the validThrough property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough) {
    offer.setValidThrough(validThrough);
  }
  
  /**
   * Set the warranty property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param warranty The value to set.
   */
  public void setWarranty(WarrantyPromise warranty) {
    offer.setWarranty(warranty);
  }
  
  /**
   * Set the acceptedPaymentMethod property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param acceptedPaymentMethods The list of values to set.
   */
  public void setAcceptedPaymentMethods(List<PaymentMethod> acceptedPaymentMethods) {
    offer.setAcceptedPaymentMethods(acceptedPaymentMethods);
  }
  
  /**
   * Set the addOn property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param addsOn The list of values to set.
   */
  public void setAddsOn(List<Offer> addsOn) {
    offer.setAddsOn(addsOn);
  }
  
  /**
   * Set the additionalType property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the advanceBookingRequirement property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param advanceBookingRequirements The list of values to set.
   */
  public void setAdvanceBookingRequirements(List<QuantitativeValue> advanceBookingRequirements) {
    offer.setAdvanceBookingRequirements(advanceBookingRequirements);
  }
  
  /**
   * Set the aggregateRating property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
    offer.setAggregateRatings(aggregateRatings);
  }
  
  /**
   * Set the alternateName property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the availability property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param availabilities The list of values to set.
   */
  public void setAvailabilities(List<ItemAvailability> availabilities) {
    offer.setAvailabilities(availabilities);
  }
  
  /**
   * Set the availabilityEnds property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param availabilityEndss The list of values to set.
   */
  public void setAvailabilityEndss(List<Date> availabilityEndss) {
    offer.setAvailabilityEndss(availabilityEndss);
  }
  
  /**
   * Set the availabilityStarts property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param availabilityStartss The list of values to set.
   */
  public void setAvailabilityStartss(List<Date> availabilityStartss) {
    offer.setAvailabilityStartss(availabilityStartss);
  }
  
  /**
   * Set the availableAtOrFrom property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param availableAtOrFroms The list of values to set.
   */
  public void setAvailableAtOrFroms(List<Place> availableAtOrFroms) {
    offer.setAvailableAtOrFroms(availableAtOrFroms);
  }
  
  /**
   * Set the availableDeliveryMethod property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param availableDeliveryMethods The list of values to set.
   */
  public void setAvailableDeliveryMethods(List<DeliveryMethod> availableDeliveryMethods) {
    offer.setAvailableDeliveryMethods(availableDeliveryMethods);
  }
  
  /**
   * Set the businessFunction property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param businessFunctions The list of values to set.
   */
  public void setBusinessFunctions(List<BusinessFunction> businessFunctions) {
    offer.setBusinessFunctions(businessFunctions);
  }
  
  /**
   * Set the category property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param categories The list of values to set.
   */
  public void setCategories(List<Thing> categories) {
    offer.setCategories(categories);
  }
  
  /**
   * Set the deliveryLeadTime property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param deliveryLeadTimes The list of values to set.
   */
  public void setDeliveryLeadTimes(List<QuantitativeValue> deliveryLeadTimes) {
    offer.setDeliveryLeadTimes(deliveryLeadTimes);
  }
  
  /**
   * Set the description property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the eligibleCustomerType property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleCustomerTypes The list of values to set.
   */
  public void setEligibleCustomerTypes(List<BusinessEntityType> eligibleCustomerTypes) {
    offer.setEligibleCustomerTypes(eligibleCustomerTypes);
  }
  
  /**
   * Set the eligibleDuration property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleDurations The list of values to set.
   */
  public void setEligibleDurations(List<QuantitativeValue> eligibleDurations) {
    offer.setEligibleDurations(eligibleDurations);
  }
  
  /**
   * Set the eligibleQuantity property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleQuantities The list of values to set.
   */
  public void setEligibleQuantities(List<QuantitativeValue> eligibleQuantities) {
    offer.setEligibleQuantities(eligibleQuantities);
  }
  
  /**
   * Set the eligibleRegion property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleRegions The list of values to set.
   */
  public void setEligibleRegions(List<Thing> eligibleRegions) {
    offer.setEligibleRegions(eligibleRegions);
  }
  
  /**
   * Set the eligibleTransactionVolume property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param eligibleTransactionVolumes The list of values to set.
   */
  public void setEligibleTransactionVolumes(List<PriceSpecification> eligibleTransactionVolumes) {
    offer.setEligibleTransactionVolumes(eligibleTransactionVolumes);
  }
  
  /**
   * Set the gtin13 property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param gtin13s The list of values to set.
   */
  public void setGtin13s(List<String> gtin13s) {
    offer.setGtin13s(gtin13s);
  }
  
  /**
   * Set the gtin14 property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param gtin14s The list of values to set.
   */
  public void setGtin14s(List<String> gtin14s) {
    offer.setGtin14s(gtin14s);
  }
  
  /**
   * Set the gtin8 property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param gtin8s The list of values to set.
   */
  public void setGtin8s(List<String> gtin8s) {
    offer.setGtin8s(gtin8s);
  }
  
  /**
   * Set the highPrice property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param highPrices The list of values to set.
   */
  public void setHighPrices(List<Thing> highPrices) {
  	this.highPrice = highPrices;
  }
  
  /**
   * Set the image property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the includesObject property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param includesObjects The list of values to set.
   */
  public void setIncludesObjects(List<TypeAndQuantityNode> includesObjects) {
    offer.setIncludesObjects(includesObjects);
  }
  
  /**
   * Set the inventoryLevel property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param inventoryLevels The list of values to set.
   */
  public void setInventoryLevels(List<QuantitativeValue> inventoryLevels) {
    offer.setInventoryLevels(inventoryLevels);
  }
  
  /**
   * Set the itemCondition property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param itemConditions The list of values to set.
   */
  public void setItemConditions(List<OfferItemCondition> itemConditions) {
    offer.setItemConditions(itemConditions);
  }
  
  /**
   * Set the itemOffered property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param itemOffereds The list of values to set.
   */
  public void setItemOffereds(List<Product> itemOffereds) {
    offer.setItemOffereds(itemOffereds);
  }
  
  /**
   * Set the lowPrice property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param lowPrices The list of values to set.
   */
  public void setLowPrices(List<Thing> lowPrices) {
  	this.lowPrice = lowPrices;
  }
  
  /**
   * Set the mpn property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param mpns The list of values to set.
   */
  public void setMpns(List<String> mpns) {
    offer.setMpns(mpns);
  }
  
  /**
   * Set the name property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offerCount property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param offerCounts The list of values to set.
   */
  public void setOfferCounts(List<Long> offerCounts) {
  	this.offerCount = offerCounts;
  }
  
  /**
   * Set the price property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param prices The list of values to set.
   */
  public void setPrices(List<Thing> prices) {
    offer.setPrices(prices);
  }
  
  /**
   * Set the priceCurrency property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies) {
    offer.setPriceCurrencies(priceCurrencies);
  }
  
  /**
   * Set the priceSpecification property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param priceSpecifications The list of values to set.
   */
  public void setPriceSpecifications(List<PriceSpecification> priceSpecifications) {
    offer.setPriceSpecifications(priceSpecifications);
  }
  
  /**
   * Set the priceValidUntil property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param priceValidUntils The list of values to set.
   */
  public void setPriceValidUntils(List<Date> priceValidUntils) {
    offer.setPriceValidUntils(priceValidUntils);
  }
  
  /**
   * Set the review property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
    offer.setReviews(reviews);
  }
  
  /**
   * Set the sameAs property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seller property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param sellers The list of values to set.
   */
  public void setSellers(List<Thing> sellers) {
    offer.setSellers(sellers);
  }
  
  /**
   * Set the serialNumber property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param serialNumbers The list of values to set.
   */
  public void setSerialNumbers(List<String> serialNumbers) {
    offer.setSerialNumbers(serialNumbers);
  }
  
  /**
   * Set the sku property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param skus The list of values to set.
   */
  public void setSkus(List<String> skus) {
    offer.setSkus(skus);
  }
  
  /**
   * Set the url property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the validFrom property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms) {
    offer.setValidFroms(validFroms);
  }
  
  /**
   * Set the validThrough property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs) {
    offer.setValidThroughs(validThroughs);
  }
  
  /**
   * Set the warranty property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param warranties The list of values to set.
   */
  public void setWarranties(List<WarrantyPromise> warranties) {
    offer.setWarranties(warranties);
  }
  
  /**
   * Adds a acceptedPaymentMethod property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param acceptedPaymentMethod The value to add.
   */
  public void addAcceptedPaymentMethod(PaymentMethod acceptedPaymentMethod) {
    offer.addAcceptedPaymentMethod(acceptedPaymentMethod);
  }
  
  /**
   * Adds a addOn property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param addOn The value to add.
   */
  public void addAddOn(Offer addOn) {
    offer.addAddOn(addOn);
  }
  
  /**
   * Adds a additionalType property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a advanceBookingRequirement property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param advanceBookingRequirement The value to add.
   */
  public void addAdvanceBookingRequirement(QuantitativeValue advanceBookingRequirement) {
    offer.addAdvanceBookingRequirement(advanceBookingRequirement);
  }
  
  /**
   * Adds a aggregateRating property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
    offer.addAggregateRating(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a availability property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param availability The value to add.
   */
  public void addAvailability(ItemAvailability availability) {
    offer.addAvailability(availability);
  }
  
  /**
   * Adds a availabilityEnds property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param availabilityEnds The value to add.
   */
  public void addAvailabilityEnds(Date availabilityEnds) {
    offer.addAvailabilityEnds(availabilityEnds);
  }
  
  /**
   * Adds a availabilityStarts property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param availabilityStarts The value to add.
   */
  public void addAvailabilityStarts(Date availabilityStarts) {
    offer.addAvailabilityStarts(availabilityStarts);
  }
  
  /**
   * Adds a availableAtOrFrom property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param availableAtOrFrom The value to add.
   */
  public void addAvailableAtOrFrom(Place availableAtOrFrom) {
    offer.addAvailableAtOrFrom(availableAtOrFrom);
  }
  
  /**
   * Adds a availableDeliveryMethod property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param availableDeliveryMethod The value to add.
   */
  public void addAvailableDeliveryMethod(DeliveryMethod availableDeliveryMethod) {
    offer.addAvailableDeliveryMethod(availableDeliveryMethod);
  }
  
  /**
   * Adds a businessFunction property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param businessFunction The value to add.
   */
  public void addBusinessFunction(BusinessFunction businessFunction) {
    offer.addBusinessFunction(businessFunction);
  }
  
  /**
   * Adds a category property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param category The value to add.
   */
  public void addCategory(Thing category) {
    offer.addCategory(category);
  }
  
  /**
   * Adds a deliveryLeadTime property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param deliveryLeadTime The value to add.
   */
  public void addDeliveryLeadTime(QuantitativeValue deliveryLeadTime) {
    offer.addDeliveryLeadTime(deliveryLeadTime);
  }
  
  /**
   * Adds a description property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a eligibleCustomerType property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param eligibleCustomerType The value to add.
   */
  public void addEligibleCustomerType(BusinessEntityType eligibleCustomerType) {
    offer.addEligibleCustomerType(eligibleCustomerType);
  }
  
  /**
   * Adds a eligibleDuration property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param eligibleDuration The value to add.
   */
  public void addEligibleDuration(QuantitativeValue eligibleDuration) {
    offer.addEligibleDuration(eligibleDuration);
  }
  
  /**
   * Adds a eligibleQuantity property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param eligibleQuantity The value to add.
   */
  public void addEligibleQuantity(QuantitativeValue eligibleQuantity) {
    offer.addEligibleQuantity(eligibleQuantity);
  }
  
  /**
   * Adds a eligibleRegion property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param eligibleRegion The value to add.
   */
  public void addEligibleRegion(Thing eligibleRegion) {
    offer.addEligibleRegion(eligibleRegion);
  }
  
  /**
   * Adds a eligibleTransactionVolume property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param eligibleTransactionVolume The value to add.
   */
  public void addEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
    offer.addEligibleTransactionVolume(eligibleTransactionVolume);
  }
  
  /**
   * Adds a gtin13 property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param gtin13 The value to add.
   */
  public void addGtin13(String gtin13) {
    offer.addGtin13(gtin13);
  }
  
  /**
   * Adds a gtin14 property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param gtin14 The value to add.
   */
  public void addGtin14(String gtin14) {
    offer.addGtin14(gtin14);
  }
  
  /**
   * Adds a gtin8 property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param gtin8 The value to add.
   */
  public void addGtin8(String gtin8) {
    offer.addGtin8(gtin8);
  }
  
  /**
   * Adds a highPrice property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param highPrice The value to add.
   */
  public void addHighPrice(Thing highPrice) {
  	this.highPrice.add(highPrice);
  }
  
  /**
   * Adds a image property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a includesObject property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param includesObject The value to add.
   */
  public void addIncludesObject(TypeAndQuantityNode includesObject) {
    offer.addIncludesObject(includesObject);
  }
  
  /**
   * Adds a inventoryLevel property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param inventoryLevel The value to add.
   */
  public void addInventoryLevel(QuantitativeValue inventoryLevel) {
    offer.addInventoryLevel(inventoryLevel);
  }
  
  /**
   * Adds a itemCondition property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param itemCondition The value to add.
   */
  public void addItemCondition(OfferItemCondition itemCondition) {
    offer.addItemCondition(itemCondition);
  }
  
  /**
   * Adds a itemOffered property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param itemOffered The value to add.
   */
  public void addItemOffered(Product itemOffered) {
    offer.addItemOffered(itemOffered);
  }
  
  /**
   * Adds a lowPrice property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param lowPrice The value to add.
   */
  public void addLowPrice(Thing lowPrice) {
  	this.lowPrice.add(lowPrice);
  }
  
  /**
   * Adds a mpn property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param mpn The value to add.
   */
  public void addMpn(String mpn) {
    offer.addMpn(mpn);
  }
  
  /**
   * Adds a name property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offerCount property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param offerCount The value to add.
   */
  public void addOfferCount(Long offerCount) {
  	this.offerCount.add(offerCount);
  }
  
  /**
   * Adds a price property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param price The value to add.
   */
  public void addPrice(Thing price) {
    offer.addPrice(price);
  }
  
  /**
   * Adds a priceCurrency property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency) {
    offer.addPriceCurrency(priceCurrency);
  }
  
  /**
   * Adds a priceSpecification property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param priceSpecification The value to add.
   */
  public void addPriceSpecification(PriceSpecification priceSpecification) {
    offer.addPriceSpecification(priceSpecification);
  }
  
  /**
   * Adds a priceValidUntil property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param priceValidUntil The value to add.
   */
  public void addPriceValidUntil(Date priceValidUntil) {
    offer.addPriceValidUntil(priceValidUntil);
  }
  
  /**
   * Adds a review property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
    offer.addReview(review);
  }
  
  /**
   * Adds a sameAs property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seller property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param seller The value to add.
   */
  public void addSeller(Thing seller) {
    offer.addSeller(seller);
  }
  
  /**
   * Adds a serialNumber property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param serialNumber The value to add.
   */
  public void addSerialNumber(String serialNumber) {
    offer.addSerialNumber(serialNumber);
  }
  
  /**
   * Adds a sku property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param sku The value to add.
   */
  public void addSku(String sku) {
    offer.addSku(sku);
  }
  
  /**
   * Adds a url property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a validFrom property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom) {
    offer.addValidFrom(validFrom);
  }
  
  /**
   * Adds a validThrough property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough) {
    offer.addValidThrough(validThrough);
  }
  
  /**
   * Adds a warranty property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param warranty The value to add.
   */
  public void addWarranty(WarrantyPromise warranty) {
    offer.addWarranty(warranty);
  }
  
}