package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.Number;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The average rating based on multiple ratings or reviews.
 */
public class AggregateRatingImpl extends SchemaObjectImpl implements AggregateRating {


  private RatingImpl rating;
  private ThingImpl thing;

  /**
   * The item that is being reviewed/rated.
   */
  private List<Thing> itemReviewed = new LinkedList<Thing>();
  
  /**
   * The count of total number of ratings.
   */
  private List<Number> ratingCount = new LinkedList<Number>();
  
  /**
   * The count of total number of reviews.
   */
  private List<Number> reviewCount = new LinkedList<Number>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public AggregateRatingImpl() {
    super("http://schema.org/AggregateRating");
    rating = new RatingImpl();
  }
  /**
   * Get a single additionalType property value for this AggregateRating object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this AggregateRating object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single bestRating property value for this AggregateRating object.
   *
   * @return The first bestRating property value.
   */
  public Thing getBestRating() {
    return rating.getBestRating();
  }
  
  /**
   * Get a single description property value for this AggregateRating object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this AggregateRating object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single itemReviewed property value for this AggregateRating object.
   *
   * @return The first itemReviewed property value.
   */
  public Thing getItemReviewed() {
  	return this.itemReviewed.isEmpty() ? null : this.itemReviewed.get(0);
  }
  
  /**
   * Get a single name property value for this AggregateRating object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single ratingCount property value for this AggregateRating object.
   *
   * @return The first ratingCount property value.
   */
  public Number getRatingCount() {
  	return this.ratingCount.isEmpty() ? null : this.ratingCount.get(0);
  }
  
  /**
   * Get a single ratingValue property value for this AggregateRating object.
   *
   * @return The first ratingValue property value.
   */
  public String getRatingValue() {
    return rating.getRatingValue();
  }
  
  /**
   * Get a single reviewCount property value for this AggregateRating object.
   *
   * @return The first reviewCount property value.
   */
  public Number getReviewCount() {
  	return this.reviewCount.isEmpty() ? null : this.reviewCount.get(0);
  }
  
  /**
   * Get a single sameAs property value for this AggregateRating object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this AggregateRating object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single worstRating property value for this AggregateRating object.
   *
   * @return The first worstRating property value.
   */
  public Thing getWorstRating() {
    return rating.getWorstRating();
  }
  
  /**
   * Get all the additionalType property values for this AggregateRating object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this AggregateRating object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the bestRating property values for this AggregateRating object.
   *
   * @return A list of bestRating property values.
   */
  public List<Thing> getBestRatings() {
    return rating.getBestRatings();
  }
  
  /**
   * Get all the description property values for this AggregateRating object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this AggregateRating object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the itemReviewed property values for this AggregateRating object.
   *
   * @return A list of itemReviewed property values.
   */
  public List<Thing> getItemRevieweds() {
  	return this.itemReviewed;
  }
  
  /**
   * Get all the name property values for this AggregateRating object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the ratingCount property values for this AggregateRating object.
   *
   * @return A list of ratingCount property values.
   */
  public List<Number> getRatingCounts() {
  	return this.ratingCount;
  }
  
  /**
   * Get all the ratingValue property values for this AggregateRating object.
   *
   * @return A list of ratingValue property values.
   */
  public List<String> getRatingValues() {
    return rating.getRatingValues();
  }
  
  /**
   * Get all the reviewCount property values for this AggregateRating object.
   *
   * @return A list of reviewCount property values.
   */
  public List<Number> getReviewCounts() {
  	return this.reviewCount;
  }
  
  /**
   * Get all the sameAs property values for this AggregateRating object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this AggregateRating object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the worstRating property values for this AggregateRating object.
   *
   * @return A list of worstRating property values.
   */
  public List<Thing> getWorstRatings() {
    return rating.getWorstRatings();
  }
  
  /**
   * Set the additionalType property value for this AggregateRating object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this AggregateRating object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the bestRating property value for this AggregateRating object; overwriting any existing values.
   *
   * @param bestRating The value to set.
   */
  public void setBestRating(Thing bestRating) {
    rating.setBestRating(bestRating);
  }
  
  /**
   * Set the description property value for this AggregateRating object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this AggregateRating object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the itemReviewed property value for this AggregateRating object; overwriting any existing values.
   *
   * @param itemReviewed The value to set.
   */
  public void setItemReviewed(Thing itemReviewed) {
  	this.itemReviewed.clear();
  	this.itemReviewed.add(itemReviewed);
  }
  
  /**
   * Set the name property value for this AggregateRating object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the ratingCount property value for this AggregateRating object; overwriting any existing values.
   *
   * @param ratingCount The value to set.
   */
  public void setRatingCount(Number ratingCount) {
  	this.ratingCount.clear();
  	this.ratingCount.add(ratingCount);
  }
  
  /**
   * Set the ratingValue property value for this AggregateRating object; overwriting any existing values.
   *
   * @param ratingValue The value to set.
   */
  public void setRatingValue(String ratingValue) {
    rating.setRatingValue(ratingValue);
  }
  
  /**
   * Set the reviewCount property value for this AggregateRating object; overwriting any existing values.
   *
   * @param reviewCount The value to set.
   */
  public void setReviewCount(Number reviewCount) {
  	this.reviewCount.clear();
  	this.reviewCount.add(reviewCount);
  }
  
  /**
   * Set the sameAs property value for this AggregateRating object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this AggregateRating object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the worstRating property value for this AggregateRating object; overwriting any existing values.
   *
   * @param worstRating The value to set.
   */
  public void setWorstRating(Thing worstRating) {
    rating.setWorstRating(worstRating);
  }
  
  /**
   * Set the additionalType property values for this AggregateRating object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this AggregateRating object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the bestRating property values for this AggregateRating object; overwriting any existing values.
   *
   * @param bestRatings The list of values to set.
   */
  public void setBestRatings(List<Thing> bestRatings) {
    rating.setBestRatings(bestRatings);
  }
  
  /**
   * Set the description property values for this AggregateRating object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this AggregateRating object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the itemReviewed property values for this AggregateRating object; overwriting any existing values.
   *
   * @param itemRevieweds The list of values to set.
   */
  public void setItemRevieweds(List<Thing> itemRevieweds) {
  	this.itemReviewed = itemRevieweds;
  }
  
  /**
   * Set the name property values for this AggregateRating object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the ratingCount property values for this AggregateRating object; overwriting any existing values.
   *
   * @param ratingCounts The list of values to set.
   */
  public void setRatingCounts(List<Number> ratingCounts) {
  	this.ratingCount = ratingCounts;
  }
  
  /**
   * Set the ratingValue property values for this AggregateRating object; overwriting any existing values.
   *
   * @param ratingValues The list of values to set.
   */
  public void setRatingValues(List<String> ratingValues) {
    rating.setRatingValues(ratingValues);
  }
  
  /**
   * Set the reviewCount property values for this AggregateRating object; overwriting any existing values.
   *
   * @param reviewCounts The list of values to set.
   */
  public void setReviewCounts(List<Number> reviewCounts) {
  	this.reviewCount = reviewCounts;
  }
  
  /**
   * Set the sameAs property values for this AggregateRating object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this AggregateRating object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the worstRating property values for this AggregateRating object; overwriting any existing values.
   *
   * @param worstRatings The list of values to set.
   */
  public void setWorstRatings(List<Thing> worstRatings) {
    rating.setWorstRatings(worstRatings);
  }
  
  /**
   * Adds a additionalType property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a bestRating property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param bestRating The value to add.
   */
  public void addBestRating(Thing bestRating) {
    rating.addBestRating(bestRating);
  }
  
  /**
   * Adds a description property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a itemReviewed property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param itemReviewed The value to add.
   */
  public void addItemReviewed(Thing itemReviewed) {
  	this.itemReviewed.add(itemReviewed);
  }
  
  /**
   * Adds a name property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a ratingCount property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param ratingCount The value to add.
   */
  public void addRatingCount(Number ratingCount) {
  	this.ratingCount.add(ratingCount);
  }
  
  /**
   * Adds a ratingValue property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param ratingValue The value to add.
   */
  public void addRatingValue(String ratingValue) {
    rating.addRatingValue(ratingValue);
  }
  
  /**
   * Adds a reviewCount property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param reviewCount The value to add.
   */
  public void addReviewCount(Number reviewCount) {
  	this.reviewCount.add(reviewCount);
  }
  
  /**
   * Adds a sameAs property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a worstRating property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param worstRating The value to add.
   */
  public void addWorstRating(Thing worstRating) {
    rating.addWorstRating(worstRating);
  }
  
}