package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AlignmentObject;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An intangible item that describes an alignment between a learning resource and a node in an educational framework.
 */
public class AlignmentObjectImpl extends SchemaObjectImpl implements AlignmentObject {


  private ThingImpl thing;

  /**
   * A category of alignment between the learning resource and the framework node. Recommended values include: 'assesses', 'teaches', 'requires', 'textComplexity', 'readingLevel', 'educationalSubject', and 'educationLevel'.
   */
  private List<String> alignmentType = new LinkedList<String>();
  
  /**
   * The framework to which the resource being described is aligned.
   */
  private List<String> educationalFramework = new LinkedList<String>();
  
  /**
   * The description of a node in an established educational framework.
   */
  private List<String> targetDescription = new LinkedList<String>();
  
  /**
   * The name of a node in an established educational framework.
   */
  private List<String> targetName = new LinkedList<String>();
  
  /**
   * The URL of a node in an established educational framework.
   */
  private List<URL> targetUrl = new LinkedList<URL>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public AlignmentObjectImpl() {
    super("http://schema.org/AlignmentObject");
  }
  /**
   * Get a single additionalType property value for this AlignmentObject object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alignmentType property value for this AlignmentObject object.
   *
   * @return The first alignmentType property value.
   */
  public String getAlignmentType() {
  	return this.alignmentType.isEmpty() ? null : this.alignmentType.get(0);
  }
  
  /**
   * Get a single alternateName property value for this AlignmentObject object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this AlignmentObject object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single educationalFramework property value for this AlignmentObject object.
   *
   * @return The first educationalFramework property value.
   */
  public String getEducationalFramework() {
  	return this.educationalFramework.isEmpty() ? null : this.educationalFramework.get(0);
  }
  
  /**
   * Get a single image property value for this AlignmentObject object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this AlignmentObject object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single sameAs property value for this AlignmentObject object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single targetDescription property value for this AlignmentObject object.
   *
   * @return The first targetDescription property value.
   */
  public String getTargetDescription() {
  	return this.targetDescription.isEmpty() ? null : this.targetDescription.get(0);
  }
  
  /**
   * Get a single targetName property value for this AlignmentObject object.
   *
   * @return The first targetName property value.
   */
  public String getTargetName() {
  	return this.targetName.isEmpty() ? null : this.targetName.get(0);
  }
  
  /**
   * Get a single targetUrl property value for this AlignmentObject object.
   *
   * @return The first targetUrl property value.
   */
  public URL getTargetUrl() {
  	return this.targetUrl.isEmpty() ? null : this.targetUrl.get(0);
  }
  
  /**
   * Get a single url property value for this AlignmentObject object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this AlignmentObject object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alignmentType property values for this AlignmentObject object.
   *
   * @return A list of alignmentType property values.
   */
  public List<String> getAlignmentTypes() {
  	return this.alignmentType;
  }
  
  /**
   * Get all the alternateName property values for this AlignmentObject object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this AlignmentObject object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the educationalFramework property values for this AlignmentObject object.
   *
   * @return A list of educationalFramework property values.
   */
  public List<String> getEducationalFrameworks() {
  	return this.educationalFramework;
  }
  
  /**
   * Get all the image property values for this AlignmentObject object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this AlignmentObject object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the sameAs property values for this AlignmentObject object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the targetDescription property values for this AlignmentObject object.
   *
   * @return A list of targetDescription property values.
   */
  public List<String> getTargetDescriptions() {
  	return this.targetDescription;
  }
  
  /**
   * Get all the targetName property values for this AlignmentObject object.
   *
   * @return A list of targetName property values.
   */
  public List<String> getTargetNames() {
  	return this.targetName;
  }
  
  /**
   * Get all the targetUrl property values for this AlignmentObject object.
   *
   * @return A list of targetUrl property values.
   */
  public List<URL> getTargetUrls() {
  	return this.targetUrl;
  }
  
  /**
   * Get all the url property values for this AlignmentObject object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alignmentType property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param alignmentType The value to set.
   */
  public void setAlignmentType(String alignmentType) {
  	this.alignmentType.clear();
  	this.alignmentType.add(alignmentType);
  }
  
  /**
   * Set the alternateName property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the educationalFramework property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param educationalFramework The value to set.
   */
  public void setEducationalFramework(String educationalFramework) {
  	this.educationalFramework.clear();
  	this.educationalFramework.add(educationalFramework);
  }
  
  /**
   * Set the image property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the sameAs property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the targetDescription property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetDescription The value to set.
   */
  public void setTargetDescription(String targetDescription) {
  	this.targetDescription.clear();
  	this.targetDescription.add(targetDescription);
  }
  
  /**
   * Set the targetName property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetName The value to set.
   */
  public void setTargetName(String targetName) {
  	this.targetName.clear();
  	this.targetName.add(targetName);
  }
  
  /**
   * Set the targetUrl property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetUrl The value to set.
   */
  public void setTargetUrl(URL targetUrl) {
  	this.targetUrl.clear();
  	this.targetUrl.add(targetUrl);
  }
  
  /**
   * Set the url property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alignmentType property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param alignmentTypes The list of values to set.
   */
  public void setAlignmentTypes(List<String> alignmentTypes) {
  	this.alignmentType = alignmentTypes;
  }
  
  /**
   * Set the alternateName property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the educationalFramework property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param educationalFrameworks The list of values to set.
   */
  public void setEducationalFrameworks(List<String> educationalFrameworks) {
  	this.educationalFramework = educationalFrameworks;
  }
  
  /**
   * Set the image property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the sameAs property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the targetDescription property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetDescriptions The list of values to set.
   */
  public void setTargetDescriptions(List<String> targetDescriptions) {
  	this.targetDescription = targetDescriptions;
  }
  
  /**
   * Set the targetName property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetNames The list of values to set.
   */
  public void setTargetNames(List<String> targetNames) {
  	this.targetName = targetNames;
  }
  
  /**
   * Set the targetUrl property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetUrls The list of values to set.
   */
  public void setTargetUrls(List<URL> targetUrls) {
  	this.targetUrl = targetUrls;
  }
  
  /**
   * Set the url property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alignmentType property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param alignmentType The value to add.
   */
  public void addAlignmentType(String alignmentType) {
  	this.alignmentType.add(alignmentType);
  }
  
  /**
   * Adds a alternateName property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a educationalFramework property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param educationalFramework The value to add.
   */
  public void addEducationalFramework(String educationalFramework) {
  	this.educationalFramework.add(educationalFramework);
  }
  
  /**
   * Adds a image property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a sameAs property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a targetDescription property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param targetDescription The value to add.
   */
  public void addTargetDescription(String targetDescription) {
  	this.targetDescription.add(targetDescription);
  }
  
  /**
   * Adds a targetName property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param targetName The value to add.
   */
  public void addTargetName(String targetName) {
  	this.targetName.add(targetName);
  }
  
  /**
   * Adds a targetUrl property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param targetUrl The value to add.
   */
  public void addTargetUrl(URL targetUrl) {
  	this.targetUrl.add(targetUrl);
  }
  
  /**
   * Adds a url property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}