package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.AnatomicalSystem;
import org.schema.MedicalCode;
import org.schema.MedicalCondition;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An anatomical system is a group of anatomical structures that work together to perform a certain task. Anatomical systems, such as organ systems, are one organizing principle of anatomy, and can includes circulatory, digestive, endocrine, integumentary, immune, lymphatic, muscular, nervous, reproductive, respiratory, skeletal, urinary, vestibular, and other systems.
 */
public class AnatomicalSystemImpl extends SchemaObjectImpl implements AnatomicalSystem {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * If applicable, a description of the pathophysiology associated with the anatomical system, including potential abnormal changes in the mechanical, physical, and biochemical functions of the system.
   */
  private List<String> associatedPathophysiology = new LinkedList<String>();
  
  /**
   * The underlying anatomical structures, such as organs, that comprise the anatomical system.
   */
  private List<Thing> comprisedOf = new LinkedList<Thing>();
  
  /**
   * A medical condition associated with this anatomy.
   */
  private List<MedicalCondition> relatedCondition = new LinkedList<MedicalCondition>();
  
  /**
   * Related anatomical structure(s) that are not part of the system but relate or connect to it, such as vascular bundles associated with an organ system.
   */
  private List<AnatomicalStructure> relatedStructure = new LinkedList<AnatomicalStructure>();
  
  /**
   * A medical therapy related to this anatomy.
   */
  private List<MedicalTherapy> relatedTherapy = new LinkedList<MedicalTherapy>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public AnatomicalSystemImpl() {
    super("http://schema.org/AnatomicalSystem");
    medicalEntity = new MedicalEntityImpl();
  }
  /**
   * Get a single additionalType property value for this AnatomicalSystem object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this AnatomicalSystem object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single associatedPathophysiology property value for this AnatomicalSystem object.
   *
   * @return The first associatedPathophysiology property value.
   */
  public String getAssociatedPathophysiology() {
  	return this.associatedPathophysiology.isEmpty() ? null : this.associatedPathophysiology.get(0);
  }
  
  /**
   * Get a single code property value for this AnatomicalSystem object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single comprisedOf property value for this AnatomicalSystem object.
   *
   * @return The first comprisedOf property value.
   */
  public Thing getComprisedOf() {
  	return this.comprisedOf.isEmpty() ? null : this.comprisedOf.get(0);
  }
  
  /**
   * Get a single description property value for this AnatomicalSystem object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this AnatomicalSystem object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this AnatomicalSystem object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this AnatomicalSystem object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this AnatomicalSystem object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single recognizingAuthority property value for this AnatomicalSystem object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relatedCondition property value for this AnatomicalSystem object.
   *
   * @return The first relatedCondition property value.
   */
  public MedicalCondition getRelatedCondition() {
  	return this.relatedCondition.isEmpty() ? null : this.relatedCondition.get(0);
  }
  
  /**
   * Get a single relatedStructure property value for this AnatomicalSystem object.
   *
   * @return The first relatedStructure property value.
   */
  public AnatomicalStructure getRelatedStructure() {
  	return this.relatedStructure.isEmpty() ? null : this.relatedStructure.get(0);
  }
  
  /**
   * Get a single relatedTherapy property value for this AnatomicalSystem object.
   *
   * @return The first relatedTherapy property value.
   */
  public MedicalTherapy getRelatedTherapy() {
  	return this.relatedTherapy.isEmpty() ? null : this.relatedTherapy.get(0);
  }
  
  /**
   * Get a single relevantSpecialty property value for this AnatomicalSystem object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this AnatomicalSystem object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this AnatomicalSystem object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this AnatomicalSystem object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this AnatomicalSystem object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this AnatomicalSystem object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the associatedPathophysiology property values for this AnatomicalSystem object.
   *
   * @return A list of associatedPathophysiology property values.
   */
  public List<String> getAssociatedPathophysiologies() {
  	return this.associatedPathophysiology;
  }
  
  /**
   * Get all the code property values for this AnatomicalSystem object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the comprisedOf property values for this AnatomicalSystem object.
   *
   * @return A list of comprisedOf property values.
   */
  public List<Thing> getComprisedsOf() {
  	return this.comprisedOf;
  }
  
  /**
   * Get all the description property values for this AnatomicalSystem object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this AnatomicalSystem object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this AnatomicalSystem object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this AnatomicalSystem object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this AnatomicalSystem object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the recognizingAuthority property values for this AnatomicalSystem object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relatedCondition property values for this AnatomicalSystem object.
   *
   * @return A list of relatedCondition property values.
   */
  public List<MedicalCondition> getRelatedConditions() {
  	return this.relatedCondition;
  }
  
  /**
   * Get all the relatedStructure property values for this AnatomicalSystem object.
   *
   * @return A list of relatedStructure property values.
   */
  public List<AnatomicalStructure> getRelatedStructures() {
  	return this.relatedStructure;
  }
  
  /**
   * Get all the relatedTherapy property values for this AnatomicalSystem object.
   *
   * @return A list of relatedTherapy property values.
   */
  public List<MedicalTherapy> getRelatedTherapies() {
  	return this.relatedTherapy;
  }
  
  /**
   * Get all the relevantSpecialty property values for this AnatomicalSystem object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this AnatomicalSystem object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this AnatomicalSystem object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this AnatomicalSystem object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the associatedPathophysiology property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param associatedPathophysiology The value to set.
   */
  public void setAssociatedPathophysiology(String associatedPathophysiology) {
  	this.associatedPathophysiology.clear();
  	this.associatedPathophysiology.add(associatedPathophysiology);
  }
  
  /**
   * Set the code property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the comprisedOf property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param comprisedOf The value to set.
   */
  public void setComprisedOf(Thing comprisedOf) {
  	this.comprisedOf.clear();
  	this.comprisedOf.add(comprisedOf);
  }
  
  /**
   * Set the description property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the recognizingAuthority property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relatedCondition property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedCondition The value to set.
   */
  public void setRelatedCondition(MedicalCondition relatedCondition) {
  	this.relatedCondition.clear();
  	this.relatedCondition.add(relatedCondition);
  }
  
  /**
   * Set the relatedStructure property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedStructure The value to set.
   */
  public void setRelatedStructure(AnatomicalStructure relatedStructure) {
  	this.relatedStructure.clear();
  	this.relatedStructure.add(relatedStructure);
  }
  
  /**
   * Set the relatedTherapy property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedTherapy The value to set.
   */
  public void setRelatedTherapy(MedicalTherapy relatedTherapy) {
  	this.relatedTherapy.clear();
  	this.relatedTherapy.add(relatedTherapy);
  }
  
  /**
   * Set the relevantSpecialty property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the associatedPathophysiology property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param associatedPathophysiologies The list of values to set.
   */
  public void setAssociatedPathophysiologies(List<String> associatedPathophysiologies) {
  	this.associatedPathophysiology = associatedPathophysiologies;
  }
  
  /**
   * Set the code property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the comprisedOf property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param comprisedsOf The list of values to set.
   */
  public void setComprisedsOf(List<Thing> comprisedsOf) {
  	this.comprisedOf = comprisedsOf;
  }
  
  /**
   * Set the description property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the recognizingAuthority property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relatedCondition property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedConditions The list of values to set.
   */
  public void setRelatedConditions(List<MedicalCondition> relatedConditions) {
  	this.relatedCondition = relatedConditions;
  }
  
  /**
   * Set the relatedStructure property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedStructures The list of values to set.
   */
  public void setRelatedStructures(List<AnatomicalStructure> relatedStructures) {
  	this.relatedStructure = relatedStructures;
  }
  
  /**
   * Set the relatedTherapy property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedTherapies The list of values to set.
   */
  public void setRelatedTherapies(List<MedicalTherapy> relatedTherapies) {
  	this.relatedTherapy = relatedTherapies;
  }
  
  /**
   * Set the relevantSpecialty property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a associatedPathophysiology property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param associatedPathophysiology The value to add.
   */
  public void addAssociatedPathophysiology(String associatedPathophysiology) {
  	this.associatedPathophysiology.add(associatedPathophysiology);
  }
  
  /**
   * Adds a code property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a comprisedOf property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param comprisedOf The value to add.
   */
  public void addComprisedOf(Thing comprisedOf) {
  	this.comprisedOf.add(comprisedOf);
  }
  
  /**
   * Adds a description property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a recognizingAuthority property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relatedCondition property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relatedCondition The value to add.
   */
  public void addRelatedCondition(MedicalCondition relatedCondition) {
  	this.relatedCondition.add(relatedCondition);
  }
  
  /**
   * Adds a relatedStructure property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relatedStructure The value to add.
   */
  public void addRelatedStructure(AnatomicalStructure relatedStructure) {
  	this.relatedStructure.add(relatedStructure);
  }
  
  /**
   * Adds a relatedTherapy property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relatedTherapy The value to add.
   */
  public void addRelatedTherapy(MedicalTherapy relatedTherapy) {
  	this.relatedTherapy.add(relatedTherapy);
  }
  
  /**
   * Adds a relevantSpecialty property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}