package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.BroadcastEvent;
import org.schema.BroadcastService;
import org.schema.Duration;
import org.schema.Event;
import org.schema.EventStatusType;
import org.schema.Offer;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An over the air or online broadcast event.
 */
public class BroadcastEventImpl extends SchemaObjectImpl implements BroadcastEvent {


  private EventImpl event;
  private PublicationEventImpl publicationEvent;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public BroadcastEventImpl() {
    super("http://schema.org/BroadcastEvent");
    publicationEvent = new PublicationEventImpl();
  }
  /**
   * Get a single additionalType property value for this BroadcastEvent object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this BroadcastEvent object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single attendee property value for this BroadcastEvent object.
   *
   * @return The first attendee property value.
   */
  public Thing getAttendee() {
    return event.getAttendee();
  }
  
  /**
   * Get a single description property value for this BroadcastEvent object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single doorTime property value for this BroadcastEvent object.
   *
   * @return The first doorTime property value.
   */
  public Date getDoorTime() {
    return event.getDoorTime();
  }
  
  /**
   * Get a single duration property value for this BroadcastEvent object.
   *
   * @return The first duration property value.
   */
  public Duration getDuration() {
    return event.getDuration();
  }
  
  /**
   * Get a single endDate property value for this BroadcastEvent object.
   *
   * @return The first endDate property value.
   */
  public Date getEndDate() {
    return event.getEndDate();
  }
  
  /**
   * Get a single eventStatus property value for this BroadcastEvent object.
   *
   * @return The first eventStatus property value.
   */
  public EventStatusType getEventStatus() {
    return event.getEventStatus();
  }
  
  /**
   * Get a single free property value for this BroadcastEvent object.
   *
   * @return The first free property value.
   */
  public Boolean getFree() {
    return publicationEvent.getFree();
  }
  
  /**
   * Get a single image property value for this BroadcastEvent object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single location property value for this BroadcastEvent object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
    return event.getLocation();
  }
  
  /**
   * Get a single name property value for this BroadcastEvent object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offers property value for this BroadcastEvent object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers() {
    return event.getOffers();
  }
  
  /**
   * Get a single performer property value for this BroadcastEvent object.
   *
   * @return The first performer property value.
   */
  public Thing getPerformer() {
    return event.getPerformer();
  }
  
  /**
   * Get a single previousStartDate property value for this BroadcastEvent object.
   *
   * @return The first previousStartDate property value.
   */
  public Date getPreviousStartDate() {
    return event.getPreviousStartDate();
  }
  
  /**
   * Get a single publishedOn property value for this BroadcastEvent object.
   *
   * @return The first publishedOn property value.
   */
  public BroadcastService getPublishedOn() {
    return publicationEvent.getPublishedOn();
  }
  
  /**
   * Get a single sameAs property value for this BroadcastEvent object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single startDate property value for this BroadcastEvent object.
   *
   * @return The first startDate property value.
   */
  public Date getStartDate() {
    return event.getStartDate();
  }
  
  /**
   * Get a single subEvent property value for this BroadcastEvent object.
   *
   * @return The first subEvent property value.
   */
  public Event getSubEvent() {
    return event.getSubEvent();
  }
  
  /**
   * Get a single superEvent property value for this BroadcastEvent object.
   *
   * @return The first superEvent property value.
   */
  public Event getSuperEvent() {
    return event.getSuperEvent();
  }
  
  /**
   * Get a single typicalAgeRange property value for this BroadcastEvent object.
   *
   * @return The first typicalAgeRange property value.
   */
  public String getTypicalAgeRange() {
    return event.getTypicalAgeRange();
  }
  
  /**
   * Get a single url property value for this BroadcastEvent object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this BroadcastEvent object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this BroadcastEvent object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the attendee property values for this BroadcastEvent object.
   *
   * @return A list of attendee property values.
   */
  public List<Thing> getAttendees() {
    return event.getAttendees();
  }
  
  /**
   * Get all the description property values for this BroadcastEvent object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the doorTime property values for this BroadcastEvent object.
   *
   * @return A list of doorTime property values.
   */
  public List<Date> getDoorTimes() {
    return event.getDoorTimes();
  }
  
  /**
   * Get all the duration property values for this BroadcastEvent object.
   *
   * @return A list of duration property values.
   */
  public List<Duration> getDurations() {
    return event.getDurations();
  }
  
  /**
   * Get all the endDate property values for this BroadcastEvent object.
   *
   * @return A list of endDate property values.
   */
  public List<Date> getEndDates() {
    return event.getEndDates();
  }
  
  /**
   * Get all the eventStatus property values for this BroadcastEvent object.
   *
   * @return A list of eventStatus property values.
   */
  public List<EventStatusType> getEventStatuses() {
    return event.getEventStatuses();
  }
  
  /**
   * Get all the free property values for this BroadcastEvent object.
   *
   * @return A list of free property values.
   */
  public List<Boolean> getFrees() {
    return publicationEvent.getFrees();
  }
  
  /**
   * Get all the image property values for this BroadcastEvent object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the location property values for this BroadcastEvent object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
    return event.getLocations();
  }
  
  /**
   * Get all the name property values for this BroadcastEvent object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offers property values for this BroadcastEvent object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss() {
    return event.getOfferss();
  }
  
  /**
   * Get all the performer property values for this BroadcastEvent object.
   *
   * @return A list of performer property values.
   */
  public List<Thing> getPerformers() {
    return event.getPerformers();
  }
  
  /**
   * Get all the previousStartDate property values for this BroadcastEvent object.
   *
   * @return A list of previousStartDate property values.
   */
  public List<Date> getPreviousStartDates() {
    return event.getPreviousStartDates();
  }
  
  /**
   * Get all the publishedOn property values for this BroadcastEvent object.
   *
   * @return A list of publishedOn property values.
   */
  public List<BroadcastService> getPublishedsOn() {
    return publicationEvent.getPublishedsOn();
  }
  
  /**
   * Get all the sameAs property values for this BroadcastEvent object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the startDate property values for this BroadcastEvent object.
   *
   * @return A list of startDate property values.
   */
  public List<Date> getStartDates() {
    return event.getStartDates();
  }
  
  /**
   * Get all the subEvent property values for this BroadcastEvent object.
   *
   * @return A list of subEvent property values.
   */
  public List<Event> getSubEvents() {
    return event.getSubEvents();
  }
  
  /**
   * Get all the superEvent property values for this BroadcastEvent object.
   *
   * @return A list of superEvent property values.
   */
  public List<Event> getSuperEvents() {
    return event.getSuperEvents();
  }
  
  /**
   * Get all the typicalAgeRange property values for this BroadcastEvent object.
   *
   * @return A list of typicalAgeRange property values.
   */
  public List<String> getTypicalAgeRanges() {
    return event.getTypicalAgeRanges();
  }
  
  /**
   * Get all the url property values for this BroadcastEvent object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the attendee property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param attendee The value to set.
   */
  public void setAttendee(Thing attendee) {
    event.setAttendee(attendee);
  }
  
  /**
   * Set the description property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the doorTime property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param doorTime The value to set.
   */
  public void setDoorTime(Date doorTime) {
    event.setDoorTime(doorTime);
  }
  
  /**
   * Set the duration property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param duration The value to set.
   */
  public void setDuration(Duration duration) {
    event.setDuration(duration);
  }
  
  /**
   * Set the endDate property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param endDate The value to set.
   */
  public void setEndDate(Date endDate) {
    event.setEndDate(endDate);
  }
  
  /**
   * Set the eventStatus property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param eventStatus The value to set.
   */
  public void setEventStatus(EventStatusType eventStatus) {
    event.setEventStatus(eventStatus);
  }
  
  /**
   * Set the free property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param free The value to set.
   */
  public void setFree(Boolean free) {
    publicationEvent.setFree(free);
  }
  
  /**
   * Set the image property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the location property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
    event.setLocation(location);
  }
  
  /**
   * Set the name property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offers property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers) {
    event.setOffers(offers);
  }
  
  /**
   * Set the performer property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param performer The value to set.
   */
  public void setPerformer(Thing performer) {
    event.setPerformer(performer);
  }
  
  /**
   * Set the previousStartDate property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param previousStartDate The value to set.
   */
  public void setPreviousStartDate(Date previousStartDate) {
    event.setPreviousStartDate(previousStartDate);
  }
  
  /**
   * Set the publishedOn property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param publishedOn The value to set.
   */
  public void setPublishedOn(BroadcastService publishedOn) {
    publicationEvent.setPublishedOn(publishedOn);
  }
  
  /**
   * Set the sameAs property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the startDate property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param startDate The value to set.
   */
  public void setStartDate(Date startDate) {
    event.setStartDate(startDate);
  }
  
  /**
   * Set the subEvent property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param subEvent The value to set.
   */
  public void setSubEvent(Event subEvent) {
    event.setSubEvent(subEvent);
  }
  
  /**
   * Set the superEvent property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param superEvent The value to set.
   */
  public void setSuperEvent(Event superEvent) {
    event.setSuperEvent(superEvent);
  }
  
  /**
   * Set the typicalAgeRange property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param typicalAgeRange The value to set.
   */
  public void setTypicalAgeRange(String typicalAgeRange) {
    event.setTypicalAgeRange(typicalAgeRange);
  }
  
  /**
   * Set the url property value for this BroadcastEvent object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the attendee property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param attendees The list of values to set.
   */
  public void setAttendees(List<Thing> attendees) {
    event.setAttendees(attendees);
  }
  
  /**
   * Set the description property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the doorTime property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param doorTimes The list of values to set.
   */
  public void setDoorTimes(List<Date> doorTimes) {
    event.setDoorTimes(doorTimes);
  }
  
  /**
   * Set the duration property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param durations The list of values to set.
   */
  public void setDurations(List<Duration> durations) {
    event.setDurations(durations);
  }
  
  /**
   * Set the endDate property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param endDates The list of values to set.
   */
  public void setEndDates(List<Date> endDates) {
    event.setEndDates(endDates);
  }
  
  /**
   * Set the eventStatus property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param eventStatuses The list of values to set.
   */
  public void setEventStatuses(List<EventStatusType> eventStatuses) {
    event.setEventStatuses(eventStatuses);
  }
  
  /**
   * Set the free property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param frees The list of values to set.
   */
  public void setFrees(List<Boolean> frees) {
    publicationEvent.setFrees(frees);
  }
  
  /**
   * Set the image property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the location property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
    event.setLocations(locations);
  }
  
  /**
   * Set the name property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offers property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss) {
    event.setOfferss(offerss);
  }
  
  /**
   * Set the performer property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param performers The list of values to set.
   */
  public void setPerformers(List<Thing> performers) {
    event.setPerformers(performers);
  }
  
  /**
   * Set the previousStartDate property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param previousStartDates The list of values to set.
   */
  public void setPreviousStartDates(List<Date> previousStartDates) {
    event.setPreviousStartDates(previousStartDates);
  }
  
  /**
   * Set the publishedOn property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param publishedsOn The list of values to set.
   */
  public void setPublishedsOn(List<BroadcastService> publishedsOn) {
    publicationEvent.setPublishedsOn(publishedsOn);
  }
  
  /**
   * Set the sameAs property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the startDate property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param startDates The list of values to set.
   */
  public void setStartDates(List<Date> startDates) {
    event.setStartDates(startDates);
  }
  
  /**
   * Set the subEvent property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param subEvents The list of values to set.
   */
  public void setSubEvents(List<Event> subEvents) {
    event.setSubEvents(subEvents);
  }
  
  /**
   * Set the superEvent property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param superEvents The list of values to set.
   */
  public void setSuperEvents(List<Event> superEvents) {
    event.setSuperEvents(superEvents);
  }
  
  /**
   * Set the typicalAgeRange property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param typicalAgeRanges The list of values to set.
   */
  public void setTypicalAgeRanges(List<String> typicalAgeRanges) {
    event.setTypicalAgeRanges(typicalAgeRanges);
  }
  
  /**
   * Set the url property values for this BroadcastEvent object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a attendee property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param attendee The value to add.
   */
  public void addAttendee(Thing attendee) {
    event.addAttendee(attendee);
  }
  
  /**
   * Adds a description property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a doorTime property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param doorTime The value to add.
   */
  public void addDoorTime(Date doorTime) {
    event.addDoorTime(doorTime);
  }
  
  /**
   * Adds a duration property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param duration The value to add.
   */
  public void addDuration(Duration duration) {
    event.addDuration(duration);
  }
  
  /**
   * Adds a endDate property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param endDate The value to add.
   */
  public void addEndDate(Date endDate) {
    event.addEndDate(endDate);
  }
  
  /**
   * Adds a eventStatus property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param eventStatus The value to add.
   */
  public void addEventStatus(EventStatusType eventStatus) {
    event.addEventStatus(eventStatus);
  }
  
  /**
   * Adds a free property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param free The value to add.
   */
  public void addFree(Boolean free) {
    publicationEvent.addFree(free);
  }
  
  /**
   * Adds a image property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a location property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
    event.addLocation(location);
  }
  
  /**
   * Adds a name property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offers property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers) {
    event.addOffers(offers);
  }
  
  /**
   * Adds a performer property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param performer The value to add.
   */
  public void addPerformer(Thing performer) {
    event.addPerformer(performer);
  }
  
  /**
   * Adds a previousStartDate property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param previousStartDate The value to add.
   */
  public void addPreviousStartDate(Date previousStartDate) {
    event.addPreviousStartDate(previousStartDate);
  }
  
  /**
   * Adds a publishedOn property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param publishedOn The value to add.
   */
  public void addPublishedOn(BroadcastService publishedOn) {
    publicationEvent.addPublishedOn(publishedOn);
  }
  
  /**
   * Adds a sameAs property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a startDate property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param startDate The value to add.
   */
  public void addStartDate(Date startDate) {
    event.addStartDate(startDate);
  }
  
  /**
   * Adds a subEvent property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param subEvent The value to add.
   */
  public void addSubEvent(Event subEvent) {
    event.addSubEvent(subEvent);
  }
  
  /**
   * Adds a superEvent property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param superEvent The value to add.
   */
  public void addSuperEvent(Event superEvent) {
    event.addSuperEvent(superEvent);
  }
  
  /**
   * Adds a typicalAgeRange property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param typicalAgeRange The value to add.
   */
  public void addTypicalAgeRange(String typicalAgeRange) {
    event.addTypicalAgeRange(typicalAgeRange);
  }
  
  /**
   * Adds a url property value for this BroadcastEvent object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}