package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.BroadcastService;
import org.schema.Organization;
import org.schema.Place;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A delivery service through which content is provided via broadcast over the air or online.
 */
public class BroadcastServiceImpl extends SchemaObjectImpl implements BroadcastService {


  private ThingImpl thing;

  /**
   * The area within which users can expect to reach the broadcast service.
   */
  private List<Place> area = new LinkedList<Place>();
  
  /**
   * The organization owning or operating the broadcast service.
   */
  private List<Organization> broadcaster = new LinkedList<Organization>();
  
  /**
   * A broadcast service to which the broadcast service may belong to such as regional variations of a national channel.
   */
  private List<BroadcastService> parentService = new LinkedList<BroadcastService>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public BroadcastServiceImpl() {
    super("http://schema.org/BroadcastService");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this BroadcastService object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this BroadcastService object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single area property value for this BroadcastService object.
   *
   * @return The first area property value.
   */
  public Place getArea() {
  	return this.area.isEmpty() ? null : this.area.get(0);
  }
  
  /**
   * Get a single broadcaster property value for this BroadcastService object.
   *
   * @return The first broadcaster property value.
   */
  public Organization getBroadcaster() {
  	return this.broadcaster.isEmpty() ? null : this.broadcaster.get(0);
  }
  
  /**
   * Get a single description property value for this BroadcastService object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this BroadcastService object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this BroadcastService object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single parentService property value for this BroadcastService object.
   *
   * @return The first parentService property value.
   */
  public BroadcastService getParentService() {
  	return this.parentService.isEmpty() ? null : this.parentService.get(0);
  }
  
  /**
   * Get a single sameAs property value for this BroadcastService object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this BroadcastService object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this BroadcastService object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this BroadcastService object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the area property values for this BroadcastService object.
   *
   * @return A list of area property values.
   */
  public List<Place> getAreas() {
  	return this.area;
  }
  
  /**
   * Get all the broadcaster property values for this BroadcastService object.
   *
   * @return A list of broadcaster property values.
   */
  public List<Organization> getBroadcasters() {
  	return this.broadcaster;
  }
  
  /**
   * Get all the description property values for this BroadcastService object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this BroadcastService object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this BroadcastService object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the parentService property values for this BroadcastService object.
   *
   * @return A list of parentService property values.
   */
  public List<BroadcastService> getParentServices() {
  	return this.parentService;
  }
  
  /**
   * Get all the sameAs property values for this BroadcastService object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this BroadcastService object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this BroadcastService object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this BroadcastService object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the area property value for this BroadcastService object; overwriting any existing values.
   *
   * @param area The value to set.
   */
  public void setArea(Place area) {
  	this.area.clear();
  	this.area.add(area);
  }
  
  /**
   * Set the broadcaster property value for this BroadcastService object; overwriting any existing values.
   *
   * @param broadcaster The value to set.
   */
  public void setBroadcaster(Organization broadcaster) {
  	this.broadcaster.clear();
  	this.broadcaster.add(broadcaster);
  }
  
  /**
   * Set the description property value for this BroadcastService object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this BroadcastService object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this BroadcastService object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the parentService property value for this BroadcastService object; overwriting any existing values.
   *
   * @param parentService The value to set.
   */
  public void setParentService(BroadcastService parentService) {
  	this.parentService.clear();
  	this.parentService.add(parentService);
  }
  
  /**
   * Set the sameAs property value for this BroadcastService object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this BroadcastService object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this BroadcastService object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this BroadcastService object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the area property values for this BroadcastService object; overwriting any existing values.
   *
   * @param areas The list of values to set.
   */
  public void setAreas(List<Place> areas) {
  	this.area = areas;
  }
  
  /**
   * Set the broadcaster property values for this BroadcastService object; overwriting any existing values.
   *
   * @param broadcasters The list of values to set.
   */
  public void setBroadcasters(List<Organization> broadcasters) {
  	this.broadcaster = broadcasters;
  }
  
  /**
   * Set the description property values for this BroadcastService object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this BroadcastService object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this BroadcastService object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the parentService property values for this BroadcastService object; overwriting any existing values.
   *
   * @param parentServices The list of values to set.
   */
  public void setParentServices(List<BroadcastService> parentServices) {
  	this.parentService = parentServices;
  }
  
  /**
   * Set the sameAs property values for this BroadcastService object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this BroadcastService object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a area property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param area The value to add.
   */
  public void addArea(Place area) {
  	this.area.add(area);
  }
  
  /**
   * Adds a broadcaster property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param broadcaster The value to add.
   */
  public void addBroadcaster(Organization broadcaster) {
  	this.broadcaster.add(broadcaster);
  }
  
  /**
   * Adds a description property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a parentService property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param parentService The value to add.
   */
  public void addParentService(BroadcastService parentService) {
  	this.parentService.add(parentService);
  }
  
  /**
   * Adds a sameAs property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}