package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.BusTrip;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A trip on a commercial bus line.
 */
public class BusTripImpl extends SchemaObjectImpl implements BusTrip {


  private ThingImpl thing;

  /**
   * The stop or station from which the bus arrives.
   */
  private List<Thing> arrivalBusStop = new LinkedList<Thing>();
  
  /**
   * The expected arrival time.
   */
  private List<Date> arrivalTime = new LinkedList<Date>();
  
  /**
   * The name of the bus (e.g. Bolt Express).
   */
  private List<String> busName = new LinkedList<String>();
  
  /**
   * The unique identifier for the trainbus.
   */
  private List<String> busNumber = new LinkedList<String>();
  
  /**
   * The stop or station from which the bus departs.
   */
  private List<Thing> departureBusStop = new LinkedList<Thing>();
  
  /**
   * The expected departure time.
   */
  private List<Date> departureTime = new LinkedList<Date>();
  
  /**
   * The organization or agency that is providing the service.
   */
  private List<Thing> provider = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public BusTripImpl() {
    super("http://schema.org/BusTrip");
  }
  /**
   * Get a single additionalType property value for this BusTrip object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this BusTrip object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single arrivalBusStop property value for this BusTrip object.
   *
   * @return The first arrivalBusStop property value.
   */
  public Thing getArrivalBusStop() {
  	return this.arrivalBusStop.isEmpty() ? null : this.arrivalBusStop.get(0);
  }
  
  /**
   * Get a single arrivalTime property value for this BusTrip object.
   *
   * @return The first arrivalTime property value.
   */
  public Date getArrivalTime() {
  	return this.arrivalTime.isEmpty() ? null : this.arrivalTime.get(0);
  }
  
  /**
   * Get a single busName property value for this BusTrip object.
   *
   * @return The first busName property value.
   */
  public String getBusName() {
  	return this.busName.isEmpty() ? null : this.busName.get(0);
  }
  
  /**
   * Get a single busNumber property value for this BusTrip object.
   *
   * @return The first busNumber property value.
   */
  public String getBusNumber() {
  	return this.busNumber.isEmpty() ? null : this.busNumber.get(0);
  }
  
  /**
   * Get a single departureBusStop property value for this BusTrip object.
   *
   * @return The first departureBusStop property value.
   */
  public Thing getDepartureBusStop() {
  	return this.departureBusStop.isEmpty() ? null : this.departureBusStop.get(0);
  }
  
  /**
   * Get a single departureTime property value for this BusTrip object.
   *
   * @return The first departureTime property value.
   */
  public Date getDepartureTime() {
  	return this.departureTime.isEmpty() ? null : this.departureTime.get(0);
  }
  
  /**
   * Get a single description property value for this BusTrip object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this BusTrip object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this BusTrip object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single provider property value for this BusTrip object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
  	return this.provider.isEmpty() ? null : this.provider.get(0);
  }
  
  /**
   * Get a single sameAs property value for this BusTrip object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this BusTrip object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this BusTrip object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this BusTrip object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the arrivalBusStop property values for this BusTrip object.
   *
   * @return A list of arrivalBusStop property values.
   */
  public List<Thing> getArrivalBusStops() {
  	return this.arrivalBusStop;
  }
  
  /**
   * Get all the arrivalTime property values for this BusTrip object.
   *
   * @return A list of arrivalTime property values.
   */
  public List<Date> getArrivalTimes() {
  	return this.arrivalTime;
  }
  
  /**
   * Get all the busName property values for this BusTrip object.
   *
   * @return A list of busName property values.
   */
  public List<String> getBusNames() {
  	return this.busName;
  }
  
  /**
   * Get all the busNumber property values for this BusTrip object.
   *
   * @return A list of busNumber property values.
   */
  public List<String> getBusNumbers() {
  	return this.busNumber;
  }
  
  /**
   * Get all the departureBusStop property values for this BusTrip object.
   *
   * @return A list of departureBusStop property values.
   */
  public List<Thing> getDepartureBusStops() {
  	return this.departureBusStop;
  }
  
  /**
   * Get all the departureTime property values for this BusTrip object.
   *
   * @return A list of departureTime property values.
   */
  public List<Date> getDepartureTimes() {
  	return this.departureTime;
  }
  
  /**
   * Get all the description property values for this BusTrip object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this BusTrip object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this BusTrip object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the provider property values for this BusTrip object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
  	return this.provider;
  }
  
  /**
   * Get all the sameAs property values for this BusTrip object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this BusTrip object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this BusTrip object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this BusTrip object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the arrivalBusStop property value for this BusTrip object; overwriting any existing values.
   *
   * @param arrivalBusStop The value to set.
   */
  public void setArrivalBusStop(Thing arrivalBusStop) {
  	this.arrivalBusStop.clear();
  	this.arrivalBusStop.add(arrivalBusStop);
  }
  
  /**
   * Set the arrivalTime property value for this BusTrip object; overwriting any existing values.
   *
   * @param arrivalTime The value to set.
   */
  public void setArrivalTime(Date arrivalTime) {
  	this.arrivalTime.clear();
  	this.arrivalTime.add(arrivalTime);
  }
  
  /**
   * Set the busName property value for this BusTrip object; overwriting any existing values.
   *
   * @param busName The value to set.
   */
  public void setBusName(String busName) {
  	this.busName.clear();
  	this.busName.add(busName);
  }
  
  /**
   * Set the busNumber property value for this BusTrip object; overwriting any existing values.
   *
   * @param busNumber The value to set.
   */
  public void setBusNumber(String busNumber) {
  	this.busNumber.clear();
  	this.busNumber.add(busNumber);
  }
  
  /**
   * Set the departureBusStop property value for this BusTrip object; overwriting any existing values.
   *
   * @param departureBusStop The value to set.
   */
  public void setDepartureBusStop(Thing departureBusStop) {
  	this.departureBusStop.clear();
  	this.departureBusStop.add(departureBusStop);
  }
  
  /**
   * Set the departureTime property value for this BusTrip object; overwriting any existing values.
   *
   * @param departureTime The value to set.
   */
  public void setDepartureTime(Date departureTime) {
  	this.departureTime.clear();
  	this.departureTime.add(departureTime);
  }
  
  /**
   * Set the description property value for this BusTrip object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this BusTrip object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this BusTrip object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the provider property value for this BusTrip object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
  	this.provider.clear();
  	this.provider.add(provider);
  }
  
  /**
   * Set the sameAs property value for this BusTrip object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this BusTrip object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this BusTrip object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this BusTrip object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the arrivalBusStop property values for this BusTrip object; overwriting any existing values.
   *
   * @param arrivalBusStops The list of values to set.
   */
  public void setArrivalBusStops(List<Thing> arrivalBusStops) {
  	this.arrivalBusStop = arrivalBusStops;
  }
  
  /**
   * Set the arrivalTime property values for this BusTrip object; overwriting any existing values.
   *
   * @param arrivalTimes The list of values to set.
   */
  public void setArrivalTimes(List<Date> arrivalTimes) {
  	this.arrivalTime = arrivalTimes;
  }
  
  /**
   * Set the busName property values for this BusTrip object; overwriting any existing values.
   *
   * @param busNames The list of values to set.
   */
  public void setBusNames(List<String> busNames) {
  	this.busName = busNames;
  }
  
  /**
   * Set the busNumber property values for this BusTrip object; overwriting any existing values.
   *
   * @param busNumbers The list of values to set.
   */
  public void setBusNumbers(List<String> busNumbers) {
  	this.busNumber = busNumbers;
  }
  
  /**
   * Set the departureBusStop property values for this BusTrip object; overwriting any existing values.
   *
   * @param departureBusStops The list of values to set.
   */
  public void setDepartureBusStops(List<Thing> departureBusStops) {
  	this.departureBusStop = departureBusStops;
  }
  
  /**
   * Set the departureTime property values for this BusTrip object; overwriting any existing values.
   *
   * @param departureTimes The list of values to set.
   */
  public void setDepartureTimes(List<Date> departureTimes) {
  	this.departureTime = departureTimes;
  }
  
  /**
   * Set the description property values for this BusTrip object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this BusTrip object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this BusTrip object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the provider property values for this BusTrip object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
  	this.provider = providers;
  }
  
  /**
   * Set the sameAs property values for this BusTrip object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this BusTrip object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a arrivalBusStop property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param arrivalBusStop The value to add.
   */
  public void addArrivalBusStop(Thing arrivalBusStop) {
  	this.arrivalBusStop.add(arrivalBusStop);
  }
  
  /**
   * Adds a arrivalTime property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param arrivalTime The value to add.
   */
  public void addArrivalTime(Date arrivalTime) {
  	this.arrivalTime.add(arrivalTime);
  }
  
  /**
   * Adds a busName property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param busName The value to add.
   */
  public void addBusName(String busName) {
  	this.busName.add(busName);
  }
  
  /**
   * Adds a busNumber property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param busNumber The value to add.
   */
  public void addBusNumber(String busNumber) {
  	this.busNumber.add(busNumber);
  }
  
  /**
   * Adds a departureBusStop property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param departureBusStop The value to add.
   */
  public void addDepartureBusStop(Thing departureBusStop) {
  	this.departureBusStop.add(departureBusStop);
  }
  
  /**
   * Adds a departureTime property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param departureTime The value to add.
   */
  public void addDepartureTime(Date departureTime) {
  	this.departureTime.add(departureTime);
  }
  
  /**
   * Adds a description property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a provider property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
  	this.provider.add(provider);
  }
  
  /**
   * Adds a sameAs property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this BusTrip object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}