package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.BusinessAudience;
import org.schema.QuantitativeValue;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A set of characteristics belonging to businesses, e.g. who compose an item's target audience.
 */
public class BusinessAudienceImpl extends SchemaObjectImpl implements BusinessAudience {


  private AudienceImpl audience;
  private ThingImpl thing;

  /**
   * The size of business by number of employees.
   */
  private List<QuantitativeValue> numberofEmployees = new LinkedList<QuantitativeValue>();
  
  /**
   * The size of the business in annual revenue.
   */
  private List<QuantitativeValue> yearlyRevenue = new LinkedList<QuantitativeValue>();
  
  /**
   * The age of the business.
   */
  private List<QuantitativeValue> yearsInOperation = new LinkedList<QuantitativeValue>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public BusinessAudienceImpl() {
    super("http://schema.org/BusinessAudience");
    audience = new AudienceImpl();
  }
  /**
   * Get a single additionalType property value for this BusinessAudience object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this BusinessAudience object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single audienceType property value for this BusinessAudience object.
   *
   * @return The first audienceType property value.
   */
  public String getAudienceType() {
    return audience.getAudienceType();
  }
  
  /**
   * Get a single description property value for this BusinessAudience object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single geographicArea property value for this BusinessAudience object.
   *
   * @return The first geographicArea property value.
   */
  public AdministrativeArea getGeographicArea() {
    return audience.getGeographicArea();
  }
  
  /**
   * Get a single image property value for this BusinessAudience object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this BusinessAudience object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single numberofEmployees property value for this BusinessAudience object.
   *
   * @return The first numberofEmployees property value.
   */
  public QuantitativeValue getNumberofEmployees() {
  	return this.numberofEmployees.isEmpty() ? null : this.numberofEmployees.get(0);
  }
  
  /**
   * Get a single sameAs property value for this BusinessAudience object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this BusinessAudience object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single yearlyRevenue property value for this BusinessAudience object.
   *
   * @return The first yearlyRevenue property value.
   */
  public QuantitativeValue getYearlyRevenue() {
  	return this.yearlyRevenue.isEmpty() ? null : this.yearlyRevenue.get(0);
  }
  
  /**
   * Get a single yearsInOperation property value for this BusinessAudience object.
   *
   * @return The first yearsInOperation property value.
   */
  public QuantitativeValue getYearsInOperation() {
  	return this.yearsInOperation.isEmpty() ? null : this.yearsInOperation.get(0);
  }
  
  /**
   * Get all the additionalType property values for this BusinessAudience object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this BusinessAudience object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the audienceType property values for this BusinessAudience object.
   *
   * @return A list of audienceType property values.
   */
  public List<String> getAudienceTypes() {
    return audience.getAudienceTypes();
  }
  
  /**
   * Get all the description property values for this BusinessAudience object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the geographicArea property values for this BusinessAudience object.
   *
   * @return A list of geographicArea property values.
   */
  public List<AdministrativeArea> getGeographicAreas() {
    return audience.getGeographicAreas();
  }
  
  /**
   * Get all the image property values for this BusinessAudience object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this BusinessAudience object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the numberofEmployees property values for this BusinessAudience object.
   *
   * @return A list of numberofEmployees property values.
   */
  public List<QuantitativeValue> getNumberofEmployeess() {
  	return this.numberofEmployees;
  }
  
  /**
   * Get all the sameAs property values for this BusinessAudience object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this BusinessAudience object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the yearlyRevenue property values for this BusinessAudience object.
   *
   * @return A list of yearlyRevenue property values.
   */
  public List<QuantitativeValue> getYearlyRevenues() {
  	return this.yearlyRevenue;
  }
  
  /**
   * Get all the yearsInOperation property values for this BusinessAudience object.
   *
   * @return A list of yearsInOperation property values.
   */
  public List<QuantitativeValue> getYearsInOperations() {
  	return this.yearsInOperation;
  }
  
  /**
   * Set the additionalType property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the audienceType property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param audienceType The value to set.
   */
  public void setAudienceType(String audienceType) {
    audience.setAudienceType(audienceType);
  }
  
  /**
   * Set the description property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the geographicArea property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param geographicArea The value to set.
   */
  public void setGeographicArea(AdministrativeArea geographicArea) {
    audience.setGeographicArea(geographicArea);
  }
  
  /**
   * Set the image property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the numberofEmployees property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param numberofEmployees The value to set.
   */
  public void setNumberofEmployees(QuantitativeValue numberofEmployees) {
  	this.numberofEmployees.clear();
  	this.numberofEmployees.add(numberofEmployees);
  }
  
  /**
   * Set the sameAs property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the yearlyRevenue property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param yearlyRevenue The value to set.
   */
  public void setYearlyRevenue(QuantitativeValue yearlyRevenue) {
  	this.yearlyRevenue.clear();
  	this.yearlyRevenue.add(yearlyRevenue);
  }
  
  /**
   * Set the yearsInOperation property value for this BusinessAudience object; overwriting any existing values.
   *
   * @param yearsInOperation The value to set.
   */
  public void setYearsInOperation(QuantitativeValue yearsInOperation) {
  	this.yearsInOperation.clear();
  	this.yearsInOperation.add(yearsInOperation);
  }
  
  /**
   * Set the additionalType property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the audienceType property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param audienceTypes The list of values to set.
   */
  public void setAudienceTypes(List<String> audienceTypes) {
    audience.setAudienceTypes(audienceTypes);
  }
  
  /**
   * Set the description property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the geographicArea property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param geographicAreas The list of values to set.
   */
  public void setGeographicAreas(List<AdministrativeArea> geographicAreas) {
    audience.setGeographicAreas(geographicAreas);
  }
  
  /**
   * Set the image property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the numberofEmployees property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param numberofEmployeess The list of values to set.
   */
  public void setNumberofEmployeess(List<QuantitativeValue> numberofEmployeess) {
  	this.numberofEmployees = numberofEmployeess;
  }
  
  /**
   * Set the sameAs property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the yearlyRevenue property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param yearlyRevenues The list of values to set.
   */
  public void setYearlyRevenues(List<QuantitativeValue> yearlyRevenues) {
  	this.yearlyRevenue = yearlyRevenues;
  }
  
  /**
   * Set the yearsInOperation property values for this BusinessAudience object; overwriting any existing values.
   *
   * @param yearsInOperations The list of values to set.
   */
  public void setYearsInOperations(List<QuantitativeValue> yearsInOperations) {
  	this.yearsInOperation = yearsInOperations;
  }
  
  /**
   * Adds a additionalType property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a audienceType property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param audienceType The value to add.
   */
  public void addAudienceType(String audienceType) {
    audience.addAudienceType(audienceType);
  }
  
  /**
   * Adds a description property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a geographicArea property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param geographicArea The value to add.
   */
  public void addGeographicArea(AdministrativeArea geographicArea) {
    audience.addGeographicArea(geographicArea);
  }
  
  /**
   * Adds a image property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a numberofEmployees property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param numberofEmployees The value to add.
   */
  public void addNumberofEmployees(QuantitativeValue numberofEmployees) {
  	this.numberofEmployees.add(numberofEmployees);
  }
  
  /**
   * Adds a sameAs property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a yearlyRevenue property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param yearlyRevenue The value to add.
   */
  public void addYearlyRevenue(QuantitativeValue yearlyRevenue) {
  	this.yearlyRevenue.add(yearlyRevenue);
  }
  
  /**
   * Adds a yearsInOperation property value for this BusinessAudience object; appending it to the list of existing values.
   *
   * @param yearsInOperation The value to add.
   */
  public void addYearsInOperation(QuantitativeValue yearsInOperation) {
  	this.yearsInOperation.add(yearsInOperation);
  }
  
}