package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.City;
import org.schema.Event;
import org.schema.OpeningHoursSpecification;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Review;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A city or town.
 */
public class CityImpl extends SchemaObjectImpl implements City {


  private PlaceImpl place;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public CityImpl() {
    super("http://schema.org/City");
  }
  /**
   * Get a single additionalType property value for this City object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single address property value for this City object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress() {
    return place.getAddress();
  }
  
  /**
   * Get a single aggregateRating property value for this City object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
    return place.getAggregateRating();
  }
  
  /**
   * Get a single alternateName property value for this City object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single containedIn property value for this City object.
   *
   * @return The first containedIn property value.
   */
  public Place getContainedIn() {
    return place.getContainedIn();
  }
  
  /**
   * Get a single description property value for this City object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single event property value for this City object.
   *
   * @return The first event property value.
   */
  public Event getEvent() {
    return place.getEvent();
  }
  
  /**
   * Get a single faxNumber property value for this City object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
    return place.getFaxNumber();
  }
  
  /**
   * Get a single geo property value for this City object.
   *
   * @return The first geo property value.
   */
  public Thing getGeo() {
    return place.getGeo();
  }
  
  /**
   * Get a single globalLocationNumber property value for this City object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber() {
    return place.getGlobalLocationNumber();
  }
  
  /**
   * Get a single image property value for this City object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single interactionCount property value for this City object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
    return place.getInteractionCount();
  }
  
  /**
   * Get a single isicV4 property value for this City object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4() {
    return place.getIsicV4();
  }
  
  /**
   * Get a single logo property value for this City object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo() {
    return place.getLogo();
  }
  
  /**
   * Get a single map property value for this City object.
   *
   * @return The first map property value.
   */
  public URL getMap() {
    return place.getMap();
  }
  
  /**
   * Get a single name property value for this City object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single openingHoursSpecification property value for this City object.
   *
   * @return The first openingHoursSpecification property value.
   */
  public OpeningHoursSpecification getOpeningHoursSpecification() {
    return place.getOpeningHoursSpecification();
  }
  
  /**
   * Get a single photo property value for this City object.
   *
   * @return The first photo property value.
   */
  public Thing getPhoto() {
    return place.getPhoto();
  }
  
  /**
   * Get a single review property value for this City object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
    return place.getReview();
  }
  
  /**
   * Get a single sameAs property value for this City object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single telephone property value for this City object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
    return place.getTelephone();
  }
  
  /**
   * Get a single url property value for this City object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this City object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the address property values for this City object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses() {
    return place.getAddresses();
  }
  
  /**
   * Get all the aggregateRating property values for this City object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
    return place.getAggregateRatings();
  }
  
  /**
   * Get all the alternateName property values for this City object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the containedIn property values for this City object.
   *
   * @return A list of containedIn property values.
   */
  public List<Place> getContainedsIn() {
    return place.getContainedsIn();
  }
  
  /**
   * Get all the description property values for this City object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the event property values for this City object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents() {
    return place.getEvents();
  }
  
  /**
   * Get all the faxNumber property values for this City object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
    return place.getFaxNumbers();
  }
  
  /**
   * Get all the geo property values for this City object.
   *
   * @return A list of geo property values.
   */
  public List<Thing> getGeos() {
    return place.getGeos();
  }
  
  /**
   * Get all the globalLocationNumber property values for this City object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers() {
    return place.getGlobalLocationNumbers();
  }
  
  /**
   * Get all the image property values for this City object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the interactionCount property values for this City object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
    return place.getInteractionCounts();
  }
  
  /**
   * Get all the isicV4 property values for this City object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s() {
    return place.getIsicV4s();
  }
  
  /**
   * Get all the logo property values for this City object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes() {
    return place.getLogoes();
  }
  
  /**
   * Get all the map property values for this City object.
   *
   * @return A list of map property values.
   */
  public List<URL> getMaps() {
    return place.getMaps();
  }
  
  /**
   * Get all the name property values for this City object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the openingHoursSpecification property values for this City object.
   *
   * @return A list of openingHoursSpecification property values.
   */
  public List<OpeningHoursSpecification> getOpeningHoursSpecifications() {
    return place.getOpeningHoursSpecifications();
  }
  
  /**
   * Get all the photo property values for this City object.
   *
   * @return A list of photo property values.
   */
  public List<Thing> getPhotos() {
    return place.getPhotos();
  }
  
  /**
   * Get all the review property values for this City object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
    return place.getReviews();
  }
  
  /**
   * Get all the sameAs property values for this City object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the telephone property values for this City object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
    return place.getTelephones();
  }
  
  /**
   * Get all the url property values for this City object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this City object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the address property value for this City object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address) {
    place.setAddress(address);
  }
  
  /**
   * Set the aggregateRating property value for this City object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
    place.setAggregateRating(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this City object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the containedIn property value for this City object; overwriting any existing values.
   *
   * @param containedIn The value to set.
   */
  public void setContainedIn(Place containedIn) {
    place.setContainedIn(containedIn);
  }
  
  /**
   * Set the description property value for this City object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the event property value for this City object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event) {
    place.setEvent(event);
  }
  
  /**
   * Set the faxNumber property value for this City object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
    place.setFaxNumber(faxNumber);
  }
  
  /**
   * Set the geo property value for this City object; overwriting any existing values.
   *
   * @param geo The value to set.
   */
  public void setGeo(Thing geo) {
    place.setGeo(geo);
  }
  
  /**
   * Set the globalLocationNumber property value for this City object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber) {
    place.setGlobalLocationNumber(globalLocationNumber);
  }
  
  /**
   * Set the image property value for this City object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the interactionCount property value for this City object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
    place.setInteractionCount(interactionCount);
  }
  
  /**
   * Set the isicV4 property value for this City object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4) {
    place.setIsicV4(isicV4);
  }
  
  /**
   * Set the logo property value for this City object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo) {
    place.setLogo(logo);
  }
  
  /**
   * Set the map property value for this City object; overwriting any existing values.
   *
   * @param map The value to set.
   */
  public void setMap(URL map) {
    place.setMap(map);
  }
  
  /**
   * Set the name property value for this City object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the openingHoursSpecification property value for this City object; overwriting any existing values.
   *
   * @param openingHoursSpecification The value to set.
   */
  public void setOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification) {
    place.setOpeningHoursSpecification(openingHoursSpecification);
  }
  
  /**
   * Set the photo property value for this City object; overwriting any existing values.
   *
   * @param photo The value to set.
   */
  public void setPhoto(Thing photo) {
    place.setPhoto(photo);
  }
  
  /**
   * Set the review property value for this City object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
    place.setReview(review);
  }
  
  /**
   * Set the sameAs property value for this City object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the telephone property value for this City object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
    place.setTelephone(telephone);
  }
  
  /**
   * Set the url property value for this City object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this City object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the address property values for this City object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses) {
    place.setAddresses(addresses);
  }
  
  /**
   * Set the aggregateRating property values for this City object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
    place.setAggregateRatings(aggregateRatings);
  }
  
  /**
   * Set the alternateName property values for this City object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the containedIn property values for this City object; overwriting any existing values.
   *
   * @param containedsIn The list of values to set.
   */
  public void setContainedsIn(List<Place> containedsIn) {
    place.setContainedsIn(containedsIn);
  }
  
  /**
   * Set the description property values for this City object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the event property values for this City object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events) {
    place.setEvents(events);
  }
  
  /**
   * Set the faxNumber property values for this City object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
    place.setFaxNumbers(faxNumbers);
  }
  
  /**
   * Set the geo property values for this City object; overwriting any existing values.
   *
   * @param geos The list of values to set.
   */
  public void setGeos(List<Thing> geos) {
    place.setGeos(geos);
  }
  
  /**
   * Set the globalLocationNumber property values for this City object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers) {
    place.setGlobalLocationNumbers(globalLocationNumbers);
  }
  
  /**
   * Set the image property values for this City object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the interactionCount property values for this City object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
    place.setInteractionCounts(interactionCounts);
  }
  
  /**
   * Set the isicV4 property values for this City object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s) {
    place.setIsicV4s(isicV4s);
  }
  
  /**
   * Set the logo property values for this City object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes) {
    place.setLogoes(logoes);
  }
  
  /**
   * Set the map property values for this City object; overwriting any existing values.
   *
   * @param maps The list of values to set.
   */
  public void setMaps(List<URL> maps) {
    place.setMaps(maps);
  }
  
  /**
   * Set the name property values for this City object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the openingHoursSpecification property values for this City object; overwriting any existing values.
   *
   * @param openingHoursSpecifications The list of values to set.
   */
  public void setOpeningHoursSpecifications(List<OpeningHoursSpecification> openingHoursSpecifications) {
    place.setOpeningHoursSpecifications(openingHoursSpecifications);
  }
  
  /**
   * Set the photo property values for this City object; overwriting any existing values.
   *
   * @param photos The list of values to set.
   */
  public void setPhotos(List<Thing> photos) {
    place.setPhotos(photos);
  }
  
  /**
   * Set the review property values for this City object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
    place.setReviews(reviews);
  }
  
  /**
   * Set the sameAs property values for this City object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the telephone property values for this City object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
    place.setTelephones(telephones);
  }
  
  /**
   * Set the url property values for this City object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this City object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a address property value for this City object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address) {
    place.addAddress(address);
  }
  
  /**
   * Adds a aggregateRating property value for this City object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
    place.addAggregateRating(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this City object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a containedIn property value for this City object; appending it to the list of existing values.
   *
   * @param containedIn The value to add.
   */
  public void addContainedIn(Place containedIn) {
    place.addContainedIn(containedIn);
  }
  
  /**
   * Adds a description property value for this City object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a event property value for this City object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event) {
    place.addEvent(event);
  }
  
  /**
   * Adds a faxNumber property value for this City object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
    place.addFaxNumber(faxNumber);
  }
  
  /**
   * Adds a geo property value for this City object; appending it to the list of existing values.
   *
   * @param geo The value to add.
   */
  public void addGeo(Thing geo) {
    place.addGeo(geo);
  }
  
  /**
   * Adds a globalLocationNumber property value for this City object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber) {
    place.addGlobalLocationNumber(globalLocationNumber);
  }
  
  /**
   * Adds a image property value for this City object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a interactionCount property value for this City object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
    place.addInteractionCount(interactionCount);
  }
  
  /**
   * Adds a isicV4 property value for this City object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4) {
    place.addIsicV4(isicV4);
  }
  
  /**
   * Adds a logo property value for this City object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo) {
    place.addLogo(logo);
  }
  
  /**
   * Adds a map property value for this City object; appending it to the list of existing values.
   *
   * @param map The value to add.
   */
  public void addMap(URL map) {
    place.addMap(map);
  }
  
  /**
   * Adds a name property value for this City object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a openingHoursSpecification property value for this City object; appending it to the list of existing values.
   *
   * @param openingHoursSpecification The value to add.
   */
  public void addOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification) {
    place.addOpeningHoursSpecification(openingHoursSpecification);
  }
  
  /**
   * Adds a photo property value for this City object; appending it to the list of existing values.
   *
   * @param photo The value to add.
   */
  public void addPhoto(Thing photo) {
    place.addPhoto(photo);
  }
  
  /**
   * Adds a review property value for this City object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
    place.addReview(review);
  }
  
  /**
   * Adds a sameAs property value for this City object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a telephone property value for this City object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
    place.addTelephone(telephone);
  }
  
  /**
   * Adds a url property value for this City object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}