package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.ConfirmAction;
import org.schema.Event;
import org.schema.Language;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The act of notifying someone that a future event/action is going to happen as expected.<p>Related actions:</p><ul><li><a href="http://schema.org/CancelAction">CancelAction</a>: The antagonym of ConfirmAction.</li></ul>
 */
public class ConfirmActionImpl extends SchemaObjectImpl implements ConfirmAction {


  private ActionImpl action;
  private CommunicateActionImpl communicateAction;
  private InformActionImpl informAction;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ConfirmActionImpl() {
    super("http://schema.org/ConfirmAction");
    informAction = new InformActionImpl();
  }
  /**
   * Get a single about property value for this ConfirmAction object.
   *
   * @return The first about property value.
   */
  public Thing getAbout() {
    return communicateAction.getAbout();
  }
  
  /**
   * Get a single additionalType property value for this ConfirmAction object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single agent property value for this ConfirmAction object.
   *
   * @return The first agent property value.
   */
  public Thing getAgent() {
    return action.getAgent();
  }
  
  /**
   * Get a single alternateName property value for this ConfirmAction object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this ConfirmAction object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single endTime property value for this ConfirmAction object.
   *
   * @return The first endTime property value.
   */
  public Date getEndTime() {
    return action.getEndTime();
  }
  
  /**
   * Get a single event property value for this ConfirmAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent() {
    return informAction.getEvent();
  }
  
  /**
   * Get a single image property value for this ConfirmAction object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single instrument property value for this ConfirmAction object.
   *
   * @return The first instrument property value.
   */
  public Thing getInstrument() {
    return action.getInstrument();
  }
  
  /**
   * Get a single language property value for this ConfirmAction object.
   *
   * @return The first language property value.
   */
  public Language getLanguage() {
    return communicateAction.getLanguage();
  }
  
  /**
   * Get a single location property value for this ConfirmAction object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
    return action.getLocation();
  }
  
  /**
   * Get a single name property value for this ConfirmAction object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single object property value for this ConfirmAction object.
   *
   * @return The first object property value.
   */
  public Thing getObject() {
    return action.getObject();
  }
  
  /**
   * Get a single participant property value for this ConfirmAction object.
   *
   * @return The first participant property value.
   */
  public Thing getParticipant() {
    return action.getParticipant();
  }
  
  /**
   * Get a single recipient property value for this ConfirmAction object.
   *
   * @return The first recipient property value.
   */
  public Thing getRecipient() {
    return communicateAction.getRecipient();
  }
  
  /**
   * Get a single result property value for this ConfirmAction object.
   *
   * @return The first result property value.
   */
  public Thing getResult() {
    return action.getResult();
  }
  
  /**
   * Get a single sameAs property value for this ConfirmAction object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single startTime property value for this ConfirmAction object.
   *
   * @return The first startTime property value.
   */
  public Date getStartTime() {
    return action.getStartTime();
  }
  
  /**
   * Get a single url property value for this ConfirmAction object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the about property values for this ConfirmAction object.
   *
   * @return A list of about property values.
   */
  public List<Thing> getAbouts() {
    return communicateAction.getAbouts();
  }
  
  /**
   * Get all the additionalType property values for this ConfirmAction object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the agent property values for this ConfirmAction object.
   *
   * @return A list of agent property values.
   */
  public List<Thing> getAgents() {
    return action.getAgents();
  }
  
  /**
   * Get all the alternateName property values for this ConfirmAction object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this ConfirmAction object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the endTime property values for this ConfirmAction object.
   *
   * @return A list of endTime property values.
   */
  public List<Date> getEndTimes() {
    return action.getEndTimes();
  }
  
  /**
   * Get all the event property values for this ConfirmAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents() {
    return informAction.getEvents();
  }
  
  /**
   * Get all the image property values for this ConfirmAction object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the instrument property values for this ConfirmAction object.
   *
   * @return A list of instrument property values.
   */
  public List<Thing> getInstruments() {
    return action.getInstruments();
  }
  
  /**
   * Get all the language property values for this ConfirmAction object.
   *
   * @return A list of language property values.
   */
  public List<Language> getLanguages() {
    return communicateAction.getLanguages();
  }
  
  /**
   * Get all the location property values for this ConfirmAction object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
    return action.getLocations();
  }
  
  /**
   * Get all the name property values for this ConfirmAction object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the object property values for this ConfirmAction object.
   *
   * @return A list of object property values.
   */
  public List<Thing> getObjects() {
    return action.getObjects();
  }
  
  /**
   * Get all the participant property values for this ConfirmAction object.
   *
   * @return A list of participant property values.
   */
  public List<Thing> getParticipants() {
    return action.getParticipants();
  }
  
  /**
   * Get all the recipient property values for this ConfirmAction object.
   *
   * @return A list of recipient property values.
   */
  public List<Thing> getRecipients() {
    return communicateAction.getRecipients();
  }
  
  /**
   * Get all the result property values for this ConfirmAction object.
   *
   * @return A list of result property values.
   */
  public List<Thing> getResults() {
    return action.getResults();
  }
  
  /**
   * Get all the sameAs property values for this ConfirmAction object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the startTime property values for this ConfirmAction object.
   *
   * @return A list of startTime property values.
   */
  public List<Date> getStartTimes() {
    return action.getStartTimes();
  }
  
  /**
   * Get all the url property values for this ConfirmAction object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the about property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param about The value to set.
   */
  public void setAbout(Thing about) {
    communicateAction.setAbout(about);
  }
  
  /**
   * Set the additionalType property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the agent property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param agent The value to set.
   */
  public void setAgent(Thing agent) {
    action.setAgent(agent);
  }
  
  /**
   * Set the alternateName property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the endTime property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param endTime The value to set.
   */
  public void setEndTime(Date endTime) {
    action.setEndTime(endTime);
  }
  
  /**
   * Set the event property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event) {
    informAction.setEvent(event);
  }
  
  /**
   * Set the image property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the instrument property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param instrument The value to set.
   */
  public void setInstrument(Thing instrument) {
    action.setInstrument(instrument);
  }
  
  /**
   * Set the language property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param language The value to set.
   */
  public void setLanguage(Language language) {
    communicateAction.setLanguage(language);
  }
  
  /**
   * Set the location property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
    action.setLocation(location);
  }
  
  /**
   * Set the name property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the object property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param object The value to set.
   */
  public void setObject(Thing object) {
    action.setObject(object);
  }
  
  /**
   * Set the participant property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param participant The value to set.
   */
  public void setParticipant(Thing participant) {
    action.setParticipant(participant);
  }
  
  /**
   * Set the recipient property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param recipient The value to set.
   */
  public void setRecipient(Thing recipient) {
    communicateAction.setRecipient(recipient);
  }
  
  /**
   * Set the result property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param result The value to set.
   */
  public void setResult(Thing result) {
    action.setResult(result);
  }
  
  /**
   * Set the sameAs property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the startTime property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param startTime The value to set.
   */
  public void setStartTime(Date startTime) {
    action.setStartTime(startTime);
  }
  
  /**
   * Set the url property value for this ConfirmAction object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the about property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param abouts The list of values to set.
   */
  public void setAbouts(List<Thing> abouts) {
    communicateAction.setAbouts(abouts);
  }
  
  /**
   * Set the additionalType property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the agent property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param agents The list of values to set.
   */
  public void setAgents(List<Thing> agents) {
    action.setAgents(agents);
  }
  
  /**
   * Set the alternateName property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the endTime property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param endTimes The list of values to set.
   */
  public void setEndTimes(List<Date> endTimes) {
    action.setEndTimes(endTimes);
  }
  
  /**
   * Set the event property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events) {
    informAction.setEvents(events);
  }
  
  /**
   * Set the image property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the instrument property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param instruments The list of values to set.
   */
  public void setInstruments(List<Thing> instruments) {
    action.setInstruments(instruments);
  }
  
  /**
   * Set the language property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param languages The list of values to set.
   */
  public void setLanguages(List<Language> languages) {
    communicateAction.setLanguages(languages);
  }
  
  /**
   * Set the location property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
    action.setLocations(locations);
  }
  
  /**
   * Set the name property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the object property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param objects The list of values to set.
   */
  public void setObjects(List<Thing> objects) {
    action.setObjects(objects);
  }
  
  /**
   * Set the participant property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param participants The list of values to set.
   */
  public void setParticipants(List<Thing> participants) {
    action.setParticipants(participants);
  }
  
  /**
   * Set the recipient property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param recipients The list of values to set.
   */
  public void setRecipients(List<Thing> recipients) {
    communicateAction.setRecipients(recipients);
  }
  
  /**
   * Set the result property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param results The list of values to set.
   */
  public void setResults(List<Thing> results) {
    action.setResults(results);
  }
  
  /**
   * Set the sameAs property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the startTime property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param startTimes The list of values to set.
   */
  public void setStartTimes(List<Date> startTimes) {
    action.setStartTimes(startTimes);
  }
  
  /**
   * Set the url property values for this ConfirmAction object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a about property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param about The value to add.
   */
  public void addAbout(Thing about) {
    communicateAction.addAbout(about);
  }
  
  /**
   * Adds a additionalType property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a agent property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param agent The value to add.
   */
  public void addAgent(Thing agent) {
    action.addAgent(agent);
  }
  
  /**
   * Adds a alternateName property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a endTime property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param endTime The value to add.
   */
  public void addEndTime(Date endTime) {
    action.addEndTime(endTime);
  }
  
  /**
   * Adds a event property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event) {
    informAction.addEvent(event);
  }
  
  /**
   * Adds a image property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a instrument property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param instrument The value to add.
   */
  public void addInstrument(Thing instrument) {
    action.addInstrument(instrument);
  }
  
  /**
   * Adds a language property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param language The value to add.
   */
  public void addLanguage(Language language) {
    communicateAction.addLanguage(language);
  }
  
  /**
   * Adds a location property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
    action.addLocation(location);
  }
  
  /**
   * Adds a name property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a object property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param object The value to add.
   */
  public void addObject(Thing object) {
    action.addObject(object);
  }
  
  /**
   * Adds a participant property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param participant The value to add.
   */
  public void addParticipant(Thing participant) {
    action.addParticipant(participant);
  }
  
  /**
   * Adds a recipient property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param recipient The value to add.
   */
  public void addRecipient(Thing recipient) {
    communicateAction.addRecipient(recipient);
  }
  
  /**
   * Adds a result property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param result The value to add.
   */
  public void addResult(Thing result) {
    action.addResult(result);
  }
  
  /**
   * Adds a sameAs property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a startTime property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param startTime The value to add.
   */
  public void addStartTime(Date startTime) {
    action.addStartTime(startTime);
  }
  
  /**
   * Adds a url property value for this ConfirmAction object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}