package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.ContactPoint;
import org.schema.ContactPointOption;
import org.schema.Language;
import org.schema.OpeningHoursSpecification;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A contact point&#x2014;for example, a Customer Complaints department.
 */
public class ContactPointImpl extends SchemaObjectImpl implements ContactPoint {


  private ThingImpl thing;

  /**
   * The location served by this contact point (e.g., a phone number intended for Europeans vs. North Americans or only within the United States.)
   */
  private List<AdministrativeArea> areaServed = new LinkedList<AdministrativeArea>();
  
  /**
   * A language someone may use with the item.
   */
  private List<Language> availableLanguage = new LinkedList<Language>();
  
  /**
   * An option available on this contact point (e.g. a toll-free number or support for hearing-impaired callers.)
   */
  private List<ContactPointOption> contactOption = new LinkedList<ContactPointOption>();
  
  /**
   * A person or organization can have different contact points, for different purposes. For example, a sales contact point, a PR contact point and so on. This property is used to specify the kind of contact point.
   */
  private List<String> contactType = new LinkedList<String>();
  
  /**
   * Email address.
   */
  private List<String> email = new LinkedList<String>();
  
  /**
   * The fax number.
   */
  private List<String> faxNumber = new LinkedList<String>();
  
  /**
   * The hours during which this contact point is available.
   */
  private List<OpeningHoursSpecification> hoursAvailable = new LinkedList<OpeningHoursSpecification>();
  
  /**
   * The product or service this support contact point is related to (such as product support for a particular product line). This can be a specific product or product line (e.g. "iPhone") or a general category of products or services (e.g. "smartphones").
   */
  private List<Thing> productSupported = new LinkedList<Thing>();
  
  /**
   * The telephone number.
   */
  private List<String> telephone = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ContactPointImpl() {
    super("http://schema.org/ContactPoint");
  }
  /**
   * Get a single additionalType property value for this ContactPoint object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this ContactPoint object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single areaServed property value for this ContactPoint object.
   *
   * @return The first areaServed property value.
   */
  public AdministrativeArea getAreaServed() {
  	return this.areaServed.isEmpty() ? null : this.areaServed.get(0);
  }
  
  /**
   * Get a single availableLanguage property value for this ContactPoint object.
   *
   * @return The first availableLanguage property value.
   */
  public Language getAvailableLanguage() {
  	return this.availableLanguage.isEmpty() ? null : this.availableLanguage.get(0);
  }
  
  /**
   * Get a single contactOption property value for this ContactPoint object.
   *
   * @return The first contactOption property value.
   */
  public ContactPointOption getContactOption() {
  	return this.contactOption.isEmpty() ? null : this.contactOption.get(0);
  }
  
  /**
   * Get a single contactType property value for this ContactPoint object.
   *
   * @return The first contactType property value.
   */
  public String getContactType() {
  	return this.contactType.isEmpty() ? null : this.contactType.get(0);
  }
  
  /**
   * Get a single description property value for this ContactPoint object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single email property value for this ContactPoint object.
   *
   * @return The first email property value.
   */
  public String getEmail() {
  	return this.email.isEmpty() ? null : this.email.get(0);
  }
  
  /**
   * Get a single faxNumber property value for this ContactPoint object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
  	return this.faxNumber.isEmpty() ? null : this.faxNumber.get(0);
  }
  
  /**
   * Get a single hoursAvailable property value for this ContactPoint object.
   *
   * @return The first hoursAvailable property value.
   */
  public OpeningHoursSpecification getHoursAvailable() {
  	return this.hoursAvailable.isEmpty() ? null : this.hoursAvailable.get(0);
  }
  
  /**
   * Get a single image property value for this ContactPoint object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this ContactPoint object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single productSupported property value for this ContactPoint object.
   *
   * @return The first productSupported property value.
   */
  public Thing getProductSupported() {
  	return this.productSupported.isEmpty() ? null : this.productSupported.get(0);
  }
  
  /**
   * Get a single sameAs property value for this ContactPoint object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single telephone property value for this ContactPoint object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
  	return this.telephone.isEmpty() ? null : this.telephone.get(0);
  }
  
  /**
   * Get a single url property value for this ContactPoint object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this ContactPoint object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this ContactPoint object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the areaServed property values for this ContactPoint object.
   *
   * @return A list of areaServed property values.
   */
  public List<AdministrativeArea> getAreaServeds() {
  	return this.areaServed;
  }
  
  /**
   * Get all the availableLanguage property values for this ContactPoint object.
   *
   * @return A list of availableLanguage property values.
   */
  public List<Language> getAvailableLanguages() {
  	return this.availableLanguage;
  }
  
  /**
   * Get all the contactOption property values for this ContactPoint object.
   *
   * @return A list of contactOption property values.
   */
  public List<ContactPointOption> getContactOptions() {
  	return this.contactOption;
  }
  
  /**
   * Get all the contactType property values for this ContactPoint object.
   *
   * @return A list of contactType property values.
   */
  public List<String> getContactTypes() {
  	return this.contactType;
  }
  
  /**
   * Get all the description property values for this ContactPoint object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the email property values for this ContactPoint object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails() {
  	return this.email;
  }
  
  /**
   * Get all the faxNumber property values for this ContactPoint object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
  	return this.faxNumber;
  }
  
  /**
   * Get all the hoursAvailable property values for this ContactPoint object.
   *
   * @return A list of hoursAvailable property values.
   */
  public List<OpeningHoursSpecification> getHoursAvailables() {
  	return this.hoursAvailable;
  }
  
  /**
   * Get all the image property values for this ContactPoint object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this ContactPoint object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the productSupported property values for this ContactPoint object.
   *
   * @return A list of productSupported property values.
   */
  public List<Thing> getProductSupporteds() {
  	return this.productSupported;
  }
  
  /**
   * Get all the sameAs property values for this ContactPoint object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the telephone property values for this ContactPoint object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
  	return this.telephone;
  }
  
  /**
   * Get all the url property values for this ContactPoint object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this ContactPoint object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this ContactPoint object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the areaServed property value for this ContactPoint object; overwriting any existing values.
   *
   * @param areaServed The value to set.
   */
  public void setAreaServed(AdministrativeArea areaServed) {
  	this.areaServed.clear();
  	this.areaServed.add(areaServed);
  }
  
  /**
   * Set the availableLanguage property value for this ContactPoint object; overwriting any existing values.
   *
   * @param availableLanguage The value to set.
   */
  public void setAvailableLanguage(Language availableLanguage) {
  	this.availableLanguage.clear();
  	this.availableLanguage.add(availableLanguage);
  }
  
  /**
   * Set the contactOption property value for this ContactPoint object; overwriting any existing values.
   *
   * @param contactOption The value to set.
   */
  public void setContactOption(ContactPointOption contactOption) {
  	this.contactOption.clear();
  	this.contactOption.add(contactOption);
  }
  
  /**
   * Set the contactType property value for this ContactPoint object; overwriting any existing values.
   *
   * @param contactType The value to set.
   */
  public void setContactType(String contactType) {
  	this.contactType.clear();
  	this.contactType.add(contactType);
  }
  
  /**
   * Set the description property value for this ContactPoint object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the email property value for this ContactPoint object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email) {
  	this.email.clear();
  	this.email.add(email);
  }
  
  /**
   * Set the faxNumber property value for this ContactPoint object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
  	this.faxNumber.clear();
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Set the hoursAvailable property value for this ContactPoint object; overwriting any existing values.
   *
   * @param hoursAvailable The value to set.
   */
  public void setHoursAvailable(OpeningHoursSpecification hoursAvailable) {
  	this.hoursAvailable.clear();
  	this.hoursAvailable.add(hoursAvailable);
  }
  
  /**
   * Set the image property value for this ContactPoint object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this ContactPoint object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the productSupported property value for this ContactPoint object; overwriting any existing values.
   *
   * @param productSupported The value to set.
   */
  public void setProductSupported(Thing productSupported) {
  	this.productSupported.clear();
  	this.productSupported.add(productSupported);
  }
  
  /**
   * Set the sameAs property value for this ContactPoint object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the telephone property value for this ContactPoint object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
  	this.telephone.clear();
  	this.telephone.add(telephone);
  }
  
  /**
   * Set the url property value for this ContactPoint object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this ContactPoint object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this ContactPoint object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the areaServed property values for this ContactPoint object; overwriting any existing values.
   *
   * @param areaServeds The list of values to set.
   */
  public void setAreaServeds(List<AdministrativeArea> areaServeds) {
  	this.areaServed = areaServeds;
  }
  
  /**
   * Set the availableLanguage property values for this ContactPoint object; overwriting any existing values.
   *
   * @param availableLanguages The list of values to set.
   */
  public void setAvailableLanguages(List<Language> availableLanguages) {
  	this.availableLanguage = availableLanguages;
  }
  
  /**
   * Set the contactOption property values for this ContactPoint object; overwriting any existing values.
   *
   * @param contactOptions The list of values to set.
   */
  public void setContactOptions(List<ContactPointOption> contactOptions) {
  	this.contactOption = contactOptions;
  }
  
  /**
   * Set the contactType property values for this ContactPoint object; overwriting any existing values.
   *
   * @param contactTypes The list of values to set.
   */
  public void setContactTypes(List<String> contactTypes) {
  	this.contactType = contactTypes;
  }
  
  /**
   * Set the description property values for this ContactPoint object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the email property values for this ContactPoint object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails) {
  	this.email = emails;
  }
  
  /**
   * Set the faxNumber property values for this ContactPoint object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
  	this.faxNumber = faxNumbers;
  }
  
  /**
   * Set the hoursAvailable property values for this ContactPoint object; overwriting any existing values.
   *
   * @param hoursAvailables The list of values to set.
   */
  public void setHoursAvailables(List<OpeningHoursSpecification> hoursAvailables) {
  	this.hoursAvailable = hoursAvailables;
  }
  
  /**
   * Set the image property values for this ContactPoint object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this ContactPoint object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the productSupported property values for this ContactPoint object; overwriting any existing values.
   *
   * @param productSupporteds The list of values to set.
   */
  public void setProductSupporteds(List<Thing> productSupporteds) {
  	this.productSupported = productSupporteds;
  }
  
  /**
   * Set the sameAs property values for this ContactPoint object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the telephone property values for this ContactPoint object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
  	this.telephone = telephones;
  }
  
  /**
   * Set the url property values for this ContactPoint object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a areaServed property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param areaServed The value to add.
   */
  public void addAreaServed(AdministrativeArea areaServed) {
  	this.areaServed.add(areaServed);
  }
  
  /**
   * Adds a availableLanguage property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param availableLanguage The value to add.
   */
  public void addAvailableLanguage(Language availableLanguage) {
  	this.availableLanguage.add(availableLanguage);
  }
  
  /**
   * Adds a contactOption property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param contactOption The value to add.
   */
  public void addContactOption(ContactPointOption contactOption) {
  	this.contactOption.add(contactOption);
  }
  
  /**
   * Adds a contactType property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param contactType The value to add.
   */
  public void addContactType(String contactType) {
  	this.contactType.add(contactType);
  }
  
  /**
   * Adds a description property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a email property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email) {
  	this.email.add(email);
  }
  
  /**
   * Adds a faxNumber property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Adds a hoursAvailable property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param hoursAvailable The value to add.
   */
  public void addHoursAvailable(OpeningHoursSpecification hoursAvailable) {
  	this.hoursAvailable.add(hoursAvailable);
  }
  
  /**
   * Adds a image property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a productSupported property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param productSupported The value to add.
   */
  public void addProductSupported(Thing productSupported) {
  	this.productSupported.add(productSupported);
  }
  
  /**
   * Adds a sameAs property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a telephone property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
  	this.telephone.add(telephone);
  }
  
  /**
   * Adds a url property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}