package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.AlignmentObject;
import org.schema.Audience;
import org.schema.AudioObject;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.MediaObject;
import org.schema.Number;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.Review;
import org.schema.Thing;
import org.schema.VideoObject;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The most generic kind of creative work, including books, movies, photographs, software programs, etc.
 */
public class CreativeWorkImpl extends SchemaObjectImpl implements CreativeWork {


  private ThingImpl thing;

  /**
   * The subject matter of the content.
   */
  private List<Thing> about = new LinkedList<Thing>();
  
  /**
   * Indicates that the resource is compatible with the referenced accessibility API (<a href="http://www.w3.org/wiki/WebSchemas/Accessibility">WebSchemas wiki lists possible values</a>).
         
   */
  private List<String> accessibilityAPI = new LinkedList<String>();
  
  /**
   * Identifies input methods that are sufficient to fully control the described resource (<a href="http://www.w3.org/wiki/WebSchemas/Accessibility">WebSchemas wiki lists possible values</a>).
   */
  private List<String> accessibilityControl = new LinkedList<String>();
  
  /**
   * Content features of the resource, such as accessible media, alternatives and supported enhancements for accessibility (<a href="http://www.w3.org/wiki/WebSchemas/Accessibility">WebSchemas wiki lists possible values</a>).
   */
  private List<String> accessibilityFeature = new LinkedList<String>();
  
  /**
   * A characteristic of the described resource that is physiologically dangerous to some users. Related to WCAG 2.0 guideline 2.3. (<a href="http://www.w3.org/wiki/WebSchemas/Accessibility">WebSchemas wiki lists possible values</a>)
   */
  private List<String> accessibilityHazard = new LinkedList<String>();
  
  /**
   * Specifies the Person that is legally accountable for the CreativeWork.
   */
  private List<Person> accountablePerson = new LinkedList<Person>();
  
  /**
   * The overall rating, based on a collection of reviews or ratings, of the item.
   */
  private List<AggregateRating> aggregateRating = new LinkedList<AggregateRating>();
  
  /**
   * A secondary title of the CreativeWork.
   */
  private List<String> alternativeHeadline = new LinkedList<String>();
  
  /**
   * The media objects that encode this creative work. This property is a synonym for encodings.
   */
  private List<MediaObject> associatedMedia = new LinkedList<MediaObject>();
  
  /**
   * The intended audience of the item, i.e. the group for whom the item was created.
   */
  private List<Audience> audience = new LinkedList<Audience>();
  
  /**
   * An embedded audio object.
   */
  private List<AudioObject> audio = new LinkedList<AudioObject>();
  
  /**
   * The author of this content. Please note that author is special in that HTML 5 provides a special mechanism for indicating authorship via the rel tag. That is equivalent to this and may be used interchangeably.
   */
  private List<Thing> author = new LinkedList<Thing>();
  
  /**
   * An award won by this person or for this creative work.
   */
  private List<String> award = new LinkedList<String>();
  
  /**
   * A citation or reference to another creative work, such as another publication, web page, scholarly article, etc.
   */
  private List<Thing> citation = new LinkedList<Thing>();
  
  /**
   * Comments, typically from users, on this CreativeWork.
   */
  private List<Thing> comment = new LinkedList<Thing>();
  
  /**
   * The number of comments this CreativeWork (e.g. Article, Question or Answer) has received. This is most applicable to works published in Web sites with commenting system; additional comments may exist elsewhere.
   */
  private List<Long> commentCount = new LinkedList<Long>();
  
  /**
   * The location of the content.
   */
  private List<Place> contentLocation = new LinkedList<Place>();
  
  /**
   * Official rating of a piece of content&#x2014;for example,'MPAA PG-13'.
   */
  private List<String> contentRating = new LinkedList<String>();
  
  /**
   * A secondary contributor to the CreativeWork.
   */
  private List<Thing> contributor = new LinkedList<Thing>();
  
  /**
   * The party holding the legal copyright to the CreativeWork.
   */
  private List<Thing> copyrightHolder = new LinkedList<Thing>();
  
  /**
   * The year during which the claimed copyright for the CreativeWork was first asserted.
   */
  private List<Number> copyrightYear = new LinkedList<Number>();
  
  /**
   * The creator/author of this CreativeWork or UserComments. This is the same as the Author property for CreativeWork.
   */
  private List<Thing> creator = new LinkedList<Thing>();
  
  /**
   * The date on which the CreativeWork was created.
   */
  private List<Date> dateCreated = new LinkedList<Date>();
  
  /**
   * The date on which the CreativeWork was most recently modified.
   */
  private List<Date> dateModified = new LinkedList<Date>();
  
  /**
   * Date of first broadcast/publication.
   */
  private List<Date> datePublished = new LinkedList<Date>();
  
  /**
   * A link to the page containing the comments of the CreativeWork.
   */
  private List<URL> discussionUrl = new LinkedList<URL>();
  
  /**
   * Specifies the Person who edited the CreativeWork.
   */
  private List<Person> editor = new LinkedList<Person>();
  
  /**
   * An alignment to an established educational framework.
   */
  private List<AlignmentObject> educationalAlignment = new LinkedList<AlignmentObject>();
  
  /**
   * The purpose of a work in the context of education; for example, 'assignment', 'group work'.
   */
  private List<String> educationalUse = new LinkedList<String>();
  
  /**
   * A media object that encode this CreativeWork.
   */
  private List<MediaObject> encoding = new LinkedList<MediaObject>();
  
  /**
   * Genre of the creative work
   */
  private List<String> genre = new LinkedList<String>();
  
  /**
   * Headline of the article
   */
  private List<String> headline = new LinkedList<String>();
  
  /**
   * The language of the content. please use one of the language codes from the <a href='http://tools.ietf.org/html/bcp47'>IETF BCP 47 standard.</a>
   */
  private List<String> inLanguage = new LinkedList<String>();
  
  /**
   * A count of a specific user interactions with this item&#x2014;for example, <code>20 UserLikes</code>, <code>5 UserComments</code>, or <code>300 UserDownloads</code>. The user interaction type should be one of the sub types of <a href='UserInteraction'>UserInteraction</a>.
   */
  private List<String> interactionCount = new LinkedList<String>();
  
  /**
   * The predominant mode of learning supported by the learning resource. Acceptable values are 'active', 'expositive', or 'mixed'.
   */
  private List<String> interactivityType = new LinkedList<String>();
  
  /**
   * A resource that was used in the creation of this resource. This term can be repeated for multiple sources. For example, http://example.com/great-multiplication-intro.html
   */
  private List<URL> isBasedOnUrl = new LinkedList<URL>();
  
  /**
   * Indicates whether this content is family friendly.
   */
  private List<Boolean> isFamilyFriendly = new LinkedList<Boolean>();
  
  /**
   * The keywords/tags used to describe this content.
   */
  private List<String> keywords = new LinkedList<String>();
  
  /**
   * The predominant type or kind characterizing the learning resource. For example, 'presentation', 'handout'.
   */
  private List<String> learningResourceType = new LinkedList<String>();
  
  /**
   * Indicates that the CreativeWork contains a reference to, but is not necessarily about a concept.
   */
  private List<Thing> mentions = new LinkedList<Thing>();
  
  /**
   * An offer to transfer some rights to an item or to provide a service&#x2014;for example, an offer to sell tickets to an event, to rent the DVD of a movie, to stream a TV show over the internet, to repair a motorcycle, or to loan a book.
   */
  private List<Offer> offers = new LinkedList<Offer>();
  
  /**
   * The organization or agency that is providing the service.
   */
  private List<Thing> provider = new LinkedList<Thing>();
  
  /**
   * The publisher of the creative work.
   */
  private List<Organization> publisher = new LinkedList<Organization>();
  
  /**
   * Link to page describing the editorial principles of the organization primarily responsible for the creation of the CreativeWork.
   */
  private List<URL> publishingPrinciples = new LinkedList<URL>();
  
  /**
   * A review of the item.
   */
  private List<Review> review = new LinkedList<Review>();
  
  /**
   * The Organization on whose behalf the creator was working.
   */
  private List<Organization> sourceOrganization = new LinkedList<Organization>();
  
  /**
   * The textual content of this CreativeWork.
   */
  private List<String> text = new LinkedList<String>();
  
  /**
   * A thumbnail image relevant to the Thing.
   */
  private List<URL> thumbnailUrl = new LinkedList<URL>();
  
  /**
   * Approximate or typical time it takes to work with or through this learning resource for the typical intended target audience, e.g. 'P30M', 'P1H25M'.
   */
  private List<Duration> timeRequired = new LinkedList<Duration>();
  
  /**
   * The typical expected age range, e.g. '7-9', '11-'.
   */
  private List<String> typicalAgeRange = new LinkedList<String>();
  
  /**
   * The version of the CreativeWork embodied by a specified resource.
   */
  private List<Number> version = new LinkedList<Number>();
  
  /**
   * An embedded video object.
   */
  private List<VideoObject> video = new LinkedList<VideoObject>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public CreativeWorkImpl() {
    super("http://schema.org/CreativeWork");
    thing = new ThingImpl();
  }
  /**
   * Get a single about property value for this CreativeWork object.
   *
   * @return The first about property value.
   */
  public Thing getAbout() {
  	return this.about.isEmpty() ? null : this.about.get(0);
  }
  
  /**
   * Get a single accessibilityAPI property value for this CreativeWork object.
   *
   * @return The first accessibilityAPI property value.
   */
  public String getAccessibilityAPI() {
  	return this.accessibilityAPI.isEmpty() ? null : this.accessibilityAPI.get(0);
  }
  
  /**
   * Get a single accessibilityControl property value for this CreativeWork object.
   *
   * @return The first accessibilityControl property value.
   */
  public String getAccessibilityControl() {
  	return this.accessibilityControl.isEmpty() ? null : this.accessibilityControl.get(0);
  }
  
  /**
   * Get a single accessibilityFeature property value for this CreativeWork object.
   *
   * @return The first accessibilityFeature property value.
   */
  public String getAccessibilityFeature() {
  	return this.accessibilityFeature.isEmpty() ? null : this.accessibilityFeature.get(0);
  }
  
  /**
   * Get a single accessibilityHazard property value for this CreativeWork object.
   *
   * @return The first accessibilityHazard property value.
   */
  public String getAccessibilityHazard() {
  	return this.accessibilityHazard.isEmpty() ? null : this.accessibilityHazard.get(0);
  }
  
  /**
   * Get a single accountablePerson property value for this CreativeWork object.
   *
   * @return The first accountablePerson property value.
   */
  public Person getAccountablePerson() {
  	return this.accountablePerson.isEmpty() ? null : this.accountablePerson.get(0);
  }
  
  /**
   * Get a single additionalType property value for this CreativeWork object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single aggregateRating property value for this CreativeWork object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
  	return this.aggregateRating.isEmpty() ? null : this.aggregateRating.get(0);
  }
  
  /**
   * Get a single alternateName property value for this CreativeWork object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single alternativeHeadline property value for this CreativeWork object.
   *
   * @return The first alternativeHeadline property value.
   */
  public String getAlternativeHeadline() {
  	return this.alternativeHeadline.isEmpty() ? null : this.alternativeHeadline.get(0);
  }
  
  /**
   * Get a single associatedMedia property value for this CreativeWork object.
   *
   * @return The first associatedMedia property value.
   */
  public MediaObject getAssociatedMedia() {
  	return this.associatedMedia.isEmpty() ? null : this.associatedMedia.get(0);
  }
  
  /**
   * Get a single audience property value for this CreativeWork object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience() {
  	return this.audience.isEmpty() ? null : this.audience.get(0);
  }
  
  /**
   * Get a single audio property value for this CreativeWork object.
   *
   * @return The first audio property value.
   */
  public AudioObject getAudio() {
  	return this.audio.isEmpty() ? null : this.audio.get(0);
  }
  
  /**
   * Get a single author property value for this CreativeWork object.
   *
   * @return The first author property value.
   */
  public Thing getAuthor() {
  	return this.author.isEmpty() ? null : this.author.get(0);
  }
  
  /**
   * Get a single award property value for this CreativeWork object.
   *
   * @return The first award property value.
   */
  public String getAward() {
  	return this.award.isEmpty() ? null : this.award.get(0);
  }
  
  /**
   * Get a single citation property value for this CreativeWork object.
   *
   * @return The first citation property value.
   */
  public Thing getCitation() {
  	return this.citation.isEmpty() ? null : this.citation.get(0);
  }
  
  /**
   * Get a single comment property value for this CreativeWork object.
   *
   * @return The first comment property value.
   */
  public Thing getComment() {
  	return this.comment.isEmpty() ? null : this.comment.get(0);
  }
  
  /**
   * Get a single commentCount property value for this CreativeWork object.
   *
   * @return The first commentCount property value.
   */
  public Long getCommentCount() {
  	return this.commentCount.isEmpty() ? null : this.commentCount.get(0);
  }
  
  /**
   * Get a single contentLocation property value for this CreativeWork object.
   *
   * @return The first contentLocation property value.
   */
  public Place getContentLocation() {
  	return this.contentLocation.isEmpty() ? null : this.contentLocation.get(0);
  }
  
  /**
   * Get a single contentRating property value for this CreativeWork object.
   *
   * @return The first contentRating property value.
   */
  public String getContentRating() {
  	return this.contentRating.isEmpty() ? null : this.contentRating.get(0);
  }
  
  /**
   * Get a single contributor property value for this CreativeWork object.
   *
   * @return The first contributor property value.
   */
  public Thing getContributor() {
  	return this.contributor.isEmpty() ? null : this.contributor.get(0);
  }
  
  /**
   * Get a single copyrightHolder property value for this CreativeWork object.
   *
   * @return The first copyrightHolder property value.
   */
  public Thing getCopyrightHolder() {
  	return this.copyrightHolder.isEmpty() ? null : this.copyrightHolder.get(0);
  }
  
  /**
   * Get a single copyrightYear property value for this CreativeWork object.
   *
   * @return The first copyrightYear property value.
   */
  public Number getCopyrightYear() {
  	return this.copyrightYear.isEmpty() ? null : this.copyrightYear.get(0);
  }
  
  /**
   * Get a single creator property value for this CreativeWork object.
   *
   * @return The first creator property value.
   */
  public Thing getCreator() {
  	return this.creator.isEmpty() ? null : this.creator.get(0);
  }
  
  /**
   * Get a single dateCreated property value for this CreativeWork object.
   *
   * @return The first dateCreated property value.
   */
  public Date getDateCreated() {
  	return this.dateCreated.isEmpty() ? null : this.dateCreated.get(0);
  }
  
  /**
   * Get a single dateModified property value for this CreativeWork object.
   *
   * @return The first dateModified property value.
   */
  public Date getDateModified() {
  	return this.dateModified.isEmpty() ? null : this.dateModified.get(0);
  }
  
  /**
   * Get a single datePublished property value for this CreativeWork object.
   *
   * @return The first datePublished property value.
   */
  public Date getDatePublished() {
  	return this.datePublished.isEmpty() ? null : this.datePublished.get(0);
  }
  
  /**
   * Get a single description property value for this CreativeWork object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single discussionUrl property value for this CreativeWork object.
   *
   * @return The first discussionUrl property value.
   */
  public URL getDiscussionUrl() {
  	return this.discussionUrl.isEmpty() ? null : this.discussionUrl.get(0);
  }
  
  /**
   * Get a single editor property value for this CreativeWork object.
   *
   * @return The first editor property value.
   */
  public Person getEditor() {
  	return this.editor.isEmpty() ? null : this.editor.get(0);
  }
  
  /**
   * Get a single educationalAlignment property value for this CreativeWork object.
   *
   * @return The first educationalAlignment property value.
   */
  public AlignmentObject getEducationalAlignment() {
  	return this.educationalAlignment.isEmpty() ? null : this.educationalAlignment.get(0);
  }
  
  /**
   * Get a single educationalUse property value for this CreativeWork object.
   *
   * @return The first educationalUse property value.
   */
  public String getEducationalUse() {
  	return this.educationalUse.isEmpty() ? null : this.educationalUse.get(0);
  }
  
  /**
   * Get a single encoding property value for this CreativeWork object.
   *
   * @return The first encoding property value.
   */
  public MediaObject getEncoding() {
  	return this.encoding.isEmpty() ? null : this.encoding.get(0);
  }
  
  /**
   * Get a single genre property value for this CreativeWork object.
   *
   * @return The first genre property value.
   */
  public String getGenre() {
  	return this.genre.isEmpty() ? null : this.genre.get(0);
  }
  
  /**
   * Get a single headline property value for this CreativeWork object.
   *
   * @return The first headline property value.
   */
  public String getHeadline() {
  	return this.headline.isEmpty() ? null : this.headline.get(0);
  }
  
  /**
   * Get a single image property value for this CreativeWork object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single inLanguage property value for this CreativeWork object.
   *
   * @return The first inLanguage property value.
   */
  public String getInLanguage() {
  	return this.inLanguage.isEmpty() ? null : this.inLanguage.get(0);
  }
  
  /**
   * Get a single interactionCount property value for this CreativeWork object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
  	return this.interactionCount.isEmpty() ? null : this.interactionCount.get(0);
  }
  
  /**
   * Get a single interactivityType property value for this CreativeWork object.
   *
   * @return The first interactivityType property value.
   */
  public String getInteractivityType() {
  	return this.interactivityType.isEmpty() ? null : this.interactivityType.get(0);
  }
  
  /**
   * Get a single isBasedOnUrl property value for this CreativeWork object.
   *
   * @return The first isBasedOnUrl property value.
   */
  public URL getIsBasedOnUrl() {
  	return this.isBasedOnUrl.isEmpty() ? null : this.isBasedOnUrl.get(0);
  }
  
  /**
   * Get a single isFamilyFriendly property value for this CreativeWork object.
   *
   * @return The first isFamilyFriendly property value.
   */
  public Boolean getIsFamilyFriendly() {
  	return this.isFamilyFriendly.isEmpty() ? null : this.isFamilyFriendly.get(0);
  }
  
  /**
   * Get a single keywords property value for this CreativeWork object.
   *
   * @return The first keywords property value.
   */
  public String getKeywords() {
  	return this.keywords.isEmpty() ? null : this.keywords.get(0);
  }
  
  /**
   * Get a single learningResourceType property value for this CreativeWork object.
   *
   * @return The first learningResourceType property value.
   */
  public String getLearningResourceType() {
  	return this.learningResourceType.isEmpty() ? null : this.learningResourceType.get(0);
  }
  
  /**
   * Get a single mentions property value for this CreativeWork object.
   *
   * @return The first mentions property value.
   */
  public Thing getMentions() {
  	return this.mentions.isEmpty() ? null : this.mentions.get(0);
  }
  
  /**
   * Get a single name property value for this CreativeWork object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offers property value for this CreativeWork object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers() {
  	return this.offers.isEmpty() ? null : this.offers.get(0);
  }
  
  /**
   * Get a single provider property value for this CreativeWork object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
  	return this.provider.isEmpty() ? null : this.provider.get(0);
  }
  
  /**
   * Get a single publisher property value for this CreativeWork object.
   *
   * @return The first publisher property value.
   */
  public Organization getPublisher() {
  	return this.publisher.isEmpty() ? null : this.publisher.get(0);
  }
  
  /**
   * Get a single publishingPrinciples property value for this CreativeWork object.
   *
   * @return The first publishingPrinciples property value.
   */
  public URL getPublishingPrinciples() {
  	return this.publishingPrinciples.isEmpty() ? null : this.publishingPrinciples.get(0);
  }
  
  /**
   * Get a single review property value for this CreativeWork object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
  	return this.review.isEmpty() ? null : this.review.get(0);
  }
  
  /**
   * Get a single sameAs property value for this CreativeWork object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single sourceOrganization property value for this CreativeWork object.
   *
   * @return The first sourceOrganization property value.
   */
  public Organization getSourceOrganization() {
  	return this.sourceOrganization.isEmpty() ? null : this.sourceOrganization.get(0);
  }
  
  /**
   * Get a single text property value for this CreativeWork object.
   *
   * @return The first text property value.
   */
  public String getText() {
  	return this.text.isEmpty() ? null : this.text.get(0);
  }
  
  /**
   * Get a single thumbnailUrl property value for this CreativeWork object.
   *
   * @return The first thumbnailUrl property value.
   */
  public URL getThumbnailUrl() {
  	return this.thumbnailUrl.isEmpty() ? null : this.thumbnailUrl.get(0);
  }
  
  /**
   * Get a single timeRequired property value for this CreativeWork object.
   *
   * @return The first timeRequired property value.
   */
  public Duration getTimeRequired() {
  	return this.timeRequired.isEmpty() ? null : this.timeRequired.get(0);
  }
  
  /**
   * Get a single typicalAgeRange property value for this CreativeWork object.
   *
   * @return The first typicalAgeRange property value.
   */
  public String getTypicalAgeRange() {
  	return this.typicalAgeRange.isEmpty() ? null : this.typicalAgeRange.get(0);
  }
  
  /**
   * Get a single url property value for this CreativeWork object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single version property value for this CreativeWork object.
   *
   * @return The first version property value.
   */
  public Number getVersion() {
  	return this.version.isEmpty() ? null : this.version.get(0);
  }
  
  /**
   * Get a single video property value for this CreativeWork object.
   *
   * @return The first video property value.
   */
  public VideoObject getVideo() {
  	return this.video.isEmpty() ? null : this.video.get(0);
  }
  
  /**
   * Get all the about property values for this CreativeWork object.
   *
   * @return A list of about property values.
   */
  public List<Thing> getAbouts() {
  	return this.about;
  }
  
  /**
   * Get all the accessibilityAPI property values for this CreativeWork object.
   *
   * @return A list of accessibilityAPI property values.
   */
  public List<String> getAccessibilityAPIs() {
  	return this.accessibilityAPI;
  }
  
  /**
   * Get all the accessibilityControl property values for this CreativeWork object.
   *
   * @return A list of accessibilityControl property values.
   */
  public List<String> getAccessibilityControls() {
  	return this.accessibilityControl;
  }
  
  /**
   * Get all the accessibilityFeature property values for this CreativeWork object.
   *
   * @return A list of accessibilityFeature property values.
   */
  public List<String> getAccessibilityFeatures() {
  	return this.accessibilityFeature;
  }
  
  /**
   * Get all the accessibilityHazard property values for this CreativeWork object.
   *
   * @return A list of accessibilityHazard property values.
   */
  public List<String> getAccessibilityHazards() {
  	return this.accessibilityHazard;
  }
  
  /**
   * Get all the accountablePerson property values for this CreativeWork object.
   *
   * @return A list of accountablePerson property values.
   */
  public List<Person> getAccountablePersons() {
  	return this.accountablePerson;
  }
  
  /**
   * Get all the additionalType property values for this CreativeWork object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the aggregateRating property values for this CreativeWork object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
  	return this.aggregateRating;
  }
  
  /**
   * Get all the alternateName property values for this CreativeWork object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the alternativeHeadline property values for this CreativeWork object.
   *
   * @return A list of alternativeHeadline property values.
   */
  public List<String> getAlternativeHeadlines() {
  	return this.alternativeHeadline;
  }
  
  /**
   * Get all the associatedMedia property values for this CreativeWork object.
   *
   * @return A list of associatedMedia property values.
   */
  public List<MediaObject> getAssociatedMedias() {
  	return this.associatedMedia;
  }
  
  /**
   * Get all the audience property values for this CreativeWork object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences() {
  	return this.audience;
  }
  
  /**
   * Get all the audio property values for this CreativeWork object.
   *
   * @return A list of audio property values.
   */
  public List<AudioObject> getAudios() {
  	return this.audio;
  }
  
  /**
   * Get all the author property values for this CreativeWork object.
   *
   * @return A list of author property values.
   */
  public List<Thing> getAuthors() {
  	return this.author;
  }
  
  /**
   * Get all the award property values for this CreativeWork object.
   *
   * @return A list of award property values.
   */
  public List<String> getAwards() {
  	return this.award;
  }
  
  /**
   * Get all the citation property values for this CreativeWork object.
   *
   * @return A list of citation property values.
   */
  public List<Thing> getCitations() {
  	return this.citation;
  }
  
  /**
   * Get all the comment property values for this CreativeWork object.
   *
   * @return A list of comment property values.
   */
  public List<Thing> getComments() {
  	return this.comment;
  }
  
  /**
   * Get all the commentCount property values for this CreativeWork object.
   *
   * @return A list of commentCount property values.
   */
  public List<Long> getCommentCounts() {
  	return this.commentCount;
  }
  
  /**
   * Get all the contentLocation property values for this CreativeWork object.
   *
   * @return A list of contentLocation property values.
   */
  public List<Place> getContentLocations() {
  	return this.contentLocation;
  }
  
  /**
   * Get all the contentRating property values for this CreativeWork object.
   *
   * @return A list of contentRating property values.
   */
  public List<String> getContentRatings() {
  	return this.contentRating;
  }
  
  /**
   * Get all the contributor property values for this CreativeWork object.
   *
   * @return A list of contributor property values.
   */
  public List<Thing> getContributors() {
  	return this.contributor;
  }
  
  /**
   * Get all the copyrightHolder property values for this CreativeWork object.
   *
   * @return A list of copyrightHolder property values.
   */
  public List<Thing> getCopyrightHolders() {
  	return this.copyrightHolder;
  }
  
  /**
   * Get all the copyrightYear property values for this CreativeWork object.
   *
   * @return A list of copyrightYear property values.
   */
  public List<Number> getCopyrightYears() {
  	return this.copyrightYear;
  }
  
  /**
   * Get all the creator property values for this CreativeWork object.
   *
   * @return A list of creator property values.
   */
  public List<Thing> getCreators() {
  	return this.creator;
  }
  
  /**
   * Get all the dateCreated property values for this CreativeWork object.
   *
   * @return A list of dateCreated property values.
   */
  public List<Date> getDateCreateds() {
  	return this.dateCreated;
  }
  
  /**
   * Get all the dateModified property values for this CreativeWork object.
   *
   * @return A list of dateModified property values.
   */
  public List<Date> getDateModifieds() {
  	return this.dateModified;
  }
  
  /**
   * Get all the datePublished property values for this CreativeWork object.
   *
   * @return A list of datePublished property values.
   */
  public List<Date> getDatePublisheds() {
  	return this.datePublished;
  }
  
  /**
   * Get all the description property values for this CreativeWork object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the discussionUrl property values for this CreativeWork object.
   *
   * @return A list of discussionUrl property values.
   */
  public List<URL> getDiscussionUrls() {
  	return this.discussionUrl;
  }
  
  /**
   * Get all the editor property values for this CreativeWork object.
   *
   * @return A list of editor property values.
   */
  public List<Person> getEditors() {
  	return this.editor;
  }
  
  /**
   * Get all the educationalAlignment property values for this CreativeWork object.
   *
   * @return A list of educationalAlignment property values.
   */
  public List<AlignmentObject> getEducationalAlignments() {
  	return this.educationalAlignment;
  }
  
  /**
   * Get all the educationalUse property values for this CreativeWork object.
   *
   * @return A list of educationalUse property values.
   */
  public List<String> getEducationalUses() {
  	return this.educationalUse;
  }
  
  /**
   * Get all the encoding property values for this CreativeWork object.
   *
   * @return A list of encoding property values.
   */
  public List<MediaObject> getEncodings() {
  	return this.encoding;
  }
  
  /**
   * Get all the genre property values for this CreativeWork object.
   *
   * @return A list of genre property values.
   */
  public List<String> getGenres() {
  	return this.genre;
  }
  
  /**
   * Get all the headline property values for this CreativeWork object.
   *
   * @return A list of headline property values.
   */
  public List<String> getHeadlines() {
  	return this.headline;
  }
  
  /**
   * Get all the image property values for this CreativeWork object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the inLanguage property values for this CreativeWork object.
   *
   * @return A list of inLanguage property values.
   */
  public List<String> getInLanguages() {
  	return this.inLanguage;
  }
  
  /**
   * Get all the interactionCount property values for this CreativeWork object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
  	return this.interactionCount;
  }
  
  /**
   * Get all the interactivityType property values for this CreativeWork object.
   *
   * @return A list of interactivityType property values.
   */
  public List<String> getInteractivityTypes() {
  	return this.interactivityType;
  }
  
  /**
   * Get all the isBasedOnUrl property values for this CreativeWork object.
   *
   * @return A list of isBasedOnUrl property values.
   */
  public List<URL> getIsBasedOnUrls() {
  	return this.isBasedOnUrl;
  }
  
  /**
   * Get all the isFamilyFriendly property values for this CreativeWork object.
   *
   * @return A list of isFamilyFriendly property values.
   */
  public List<Boolean> getIsFamilyFriendlies() {
  	return this.isFamilyFriendly;
  }
  
  /**
   * Get all the keywords property values for this CreativeWork object.
   *
   * @return A list of keywords property values.
   */
  public List<String> getKeywordss() {
  	return this.keywords;
  }
  
  /**
   * Get all the learningResourceType property values for this CreativeWork object.
   *
   * @return A list of learningResourceType property values.
   */
  public List<String> getLearningResourceTypes() {
  	return this.learningResourceType;
  }
  
  /**
   * Get all the mentions property values for this CreativeWork object.
   *
   * @return A list of mentions property values.
   */
  public List<Thing> getMentionss() {
  	return this.mentions;
  }
  
  /**
   * Get all the name property values for this CreativeWork object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offers property values for this CreativeWork object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss() {
  	return this.offers;
  }
  
  /**
   * Get all the provider property values for this CreativeWork object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
  	return this.provider;
  }
  
  /**
   * Get all the publisher property values for this CreativeWork object.
   *
   * @return A list of publisher property values.
   */
  public List<Organization> getPublishers() {
  	return this.publisher;
  }
  
  /**
   * Get all the publishingPrinciples property values for this CreativeWork object.
   *
   * @return A list of publishingPrinciples property values.
   */
  public List<URL> getPublishingPrincipless() {
  	return this.publishingPrinciples;
  }
  
  /**
   * Get all the review property values for this CreativeWork object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
  	return this.review;
  }
  
  /**
   * Get all the sameAs property values for this CreativeWork object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the sourceOrganization property values for this CreativeWork object.
   *
   * @return A list of sourceOrganization property values.
   */
  public List<Organization> getSourceOrganizations() {
  	return this.sourceOrganization;
  }
  
  /**
   * Get all the text property values for this CreativeWork object.
   *
   * @return A list of text property values.
   */
  public List<String> getTexts() {
  	return this.text;
  }
  
  /**
   * Get all the thumbnailUrl property values for this CreativeWork object.
   *
   * @return A list of thumbnailUrl property values.
   */
  public List<URL> getThumbnailUrls() {
  	return this.thumbnailUrl;
  }
  
  /**
   * Get all the timeRequired property values for this CreativeWork object.
   *
   * @return A list of timeRequired property values.
   */
  public List<Duration> getTimeRequireds() {
  	return this.timeRequired;
  }
  
  /**
   * Get all the typicalAgeRange property values for this CreativeWork object.
   *
   * @return A list of typicalAgeRange property values.
   */
  public List<String> getTypicalAgeRanges() {
  	return this.typicalAgeRange;
  }
  
  /**
   * Get all the url property values for this CreativeWork object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the version property values for this CreativeWork object.
   *
   * @return A list of version property values.
   */
  public List<Number> getVersions() {
  	return this.version;
  }
  
  /**
   * Get all the video property values for this CreativeWork object.
   *
   * @return A list of video property values.
   */
  public List<VideoObject> getVideos() {
  	return this.video;
  }
  
  /**
   * Set the about property value for this CreativeWork object; overwriting any existing values.
   *
   * @param about The value to set.
   */
  public void setAbout(Thing about) {
  	this.about.clear();
  	this.about.add(about);
  }
  
  /**
   * Set the accessibilityAPI property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityAPI The value to set.
   */
  public void setAccessibilityAPI(String accessibilityAPI) {
  	this.accessibilityAPI.clear();
  	this.accessibilityAPI.add(accessibilityAPI);
  }
  
  /**
   * Set the accessibilityControl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityControl The value to set.
   */
  public void setAccessibilityControl(String accessibilityControl) {
  	this.accessibilityControl.clear();
  	this.accessibilityControl.add(accessibilityControl);
  }
  
  /**
   * Set the accessibilityFeature property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityFeature The value to set.
   */
  public void setAccessibilityFeature(String accessibilityFeature) {
  	this.accessibilityFeature.clear();
  	this.accessibilityFeature.add(accessibilityFeature);
  }
  
  /**
   * Set the accessibilityHazard property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityHazard The value to set.
   */
  public void setAccessibilityHazard(String accessibilityHazard) {
  	this.accessibilityHazard.clear();
  	this.accessibilityHazard.add(accessibilityHazard);
  }
  
  /**
   * Set the accountablePerson property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accountablePerson The value to set.
   */
  public void setAccountablePerson(Person accountablePerson) {
  	this.accountablePerson.clear();
  	this.accountablePerson.add(accountablePerson);
  }
  
  /**
   * Set the additionalType property value for this CreativeWork object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the aggregateRating property value for this CreativeWork object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.clear();
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this CreativeWork object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the alternativeHeadline property value for this CreativeWork object; overwriting any existing values.
   *
   * @param alternativeHeadline The value to set.
   */
  public void setAlternativeHeadline(String alternativeHeadline) {
  	this.alternativeHeadline.clear();
  	this.alternativeHeadline.add(alternativeHeadline);
  }
  
  /**
   * Set the associatedMedia property value for this CreativeWork object; overwriting any existing values.
   *
   * @param associatedMedia The value to set.
   */
  public void setAssociatedMedia(MediaObject associatedMedia) {
  	this.associatedMedia.clear();
  	this.associatedMedia.add(associatedMedia);
  }
  
  /**
   * Set the audience property value for this CreativeWork object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience) {
  	this.audience.clear();
  	this.audience.add(audience);
  }
  
  /**
   * Set the audio property value for this CreativeWork object; overwriting any existing values.
   *
   * @param audio The value to set.
   */
  public void setAudio(AudioObject audio) {
  	this.audio.clear();
  	this.audio.add(audio);
  }
  
  /**
   * Set the author property value for this CreativeWork object; overwriting any existing values.
   *
   * @param author The value to set.
   */
  public void setAuthor(Thing author) {
  	this.author.clear();
  	this.author.add(author);
  }
  
  /**
   * Set the award property value for this CreativeWork object; overwriting any existing values.
   *
   * @param award The value to set.
   */
  public void setAward(String award) {
  	this.award.clear();
  	this.award.add(award);
  }
  
  /**
   * Set the citation property value for this CreativeWork object; overwriting any existing values.
   *
   * @param citation The value to set.
   */
  public void setCitation(Thing citation) {
  	this.citation.clear();
  	this.citation.add(citation);
  }
  
  /**
   * Set the comment property value for this CreativeWork object; overwriting any existing values.
   *
   * @param comment The value to set.
   */
  public void setComment(Thing comment) {
  	this.comment.clear();
  	this.comment.add(comment);
  }
  
  /**
   * Set the commentCount property value for this CreativeWork object; overwriting any existing values.
   *
   * @param commentCount The value to set.
   */
  public void setCommentCount(Long commentCount) {
  	this.commentCount.clear();
  	this.commentCount.add(commentCount);
  }
  
  /**
   * Set the contentLocation property value for this CreativeWork object; overwriting any existing values.
   *
   * @param contentLocation The value to set.
   */
  public void setContentLocation(Place contentLocation) {
  	this.contentLocation.clear();
  	this.contentLocation.add(contentLocation);
  }
  
  /**
   * Set the contentRating property value for this CreativeWork object; overwriting any existing values.
   *
   * @param contentRating The value to set.
   */
  public void setContentRating(String contentRating) {
  	this.contentRating.clear();
  	this.contentRating.add(contentRating);
  }
  
  /**
   * Set the contributor property value for this CreativeWork object; overwriting any existing values.
   *
   * @param contributor The value to set.
   */
  public void setContributor(Thing contributor) {
  	this.contributor.clear();
  	this.contributor.add(contributor);
  }
  
  /**
   * Set the copyrightHolder property value for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightHolder The value to set.
   */
  public void setCopyrightHolder(Thing copyrightHolder) {
  	this.copyrightHolder.clear();
  	this.copyrightHolder.add(copyrightHolder);
  }
  
  /**
   * Set the copyrightYear property value for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightYear The value to set.
   */
  public void setCopyrightYear(Number copyrightYear) {
  	this.copyrightYear.clear();
  	this.copyrightYear.add(copyrightYear);
  }
  
  /**
   * Set the creator property value for this CreativeWork object; overwriting any existing values.
   *
   * @param creator The value to set.
   */
  public void setCreator(Thing creator) {
  	this.creator.clear();
  	this.creator.add(creator);
  }
  
  /**
   * Set the dateCreated property value for this CreativeWork object; overwriting any existing values.
   *
   * @param dateCreated The value to set.
   */
  public void setDateCreated(Date dateCreated) {
  	this.dateCreated.clear();
  	this.dateCreated.add(dateCreated);
  }
  
  /**
   * Set the dateModified property value for this CreativeWork object; overwriting any existing values.
   *
   * @param dateModified The value to set.
   */
  public void setDateModified(Date dateModified) {
  	this.dateModified.clear();
  	this.dateModified.add(dateModified);
  }
  
  /**
   * Set the datePublished property value for this CreativeWork object; overwriting any existing values.
   *
   * @param datePublished The value to set.
   */
  public void setDatePublished(Date datePublished) {
  	this.datePublished.clear();
  	this.datePublished.add(datePublished);
  }
  
  /**
   * Set the description property value for this CreativeWork object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the discussionUrl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param discussionUrl The value to set.
   */
  public void setDiscussionUrl(URL discussionUrl) {
  	this.discussionUrl.clear();
  	this.discussionUrl.add(discussionUrl);
  }
  
  /**
   * Set the editor property value for this CreativeWork object; overwriting any existing values.
   *
   * @param editor The value to set.
   */
  public void setEditor(Person editor) {
  	this.editor.clear();
  	this.editor.add(editor);
  }
  
  /**
   * Set the educationalAlignment property value for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalAlignment The value to set.
   */
  public void setEducationalAlignment(AlignmentObject educationalAlignment) {
  	this.educationalAlignment.clear();
  	this.educationalAlignment.add(educationalAlignment);
  }
  
  /**
   * Set the educationalUse property value for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalUse The value to set.
   */
  public void setEducationalUse(String educationalUse) {
  	this.educationalUse.clear();
  	this.educationalUse.add(educationalUse);
  }
  
  /**
   * Set the encoding property value for this CreativeWork object; overwriting any existing values.
   *
   * @param encoding The value to set.
   */
  public void setEncoding(MediaObject encoding) {
  	this.encoding.clear();
  	this.encoding.add(encoding);
  }
  
  /**
   * Set the genre property value for this CreativeWork object; overwriting any existing values.
   *
   * @param genre The value to set.
   */
  public void setGenre(String genre) {
  	this.genre.clear();
  	this.genre.add(genre);
  }
  
  /**
   * Set the headline property value for this CreativeWork object; overwriting any existing values.
   *
   * @param headline The value to set.
   */
  public void setHeadline(String headline) {
  	this.headline.clear();
  	this.headline.add(headline);
  }
  
  /**
   * Set the image property value for this CreativeWork object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the inLanguage property value for this CreativeWork object; overwriting any existing values.
   *
   * @param inLanguage The value to set.
   */
  public void setInLanguage(String inLanguage) {
  	this.inLanguage.clear();
  	this.inLanguage.add(inLanguage);
  }
  
  /**
   * Set the interactionCount property value for this CreativeWork object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
  	this.interactionCount.clear();
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Set the interactivityType property value for this CreativeWork object; overwriting any existing values.
   *
   * @param interactivityType The value to set.
   */
  public void setInteractivityType(String interactivityType) {
  	this.interactivityType.clear();
  	this.interactivityType.add(interactivityType);
  }
  
  /**
   * Set the isBasedOnUrl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param isBasedOnUrl The value to set.
   */
  public void setIsBasedOnUrl(URL isBasedOnUrl) {
  	this.isBasedOnUrl.clear();
  	this.isBasedOnUrl.add(isBasedOnUrl);
  }
  
  /**
   * Set the isFamilyFriendly property value for this CreativeWork object; overwriting any existing values.
   *
   * @param isFamilyFriendly The value to set.
   */
  public void setIsFamilyFriendly(Boolean isFamilyFriendly) {
  	this.isFamilyFriendly.clear();
  	this.isFamilyFriendly.add(isFamilyFriendly);
  }
  
  /**
   * Set the keywords property value for this CreativeWork object; overwriting any existing values.
   *
   * @param keywords The value to set.
   */
  public void setKeywords(String keywords) {
  	this.keywords.clear();
  	this.keywords.add(keywords);
  }
  
  /**
   * Set the learningResourceType property value for this CreativeWork object; overwriting any existing values.
   *
   * @param learningResourceType The value to set.
   */
  public void setLearningResourceType(String learningResourceType) {
  	this.learningResourceType.clear();
  	this.learningResourceType.add(learningResourceType);
  }
  
  /**
   * Set the mentions property value for this CreativeWork object; overwriting any existing values.
   *
   * @param mentions The value to set.
   */
  public void setMentions(Thing mentions) {
  	this.mentions.clear();
  	this.mentions.add(mentions);
  }
  
  /**
   * Set the name property value for this CreativeWork object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offers property value for this CreativeWork object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers) {
  	this.offers.clear();
  	this.offers.add(offers);
  }
  
  /**
   * Set the provider property value for this CreativeWork object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
  	this.provider.clear();
  	this.provider.add(provider);
  }
  
  /**
   * Set the publisher property value for this CreativeWork object; overwriting any existing values.
   *
   * @param publisher The value to set.
   */
  public void setPublisher(Organization publisher) {
  	this.publisher.clear();
  	this.publisher.add(publisher);
  }
  
  /**
   * Set the publishingPrinciples property value for this CreativeWork object; overwriting any existing values.
   *
   * @param publishingPrinciples The value to set.
   */
  public void setPublishingPrinciples(URL publishingPrinciples) {
  	this.publishingPrinciples.clear();
  	this.publishingPrinciples.add(publishingPrinciples);
  }
  
  /**
   * Set the review property value for this CreativeWork object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
  	this.review.clear();
  	this.review.add(review);
  }
  
  /**
   * Set the sameAs property value for this CreativeWork object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the sourceOrganization property value for this CreativeWork object; overwriting any existing values.
   *
   * @param sourceOrganization The value to set.
   */
  public void setSourceOrganization(Organization sourceOrganization) {
  	this.sourceOrganization.clear();
  	this.sourceOrganization.add(sourceOrganization);
  }
  
  /**
   * Set the text property value for this CreativeWork object; overwriting any existing values.
   *
   * @param text The value to set.
   */
  public void setText(String text) {
  	this.text.clear();
  	this.text.add(text);
  }
  
  /**
   * Set the thumbnailUrl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param thumbnailUrl The value to set.
   */
  public void setThumbnailUrl(URL thumbnailUrl) {
  	this.thumbnailUrl.clear();
  	this.thumbnailUrl.add(thumbnailUrl);
  }
  
  /**
   * Set the timeRequired property value for this CreativeWork object; overwriting any existing values.
   *
   * @param timeRequired The value to set.
   */
  public void setTimeRequired(Duration timeRequired) {
  	this.timeRequired.clear();
  	this.timeRequired.add(timeRequired);
  }
  
  /**
   * Set the typicalAgeRange property value for this CreativeWork object; overwriting any existing values.
   *
   * @param typicalAgeRange The value to set.
   */
  public void setTypicalAgeRange(String typicalAgeRange) {
  	this.typicalAgeRange.clear();
  	this.typicalAgeRange.add(typicalAgeRange);
  }
  
  /**
   * Set the url property value for this CreativeWork object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the version property value for this CreativeWork object; overwriting any existing values.
   *
   * @param version The value to set.
   */
  public void setVersion(Number version) {
  	this.version.clear();
  	this.version.add(version);
  }
  
  /**
   * Set the video property value for this CreativeWork object; overwriting any existing values.
   *
   * @param video The value to set.
   */
  public void setVideo(VideoObject video) {
  	this.video.clear();
  	this.video.add(video);
  }
  
  /**
   * Set the about property values for this CreativeWork object; overwriting any existing values.
   *
   * @param abouts The list of values to set.
   */
  public void setAbouts(List<Thing> abouts) {
  	this.about = abouts;
  }
  
  /**
   * Set the accessibilityAPI property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityAPIs The list of values to set.
   */
  public void setAccessibilityAPIs(List<String> accessibilityAPIs) {
  	this.accessibilityAPI = accessibilityAPIs;
  }
  
  /**
   * Set the accessibilityControl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityControls The list of values to set.
   */
  public void setAccessibilityControls(List<String> accessibilityControls) {
  	this.accessibilityControl = accessibilityControls;
  }
  
  /**
   * Set the accessibilityFeature property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityFeatures The list of values to set.
   */
  public void setAccessibilityFeatures(List<String> accessibilityFeatures) {
  	this.accessibilityFeature = accessibilityFeatures;
  }
  
  /**
   * Set the accessibilityHazard property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityHazards The list of values to set.
   */
  public void setAccessibilityHazards(List<String> accessibilityHazards) {
  	this.accessibilityHazard = accessibilityHazards;
  }
  
  /**
   * Set the accountablePerson property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accountablePersons The list of values to set.
   */
  public void setAccountablePersons(List<Person> accountablePersons) {
  	this.accountablePerson = accountablePersons;
  }
  
  /**
   * Set the additionalType property values for this CreativeWork object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the aggregateRating property values for this CreativeWork object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
  	this.aggregateRating = aggregateRatings;
  }
  
  /**
   * Set the alternateName property values for this CreativeWork object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the alternativeHeadline property values for this CreativeWork object; overwriting any existing values.
   *
   * @param alternativeHeadlines The list of values to set.
   */
  public void setAlternativeHeadlines(List<String> alternativeHeadlines) {
  	this.alternativeHeadline = alternativeHeadlines;
  }
  
  /**
   * Set the associatedMedia property values for this CreativeWork object; overwriting any existing values.
   *
   * @param associatedMedias The list of values to set.
   */
  public void setAssociatedMedias(List<MediaObject> associatedMedias) {
  	this.associatedMedia = associatedMedias;
  }
  
  /**
   * Set the audience property values for this CreativeWork object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences) {
  	this.audience = audiences;
  }
  
  /**
   * Set the audio property values for this CreativeWork object; overwriting any existing values.
   *
   * @param audios The list of values to set.
   */
  public void setAudios(List<AudioObject> audios) {
  	this.audio = audios;
  }
  
  /**
   * Set the author property values for this CreativeWork object; overwriting any existing values.
   *
   * @param authors The list of values to set.
   */
  public void setAuthors(List<Thing> authors) {
  	this.author = authors;
  }
  
  /**
   * Set the award property values for this CreativeWork object; overwriting any existing values.
   *
   * @param awards The list of values to set.
   */
  public void setAwards(List<String> awards) {
  	this.award = awards;
  }
  
  /**
   * Set the citation property values for this CreativeWork object; overwriting any existing values.
   *
   * @param citations The list of values to set.
   */
  public void setCitations(List<Thing> citations) {
  	this.citation = citations;
  }
  
  /**
   * Set the comment property values for this CreativeWork object; overwriting any existing values.
   *
   * @param comments The list of values to set.
   */
  public void setComments(List<Thing> comments) {
  	this.comment = comments;
  }
  
  /**
   * Set the commentCount property values for this CreativeWork object; overwriting any existing values.
   *
   * @param commentCounts The list of values to set.
   */
  public void setCommentCounts(List<Long> commentCounts) {
  	this.commentCount = commentCounts;
  }
  
  /**
   * Set the contentLocation property values for this CreativeWork object; overwriting any existing values.
   *
   * @param contentLocations The list of values to set.
   */
  public void setContentLocations(List<Place> contentLocations) {
  	this.contentLocation = contentLocations;
  }
  
  /**
   * Set the contentRating property values for this CreativeWork object; overwriting any existing values.
   *
   * @param contentRatings The list of values to set.
   */
  public void setContentRatings(List<String> contentRatings) {
  	this.contentRating = contentRatings;
  }
  
  /**
   * Set the contributor property values for this CreativeWork object; overwriting any existing values.
   *
   * @param contributors The list of values to set.
   */
  public void setContributors(List<Thing> contributors) {
  	this.contributor = contributors;
  }
  
  /**
   * Set the copyrightHolder property values for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightHolders The list of values to set.
   */
  public void setCopyrightHolders(List<Thing> copyrightHolders) {
  	this.copyrightHolder = copyrightHolders;
  }
  
  /**
   * Set the copyrightYear property values for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightYears The list of values to set.
   */
  public void setCopyrightYears(List<Number> copyrightYears) {
  	this.copyrightYear = copyrightYears;
  }
  
  /**
   * Set the creator property values for this CreativeWork object; overwriting any existing values.
   *
   * @param creators The list of values to set.
   */
  public void setCreators(List<Thing> creators) {
  	this.creator = creators;
  }
  
  /**
   * Set the dateCreated property values for this CreativeWork object; overwriting any existing values.
   *
   * @param dateCreateds The list of values to set.
   */
  public void setDateCreateds(List<Date> dateCreateds) {
  	this.dateCreated = dateCreateds;
  }
  
  /**
   * Set the dateModified property values for this CreativeWork object; overwriting any existing values.
   *
   * @param dateModifieds The list of values to set.
   */
  public void setDateModifieds(List<Date> dateModifieds) {
  	this.dateModified = dateModifieds;
  }
  
  /**
   * Set the datePublished property values for this CreativeWork object; overwriting any existing values.
   *
   * @param datePublisheds The list of values to set.
   */
  public void setDatePublisheds(List<Date> datePublisheds) {
  	this.datePublished = datePublisheds;
  }
  
  /**
   * Set the description property values for this CreativeWork object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the discussionUrl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param discussionUrls The list of values to set.
   */
  public void setDiscussionUrls(List<URL> discussionUrls) {
  	this.discussionUrl = discussionUrls;
  }
  
  /**
   * Set the editor property values for this CreativeWork object; overwriting any existing values.
   *
   * @param editors The list of values to set.
   */
  public void setEditors(List<Person> editors) {
  	this.editor = editors;
  }
  
  /**
   * Set the educationalAlignment property values for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalAlignments The list of values to set.
   */
  public void setEducationalAlignments(List<AlignmentObject> educationalAlignments) {
  	this.educationalAlignment = educationalAlignments;
  }
  
  /**
   * Set the educationalUse property values for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalUses The list of values to set.
   */
  public void setEducationalUses(List<String> educationalUses) {
  	this.educationalUse = educationalUses;
  }
  
  /**
   * Set the encoding property values for this CreativeWork object; overwriting any existing values.
   *
   * @param encodings The list of values to set.
   */
  public void setEncodings(List<MediaObject> encodings) {
  	this.encoding = encodings;
  }
  
  /**
   * Set the genre property values for this CreativeWork object; overwriting any existing values.
   *
   * @param genres The list of values to set.
   */
  public void setGenres(List<String> genres) {
  	this.genre = genres;
  }
  
  /**
   * Set the headline property values for this CreativeWork object; overwriting any existing values.
   *
   * @param headlines The list of values to set.
   */
  public void setHeadlines(List<String> headlines) {
  	this.headline = headlines;
  }
  
  /**
   * Set the image property values for this CreativeWork object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the inLanguage property values for this CreativeWork object; overwriting any existing values.
   *
   * @param inLanguages The list of values to set.
   */
  public void setInLanguages(List<String> inLanguages) {
  	this.inLanguage = inLanguages;
  }
  
  /**
   * Set the interactionCount property values for this CreativeWork object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
  	this.interactionCount = interactionCounts;
  }
  
  /**
   * Set the interactivityType property values for this CreativeWork object; overwriting any existing values.
   *
   * @param interactivityTypes The list of values to set.
   */
  public void setInteractivityTypes(List<String> interactivityTypes) {
  	this.interactivityType = interactivityTypes;
  }
  
  /**
   * Set the isBasedOnUrl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param isBasedOnUrls The list of values to set.
   */
  public void setIsBasedOnUrls(List<URL> isBasedOnUrls) {
  	this.isBasedOnUrl = isBasedOnUrls;
  }
  
  /**
   * Set the isFamilyFriendly property values for this CreativeWork object; overwriting any existing values.
   *
   * @param isFamilyFriendlies The list of values to set.
   */
  public void setIsFamilyFriendlies(List<Boolean> isFamilyFriendlies) {
  	this.isFamilyFriendly = isFamilyFriendlies;
  }
  
  /**
   * Set the keywords property values for this CreativeWork object; overwriting any existing values.
   *
   * @param keywordss The list of values to set.
   */
  public void setKeywordss(List<String> keywordss) {
  	this.keywords = keywordss;
  }
  
  /**
   * Set the learningResourceType property values for this CreativeWork object; overwriting any existing values.
   *
   * @param learningResourceTypes The list of values to set.
   */
  public void setLearningResourceTypes(List<String> learningResourceTypes) {
  	this.learningResourceType = learningResourceTypes;
  }
  
  /**
   * Set the mentions property values for this CreativeWork object; overwriting any existing values.
   *
   * @param mentionss The list of values to set.
   */
  public void setMentionss(List<Thing> mentionss) {
  	this.mentions = mentionss;
  }
  
  /**
   * Set the name property values for this CreativeWork object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offers property values for this CreativeWork object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss) {
  	this.offers = offerss;
  }
  
  /**
   * Set the provider property values for this CreativeWork object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
  	this.provider = providers;
  }
  
  /**
   * Set the publisher property values for this CreativeWork object; overwriting any existing values.
   *
   * @param publishers The list of values to set.
   */
  public void setPublishers(List<Organization> publishers) {
  	this.publisher = publishers;
  }
  
  /**
   * Set the publishingPrinciples property values for this CreativeWork object; overwriting any existing values.
   *
   * @param publishingPrincipless The list of values to set.
   */
  public void setPublishingPrincipless(List<URL> publishingPrincipless) {
  	this.publishingPrinciples = publishingPrincipless;
  }
  
  /**
   * Set the review property values for this CreativeWork object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
  	this.review = reviews;
  }
  
  /**
   * Set the sameAs property values for this CreativeWork object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the sourceOrganization property values for this CreativeWork object; overwriting any existing values.
   *
   * @param sourceOrganizations The list of values to set.
   */
  public void setSourceOrganizations(List<Organization> sourceOrganizations) {
  	this.sourceOrganization = sourceOrganizations;
  }
  
  /**
   * Set the text property values for this CreativeWork object; overwriting any existing values.
   *
   * @param texts The list of values to set.
   */
  public void setTexts(List<String> texts) {
  	this.text = texts;
  }
  
  /**
   * Set the thumbnailUrl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param thumbnailUrls The list of values to set.
   */
  public void setThumbnailUrls(List<URL> thumbnailUrls) {
  	this.thumbnailUrl = thumbnailUrls;
  }
  
  /**
   * Set the timeRequired property values for this CreativeWork object; overwriting any existing values.
   *
   * @param timeRequireds The list of values to set.
   */
  public void setTimeRequireds(List<Duration> timeRequireds) {
  	this.timeRequired = timeRequireds;
  }
  
  /**
   * Set the typicalAgeRange property values for this CreativeWork object; overwriting any existing values.
   *
   * @param typicalAgeRanges The list of values to set.
   */
  public void setTypicalAgeRanges(List<String> typicalAgeRanges) {
  	this.typicalAgeRange = typicalAgeRanges;
  }
  
  /**
   * Set the url property values for this CreativeWork object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the version property values for this CreativeWork object; overwriting any existing values.
   *
   * @param versions The list of values to set.
   */
  public void setVersions(List<Number> versions) {
  	this.version = versions;
  }
  
  /**
   * Set the video property values for this CreativeWork object; overwriting any existing values.
   *
   * @param videos The list of values to set.
   */
  public void setVideos(List<VideoObject> videos) {
  	this.video = videos;
  }
  
  /**
   * Adds a about property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param about The value to add.
   */
  public void addAbout(Thing about) {
  	this.about.add(about);
  }
  
  /**
   * Adds a accessibilityAPI property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityAPI The value to add.
   */
  public void addAccessibilityAPI(String accessibilityAPI) {
  	this.accessibilityAPI.add(accessibilityAPI);
  }
  
  /**
   * Adds a accessibilityControl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityControl The value to add.
   */
  public void addAccessibilityControl(String accessibilityControl) {
  	this.accessibilityControl.add(accessibilityControl);
  }
  
  /**
   * Adds a accessibilityFeature property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityFeature The value to add.
   */
  public void addAccessibilityFeature(String accessibilityFeature) {
  	this.accessibilityFeature.add(accessibilityFeature);
  }
  
  /**
   * Adds a accessibilityHazard property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityHazard The value to add.
   */
  public void addAccessibilityHazard(String accessibilityHazard) {
  	this.accessibilityHazard.add(accessibilityHazard);
  }
  
  /**
   * Adds a accountablePerson property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accountablePerson The value to add.
   */
  public void addAccountablePerson(Person accountablePerson) {
  	this.accountablePerson.add(accountablePerson);
  }
  
  /**
   * Adds a additionalType property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a aggregateRating property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a alternativeHeadline property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param alternativeHeadline The value to add.
   */
  public void addAlternativeHeadline(String alternativeHeadline) {
  	this.alternativeHeadline.add(alternativeHeadline);
  }
  
  /**
   * Adds a associatedMedia property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param associatedMedia The value to add.
   */
  public void addAssociatedMedia(MediaObject associatedMedia) {
  	this.associatedMedia.add(associatedMedia);
  }
  
  /**
   * Adds a audience property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience) {
  	this.audience.add(audience);
  }
  
  /**
   * Adds a audio property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param audio The value to add.
   */
  public void addAudio(AudioObject audio) {
  	this.audio.add(audio);
  }
  
  /**
   * Adds a author property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param author The value to add.
   */
  public void addAuthor(Thing author) {
  	this.author.add(author);
  }
  
  /**
   * Adds a award property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param award The value to add.
   */
  public void addAward(String award) {
  	this.award.add(award);
  }
  
  /**
   * Adds a citation property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param citation The value to add.
   */
  public void addCitation(Thing citation) {
  	this.citation.add(citation);
  }
  
  /**
   * Adds a comment property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param comment The value to add.
   */
  public void addComment(Thing comment) {
  	this.comment.add(comment);
  }
  
  /**
   * Adds a commentCount property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param commentCount The value to add.
   */
  public void addCommentCount(Long commentCount) {
  	this.commentCount.add(commentCount);
  }
  
  /**
   * Adds a contentLocation property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param contentLocation The value to add.
   */
  public void addContentLocation(Place contentLocation) {
  	this.contentLocation.add(contentLocation);
  }
  
  /**
   * Adds a contentRating property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param contentRating The value to add.
   */
  public void addContentRating(String contentRating) {
  	this.contentRating.add(contentRating);
  }
  
  /**
   * Adds a contributor property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param contributor The value to add.
   */
  public void addContributor(Thing contributor) {
  	this.contributor.add(contributor);
  }
  
  /**
   * Adds a copyrightHolder property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param copyrightHolder The value to add.
   */
  public void addCopyrightHolder(Thing copyrightHolder) {
  	this.copyrightHolder.add(copyrightHolder);
  }
  
  /**
   * Adds a copyrightYear property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param copyrightYear The value to add.
   */
  public void addCopyrightYear(Number copyrightYear) {
  	this.copyrightYear.add(copyrightYear);
  }
  
  /**
   * Adds a creator property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param creator The value to add.
   */
  public void addCreator(Thing creator) {
  	this.creator.add(creator);
  }
  
  /**
   * Adds a dateCreated property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param dateCreated The value to add.
   */
  public void addDateCreated(Date dateCreated) {
  	this.dateCreated.add(dateCreated);
  }
  
  /**
   * Adds a dateModified property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param dateModified The value to add.
   */
  public void addDateModified(Date dateModified) {
  	this.dateModified.add(dateModified);
  }
  
  /**
   * Adds a datePublished property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param datePublished The value to add.
   */
  public void addDatePublished(Date datePublished) {
  	this.datePublished.add(datePublished);
  }
  
  /**
   * Adds a description property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a discussionUrl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param discussionUrl The value to add.
   */
  public void addDiscussionUrl(URL discussionUrl) {
  	this.discussionUrl.add(discussionUrl);
  }
  
  /**
   * Adds a editor property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param editor The value to add.
   */
  public void addEditor(Person editor) {
  	this.editor.add(editor);
  }
  
  /**
   * Adds a educationalAlignment property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param educationalAlignment The value to add.
   */
  public void addEducationalAlignment(AlignmentObject educationalAlignment) {
  	this.educationalAlignment.add(educationalAlignment);
  }
  
  /**
   * Adds a educationalUse property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param educationalUse The value to add.
   */
  public void addEducationalUse(String educationalUse) {
  	this.educationalUse.add(educationalUse);
  }
  
  /**
   * Adds a encoding property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param encoding The value to add.
   */
  public void addEncoding(MediaObject encoding) {
  	this.encoding.add(encoding);
  }
  
  /**
   * Adds a genre property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param genre The value to add.
   */
  public void addGenre(String genre) {
  	this.genre.add(genre);
  }
  
  /**
   * Adds a headline property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param headline The value to add.
   */
  public void addHeadline(String headline) {
  	this.headline.add(headline);
  }
  
  /**
   * Adds a image property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a inLanguage property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param inLanguage The value to add.
   */
  public void addInLanguage(String inLanguage) {
  	this.inLanguage.add(inLanguage);
  }
  
  /**
   * Adds a interactionCount property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Adds a interactivityType property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param interactivityType The value to add.
   */
  public void addInteractivityType(String interactivityType) {
  	this.interactivityType.add(interactivityType);
  }
  
  /**
   * Adds a isBasedOnUrl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param isBasedOnUrl The value to add.
   */
  public void addIsBasedOnUrl(URL isBasedOnUrl) {
  	this.isBasedOnUrl.add(isBasedOnUrl);
  }
  
  /**
   * Adds a isFamilyFriendly property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param isFamilyFriendly The value to add.
   */
  public void addIsFamilyFriendly(Boolean isFamilyFriendly) {
  	this.isFamilyFriendly.add(isFamilyFriendly);
  }
  
  /**
   * Adds a keywords property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param keywords The value to add.
   */
  public void addKeywords(String keywords) {
  	this.keywords.add(keywords);
  }
  
  /**
   * Adds a learningResourceType property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param learningResourceType The value to add.
   */
  public void addLearningResourceType(String learningResourceType) {
  	this.learningResourceType.add(learningResourceType);
  }
  
  /**
   * Adds a mentions property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param mentions The value to add.
   */
  public void addMentions(Thing mentions) {
  	this.mentions.add(mentions);
  }
  
  /**
   * Adds a name property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offers property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers) {
  	this.offers.add(offers);
  }
  
  /**
   * Adds a provider property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
  	this.provider.add(provider);
  }
  
  /**
   * Adds a publisher property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param publisher The value to add.
   */
  public void addPublisher(Organization publisher) {
  	this.publisher.add(publisher);
  }
  
  /**
   * Adds a publishingPrinciples property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param publishingPrinciples The value to add.
   */
  public void addPublishingPrinciples(URL publishingPrinciples) {
  	this.publishingPrinciples.add(publishingPrinciples);
  }
  
  /**
   * Adds a review property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
  	this.review.add(review);
  }
  
  /**
   * Adds a sameAs property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a sourceOrganization property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param sourceOrganization The value to add.
   */
  public void addSourceOrganization(Organization sourceOrganization) {
  	this.sourceOrganization.add(sourceOrganization);
  }
  
  /**
   * Adds a text property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param text The value to add.
   */
  public void addText(String text) {
  	this.text.add(text);
  }
  
  /**
   * Adds a thumbnailUrl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param thumbnailUrl The value to add.
   */
  public void addThumbnailUrl(URL thumbnailUrl) {
  	this.thumbnailUrl.add(thumbnailUrl);
  }
  
  /**
   * Adds a timeRequired property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param timeRequired The value to add.
   */
  public void addTimeRequired(Duration timeRequired) {
  	this.timeRequired.add(timeRequired);
  }
  
  /**
   * Adds a typicalAgeRange property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param typicalAgeRange The value to add.
   */
  public void addTypicalAgeRange(String typicalAgeRange) {
  	this.typicalAgeRange.add(typicalAgeRange);
  }
  
  /**
   * Adds a url property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a version property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param version The value to add.
   */
  public void addVersion(Number version) {
  	this.version.add(version);
  }
  
  /**
   * Adds a video property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param video The value to add.
   */
  public void addVideo(VideoObject video) {
  	this.video.add(video);
  }
  
}