package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.BusinessEntityType;
import org.schema.BusinessFunction;
import org.schema.DeliveryMethod;
import org.schema.Demand;
import org.schema.ItemAvailability;
import org.schema.OfferItemCondition;
import org.schema.PaymentMethod;
import org.schema.Place;
import org.schema.PriceSpecification;
import org.schema.Product;
import org.schema.QuantitativeValue;
import org.schema.Thing;
import org.schema.TypeAndQuantityNode;
import org.schema.WarrantyPromise;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply.
 */
public class DemandImpl extends SchemaObjectImpl implements Demand {


  private ThingImpl thing;

  /**
   * The payment method(s) accepted by seller for this offer.
   */
  private List<PaymentMethod> acceptedPaymentMethod = new LinkedList<PaymentMethod>();
  
  /**
   * The amount of time that is required between accepting the offer and the actual usage of the resource or service.
   */
  private List<QuantitativeValue> advanceBookingRequirement = new LinkedList<QuantitativeValue>();
  
  /**
   * The availability of this item&#x2014;for example In stock, Out of stock, Pre-order, etc.
   */
  private List<ItemAvailability> availability = new LinkedList<ItemAvailability>();
  
  /**
   * The end of the availability of the product or service included in the offer.
   */
  private List<Date> availabilityEnds = new LinkedList<Date>();
  
  /**
   * The beginning of the availability of the product or service included in the offer.
   */
  private List<Date> availabilityStarts = new LinkedList<Date>();
  
  /**
   * The place(s) from which the offer can be obtained (e.g. store locations).
   */
  private List<Place> availableAtOrFrom = new LinkedList<Place>();
  
  /**
   * The delivery method(s) available for this offer.
   */
  private List<DeliveryMethod> availableDeliveryMethod = new LinkedList<DeliveryMethod>();
  
  /**
   * The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.
   */
  private List<BusinessFunction> businessFunction = new LinkedList<BusinessFunction>();
  
  /**
   * The typical delay between the receipt of the order and the goods leaving the warehouse.
   */
  private List<QuantitativeValue> deliveryLeadTime = new LinkedList<QuantitativeValue>();
  
  /**
   * The type(s) of customers for which the given offer is valid.
   */
  private List<BusinessEntityType> eligibleCustomerType = new LinkedList<BusinessEntityType>();
  
  /**
   * The duration for which the given offer is valid.
   */
  private List<QuantitativeValue> eligibleDuration = new LinkedList<QuantitativeValue>();
  
  /**
   * The interval and unit of measurement of ordering quantities for which the offer or price specification is valid. This allows e.g. specifying that a certain freight charge is valid only for a certain quantity.
   */
  private List<QuantitativeValue> eligibleQuantity = new LinkedList<QuantitativeValue>();
  
  /**
   * The ISO 3166-1 (ISO 3166-1 alpha-2) or ISO 3166-2 code, or the GeoShape for the geo-political region(s) for which the offer or delivery charge specification is valid.
   */
  private List<Thing> eligibleRegion = new LinkedList<Thing>();
  
  /**
   * The transaction volume, in a monetary unit, for which the offer or price specification is valid, e.g. for indicating a minimal purchasing volume, to express free shipping above a certain order volume, or to limit the acceptance of credit cards to purchases to a certain minimal amount.
   */
  private List<PriceSpecification> eligibleTransactionVolume = new LinkedList<PriceSpecification>();
  
  /**
   * The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceeding zero.
   */
  private List<String> gtin13 = new LinkedList<String>();
  
  /**
   * The GTIN-14 code of the product, or the product to which the offer refers.
   */
  private List<String> gtin14 = new LinkedList<String>();
  
  /**
   * The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN.
   */
  private List<String> gtin8 = new LinkedList<String>();
  
  /**
   * This links to a node or nodes indicating the exact quantity of the products included in the offer.
   */
  private List<TypeAndQuantityNode> includesObject = new LinkedList<TypeAndQuantityNode>();
  
  /**
   * The current approximate inventory level for the item or items.
   */
  private List<QuantitativeValue> inventoryLevel = new LinkedList<QuantitativeValue>();
  
  /**
   * A predefined value from OfferItemCondition or a textual description of the condition of the product or service, or the products or services included in the offer.
   */
  private List<OfferItemCondition> itemCondition = new LinkedList<OfferItemCondition>();
  
  /**
   * The item being offered.
   */
  private List<Product> itemOffered = new LinkedList<Product>();
  
  /**
   * The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
   */
  private List<String> mpn = new LinkedList<String>();
  
  /**
   * One or more detailed price specifications, indicating the unit price and delivery or payment charges.
   */
  private List<PriceSpecification> priceSpecification = new LinkedList<PriceSpecification>();
  
  /**
   * The organization or person making the offer.
   */
  private List<Thing> seller = new LinkedList<Thing>();
  
  /**
   * The serial number or any alphanumeric identifier of a particular product. When attached to an offer, it is a shortcut for the serial number of the product included in the offer.
   */
  private List<String> serialNumber = new LinkedList<String>();
  
  /**
   * The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
   */
  private List<String> sku = new LinkedList<String>();
  
  /**
   * The date when the item becomes valid.
   */
  private List<Date> validFrom = new LinkedList<Date>();
  
  /**
   * The end of the validity of offer, price specification, or opening hours data.
   */
  private List<Date> validThrough = new LinkedList<Date>();
  
  /**
   * The warranty promise(s) included in the offer.
   */
  private List<WarrantyPromise> warranty = new LinkedList<WarrantyPromise>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public DemandImpl() {
    super("http://schema.org/Demand");
  }
  /**
   * Get a single acceptedPaymentMethod property value for this Demand object.
   *
   * @return The first acceptedPaymentMethod property value.
   */
  public PaymentMethod getAcceptedPaymentMethod() {
  	return this.acceptedPaymentMethod.isEmpty() ? null : this.acceptedPaymentMethod.get(0);
  }
  
  /**
   * Get a single additionalType property value for this Demand object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single advanceBookingRequirement property value for this Demand object.
   *
   * @return The first advanceBookingRequirement property value.
   */
  public QuantitativeValue getAdvanceBookingRequirement() {
  	return this.advanceBookingRequirement.isEmpty() ? null : this.advanceBookingRequirement.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Demand object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single availability property value for this Demand object.
   *
   * @return The first availability property value.
   */
  public ItemAvailability getAvailability() {
  	return this.availability.isEmpty() ? null : this.availability.get(0);
  }
  
  /**
   * Get a single availabilityEnds property value for this Demand object.
   *
   * @return The first availabilityEnds property value.
   */
  public Date getAvailabilityEnds() {
  	return this.availabilityEnds.isEmpty() ? null : this.availabilityEnds.get(0);
  }
  
  /**
   * Get a single availabilityStarts property value for this Demand object.
   *
   * @return The first availabilityStarts property value.
   */
  public Date getAvailabilityStarts() {
  	return this.availabilityStarts.isEmpty() ? null : this.availabilityStarts.get(0);
  }
  
  /**
   * Get a single availableAtOrFrom property value for this Demand object.
   *
   * @return The first availableAtOrFrom property value.
   */
  public Place getAvailableAtOrFrom() {
  	return this.availableAtOrFrom.isEmpty() ? null : this.availableAtOrFrom.get(0);
  }
  
  /**
   * Get a single availableDeliveryMethod property value for this Demand object.
   *
   * @return The first availableDeliveryMethod property value.
   */
  public DeliveryMethod getAvailableDeliveryMethod() {
  	return this.availableDeliveryMethod.isEmpty() ? null : this.availableDeliveryMethod.get(0);
  }
  
  /**
   * Get a single businessFunction property value for this Demand object.
   *
   * @return The first businessFunction property value.
   */
  public BusinessFunction getBusinessFunction() {
  	return this.businessFunction.isEmpty() ? null : this.businessFunction.get(0);
  }
  
  /**
   * Get a single deliveryLeadTime property value for this Demand object.
   *
   * @return The first deliveryLeadTime property value.
   */
  public QuantitativeValue getDeliveryLeadTime() {
  	return this.deliveryLeadTime.isEmpty() ? null : this.deliveryLeadTime.get(0);
  }
  
  /**
   * Get a single description property value for this Demand object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single eligibleCustomerType property value for this Demand object.
   *
   * @return The first eligibleCustomerType property value.
   */
  public BusinessEntityType getEligibleCustomerType() {
  	return this.eligibleCustomerType.isEmpty() ? null : this.eligibleCustomerType.get(0);
  }
  
  /**
   * Get a single eligibleDuration property value for this Demand object.
   *
   * @return The first eligibleDuration property value.
   */
  public QuantitativeValue getEligibleDuration() {
  	return this.eligibleDuration.isEmpty() ? null : this.eligibleDuration.get(0);
  }
  
  /**
   * Get a single eligibleQuantity property value for this Demand object.
   *
   * @return The first eligibleQuantity property value.
   */
  public QuantitativeValue getEligibleQuantity() {
  	return this.eligibleQuantity.isEmpty() ? null : this.eligibleQuantity.get(0);
  }
  
  /**
   * Get a single eligibleRegion property value for this Demand object.
   *
   * @return The first eligibleRegion property value.
   */
  public Thing getEligibleRegion() {
  	return this.eligibleRegion.isEmpty() ? null : this.eligibleRegion.get(0);
  }
  
  /**
   * Get a single eligibleTransactionVolume property value for this Demand object.
   *
   * @return The first eligibleTransactionVolume property value.
   */
  public PriceSpecification getEligibleTransactionVolume() {
  	return this.eligibleTransactionVolume.isEmpty() ? null : this.eligibleTransactionVolume.get(0);
  }
  
  /**
   * Get a single gtin13 property value for this Demand object.
   *
   * @return The first gtin13 property value.
   */
  public String getGtin13() {
  	return this.gtin13.isEmpty() ? null : this.gtin13.get(0);
  }
  
  /**
   * Get a single gtin14 property value for this Demand object.
   *
   * @return The first gtin14 property value.
   */
  public String getGtin14() {
  	return this.gtin14.isEmpty() ? null : this.gtin14.get(0);
  }
  
  /**
   * Get a single gtin8 property value for this Demand object.
   *
   * @return The first gtin8 property value.
   */
  public String getGtin8() {
  	return this.gtin8.isEmpty() ? null : this.gtin8.get(0);
  }
  
  /**
   * Get a single image property value for this Demand object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single includesObject property value for this Demand object.
   *
   * @return The first includesObject property value.
   */
  public TypeAndQuantityNode getIncludesObject() {
  	return this.includesObject.isEmpty() ? null : this.includesObject.get(0);
  }
  
  /**
   * Get a single inventoryLevel property value for this Demand object.
   *
   * @return The first inventoryLevel property value.
   */
  public QuantitativeValue getInventoryLevel() {
  	return this.inventoryLevel.isEmpty() ? null : this.inventoryLevel.get(0);
  }
  
  /**
   * Get a single itemCondition property value for this Demand object.
   *
   * @return The first itemCondition property value.
   */
  public OfferItemCondition getItemCondition() {
  	return this.itemCondition.isEmpty() ? null : this.itemCondition.get(0);
  }
  
  /**
   * Get a single itemOffered property value for this Demand object.
   *
   * @return The first itemOffered property value.
   */
  public Product getItemOffered() {
  	return this.itemOffered.isEmpty() ? null : this.itemOffered.get(0);
  }
  
  /**
   * Get a single mpn property value for this Demand object.
   *
   * @return The first mpn property value.
   */
  public String getMpn() {
  	return this.mpn.isEmpty() ? null : this.mpn.get(0);
  }
  
  /**
   * Get a single name property value for this Demand object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single priceSpecification property value for this Demand object.
   *
   * @return The first priceSpecification property value.
   */
  public PriceSpecification getPriceSpecification() {
  	return this.priceSpecification.isEmpty() ? null : this.priceSpecification.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Demand object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seller property value for this Demand object.
   *
   * @return The first seller property value.
   */
  public Thing getSeller() {
  	return this.seller.isEmpty() ? null : this.seller.get(0);
  }
  
  /**
   * Get a single serialNumber property value for this Demand object.
   *
   * @return The first serialNumber property value.
   */
  public String getSerialNumber() {
  	return this.serialNumber.isEmpty() ? null : this.serialNumber.get(0);
  }
  
  /**
   * Get a single sku property value for this Demand object.
   *
   * @return The first sku property value.
   */
  public String getSku() {
  	return this.sku.isEmpty() ? null : this.sku.get(0);
  }
  
  /**
   * Get a single url property value for this Demand object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single validFrom property value for this Demand object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom() {
  	return this.validFrom.isEmpty() ? null : this.validFrom.get(0);
  }
  
  /**
   * Get a single validThrough property value for this Demand object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough() {
  	return this.validThrough.isEmpty() ? null : this.validThrough.get(0);
  }
  
  /**
   * Get a single warranty property value for this Demand object.
   *
   * @return The first warranty property value.
   */
  public WarrantyPromise getWarranty() {
  	return this.warranty.isEmpty() ? null : this.warranty.get(0);
  }
  
  /**
   * Get all the acceptedPaymentMethod property values for this Demand object.
   *
   * @return A list of acceptedPaymentMethod property values.
   */
  public List<PaymentMethod> getAcceptedPaymentMethods() {
  	return this.acceptedPaymentMethod;
  }
  
  /**
   * Get all the additionalType property values for this Demand object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the advanceBookingRequirement property values for this Demand object.
   *
   * @return A list of advanceBookingRequirement property values.
   */
  public List<QuantitativeValue> getAdvanceBookingRequirements() {
  	return this.advanceBookingRequirement;
  }
  
  /**
   * Get all the alternateName property values for this Demand object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the availability property values for this Demand object.
   *
   * @return A list of availability property values.
   */
  public List<ItemAvailability> getAvailabilities() {
  	return this.availability;
  }
  
  /**
   * Get all the availabilityEnds property values for this Demand object.
   *
   * @return A list of availabilityEnds property values.
   */
  public List<Date> getAvailabilityEndss() {
  	return this.availabilityEnds;
  }
  
  /**
   * Get all the availabilityStarts property values for this Demand object.
   *
   * @return A list of availabilityStarts property values.
   */
  public List<Date> getAvailabilityStartss() {
  	return this.availabilityStarts;
  }
  
  /**
   * Get all the availableAtOrFrom property values for this Demand object.
   *
   * @return A list of availableAtOrFrom property values.
   */
  public List<Place> getAvailableAtOrFroms() {
  	return this.availableAtOrFrom;
  }
  
  /**
   * Get all the availableDeliveryMethod property values for this Demand object.
   *
   * @return A list of availableDeliveryMethod property values.
   */
  public List<DeliveryMethod> getAvailableDeliveryMethods() {
  	return this.availableDeliveryMethod;
  }
  
  /**
   * Get all the businessFunction property values for this Demand object.
   *
   * @return A list of businessFunction property values.
   */
  public List<BusinessFunction> getBusinessFunctions() {
  	return this.businessFunction;
  }
  
  /**
   * Get all the deliveryLeadTime property values for this Demand object.
   *
   * @return A list of deliveryLeadTime property values.
   */
  public List<QuantitativeValue> getDeliveryLeadTimes() {
  	return this.deliveryLeadTime;
  }
  
  /**
   * Get all the description property values for this Demand object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the eligibleCustomerType property values for this Demand object.
   *
   * @return A list of eligibleCustomerType property values.
   */
  public List<BusinessEntityType> getEligibleCustomerTypes() {
  	return this.eligibleCustomerType;
  }
  
  /**
   * Get all the eligibleDuration property values for this Demand object.
   *
   * @return A list of eligibleDuration property values.
   */
  public List<QuantitativeValue> getEligibleDurations() {
  	return this.eligibleDuration;
  }
  
  /**
   * Get all the eligibleQuantity property values for this Demand object.
   *
   * @return A list of eligibleQuantity property values.
   */
  public List<QuantitativeValue> getEligibleQuantities() {
  	return this.eligibleQuantity;
  }
  
  /**
   * Get all the eligibleRegion property values for this Demand object.
   *
   * @return A list of eligibleRegion property values.
   */
  public List<Thing> getEligibleRegions() {
  	return this.eligibleRegion;
  }
  
  /**
   * Get all the eligibleTransactionVolume property values for this Demand object.
   *
   * @return A list of eligibleTransactionVolume property values.
   */
  public List<PriceSpecification> getEligibleTransactionVolumes() {
  	return this.eligibleTransactionVolume;
  }
  
  /**
   * Get all the gtin13 property values for this Demand object.
   *
   * @return A list of gtin13 property values.
   */
  public List<String> getGtin13s() {
  	return this.gtin13;
  }
  
  /**
   * Get all the gtin14 property values for this Demand object.
   *
   * @return A list of gtin14 property values.
   */
  public List<String> getGtin14s() {
  	return this.gtin14;
  }
  
  /**
   * Get all the gtin8 property values for this Demand object.
   *
   * @return A list of gtin8 property values.
   */
  public List<String> getGtin8s() {
  	return this.gtin8;
  }
  
  /**
   * Get all the image property values for this Demand object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the includesObject property values for this Demand object.
   *
   * @return A list of includesObject property values.
   */
  public List<TypeAndQuantityNode> getIncludesObjects() {
  	return this.includesObject;
  }
  
  /**
   * Get all the inventoryLevel property values for this Demand object.
   *
   * @return A list of inventoryLevel property values.
   */
  public List<QuantitativeValue> getInventoryLevels() {
  	return this.inventoryLevel;
  }
  
  /**
   * Get all the itemCondition property values for this Demand object.
   *
   * @return A list of itemCondition property values.
   */
  public List<OfferItemCondition> getItemConditions() {
  	return this.itemCondition;
  }
  
  /**
   * Get all the itemOffered property values for this Demand object.
   *
   * @return A list of itemOffered property values.
   */
  public List<Product> getItemOffereds() {
  	return this.itemOffered;
  }
  
  /**
   * Get all the mpn property values for this Demand object.
   *
   * @return A list of mpn property values.
   */
  public List<String> getMpns() {
  	return this.mpn;
  }
  
  /**
   * Get all the name property values for this Demand object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the priceSpecification property values for this Demand object.
   *
   * @return A list of priceSpecification property values.
   */
  public List<PriceSpecification> getPriceSpecifications() {
  	return this.priceSpecification;
  }
  
  /**
   * Get all the sameAs property values for this Demand object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seller property values for this Demand object.
   *
   * @return A list of seller property values.
   */
  public List<Thing> getSellers() {
  	return this.seller;
  }
  
  /**
   * Get all the serialNumber property values for this Demand object.
   *
   * @return A list of serialNumber property values.
   */
  public List<String> getSerialNumbers() {
  	return this.serialNumber;
  }
  
  /**
   * Get all the sku property values for this Demand object.
   *
   * @return A list of sku property values.
   */
  public List<String> getSkus() {
  	return this.sku;
  }
  
  /**
   * Get all the url property values for this Demand object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the validFrom property values for this Demand object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms() {
  	return this.validFrom;
  }
  
  /**
   * Get all the validThrough property values for this Demand object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs() {
  	return this.validThrough;
  }
  
  /**
   * Get all the warranty property values for this Demand object.
   *
   * @return A list of warranty property values.
   */
  public List<WarrantyPromise> getWarranties() {
  	return this.warranty;
  }
  
  /**
   * Set the acceptedPaymentMethod property value for this Demand object; overwriting any existing values.
   *
   * @param acceptedPaymentMethod The value to set.
   */
  public void setAcceptedPaymentMethod(PaymentMethod acceptedPaymentMethod) {
  	this.acceptedPaymentMethod.clear();
  	this.acceptedPaymentMethod.add(acceptedPaymentMethod);
  }
  
  /**
   * Set the additionalType property value for this Demand object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the advanceBookingRequirement property value for this Demand object; overwriting any existing values.
   *
   * @param advanceBookingRequirement The value to set.
   */
  public void setAdvanceBookingRequirement(QuantitativeValue advanceBookingRequirement) {
  	this.advanceBookingRequirement.clear();
  	this.advanceBookingRequirement.add(advanceBookingRequirement);
  }
  
  /**
   * Set the alternateName property value for this Demand object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the availability property value for this Demand object; overwriting any existing values.
   *
   * @param availability The value to set.
   */
  public void setAvailability(ItemAvailability availability) {
  	this.availability.clear();
  	this.availability.add(availability);
  }
  
  /**
   * Set the availabilityEnds property value for this Demand object; overwriting any existing values.
   *
   * @param availabilityEnds The value to set.
   */
  public void setAvailabilityEnds(Date availabilityEnds) {
  	this.availabilityEnds.clear();
  	this.availabilityEnds.add(availabilityEnds);
  }
  
  /**
   * Set the availabilityStarts property value for this Demand object; overwriting any existing values.
   *
   * @param availabilityStarts The value to set.
   */
  public void setAvailabilityStarts(Date availabilityStarts) {
  	this.availabilityStarts.clear();
  	this.availabilityStarts.add(availabilityStarts);
  }
  
  /**
   * Set the availableAtOrFrom property value for this Demand object; overwriting any existing values.
   *
   * @param availableAtOrFrom The value to set.
   */
  public void setAvailableAtOrFrom(Place availableAtOrFrom) {
  	this.availableAtOrFrom.clear();
  	this.availableAtOrFrom.add(availableAtOrFrom);
  }
  
  /**
   * Set the availableDeliveryMethod property value for this Demand object; overwriting any existing values.
   *
   * @param availableDeliveryMethod The value to set.
   */
  public void setAvailableDeliveryMethod(DeliveryMethod availableDeliveryMethod) {
  	this.availableDeliveryMethod.clear();
  	this.availableDeliveryMethod.add(availableDeliveryMethod);
  }
  
  /**
   * Set the businessFunction property value for this Demand object; overwriting any existing values.
   *
   * @param businessFunction The value to set.
   */
  public void setBusinessFunction(BusinessFunction businessFunction) {
  	this.businessFunction.clear();
  	this.businessFunction.add(businessFunction);
  }
  
  /**
   * Set the deliveryLeadTime property value for this Demand object; overwriting any existing values.
   *
   * @param deliveryLeadTime The value to set.
   */
  public void setDeliveryLeadTime(QuantitativeValue deliveryLeadTime) {
  	this.deliveryLeadTime.clear();
  	this.deliveryLeadTime.add(deliveryLeadTime);
  }
  
  /**
   * Set the description property value for this Demand object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the eligibleCustomerType property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleCustomerType The value to set.
   */
  public void setEligibleCustomerType(BusinessEntityType eligibleCustomerType) {
  	this.eligibleCustomerType.clear();
  	this.eligibleCustomerType.add(eligibleCustomerType);
  }
  
  /**
   * Set the eligibleDuration property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleDuration The value to set.
   */
  public void setEligibleDuration(QuantitativeValue eligibleDuration) {
  	this.eligibleDuration.clear();
  	this.eligibleDuration.add(eligibleDuration);
  }
  
  /**
   * Set the eligibleQuantity property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleQuantity The value to set.
   */
  public void setEligibleQuantity(QuantitativeValue eligibleQuantity) {
  	this.eligibleQuantity.clear();
  	this.eligibleQuantity.add(eligibleQuantity);
  }
  
  /**
   * Set the eligibleRegion property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleRegion The value to set.
   */
  public void setEligibleRegion(Thing eligibleRegion) {
  	this.eligibleRegion.clear();
  	this.eligibleRegion.add(eligibleRegion);
  }
  
  /**
   * Set the eligibleTransactionVolume property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleTransactionVolume The value to set.
   */
  public void setEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
  	this.eligibleTransactionVolume.clear();
  	this.eligibleTransactionVolume.add(eligibleTransactionVolume);
  }
  
  /**
   * Set the gtin13 property value for this Demand object; overwriting any existing values.
   *
   * @param gtin13 The value to set.
   */
  public void setGtin13(String gtin13) {
  	this.gtin13.clear();
  	this.gtin13.add(gtin13);
  }
  
  /**
   * Set the gtin14 property value for this Demand object; overwriting any existing values.
   *
   * @param gtin14 The value to set.
   */
  public void setGtin14(String gtin14) {
  	this.gtin14.clear();
  	this.gtin14.add(gtin14);
  }
  
  /**
   * Set the gtin8 property value for this Demand object; overwriting any existing values.
   *
   * @param gtin8 The value to set.
   */
  public void setGtin8(String gtin8) {
  	this.gtin8.clear();
  	this.gtin8.add(gtin8);
  }
  
  /**
   * Set the image property value for this Demand object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the includesObject property value for this Demand object; overwriting any existing values.
   *
   * @param includesObject The value to set.
   */
  public void setIncludesObject(TypeAndQuantityNode includesObject) {
  	this.includesObject.clear();
  	this.includesObject.add(includesObject);
  }
  
  /**
   * Set the inventoryLevel property value for this Demand object; overwriting any existing values.
   *
   * @param inventoryLevel The value to set.
   */
  public void setInventoryLevel(QuantitativeValue inventoryLevel) {
  	this.inventoryLevel.clear();
  	this.inventoryLevel.add(inventoryLevel);
  }
  
  /**
   * Set the itemCondition property value for this Demand object; overwriting any existing values.
   *
   * @param itemCondition The value to set.
   */
  public void setItemCondition(OfferItemCondition itemCondition) {
  	this.itemCondition.clear();
  	this.itemCondition.add(itemCondition);
  }
  
  /**
   * Set the itemOffered property value for this Demand object; overwriting any existing values.
   *
   * @param itemOffered The value to set.
   */
  public void setItemOffered(Product itemOffered) {
  	this.itemOffered.clear();
  	this.itemOffered.add(itemOffered);
  }
  
  /**
   * Set the mpn property value for this Demand object; overwriting any existing values.
   *
   * @param mpn The value to set.
   */
  public void setMpn(String mpn) {
  	this.mpn.clear();
  	this.mpn.add(mpn);
  }
  
  /**
   * Set the name property value for this Demand object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the priceSpecification property value for this Demand object; overwriting any existing values.
   *
   * @param priceSpecification The value to set.
   */
  public void setPriceSpecification(PriceSpecification priceSpecification) {
  	this.priceSpecification.clear();
  	this.priceSpecification.add(priceSpecification);
  }
  
  /**
   * Set the sameAs property value for this Demand object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seller property value for this Demand object; overwriting any existing values.
   *
   * @param seller The value to set.
   */
  public void setSeller(Thing seller) {
  	this.seller.clear();
  	this.seller.add(seller);
  }
  
  /**
   * Set the serialNumber property value for this Demand object; overwriting any existing values.
   *
   * @param serialNumber The value to set.
   */
  public void setSerialNumber(String serialNumber) {
  	this.serialNumber.clear();
  	this.serialNumber.add(serialNumber);
  }
  
  /**
   * Set the sku property value for this Demand object; overwriting any existing values.
   *
   * @param sku The value to set.
   */
  public void setSku(String sku) {
  	this.sku.clear();
  	this.sku.add(sku);
  }
  
  /**
   * Set the url property value for this Demand object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the validFrom property value for this Demand object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom) {
  	this.validFrom.clear();
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Set the validThrough property value for this Demand object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough) {
  	this.validThrough.clear();
  	this.validThrough.add(validThrough);
  }
  
  /**
   * Set the warranty property value for this Demand object; overwriting any existing values.
   *
   * @param warranty The value to set.
   */
  public void setWarranty(WarrantyPromise warranty) {
  	this.warranty.clear();
  	this.warranty.add(warranty);
  }
  
  /**
   * Set the acceptedPaymentMethod property values for this Demand object; overwriting any existing values.
   *
   * @param acceptedPaymentMethods The list of values to set.
   */
  public void setAcceptedPaymentMethods(List<PaymentMethod> acceptedPaymentMethods) {
  	this.acceptedPaymentMethod = acceptedPaymentMethods;
  }
  
  /**
   * Set the additionalType property values for this Demand object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the advanceBookingRequirement property values for this Demand object; overwriting any existing values.
   *
   * @param advanceBookingRequirements The list of values to set.
   */
  public void setAdvanceBookingRequirements(List<QuantitativeValue> advanceBookingRequirements) {
  	this.advanceBookingRequirement = advanceBookingRequirements;
  }
  
  /**
   * Set the alternateName property values for this Demand object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the availability property values for this Demand object; overwriting any existing values.
   *
   * @param availabilities The list of values to set.
   */
  public void setAvailabilities(List<ItemAvailability> availabilities) {
  	this.availability = availabilities;
  }
  
  /**
   * Set the availabilityEnds property values for this Demand object; overwriting any existing values.
   *
   * @param availabilityEndss The list of values to set.
   */
  public void setAvailabilityEndss(List<Date> availabilityEndss) {
  	this.availabilityEnds = availabilityEndss;
  }
  
  /**
   * Set the availabilityStarts property values for this Demand object; overwriting any existing values.
   *
   * @param availabilityStartss The list of values to set.
   */
  public void setAvailabilityStartss(List<Date> availabilityStartss) {
  	this.availabilityStarts = availabilityStartss;
  }
  
  /**
   * Set the availableAtOrFrom property values for this Demand object; overwriting any existing values.
   *
   * @param availableAtOrFroms The list of values to set.
   */
  public void setAvailableAtOrFroms(List<Place> availableAtOrFroms) {
  	this.availableAtOrFrom = availableAtOrFroms;
  }
  
  /**
   * Set the availableDeliveryMethod property values for this Demand object; overwriting any existing values.
   *
   * @param availableDeliveryMethods The list of values to set.
   */
  public void setAvailableDeliveryMethods(List<DeliveryMethod> availableDeliveryMethods) {
  	this.availableDeliveryMethod = availableDeliveryMethods;
  }
  
  /**
   * Set the businessFunction property values for this Demand object; overwriting any existing values.
   *
   * @param businessFunctions The list of values to set.
   */
  public void setBusinessFunctions(List<BusinessFunction> businessFunctions) {
  	this.businessFunction = businessFunctions;
  }
  
  /**
   * Set the deliveryLeadTime property values for this Demand object; overwriting any existing values.
   *
   * @param deliveryLeadTimes The list of values to set.
   */
  public void setDeliveryLeadTimes(List<QuantitativeValue> deliveryLeadTimes) {
  	this.deliveryLeadTime = deliveryLeadTimes;
  }
  
  /**
   * Set the description property values for this Demand object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the eligibleCustomerType property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleCustomerTypes The list of values to set.
   */
  public void setEligibleCustomerTypes(List<BusinessEntityType> eligibleCustomerTypes) {
  	this.eligibleCustomerType = eligibleCustomerTypes;
  }
  
  /**
   * Set the eligibleDuration property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleDurations The list of values to set.
   */
  public void setEligibleDurations(List<QuantitativeValue> eligibleDurations) {
  	this.eligibleDuration = eligibleDurations;
  }
  
  /**
   * Set the eligibleQuantity property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleQuantities The list of values to set.
   */
  public void setEligibleQuantities(List<QuantitativeValue> eligibleQuantities) {
  	this.eligibleQuantity = eligibleQuantities;
  }
  
  /**
   * Set the eligibleRegion property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleRegions The list of values to set.
   */
  public void setEligibleRegions(List<Thing> eligibleRegions) {
  	this.eligibleRegion = eligibleRegions;
  }
  
  /**
   * Set the eligibleTransactionVolume property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleTransactionVolumes The list of values to set.
   */
  public void setEligibleTransactionVolumes(List<PriceSpecification> eligibleTransactionVolumes) {
  	this.eligibleTransactionVolume = eligibleTransactionVolumes;
  }
  
  /**
   * Set the gtin13 property values for this Demand object; overwriting any existing values.
   *
   * @param gtin13s The list of values to set.
   */
  public void setGtin13s(List<String> gtin13s) {
  	this.gtin13 = gtin13s;
  }
  
  /**
   * Set the gtin14 property values for this Demand object; overwriting any existing values.
   *
   * @param gtin14s The list of values to set.
   */
  public void setGtin14s(List<String> gtin14s) {
  	this.gtin14 = gtin14s;
  }
  
  /**
   * Set the gtin8 property values for this Demand object; overwriting any existing values.
   *
   * @param gtin8s The list of values to set.
   */
  public void setGtin8s(List<String> gtin8s) {
  	this.gtin8 = gtin8s;
  }
  
  /**
   * Set the image property values for this Demand object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the includesObject property values for this Demand object; overwriting any existing values.
   *
   * @param includesObjects The list of values to set.
   */
  public void setIncludesObjects(List<TypeAndQuantityNode> includesObjects) {
  	this.includesObject = includesObjects;
  }
  
  /**
   * Set the inventoryLevel property values for this Demand object; overwriting any existing values.
   *
   * @param inventoryLevels The list of values to set.
   */
  public void setInventoryLevels(List<QuantitativeValue> inventoryLevels) {
  	this.inventoryLevel = inventoryLevels;
  }
  
  /**
   * Set the itemCondition property values for this Demand object; overwriting any existing values.
   *
   * @param itemConditions The list of values to set.
   */
  public void setItemConditions(List<OfferItemCondition> itemConditions) {
  	this.itemCondition = itemConditions;
  }
  
  /**
   * Set the itemOffered property values for this Demand object; overwriting any existing values.
   *
   * @param itemOffereds The list of values to set.
   */
  public void setItemOffereds(List<Product> itemOffereds) {
  	this.itemOffered = itemOffereds;
  }
  
  /**
   * Set the mpn property values for this Demand object; overwriting any existing values.
   *
   * @param mpns The list of values to set.
   */
  public void setMpns(List<String> mpns) {
  	this.mpn = mpns;
  }
  
  /**
   * Set the name property values for this Demand object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the priceSpecification property values for this Demand object; overwriting any existing values.
   *
   * @param priceSpecifications The list of values to set.
   */
  public void setPriceSpecifications(List<PriceSpecification> priceSpecifications) {
  	this.priceSpecification = priceSpecifications;
  }
  
  /**
   * Set the sameAs property values for this Demand object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seller property values for this Demand object; overwriting any existing values.
   *
   * @param sellers The list of values to set.
   */
  public void setSellers(List<Thing> sellers) {
  	this.seller = sellers;
  }
  
  /**
   * Set the serialNumber property values for this Demand object; overwriting any existing values.
   *
   * @param serialNumbers The list of values to set.
   */
  public void setSerialNumbers(List<String> serialNumbers) {
  	this.serialNumber = serialNumbers;
  }
  
  /**
   * Set the sku property values for this Demand object; overwriting any existing values.
   *
   * @param skus The list of values to set.
   */
  public void setSkus(List<String> skus) {
  	this.sku = skus;
  }
  
  /**
   * Set the url property values for this Demand object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the validFrom property values for this Demand object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms) {
  	this.validFrom = validFroms;
  }
  
  /**
   * Set the validThrough property values for this Demand object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs) {
  	this.validThrough = validThroughs;
  }
  
  /**
   * Set the warranty property values for this Demand object; overwriting any existing values.
   *
   * @param warranties The list of values to set.
   */
  public void setWarranties(List<WarrantyPromise> warranties) {
  	this.warranty = warranties;
  }
  
  /**
   * Adds a acceptedPaymentMethod property value for this Demand object; appending it to the list of existing values.
   *
   * @param acceptedPaymentMethod The value to add.
   */
  public void addAcceptedPaymentMethod(PaymentMethod acceptedPaymentMethod) {
  	this.acceptedPaymentMethod.add(acceptedPaymentMethod);
  }
  
  /**
   * Adds a additionalType property value for this Demand object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a advanceBookingRequirement property value for this Demand object; appending it to the list of existing values.
   *
   * @param advanceBookingRequirement The value to add.
   */
  public void addAdvanceBookingRequirement(QuantitativeValue advanceBookingRequirement) {
  	this.advanceBookingRequirement.add(advanceBookingRequirement);
  }
  
  /**
   * Adds a alternateName property value for this Demand object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a availability property value for this Demand object; appending it to the list of existing values.
   *
   * @param availability The value to add.
   */
  public void addAvailability(ItemAvailability availability) {
  	this.availability.add(availability);
  }
  
  /**
   * Adds a availabilityEnds property value for this Demand object; appending it to the list of existing values.
   *
   * @param availabilityEnds The value to add.
   */
  public void addAvailabilityEnds(Date availabilityEnds) {
  	this.availabilityEnds.add(availabilityEnds);
  }
  
  /**
   * Adds a availabilityStarts property value for this Demand object; appending it to the list of existing values.
   *
   * @param availabilityStarts The value to add.
   */
  public void addAvailabilityStarts(Date availabilityStarts) {
  	this.availabilityStarts.add(availabilityStarts);
  }
  
  /**
   * Adds a availableAtOrFrom property value for this Demand object; appending it to the list of existing values.
   *
   * @param availableAtOrFrom The value to add.
   */
  public void addAvailableAtOrFrom(Place availableAtOrFrom) {
  	this.availableAtOrFrom.add(availableAtOrFrom);
  }
  
  /**
   * Adds a availableDeliveryMethod property value for this Demand object; appending it to the list of existing values.
   *
   * @param availableDeliveryMethod The value to add.
   */
  public void addAvailableDeliveryMethod(DeliveryMethod availableDeliveryMethod) {
  	this.availableDeliveryMethod.add(availableDeliveryMethod);
  }
  
  /**
   * Adds a businessFunction property value for this Demand object; appending it to the list of existing values.
   *
   * @param businessFunction The value to add.
   */
  public void addBusinessFunction(BusinessFunction businessFunction) {
  	this.businessFunction.add(businessFunction);
  }
  
  /**
   * Adds a deliveryLeadTime property value for this Demand object; appending it to the list of existing values.
   *
   * @param deliveryLeadTime The value to add.
   */
  public void addDeliveryLeadTime(QuantitativeValue deliveryLeadTime) {
  	this.deliveryLeadTime.add(deliveryLeadTime);
  }
  
  /**
   * Adds a description property value for this Demand object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a eligibleCustomerType property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleCustomerType The value to add.
   */
  public void addEligibleCustomerType(BusinessEntityType eligibleCustomerType) {
  	this.eligibleCustomerType.add(eligibleCustomerType);
  }
  
  /**
   * Adds a eligibleDuration property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleDuration The value to add.
   */
  public void addEligibleDuration(QuantitativeValue eligibleDuration) {
  	this.eligibleDuration.add(eligibleDuration);
  }
  
  /**
   * Adds a eligibleQuantity property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleQuantity The value to add.
   */
  public void addEligibleQuantity(QuantitativeValue eligibleQuantity) {
  	this.eligibleQuantity.add(eligibleQuantity);
  }
  
  /**
   * Adds a eligibleRegion property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleRegion The value to add.
   */
  public void addEligibleRegion(Thing eligibleRegion) {
  	this.eligibleRegion.add(eligibleRegion);
  }
  
  /**
   * Adds a eligibleTransactionVolume property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleTransactionVolume The value to add.
   */
  public void addEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
  	this.eligibleTransactionVolume.add(eligibleTransactionVolume);
  }
  
  /**
   * Adds a gtin13 property value for this Demand object; appending it to the list of existing values.
   *
   * @param gtin13 The value to add.
   */
  public void addGtin13(String gtin13) {
  	this.gtin13.add(gtin13);
  }
  
  /**
   * Adds a gtin14 property value for this Demand object; appending it to the list of existing values.
   *
   * @param gtin14 The value to add.
   */
  public void addGtin14(String gtin14) {
  	this.gtin14.add(gtin14);
  }
  
  /**
   * Adds a gtin8 property value for this Demand object; appending it to the list of existing values.
   *
   * @param gtin8 The value to add.
   */
  public void addGtin8(String gtin8) {
  	this.gtin8.add(gtin8);
  }
  
  /**
   * Adds a image property value for this Demand object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a includesObject property value for this Demand object; appending it to the list of existing values.
   *
   * @param includesObject The value to add.
   */
  public void addIncludesObject(TypeAndQuantityNode includesObject) {
  	this.includesObject.add(includesObject);
  }
  
  /**
   * Adds a inventoryLevel property value for this Demand object; appending it to the list of existing values.
   *
   * @param inventoryLevel The value to add.
   */
  public void addInventoryLevel(QuantitativeValue inventoryLevel) {
  	this.inventoryLevel.add(inventoryLevel);
  }
  
  /**
   * Adds a itemCondition property value for this Demand object; appending it to the list of existing values.
   *
   * @param itemCondition The value to add.
   */
  public void addItemCondition(OfferItemCondition itemCondition) {
  	this.itemCondition.add(itemCondition);
  }
  
  /**
   * Adds a itemOffered property value for this Demand object; appending it to the list of existing values.
   *
   * @param itemOffered The value to add.
   */
  public void addItemOffered(Product itemOffered) {
  	this.itemOffered.add(itemOffered);
  }
  
  /**
   * Adds a mpn property value for this Demand object; appending it to the list of existing values.
   *
   * @param mpn The value to add.
   */
  public void addMpn(String mpn) {
  	this.mpn.add(mpn);
  }
  
  /**
   * Adds a name property value for this Demand object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a priceSpecification property value for this Demand object; appending it to the list of existing values.
   *
   * @param priceSpecification The value to add.
   */
  public void addPriceSpecification(PriceSpecification priceSpecification) {
  	this.priceSpecification.add(priceSpecification);
  }
  
  /**
   * Adds a sameAs property value for this Demand object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seller property value for this Demand object; appending it to the list of existing values.
   *
   * @param seller The value to add.
   */
  public void addSeller(Thing seller) {
  	this.seller.add(seller);
  }
  
  /**
   * Adds a serialNumber property value for this Demand object; appending it to the list of existing values.
   *
   * @param serialNumber The value to add.
   */
  public void addSerialNumber(String serialNumber) {
  	this.serialNumber.add(serialNumber);
  }
  
  /**
   * Adds a sku property value for this Demand object; appending it to the list of existing values.
   *
   * @param sku The value to add.
   */
  public void addSku(String sku) {
  	this.sku.add(sku);
  }
  
  /**
   * Adds a url property value for this Demand object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a validFrom property value for this Demand object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom) {
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Adds a validThrough property value for this Demand object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough) {
  	this.validThrough.add(validThrough);
  }
  
  /**
   * Adds a warranty property value for this Demand object; appending it to the list of existing values.
   *
   * @param warranty The value to add.
   */
  public void addWarranty(WarrantyPromise warranty) {
  	this.warranty.add(warranty);
  }
  
}