package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.DietarySupplement;
import org.schema.DrugLegalStatus;
import org.schema.MaximumDoseSchedule;
import org.schema.MedicalCode;
import org.schema.MedicalContraindication;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalIndication;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.RecommendedDoseSchedule;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites.
 */
public class DietarySupplementImpl extends SchemaObjectImpl implements DietarySupplement {


  private MedicalEntityImpl medicalEntity;
  private MedicalTherapyImpl medicalTherapy;
  private ThingImpl thing;

  /**
   * An active ingredient, typically chemical compounds and/or biologic substances.
   */
  private List<String> activeIngredient = new LinkedList<String>();
  
  /**
   * Descriptive information establishing a historical perspective on the supplement. May include the rationale for the name, the population where the supplement first came to prominence, etc.
   */
  private List<String> background = new LinkedList<String>();
  
  /**
   * A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'.
   */
  private List<String> dosageForm = new LinkedList<String>();
  
  /**
   * True if this item's name is a proprietary/brand name (vs. generic name).
   */
  private List<Boolean> isProprietary = new LinkedList<Boolean>();
  
  /**
   * The drug or supplement's legal status, including any controlled substance schedules that apply.
   */
  private List<DrugLegalStatus> legalStatus = new LinkedList<DrugLegalStatus>();
  
  /**
   * The manufacturer of the product.
   */
  private List<Organization> manufacturer = new LinkedList<Organization>();
  
  /**
   * Recommended intake of this supplement for a given population as defined by a specific recommending authority.
   */
  private List<MaximumDoseSchedule> maximumIntake = new LinkedList<MaximumDoseSchedule>();
  
  /**
   * The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
   */
  private List<String> mechanismOfAction = new LinkedList<String>();
  
  /**
   * The generic name of this drug or supplement.
   */
  private List<String> nonProprietaryName = new LinkedList<String>();
  
  /**
   * Recommended intake of this supplement for a given population as defined by a specific recommending authority.
   */
  private List<RecommendedDoseSchedule> recommendedIntake = new LinkedList<RecommendedDoseSchedule>();
  
  /**
   * Any potential safety concern associated with the supplement. May include interactions with other drugs and foods, pregnancy, breastfeeding, known adverse reactions, and documented efficacy of the supplement.
   */
  private List<String> safetyConsideration = new LinkedList<String>();
  
  /**
   * Characteristics of the population for which this is intended, or which typically uses it, e.g. 'adults'.
   */
  private List<String> targetPopulation = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public DietarySupplementImpl() {
    super("http://schema.org/DietarySupplement");
    medicalTherapy = new MedicalTherapyImpl();
  }
  /**
   * Get a single activeIngredient property value for this DietarySupplement object.
   *
   * @return The first activeIngredient property value.
   */
  public String getActiveIngredient() {
  	return this.activeIngredient.isEmpty() ? null : this.activeIngredient.get(0);
  }
  
  /**
   * Get a single additionalType property value for this DietarySupplement object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single adverseOutcome property value for this DietarySupplement object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome() {
    return medicalTherapy.getAdverseOutcome();
  }
  
  /**
   * Get a single alternateName property value for this DietarySupplement object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single background property value for this DietarySupplement object.
   *
   * @return The first background property value.
   */
  public String getBackground() {
  	return this.background.isEmpty() ? null : this.background.get(0);
  }
  
  /**
   * Get a single code property value for this DietarySupplement object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single contraindication property value for this DietarySupplement object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication() {
    return medicalTherapy.getContraindication();
  }
  
  /**
   * Get a single description property value for this DietarySupplement object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single dosageForm property value for this DietarySupplement object.
   *
   * @return The first dosageForm property value.
   */
  public String getDosageForm() {
  	return this.dosageForm.isEmpty() ? null : this.dosageForm.get(0);
  }
  
  /**
   * Get a single duplicateTherapy property value for this DietarySupplement object.
   *
   * @return The first duplicateTherapy property value.
   */
  public MedicalTherapy getDuplicateTherapy() {
    return medicalTherapy.getDuplicateTherapy();
  }
  
  /**
   * Get a single guideline property value for this DietarySupplement object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this DietarySupplement object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single indication property value for this DietarySupplement object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication() {
    return medicalTherapy.getIndication();
  }
  
  /**
   * Get a single isProprietary property value for this DietarySupplement object.
   *
   * @return The first isProprietary property value.
   */
  public Boolean getIsProprietary() {
  	return this.isProprietary.isEmpty() ? null : this.isProprietary.get(0);
  }
  
  /**
   * Get a single legalStatus property value for this DietarySupplement object.
   *
   * @return The first legalStatus property value.
   */
  public DrugLegalStatus getLegalStatus() {
  	return this.legalStatus.isEmpty() ? null : this.legalStatus.get(0);
  }
  
  /**
   * Get a single manufacturer property value for this DietarySupplement object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer() {
  	return this.manufacturer.isEmpty() ? null : this.manufacturer.get(0);
  }
  
  /**
   * Get a single maximumIntake property value for this DietarySupplement object.
   *
   * @return The first maximumIntake property value.
   */
  public MaximumDoseSchedule getMaximumIntake() {
  	return this.maximumIntake.isEmpty() ? null : this.maximumIntake.get(0);
  }
  
  /**
   * Get a single mechanismOfAction property value for this DietarySupplement object.
   *
   * @return The first mechanismOfAction property value.
   */
  public String getMechanismOfAction() {
  	return this.mechanismOfAction.isEmpty() ? null : this.mechanismOfAction.get(0);
  }
  
  /**
   * Get a single medicineSystem property value for this DietarySupplement object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this DietarySupplement object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single nonProprietaryName property value for this DietarySupplement object.
   *
   * @return The first nonProprietaryName property value.
   */
  public String getNonProprietaryName() {
  	return this.nonProprietaryName.isEmpty() ? null : this.nonProprietaryName.get(0);
  }
  
  /**
   * Get a single recognizingAuthority property value for this DietarySupplement object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single recommendedIntake property value for this DietarySupplement object.
   *
   * @return The first recommendedIntake property value.
   */
  public RecommendedDoseSchedule getRecommendedIntake() {
  	return this.recommendedIntake.isEmpty() ? null : this.recommendedIntake.get(0);
  }
  
  /**
   * Get a single relevantSpecialty property value for this DietarySupplement object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single safetyConsideration property value for this DietarySupplement object.
   *
   * @return The first safetyConsideration property value.
   */
  public String getSafetyConsideration() {
  	return this.safetyConsideration.isEmpty() ? null : this.safetyConsideration.get(0);
  }
  
  /**
   * Get a single sameAs property value for this DietarySupplement object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seriousAdverseOutcome property value for this DietarySupplement object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome() {
    return medicalTherapy.getSeriousAdverseOutcome();
  }
  
  /**
   * Get a single study property value for this DietarySupplement object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single targetPopulation property value for this DietarySupplement object.
   *
   * @return The first targetPopulation property value.
   */
  public String getTargetPopulation() {
  	return this.targetPopulation.isEmpty() ? null : this.targetPopulation.get(0);
  }
  
  /**
   * Get a single url property value for this DietarySupplement object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the activeIngredient property values for this DietarySupplement object.
   *
   * @return A list of activeIngredient property values.
   */
  public List<String> getActiveIngredients() {
  	return this.activeIngredient;
  }
  
  /**
   * Get all the additionalType property values for this DietarySupplement object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the adverseOutcome property values for this DietarySupplement object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes() {
    return medicalTherapy.getAdverseOutcomes();
  }
  
  /**
   * Get all the alternateName property values for this DietarySupplement object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the background property values for this DietarySupplement object.
   *
   * @return A list of background property values.
   */
  public List<String> getBackgrounds() {
  	return this.background;
  }
  
  /**
   * Get all the code property values for this DietarySupplement object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the contraindication property values for this DietarySupplement object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications() {
    return medicalTherapy.getContraindications();
  }
  
  /**
   * Get all the description property values for this DietarySupplement object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the dosageForm property values for this DietarySupplement object.
   *
   * @return A list of dosageForm property values.
   */
  public List<String> getDosageForms() {
  	return this.dosageForm;
  }
  
  /**
   * Get all the duplicateTherapy property values for this DietarySupplement object.
   *
   * @return A list of duplicateTherapy property values.
   */
  public List<MedicalTherapy> getDuplicateTherapies() {
    return medicalTherapy.getDuplicateTherapies();
  }
  
  /**
   * Get all the guideline property values for this DietarySupplement object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this DietarySupplement object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the indication property values for this DietarySupplement object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications() {
    return medicalTherapy.getIndications();
  }
  
  /**
   * Get all the isProprietary property values for this DietarySupplement object.
   *
   * @return A list of isProprietary property values.
   */
  public List<Boolean> getIsProprietaries() {
  	return this.isProprietary;
  }
  
  /**
   * Get all the legalStatus property values for this DietarySupplement object.
   *
   * @return A list of legalStatus property values.
   */
  public List<DrugLegalStatus> getLegalStatuses() {
  	return this.legalStatus;
  }
  
  /**
   * Get all the manufacturer property values for this DietarySupplement object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers() {
  	return this.manufacturer;
  }
  
  /**
   * Get all the maximumIntake property values for this DietarySupplement object.
   *
   * @return A list of maximumIntake property values.
   */
  public List<MaximumDoseSchedule> getMaximumIntakes() {
  	return this.maximumIntake;
  }
  
  /**
   * Get all the mechanismOfAction property values for this DietarySupplement object.
   *
   * @return A list of mechanismOfAction property values.
   */
  public List<String> getMechanismOfActions() {
  	return this.mechanismOfAction;
  }
  
  /**
   * Get all the medicineSystem property values for this DietarySupplement object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this DietarySupplement object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the nonProprietaryName property values for this DietarySupplement object.
   *
   * @return A list of nonProprietaryName property values.
   */
  public List<String> getNonProprietaryNames() {
  	return this.nonProprietaryName;
  }
  
  /**
   * Get all the recognizingAuthority property values for this DietarySupplement object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the recommendedIntake property values for this DietarySupplement object.
   *
   * @return A list of recommendedIntake property values.
   */
  public List<RecommendedDoseSchedule> getRecommendedIntakes() {
  	return this.recommendedIntake;
  }
  
  /**
   * Get all the relevantSpecialty property values for this DietarySupplement object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the safetyConsideration property values for this DietarySupplement object.
   *
   * @return A list of safetyConsideration property values.
   */
  public List<String> getSafetyConsiderations() {
  	return this.safetyConsideration;
  }
  
  /**
   * Get all the sameAs property values for this DietarySupplement object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seriousAdverseOutcome property values for this DietarySupplement object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes() {
    return medicalTherapy.getSeriousAdverseOutcomes();
  }
  
  /**
   * Get all the study property values for this DietarySupplement object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the targetPopulation property values for this DietarySupplement object.
   *
   * @return A list of targetPopulation property values.
   */
  public List<String> getTargetPopulations() {
  	return this.targetPopulation;
  }
  
  /**
   * Get all the url property values for this DietarySupplement object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the activeIngredient property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param activeIngredient The value to set.
   */
  public void setActiveIngredient(String activeIngredient) {
  	this.activeIngredient.clear();
  	this.activeIngredient.add(activeIngredient);
  }
  
  /**
   * Set the additionalType property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the adverseOutcome property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.setAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Set the alternateName property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the background property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param background The value to set.
   */
  public void setBackground(String background) {
  	this.background.clear();
  	this.background.add(background);
  }
  
  /**
   * Set the code property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the contraindication property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication) {
    medicalTherapy.setContraindication(contraindication);
  }
  
  /**
   * Set the description property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the dosageForm property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param dosageForm The value to set.
   */
  public void setDosageForm(String dosageForm) {
  	this.dosageForm.clear();
  	this.dosageForm.add(dosageForm);
  }
  
  /**
   * Set the duplicateTherapy property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param duplicateTherapy The value to set.
   */
  public void setDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.setDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Set the guideline property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the indication property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication) {
    medicalTherapy.setIndication(indication);
  }
  
  /**
   * Set the isProprietary property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param isProprietary The value to set.
   */
  public void setIsProprietary(Boolean isProprietary) {
  	this.isProprietary.clear();
  	this.isProprietary.add(isProprietary);
  }
  
  /**
   * Set the legalStatus property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param legalStatus The value to set.
   */
  public void setLegalStatus(DrugLegalStatus legalStatus) {
  	this.legalStatus.clear();
  	this.legalStatus.add(legalStatus);
  }
  
  /**
   * Set the manufacturer property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer) {
  	this.manufacturer.clear();
  	this.manufacturer.add(manufacturer);
  }
  
  /**
   * Set the maximumIntake property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param maximumIntake The value to set.
   */
  public void setMaximumIntake(MaximumDoseSchedule maximumIntake) {
  	this.maximumIntake.clear();
  	this.maximumIntake.add(maximumIntake);
  }
  
  /**
   * Set the mechanismOfAction property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param mechanismOfAction The value to set.
   */
  public void setMechanismOfAction(String mechanismOfAction) {
  	this.mechanismOfAction.clear();
  	this.mechanismOfAction.add(mechanismOfAction);
  }
  
  /**
   * Set the medicineSystem property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the nonProprietaryName property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param nonProprietaryName The value to set.
   */
  public void setNonProprietaryName(String nonProprietaryName) {
  	this.nonProprietaryName.clear();
  	this.nonProprietaryName.add(nonProprietaryName);
  }
  
  /**
   * Set the recognizingAuthority property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the recommendedIntake property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param recommendedIntake The value to set.
   */
  public void setRecommendedIntake(RecommendedDoseSchedule recommendedIntake) {
  	this.recommendedIntake.clear();
  	this.recommendedIntake.add(recommendedIntake);
  }
  
  /**
   * Set the relevantSpecialty property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the safetyConsideration property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param safetyConsideration The value to set.
   */
  public void setSafetyConsideration(String safetyConsideration) {
  	this.safetyConsideration.clear();
  	this.safetyConsideration.add(safetyConsideration);
  }
  
  /**
   * Set the sameAs property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seriousAdverseOutcome property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.setSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Set the study property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the targetPopulation property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param targetPopulation The value to set.
   */
  public void setTargetPopulation(String targetPopulation) {
  	this.targetPopulation.clear();
  	this.targetPopulation.add(targetPopulation);
  }
  
  /**
   * Set the url property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the activeIngredient property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param activeIngredients The list of values to set.
   */
  public void setActiveIngredients(List<String> activeIngredients) {
  	this.activeIngredient = activeIngredients;
  }
  
  /**
   * Set the additionalType property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the adverseOutcome property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes) {
    medicalTherapy.setAdverseOutcomes(adverseOutcomes);
  }
  
  /**
   * Set the alternateName property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the background property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param backgrounds The list of values to set.
   */
  public void setBackgrounds(List<String> backgrounds) {
  	this.background = backgrounds;
  }
  
  /**
   * Set the code property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the contraindication property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications) {
    medicalTherapy.setContraindications(contraindications);
  }
  
  /**
   * Set the description property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the dosageForm property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param dosageForms The list of values to set.
   */
  public void setDosageForms(List<String> dosageForms) {
  	this.dosageForm = dosageForms;
  }
  
  /**
   * Set the duplicateTherapy property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param duplicateTherapies The list of values to set.
   */
  public void setDuplicateTherapies(List<MedicalTherapy> duplicateTherapies) {
    medicalTherapy.setDuplicateTherapies(duplicateTherapies);
  }
  
  /**
   * Set the guideline property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the indication property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications) {
    medicalTherapy.setIndications(indications);
  }
  
  /**
   * Set the isProprietary property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param isProprietaries The list of values to set.
   */
  public void setIsProprietaries(List<Boolean> isProprietaries) {
  	this.isProprietary = isProprietaries;
  }
  
  /**
   * Set the legalStatus property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param legalStatuses The list of values to set.
   */
  public void setLegalStatuses(List<DrugLegalStatus> legalStatuses) {
  	this.legalStatus = legalStatuses;
  }
  
  /**
   * Set the manufacturer property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers) {
  	this.manufacturer = manufacturers;
  }
  
  /**
   * Set the maximumIntake property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param maximumIntakes The list of values to set.
   */
  public void setMaximumIntakes(List<MaximumDoseSchedule> maximumIntakes) {
  	this.maximumIntake = maximumIntakes;
  }
  
  /**
   * Set the mechanismOfAction property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param mechanismOfActions The list of values to set.
   */
  public void setMechanismOfActions(List<String> mechanismOfActions) {
  	this.mechanismOfAction = mechanismOfActions;
  }
  
  /**
   * Set the medicineSystem property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the nonProprietaryName property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param nonProprietaryNames The list of values to set.
   */
  public void setNonProprietaryNames(List<String> nonProprietaryNames) {
  	this.nonProprietaryName = nonProprietaryNames;
  }
  
  /**
   * Set the recognizingAuthority property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the recommendedIntake property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param recommendedIntakes The list of values to set.
   */
  public void setRecommendedIntakes(List<RecommendedDoseSchedule> recommendedIntakes) {
  	this.recommendedIntake = recommendedIntakes;
  }
  
  /**
   * Set the relevantSpecialty property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the safetyConsideration property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param safetyConsiderations The list of values to set.
   */
  public void setSafetyConsiderations(List<String> safetyConsiderations) {
  	this.safetyConsideration = safetyConsiderations;
  }
  
  /**
   * Set the sameAs property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seriousAdverseOutcome property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes) {
    medicalTherapy.setSeriousAdverseOutcomes(seriousAdverseOutcomes);
  }
  
  /**
   * Set the study property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the targetPopulation property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param targetPopulations The list of values to set.
   */
  public void setTargetPopulations(List<String> targetPopulations) {
  	this.targetPopulation = targetPopulations;
  }
  
  /**
   * Set the url property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a activeIngredient property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param activeIngredient The value to add.
   */
  public void addActiveIngredient(String activeIngredient) {
  	this.activeIngredient.add(activeIngredient);
  }
  
  /**
   * Adds a additionalType property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a adverseOutcome property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.addAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Adds a alternateName property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a background property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param background The value to add.
   */
  public void addBackground(String background) {
  	this.background.add(background);
  }
  
  /**
   * Adds a code property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a contraindication property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication) {
    medicalTherapy.addContraindication(contraindication);
  }
  
  /**
   * Adds a description property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a dosageForm property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param dosageForm The value to add.
   */
  public void addDosageForm(String dosageForm) {
  	this.dosageForm.add(dosageForm);
  }
  
  /**
   * Adds a duplicateTherapy property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param duplicateTherapy The value to add.
   */
  public void addDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.addDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Adds a guideline property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a indication property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication) {
    medicalTherapy.addIndication(indication);
  }
  
  /**
   * Adds a isProprietary property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param isProprietary The value to add.
   */
  public void addIsProprietary(Boolean isProprietary) {
  	this.isProprietary.add(isProprietary);
  }
  
  /**
   * Adds a legalStatus property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param legalStatus The value to add.
   */
  public void addLegalStatus(DrugLegalStatus legalStatus) {
  	this.legalStatus.add(legalStatus);
  }
  
  /**
   * Adds a manufacturer property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer) {
  	this.manufacturer.add(manufacturer);
  }
  
  /**
   * Adds a maximumIntake property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param maximumIntake The value to add.
   */
  public void addMaximumIntake(MaximumDoseSchedule maximumIntake) {
  	this.maximumIntake.add(maximumIntake);
  }
  
  /**
   * Adds a mechanismOfAction property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param mechanismOfAction The value to add.
   */
  public void addMechanismOfAction(String mechanismOfAction) {
  	this.mechanismOfAction.add(mechanismOfAction);
  }
  
  /**
   * Adds a medicineSystem property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a nonProprietaryName property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param nonProprietaryName The value to add.
   */
  public void addNonProprietaryName(String nonProprietaryName) {
  	this.nonProprietaryName.add(nonProprietaryName);
  }
  
  /**
   * Adds a recognizingAuthority property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a recommendedIntake property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param recommendedIntake The value to add.
   */
  public void addRecommendedIntake(RecommendedDoseSchedule recommendedIntake) {
  	this.recommendedIntake.add(recommendedIntake);
  }
  
  /**
   * Adds a relevantSpecialty property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a safetyConsideration property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param safetyConsideration The value to add.
   */
  public void addSafetyConsideration(String safetyConsideration) {
  	this.safetyConsideration.add(safetyConsideration);
  }
  
  /**
   * Adds a sameAs property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seriousAdverseOutcome property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.addSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Adds a study property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a targetPopulation property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param targetPopulation The value to add.
   */
  public void addTargetPopulation(String targetPopulation) {
  	this.targetPopulation.add(targetPopulation);
  }
  
  /**
   * Adds a url property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}