package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.DrugCost;
import org.schema.DrugCostCategory;
import org.schema.MedicalCode;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The cost per unit of a medical drug. Note that this type is not meant to represent the price in an offer of a drug for sale; see the Offer type for that. This type will typically be used to tag wholesale or average retail cost of a drug, or maximum reimbursable cost. Costs of medical drugs vary widely depending on how and where they are paid for, so while this type captures some of the variables, costs should be used with caution by consumers of this schema's markup.
 */
public class DrugCostImpl extends SchemaObjectImpl implements DrugCost {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * The location in which the status applies.
   */
  private List<AdministrativeArea> applicableLocation = new LinkedList<AdministrativeArea>();
  
  /**
   * The category of cost, such as wholesale, retail, reimbursement cap, etc.
   */
  private List<DrugCostCategory> costCategory = new LinkedList<DrugCostCategory>();
  
  /**
   * The currency (in 3-letter <a href=http://en.wikipedia.org/wiki/ISO_4217>ISO 4217 format</a>) of the drug cost.
   */
  private List<String> costCurrency = new LinkedList<String>();
  
  /**
   * Additional details to capture the origin of the cost data. For example, 'Medicare Part B'.
   */
  private List<String> costOrigin = new LinkedList<String>();
  
  /**
   * The cost per unit of the drug.
   */
  private List<Thing> costPerUnit = new LinkedList<Thing>();
  
  /**
   * The unit in which the drug is measured, e.g. '5 mg tablet'.
   */
  private List<String> drugUnit = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public DrugCostImpl() {
    super("http://schema.org/DrugCost");
  }
  /**
   * Get a single additionalType property value for this DrugCost object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this DrugCost object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single applicableLocation property value for this DrugCost object.
   *
   * @return The first applicableLocation property value.
   */
  public AdministrativeArea getApplicableLocation() {
  	return this.applicableLocation.isEmpty() ? null : this.applicableLocation.get(0);
  }
  
  /**
   * Get a single code property value for this DrugCost object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single costCategory property value for this DrugCost object.
   *
   * @return The first costCategory property value.
   */
  public DrugCostCategory getCostCategory() {
  	return this.costCategory.isEmpty() ? null : this.costCategory.get(0);
  }
  
  /**
   * Get a single costCurrency property value for this DrugCost object.
   *
   * @return The first costCurrency property value.
   */
  public String getCostCurrency() {
  	return this.costCurrency.isEmpty() ? null : this.costCurrency.get(0);
  }
  
  /**
   * Get a single costOrigin property value for this DrugCost object.
   *
   * @return The first costOrigin property value.
   */
  public String getCostOrigin() {
  	return this.costOrigin.isEmpty() ? null : this.costOrigin.get(0);
  }
  
  /**
   * Get a single costPerUnit property value for this DrugCost object.
   *
   * @return The first costPerUnit property value.
   */
  public Thing getCostPerUnit() {
  	return this.costPerUnit.isEmpty() ? null : this.costPerUnit.get(0);
  }
  
  /**
   * Get a single description property value for this DrugCost object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single drugUnit property value for this DrugCost object.
   *
   * @return The first drugUnit property value.
   */
  public String getDrugUnit() {
  	return this.drugUnit.isEmpty() ? null : this.drugUnit.get(0);
  }
  
  /**
   * Get a single guideline property value for this DrugCost object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this DrugCost object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this DrugCost object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this DrugCost object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single recognizingAuthority property value for this DrugCost object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this DrugCost object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this DrugCost object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this DrugCost object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this DrugCost object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this DrugCost object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this DrugCost object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the applicableLocation property values for this DrugCost object.
   *
   * @return A list of applicableLocation property values.
   */
  public List<AdministrativeArea> getApplicableLocations() {
  	return this.applicableLocation;
  }
  
  /**
   * Get all the code property values for this DrugCost object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the costCategory property values for this DrugCost object.
   *
   * @return A list of costCategory property values.
   */
  public List<DrugCostCategory> getCostCategories() {
  	return this.costCategory;
  }
  
  /**
   * Get all the costCurrency property values for this DrugCost object.
   *
   * @return A list of costCurrency property values.
   */
  public List<String> getCostCurrencies() {
  	return this.costCurrency;
  }
  
  /**
   * Get all the costOrigin property values for this DrugCost object.
   *
   * @return A list of costOrigin property values.
   */
  public List<String> getCostOrigins() {
  	return this.costOrigin;
  }
  
  /**
   * Get all the costPerUnit property values for this DrugCost object.
   *
   * @return A list of costPerUnit property values.
   */
  public List<Thing> getCostPerUnits() {
  	return this.costPerUnit;
  }
  
  /**
   * Get all the description property values for this DrugCost object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the drugUnit property values for this DrugCost object.
   *
   * @return A list of drugUnit property values.
   */
  public List<String> getDrugUnits() {
  	return this.drugUnit;
  }
  
  /**
   * Get all the guideline property values for this DrugCost object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this DrugCost object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this DrugCost object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this DrugCost object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the recognizingAuthority property values for this DrugCost object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this DrugCost object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this DrugCost object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this DrugCost object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this DrugCost object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this DrugCost object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this DrugCost object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the applicableLocation property value for this DrugCost object; overwriting any existing values.
   *
   * @param applicableLocation The value to set.
   */
  public void setApplicableLocation(AdministrativeArea applicableLocation) {
  	this.applicableLocation.clear();
  	this.applicableLocation.add(applicableLocation);
  }
  
  /**
   * Set the code property value for this DrugCost object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the costCategory property value for this DrugCost object; overwriting any existing values.
   *
   * @param costCategory The value to set.
   */
  public void setCostCategory(DrugCostCategory costCategory) {
  	this.costCategory.clear();
  	this.costCategory.add(costCategory);
  }
  
  /**
   * Set the costCurrency property value for this DrugCost object; overwriting any existing values.
   *
   * @param costCurrency The value to set.
   */
  public void setCostCurrency(String costCurrency) {
  	this.costCurrency.clear();
  	this.costCurrency.add(costCurrency);
  }
  
  /**
   * Set the costOrigin property value for this DrugCost object; overwriting any existing values.
   *
   * @param costOrigin The value to set.
   */
  public void setCostOrigin(String costOrigin) {
  	this.costOrigin.clear();
  	this.costOrigin.add(costOrigin);
  }
  
  /**
   * Set the costPerUnit property value for this DrugCost object; overwriting any existing values.
   *
   * @param costPerUnit The value to set.
   */
  public void setCostPerUnit(Thing costPerUnit) {
  	this.costPerUnit.clear();
  	this.costPerUnit.add(costPerUnit);
  }
  
  /**
   * Set the description property value for this DrugCost object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the drugUnit property value for this DrugCost object; overwriting any existing values.
   *
   * @param drugUnit The value to set.
   */
  public void setDrugUnit(String drugUnit) {
  	this.drugUnit.clear();
  	this.drugUnit.add(drugUnit);
  }
  
  /**
   * Set the guideline property value for this DrugCost object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this DrugCost object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this DrugCost object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this DrugCost object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the recognizingAuthority property value for this DrugCost object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this DrugCost object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this DrugCost object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this DrugCost object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this DrugCost object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this DrugCost object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this DrugCost object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the applicableLocation property values for this DrugCost object; overwriting any existing values.
   *
   * @param applicableLocations The list of values to set.
   */
  public void setApplicableLocations(List<AdministrativeArea> applicableLocations) {
  	this.applicableLocation = applicableLocations;
  }
  
  /**
   * Set the code property values for this DrugCost object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the costCategory property values for this DrugCost object; overwriting any existing values.
   *
   * @param costCategories The list of values to set.
   */
  public void setCostCategories(List<DrugCostCategory> costCategories) {
  	this.costCategory = costCategories;
  }
  
  /**
   * Set the costCurrency property values for this DrugCost object; overwriting any existing values.
   *
   * @param costCurrencies The list of values to set.
   */
  public void setCostCurrencies(List<String> costCurrencies) {
  	this.costCurrency = costCurrencies;
  }
  
  /**
   * Set the costOrigin property values for this DrugCost object; overwriting any existing values.
   *
   * @param costOrigins The list of values to set.
   */
  public void setCostOrigins(List<String> costOrigins) {
  	this.costOrigin = costOrigins;
  }
  
  /**
   * Set the costPerUnit property values for this DrugCost object; overwriting any existing values.
   *
   * @param costPerUnits The list of values to set.
   */
  public void setCostPerUnits(List<Thing> costPerUnits) {
  	this.costPerUnit = costPerUnits;
  }
  
  /**
   * Set the description property values for this DrugCost object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the drugUnit property values for this DrugCost object; overwriting any existing values.
   *
   * @param drugUnits The list of values to set.
   */
  public void setDrugUnits(List<String> drugUnits) {
  	this.drugUnit = drugUnits;
  }
  
  /**
   * Set the guideline property values for this DrugCost object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this DrugCost object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this DrugCost object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this DrugCost object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the recognizingAuthority property values for this DrugCost object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this DrugCost object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this DrugCost object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this DrugCost object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this DrugCost object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a applicableLocation property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param applicableLocation The value to add.
   */
  public void addApplicableLocation(AdministrativeArea applicableLocation) {
  	this.applicableLocation.add(applicableLocation);
  }
  
  /**
   * Adds a code property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a costCategory property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costCategory The value to add.
   */
  public void addCostCategory(DrugCostCategory costCategory) {
  	this.costCategory.add(costCategory);
  }
  
  /**
   * Adds a costCurrency property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costCurrency The value to add.
   */
  public void addCostCurrency(String costCurrency) {
  	this.costCurrency.add(costCurrency);
  }
  
  /**
   * Adds a costOrigin property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costOrigin The value to add.
   */
  public void addCostOrigin(String costOrigin) {
  	this.costOrigin.add(costOrigin);
  }
  
  /**
   * Adds a costPerUnit property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costPerUnit The value to add.
   */
  public void addCostPerUnit(Thing costPerUnit) {
  	this.costPerUnit.add(costPerUnit);
  }
  
  /**
   * Adds a description property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a drugUnit property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param drugUnit The value to add.
   */
  public void addDrugUnit(String drugUnit) {
  	this.drugUnit.add(drugUnit);
  }
  
  /**
   * Adds a guideline property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a recognizingAuthority property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}