package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.DoseSchedule;
import org.schema.Drug;
import org.schema.DrugClass;
import org.schema.DrugCost;
import org.schema.DrugLegalStatus;
import org.schema.DrugPregnancyCategory;
import org.schema.DrugPrescriptionStatus;
import org.schema.DrugStrength;
import org.schema.MedicalCode;
import org.schema.MedicalContraindication;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalIndication;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A chemical or biologic substance, used as a medical therapy, that has a physiological effect on an organism.
 */
public class DrugImpl extends SchemaObjectImpl implements Drug {


  private MedicalEntityImpl medicalEntity;
  private MedicalTherapyImpl medicalTherapy;
  private ThingImpl thing;

  /**
   * An active ingredient, typically chemical compounds and/or biologic substances.
   */
  private List<String> activeIngredient = new LinkedList<String>();
  
  /**
   * A route by which this drug may be administered, e.g. 'oral'.
   */
  private List<String> administrationRoute = new LinkedList<String>();
  
  /**
   * Any precaution, guidance, contraindication, etc. related to consumption of alcohol while taking this drug.
   */
  private List<String> alcoholWarning = new LinkedList<String>();
  
  /**
   * An available dosage strength for the drug.
   */
  private List<DrugStrength> availableStrength = new LinkedList<DrugStrength>();
  
  /**
   * Any precaution, guidance, contraindication, etc. related to this drug's use by breastfeeding mothers.
   */
  private List<String> breastfeedingWarning = new LinkedList<String>();
  
  /**
   * Description of the absorption and elimination of drugs, including their concentration (pharmacokinetics, pK) and biological effects (pharmacodynamics, pD).
   */
  private List<String> clincalPharmacology = new LinkedList<String>();
  
  /**
   * Cost per unit of the drug, as reported by the source being tagged.
   */
  private List<DrugCost> cost = new LinkedList<DrugCost>();
  
  /**
   * A dosage form in which this drug/supplement is available, e.g. 'tablet', 'suspension', 'injection'.
   */
  private List<String> dosageForm = new LinkedList<String>();
  
  /**
   * A dosing schedule for the drug for a given population, either observed, recommended, or maximum dose based on the type used.
   */
  private List<DoseSchedule> doseSchedule = new LinkedList<DoseSchedule>();
  
  /**
   * The class of drug this belongs to (e.g., statins).
   */
  private List<DrugClass> drugClass = new LinkedList<DrugClass>();
  
  /**
   * Any precaution, guidance, contraindication, etc. related to consumption of specific foods while taking this drug.
   */
  private List<String> foodWarning = new LinkedList<String>();
  
  /**
   * Another drug that is known to interact with this drug in a way that impacts the effect of this drug or causes a risk to the patient. Note: disease interactions are typically captured as contraindications.
   */
  private List<Drug> interactingDrug = new LinkedList<Drug>();
  
  /**
   * True if the drug is available in a generic form (regardless of name).
   */
  private List<Boolean> isAvailableGenerically = new LinkedList<Boolean>();
  
  /**
   * True if this item's name is a proprietary/brand name (vs. generic name).
   */
  private List<Boolean> isProprietary = new LinkedList<Boolean>();
  
  /**
   * Link to the drug's label details.
   */
  private List<URL> labelDetails = new LinkedList<URL>();
  
  /**
   * The drug or supplement's legal status, including any controlled substance schedules that apply.
   */
  private List<DrugLegalStatus> legalStatus = new LinkedList<DrugLegalStatus>();
  
  /**
   * The manufacturer of the product.
   */
  private List<Organization> manufacturer = new LinkedList<Organization>();
  
  /**
   * The specific biochemical interaction through which this drug or supplement produces its pharmacological effect.
   */
  private List<String> mechanismOfAction = new LinkedList<String>();
  
  /**
   * The generic name of this drug or supplement.
   */
  private List<String> nonProprietaryName = new LinkedList<String>();
  
  /**
   * Any information related to overdose on a drug, including signs or symptoms, treatments, contact information for emergency response.
   */
  private List<String> overdosage = new LinkedList<String>();
  
  /**
   * Pregnancy category of this drug.
   */
  private List<DrugPregnancyCategory> pregnancyCategory = new LinkedList<DrugPregnancyCategory>();
  
  /**
   * Any precaution, guidance, contraindication, etc. related to this drug's use during pregnancy.
   */
  private List<String> pregnancyWarning = new LinkedList<String>();
  
  /**
   * Link to prescribing information for the drug.
   */
  private List<URL> prescribingInfo = new LinkedList<URL>();
  
  /**
   * Indicates whether this drug is available by prescription or over-the-counter.
   */
  private List<DrugPrescriptionStatus> prescriptionStatus = new LinkedList<DrugPrescriptionStatus>();
  
  /**
   * Any other drug related to this one, for example commonly-prescribed alternatives.
   */
  private List<Drug> relatedDrug = new LinkedList<Drug>();
  
  /**
   * Any FDA or other warnings about the drug (text or URL).
   */
  private List<Thing> warning = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public DrugImpl() {
    super("http://schema.org/Drug");
    medicalTherapy = new MedicalTherapyImpl();
  }
  /**
   * Get a single activeIngredient property value for this Drug object.
   *
   * @return The first activeIngredient property value.
   */
  public String getActiveIngredient() {
  	return this.activeIngredient.isEmpty() ? null : this.activeIngredient.get(0);
  }
  
  /**
   * Get a single additionalType property value for this Drug object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single administrationRoute property value for this Drug object.
   *
   * @return The first administrationRoute property value.
   */
  public String getAdministrationRoute() {
  	return this.administrationRoute.isEmpty() ? null : this.administrationRoute.get(0);
  }
  
  /**
   * Get a single adverseOutcome property value for this Drug object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome() {
    return medicalTherapy.getAdverseOutcome();
  }
  
  /**
   * Get a single alcoholWarning property value for this Drug object.
   *
   * @return The first alcoholWarning property value.
   */
  public String getAlcoholWarning() {
  	return this.alcoholWarning.isEmpty() ? null : this.alcoholWarning.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Drug object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single availableStrength property value for this Drug object.
   *
   * @return The first availableStrength property value.
   */
  public DrugStrength getAvailableStrength() {
  	return this.availableStrength.isEmpty() ? null : this.availableStrength.get(0);
  }
  
  /**
   * Get a single breastfeedingWarning property value for this Drug object.
   *
   * @return The first breastfeedingWarning property value.
   */
  public String getBreastfeedingWarning() {
  	return this.breastfeedingWarning.isEmpty() ? null : this.breastfeedingWarning.get(0);
  }
  
  /**
   * Get a single clincalPharmacology property value for this Drug object.
   *
   * @return The first clincalPharmacology property value.
   */
  public String getClincalPharmacology() {
  	return this.clincalPharmacology.isEmpty() ? null : this.clincalPharmacology.get(0);
  }
  
  /**
   * Get a single code property value for this Drug object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single contraindication property value for this Drug object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication() {
    return medicalTherapy.getContraindication();
  }
  
  /**
   * Get a single cost property value for this Drug object.
   *
   * @return The first cost property value.
   */
  public DrugCost getCost() {
  	return this.cost.isEmpty() ? null : this.cost.get(0);
  }
  
  /**
   * Get a single description property value for this Drug object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single dosageForm property value for this Drug object.
   *
   * @return The first dosageForm property value.
   */
  public String getDosageForm() {
  	return this.dosageForm.isEmpty() ? null : this.dosageForm.get(0);
  }
  
  /**
   * Get a single doseSchedule property value for this Drug object.
   *
   * @return The first doseSchedule property value.
   */
  public DoseSchedule getDoseSchedule() {
  	return this.doseSchedule.isEmpty() ? null : this.doseSchedule.get(0);
  }
  
  /**
   * Get a single drugClass property value for this Drug object.
   *
   * @return The first drugClass property value.
   */
  public DrugClass getDrugClass() {
  	return this.drugClass.isEmpty() ? null : this.drugClass.get(0);
  }
  
  /**
   * Get a single duplicateTherapy property value for this Drug object.
   *
   * @return The first duplicateTherapy property value.
   */
  public MedicalTherapy getDuplicateTherapy() {
    return medicalTherapy.getDuplicateTherapy();
  }
  
  /**
   * Get a single foodWarning property value for this Drug object.
   *
   * @return The first foodWarning property value.
   */
  public String getFoodWarning() {
  	return this.foodWarning.isEmpty() ? null : this.foodWarning.get(0);
  }
  
  /**
   * Get a single guideline property value for this Drug object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this Drug object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single indication property value for this Drug object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication() {
    return medicalTherapy.getIndication();
  }
  
  /**
   * Get a single interactingDrug property value for this Drug object.
   *
   * @return The first interactingDrug property value.
   */
  public Drug getInteractingDrug() {
  	return this.interactingDrug.isEmpty() ? null : this.interactingDrug.get(0);
  }
  
  /**
   * Get a single isAvailableGenerically property value for this Drug object.
   *
   * @return The first isAvailableGenerically property value.
   */
  public Boolean getIsAvailableGenerically() {
  	return this.isAvailableGenerically.isEmpty() ? null : this.isAvailableGenerically.get(0);
  }
  
  /**
   * Get a single isProprietary property value for this Drug object.
   *
   * @return The first isProprietary property value.
   */
  public Boolean getIsProprietary() {
  	return this.isProprietary.isEmpty() ? null : this.isProprietary.get(0);
  }
  
  /**
   * Get a single labelDetails property value for this Drug object.
   *
   * @return The first labelDetails property value.
   */
  public URL getLabelDetails() {
  	return this.labelDetails.isEmpty() ? null : this.labelDetails.get(0);
  }
  
  /**
   * Get a single legalStatus property value for this Drug object.
   *
   * @return The first legalStatus property value.
   */
  public DrugLegalStatus getLegalStatus() {
  	return this.legalStatus.isEmpty() ? null : this.legalStatus.get(0);
  }
  
  /**
   * Get a single manufacturer property value for this Drug object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer() {
  	return this.manufacturer.isEmpty() ? null : this.manufacturer.get(0);
  }
  
  /**
   * Get a single mechanismOfAction property value for this Drug object.
   *
   * @return The first mechanismOfAction property value.
   */
  public String getMechanismOfAction() {
  	return this.mechanismOfAction.isEmpty() ? null : this.mechanismOfAction.get(0);
  }
  
  /**
   * Get a single medicineSystem property value for this Drug object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this Drug object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single nonProprietaryName property value for this Drug object.
   *
   * @return The first nonProprietaryName property value.
   */
  public String getNonProprietaryName() {
  	return this.nonProprietaryName.isEmpty() ? null : this.nonProprietaryName.get(0);
  }
  
  /**
   * Get a single overdosage property value for this Drug object.
   *
   * @return The first overdosage property value.
   */
  public String getOverdosage() {
  	return this.overdosage.isEmpty() ? null : this.overdosage.get(0);
  }
  
  /**
   * Get a single pregnancyCategory property value for this Drug object.
   *
   * @return The first pregnancyCategory property value.
   */
  public DrugPregnancyCategory getPregnancyCategory() {
  	return this.pregnancyCategory.isEmpty() ? null : this.pregnancyCategory.get(0);
  }
  
  /**
   * Get a single pregnancyWarning property value for this Drug object.
   *
   * @return The first pregnancyWarning property value.
   */
  public String getPregnancyWarning() {
  	return this.pregnancyWarning.isEmpty() ? null : this.pregnancyWarning.get(0);
  }
  
  /**
   * Get a single prescribingInfo property value for this Drug object.
   *
   * @return The first prescribingInfo property value.
   */
  public URL getPrescribingInfo() {
  	return this.prescribingInfo.isEmpty() ? null : this.prescribingInfo.get(0);
  }
  
  /**
   * Get a single prescriptionStatus property value for this Drug object.
   *
   * @return The first prescriptionStatus property value.
   */
  public DrugPrescriptionStatus getPrescriptionStatus() {
  	return this.prescriptionStatus.isEmpty() ? null : this.prescriptionStatus.get(0);
  }
  
  /**
   * Get a single recognizingAuthority property value for this Drug object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relatedDrug property value for this Drug object.
   *
   * @return The first relatedDrug property value.
   */
  public Drug getRelatedDrug() {
  	return this.relatedDrug.isEmpty() ? null : this.relatedDrug.get(0);
  }
  
  /**
   * Get a single relevantSpecialty property value for this Drug object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this Drug object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seriousAdverseOutcome property value for this Drug object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome() {
    return medicalTherapy.getSeriousAdverseOutcome();
  }
  
  /**
   * Get a single study property value for this Drug object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this Drug object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single warning property value for this Drug object.
   *
   * @return The first warning property value.
   */
  public Thing getWarning() {
  	return this.warning.isEmpty() ? null : this.warning.get(0);
  }
  
  /**
   * Get all the activeIngredient property values for this Drug object.
   *
   * @return A list of activeIngredient property values.
   */
  public List<String> getActiveIngredients() {
  	return this.activeIngredient;
  }
  
  /**
   * Get all the additionalType property values for this Drug object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the administrationRoute property values for this Drug object.
   *
   * @return A list of administrationRoute property values.
   */
  public List<String> getAdministrationRoutes() {
  	return this.administrationRoute;
  }
  
  /**
   * Get all the adverseOutcome property values for this Drug object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes() {
    return medicalTherapy.getAdverseOutcomes();
  }
  
  /**
   * Get all the alcoholWarning property values for this Drug object.
   *
   * @return A list of alcoholWarning property values.
   */
  public List<String> getAlcoholWarnings() {
  	return this.alcoholWarning;
  }
  
  /**
   * Get all the alternateName property values for this Drug object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the availableStrength property values for this Drug object.
   *
   * @return A list of availableStrength property values.
   */
  public List<DrugStrength> getAvailableStrengths() {
  	return this.availableStrength;
  }
  
  /**
   * Get all the breastfeedingWarning property values for this Drug object.
   *
   * @return A list of breastfeedingWarning property values.
   */
  public List<String> getBreastfeedingWarnings() {
  	return this.breastfeedingWarning;
  }
  
  /**
   * Get all the clincalPharmacology property values for this Drug object.
   *
   * @return A list of clincalPharmacology property values.
   */
  public List<String> getClincalPharmacologies() {
  	return this.clincalPharmacology;
  }
  
  /**
   * Get all the code property values for this Drug object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the contraindication property values for this Drug object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications() {
    return medicalTherapy.getContraindications();
  }
  
  /**
   * Get all the cost property values for this Drug object.
   *
   * @return A list of cost property values.
   */
  public List<DrugCost> getCosts() {
  	return this.cost;
  }
  
  /**
   * Get all the description property values for this Drug object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the dosageForm property values for this Drug object.
   *
   * @return A list of dosageForm property values.
   */
  public List<String> getDosageForms() {
  	return this.dosageForm;
  }
  
  /**
   * Get all the doseSchedule property values for this Drug object.
   *
   * @return A list of doseSchedule property values.
   */
  public List<DoseSchedule> getDoseSchedules() {
  	return this.doseSchedule;
  }
  
  /**
   * Get all the drugClass property values for this Drug object.
   *
   * @return A list of drugClass property values.
   */
  public List<DrugClass> getDrugClasses() {
  	return this.drugClass;
  }
  
  /**
   * Get all the duplicateTherapy property values for this Drug object.
   *
   * @return A list of duplicateTherapy property values.
   */
  public List<MedicalTherapy> getDuplicateTherapies() {
    return medicalTherapy.getDuplicateTherapies();
  }
  
  /**
   * Get all the foodWarning property values for this Drug object.
   *
   * @return A list of foodWarning property values.
   */
  public List<String> getFoodWarnings() {
  	return this.foodWarning;
  }
  
  /**
   * Get all the guideline property values for this Drug object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this Drug object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the indication property values for this Drug object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications() {
    return medicalTherapy.getIndications();
  }
  
  /**
   * Get all the interactingDrug property values for this Drug object.
   *
   * @return A list of interactingDrug property values.
   */
  public List<Drug> getInteractingDrugs() {
  	return this.interactingDrug;
  }
  
  /**
   * Get all the isAvailableGenerically property values for this Drug object.
   *
   * @return A list of isAvailableGenerically property values.
   */
  public List<Boolean> getIsAvailableGenericallies() {
  	return this.isAvailableGenerically;
  }
  
  /**
   * Get all the isProprietary property values for this Drug object.
   *
   * @return A list of isProprietary property values.
   */
  public List<Boolean> getIsProprietaries() {
  	return this.isProprietary;
  }
  
  /**
   * Get all the labelDetails property values for this Drug object.
   *
   * @return A list of labelDetails property values.
   */
  public List<URL> getLabelDetailss() {
  	return this.labelDetails;
  }
  
  /**
   * Get all the legalStatus property values for this Drug object.
   *
   * @return A list of legalStatus property values.
   */
  public List<DrugLegalStatus> getLegalStatuses() {
  	return this.legalStatus;
  }
  
  /**
   * Get all the manufacturer property values for this Drug object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers() {
  	return this.manufacturer;
  }
  
  /**
   * Get all the mechanismOfAction property values for this Drug object.
   *
   * @return A list of mechanismOfAction property values.
   */
  public List<String> getMechanismOfActions() {
  	return this.mechanismOfAction;
  }
  
  /**
   * Get all the medicineSystem property values for this Drug object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this Drug object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the nonProprietaryName property values for this Drug object.
   *
   * @return A list of nonProprietaryName property values.
   */
  public List<String> getNonProprietaryNames() {
  	return this.nonProprietaryName;
  }
  
  /**
   * Get all the overdosage property values for this Drug object.
   *
   * @return A list of overdosage property values.
   */
  public List<String> getOverdosages() {
  	return this.overdosage;
  }
  
  /**
   * Get all the pregnancyCategory property values for this Drug object.
   *
   * @return A list of pregnancyCategory property values.
   */
  public List<DrugPregnancyCategory> getPregnancyCategories() {
  	return this.pregnancyCategory;
  }
  
  /**
   * Get all the pregnancyWarning property values for this Drug object.
   *
   * @return A list of pregnancyWarning property values.
   */
  public List<String> getPregnancyWarnings() {
  	return this.pregnancyWarning;
  }
  
  /**
   * Get all the prescribingInfo property values for this Drug object.
   *
   * @return A list of prescribingInfo property values.
   */
  public List<URL> getPrescribingInfoes() {
  	return this.prescribingInfo;
  }
  
  /**
   * Get all the prescriptionStatus property values for this Drug object.
   *
   * @return A list of prescriptionStatus property values.
   */
  public List<DrugPrescriptionStatus> getPrescriptionStatuses() {
  	return this.prescriptionStatus;
  }
  
  /**
   * Get all the recognizingAuthority property values for this Drug object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relatedDrug property values for this Drug object.
   *
   * @return A list of relatedDrug property values.
   */
  public List<Drug> getRelatedDrugs() {
  	return this.relatedDrug;
  }
  
  /**
   * Get all the relevantSpecialty property values for this Drug object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this Drug object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seriousAdverseOutcome property values for this Drug object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes() {
    return medicalTherapy.getSeriousAdverseOutcomes();
  }
  
  /**
   * Get all the study property values for this Drug object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this Drug object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the warning property values for this Drug object.
   *
   * @return A list of warning property values.
   */
  public List<Thing> getWarnings() {
  	return this.warning;
  }
  
  /**
   * Set the activeIngredient property value for this Drug object; overwriting any existing values.
   *
   * @param activeIngredient The value to set.
   */
  public void setActiveIngredient(String activeIngredient) {
  	this.activeIngredient.clear();
  	this.activeIngredient.add(activeIngredient);
  }
  
  /**
   * Set the additionalType property value for this Drug object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the administrationRoute property value for this Drug object; overwriting any existing values.
   *
   * @param administrationRoute The value to set.
   */
  public void setAdministrationRoute(String administrationRoute) {
  	this.administrationRoute.clear();
  	this.administrationRoute.add(administrationRoute);
  }
  
  /**
   * Set the adverseOutcome property value for this Drug object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.setAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Set the alcoholWarning property value for this Drug object; overwriting any existing values.
   *
   * @param alcoholWarning The value to set.
   */
  public void setAlcoholWarning(String alcoholWarning) {
  	this.alcoholWarning.clear();
  	this.alcoholWarning.add(alcoholWarning);
  }
  
  /**
   * Set the alternateName property value for this Drug object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the availableStrength property value for this Drug object; overwriting any existing values.
   *
   * @param availableStrength The value to set.
   */
  public void setAvailableStrength(DrugStrength availableStrength) {
  	this.availableStrength.clear();
  	this.availableStrength.add(availableStrength);
  }
  
  /**
   * Set the breastfeedingWarning property value for this Drug object; overwriting any existing values.
   *
   * @param breastfeedingWarning The value to set.
   */
  public void setBreastfeedingWarning(String breastfeedingWarning) {
  	this.breastfeedingWarning.clear();
  	this.breastfeedingWarning.add(breastfeedingWarning);
  }
  
  /**
   * Set the clincalPharmacology property value for this Drug object; overwriting any existing values.
   *
   * @param clincalPharmacology The value to set.
   */
  public void setClincalPharmacology(String clincalPharmacology) {
  	this.clincalPharmacology.clear();
  	this.clincalPharmacology.add(clincalPharmacology);
  }
  
  /**
   * Set the code property value for this Drug object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the contraindication property value for this Drug object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication) {
    medicalTherapy.setContraindication(contraindication);
  }
  
  /**
   * Set the cost property value for this Drug object; overwriting any existing values.
   *
   * @param cost The value to set.
   */
  public void setCost(DrugCost cost) {
  	this.cost.clear();
  	this.cost.add(cost);
  }
  
  /**
   * Set the description property value for this Drug object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the dosageForm property value for this Drug object; overwriting any existing values.
   *
   * @param dosageForm The value to set.
   */
  public void setDosageForm(String dosageForm) {
  	this.dosageForm.clear();
  	this.dosageForm.add(dosageForm);
  }
  
  /**
   * Set the doseSchedule property value for this Drug object; overwriting any existing values.
   *
   * @param doseSchedule The value to set.
   */
  public void setDoseSchedule(DoseSchedule doseSchedule) {
  	this.doseSchedule.clear();
  	this.doseSchedule.add(doseSchedule);
  }
  
  /**
   * Set the drugClass property value for this Drug object; overwriting any existing values.
   *
   * @param drugClass The value to set.
   */
  public void setDrugClass(DrugClass drugClass) {
  	this.drugClass.clear();
  	this.drugClass.add(drugClass);
  }
  
  /**
   * Set the duplicateTherapy property value for this Drug object; overwriting any existing values.
   *
   * @param duplicateTherapy The value to set.
   */
  public void setDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.setDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Set the foodWarning property value for this Drug object; overwriting any existing values.
   *
   * @param foodWarning The value to set.
   */
  public void setFoodWarning(String foodWarning) {
  	this.foodWarning.clear();
  	this.foodWarning.add(foodWarning);
  }
  
  /**
   * Set the guideline property value for this Drug object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this Drug object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the indication property value for this Drug object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication) {
    medicalTherapy.setIndication(indication);
  }
  
  /**
   * Set the interactingDrug property value for this Drug object; overwriting any existing values.
   *
   * @param interactingDrug The value to set.
   */
  public void setInteractingDrug(Drug interactingDrug) {
  	this.interactingDrug.clear();
  	this.interactingDrug.add(interactingDrug);
  }
  
  /**
   * Set the isAvailableGenerically property value for this Drug object; overwriting any existing values.
   *
   * @param isAvailableGenerically The value to set.
   */
  public void setIsAvailableGenerically(Boolean isAvailableGenerically) {
  	this.isAvailableGenerically.clear();
  	this.isAvailableGenerically.add(isAvailableGenerically);
  }
  
  /**
   * Set the isProprietary property value for this Drug object; overwriting any existing values.
   *
   * @param isProprietary The value to set.
   */
  public void setIsProprietary(Boolean isProprietary) {
  	this.isProprietary.clear();
  	this.isProprietary.add(isProprietary);
  }
  
  /**
   * Set the labelDetails property value for this Drug object; overwriting any existing values.
   *
   * @param labelDetails The value to set.
   */
  public void setLabelDetails(URL labelDetails) {
  	this.labelDetails.clear();
  	this.labelDetails.add(labelDetails);
  }
  
  /**
   * Set the legalStatus property value for this Drug object; overwriting any existing values.
   *
   * @param legalStatus The value to set.
   */
  public void setLegalStatus(DrugLegalStatus legalStatus) {
  	this.legalStatus.clear();
  	this.legalStatus.add(legalStatus);
  }
  
  /**
   * Set the manufacturer property value for this Drug object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer) {
  	this.manufacturer.clear();
  	this.manufacturer.add(manufacturer);
  }
  
  /**
   * Set the mechanismOfAction property value for this Drug object; overwriting any existing values.
   *
   * @param mechanismOfAction The value to set.
   */
  public void setMechanismOfAction(String mechanismOfAction) {
  	this.mechanismOfAction.clear();
  	this.mechanismOfAction.add(mechanismOfAction);
  }
  
  /**
   * Set the medicineSystem property value for this Drug object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this Drug object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the nonProprietaryName property value for this Drug object; overwriting any existing values.
   *
   * @param nonProprietaryName The value to set.
   */
  public void setNonProprietaryName(String nonProprietaryName) {
  	this.nonProprietaryName.clear();
  	this.nonProprietaryName.add(nonProprietaryName);
  }
  
  /**
   * Set the overdosage property value for this Drug object; overwriting any existing values.
   *
   * @param overdosage The value to set.
   */
  public void setOverdosage(String overdosage) {
  	this.overdosage.clear();
  	this.overdosage.add(overdosage);
  }
  
  /**
   * Set the pregnancyCategory property value for this Drug object; overwriting any existing values.
   *
   * @param pregnancyCategory The value to set.
   */
  public void setPregnancyCategory(DrugPregnancyCategory pregnancyCategory) {
  	this.pregnancyCategory.clear();
  	this.pregnancyCategory.add(pregnancyCategory);
  }
  
  /**
   * Set the pregnancyWarning property value for this Drug object; overwriting any existing values.
   *
   * @param pregnancyWarning The value to set.
   */
  public void setPregnancyWarning(String pregnancyWarning) {
  	this.pregnancyWarning.clear();
  	this.pregnancyWarning.add(pregnancyWarning);
  }
  
  /**
   * Set the prescribingInfo property value for this Drug object; overwriting any existing values.
   *
   * @param prescribingInfo The value to set.
   */
  public void setPrescribingInfo(URL prescribingInfo) {
  	this.prescribingInfo.clear();
  	this.prescribingInfo.add(prescribingInfo);
  }
  
  /**
   * Set the prescriptionStatus property value for this Drug object; overwriting any existing values.
   *
   * @param prescriptionStatus The value to set.
   */
  public void setPrescriptionStatus(DrugPrescriptionStatus prescriptionStatus) {
  	this.prescriptionStatus.clear();
  	this.prescriptionStatus.add(prescriptionStatus);
  }
  
  /**
   * Set the recognizingAuthority property value for this Drug object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relatedDrug property value for this Drug object; overwriting any existing values.
   *
   * @param relatedDrug The value to set.
   */
  public void setRelatedDrug(Drug relatedDrug) {
  	this.relatedDrug.clear();
  	this.relatedDrug.add(relatedDrug);
  }
  
  /**
   * Set the relevantSpecialty property value for this Drug object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this Drug object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seriousAdverseOutcome property value for this Drug object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.setSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Set the study property value for this Drug object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this Drug object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the warning property value for this Drug object; overwriting any existing values.
   *
   * @param warning The value to set.
   */
  public void setWarning(Thing warning) {
  	this.warning.clear();
  	this.warning.add(warning);
  }
  
  /**
   * Set the activeIngredient property values for this Drug object; overwriting any existing values.
   *
   * @param activeIngredients The list of values to set.
   */
  public void setActiveIngredients(List<String> activeIngredients) {
  	this.activeIngredient = activeIngredients;
  }
  
  /**
   * Set the additionalType property values for this Drug object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the administrationRoute property values for this Drug object; overwriting any existing values.
   *
   * @param administrationRoutes The list of values to set.
   */
  public void setAdministrationRoutes(List<String> administrationRoutes) {
  	this.administrationRoute = administrationRoutes;
  }
  
  /**
   * Set the adverseOutcome property values for this Drug object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes) {
    medicalTherapy.setAdverseOutcomes(adverseOutcomes);
  }
  
  /**
   * Set the alcoholWarning property values for this Drug object; overwriting any existing values.
   *
   * @param alcoholWarnings The list of values to set.
   */
  public void setAlcoholWarnings(List<String> alcoholWarnings) {
  	this.alcoholWarning = alcoholWarnings;
  }
  
  /**
   * Set the alternateName property values for this Drug object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the availableStrength property values for this Drug object; overwriting any existing values.
   *
   * @param availableStrengths The list of values to set.
   */
  public void setAvailableStrengths(List<DrugStrength> availableStrengths) {
  	this.availableStrength = availableStrengths;
  }
  
  /**
   * Set the breastfeedingWarning property values for this Drug object; overwriting any existing values.
   *
   * @param breastfeedingWarnings The list of values to set.
   */
  public void setBreastfeedingWarnings(List<String> breastfeedingWarnings) {
  	this.breastfeedingWarning = breastfeedingWarnings;
  }
  
  /**
   * Set the clincalPharmacology property values for this Drug object; overwriting any existing values.
   *
   * @param clincalPharmacologies The list of values to set.
   */
  public void setClincalPharmacologies(List<String> clincalPharmacologies) {
  	this.clincalPharmacology = clincalPharmacologies;
  }
  
  /**
   * Set the code property values for this Drug object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the contraindication property values for this Drug object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications) {
    medicalTherapy.setContraindications(contraindications);
  }
  
  /**
   * Set the cost property values for this Drug object; overwriting any existing values.
   *
   * @param costs The list of values to set.
   */
  public void setCosts(List<DrugCost> costs) {
  	this.cost = costs;
  }
  
  /**
   * Set the description property values for this Drug object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the dosageForm property values for this Drug object; overwriting any existing values.
   *
   * @param dosageForms The list of values to set.
   */
  public void setDosageForms(List<String> dosageForms) {
  	this.dosageForm = dosageForms;
  }
  
  /**
   * Set the doseSchedule property values for this Drug object; overwriting any existing values.
   *
   * @param doseSchedules The list of values to set.
   */
  public void setDoseSchedules(List<DoseSchedule> doseSchedules) {
  	this.doseSchedule = doseSchedules;
  }
  
  /**
   * Set the drugClass property values for this Drug object; overwriting any existing values.
   *
   * @param drugClasses The list of values to set.
   */
  public void setDrugClasses(List<DrugClass> drugClasses) {
  	this.drugClass = drugClasses;
  }
  
  /**
   * Set the duplicateTherapy property values for this Drug object; overwriting any existing values.
   *
   * @param duplicateTherapies The list of values to set.
   */
  public void setDuplicateTherapies(List<MedicalTherapy> duplicateTherapies) {
    medicalTherapy.setDuplicateTherapies(duplicateTherapies);
  }
  
  /**
   * Set the foodWarning property values for this Drug object; overwriting any existing values.
   *
   * @param foodWarnings The list of values to set.
   */
  public void setFoodWarnings(List<String> foodWarnings) {
  	this.foodWarning = foodWarnings;
  }
  
  /**
   * Set the guideline property values for this Drug object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this Drug object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the indication property values for this Drug object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications) {
    medicalTherapy.setIndications(indications);
  }
  
  /**
   * Set the interactingDrug property values for this Drug object; overwriting any existing values.
   *
   * @param interactingDrugs The list of values to set.
   */
  public void setInteractingDrugs(List<Drug> interactingDrugs) {
  	this.interactingDrug = interactingDrugs;
  }
  
  /**
   * Set the isAvailableGenerically property values for this Drug object; overwriting any existing values.
   *
   * @param isAvailableGenericallies The list of values to set.
   */
  public void setIsAvailableGenericallies(List<Boolean> isAvailableGenericallies) {
  	this.isAvailableGenerically = isAvailableGenericallies;
  }
  
  /**
   * Set the isProprietary property values for this Drug object; overwriting any existing values.
   *
   * @param isProprietaries The list of values to set.
   */
  public void setIsProprietaries(List<Boolean> isProprietaries) {
  	this.isProprietary = isProprietaries;
  }
  
  /**
   * Set the labelDetails property values for this Drug object; overwriting any existing values.
   *
   * @param labelDetailss The list of values to set.
   */
  public void setLabelDetailss(List<URL> labelDetailss) {
  	this.labelDetails = labelDetailss;
  }
  
  /**
   * Set the legalStatus property values for this Drug object; overwriting any existing values.
   *
   * @param legalStatuses The list of values to set.
   */
  public void setLegalStatuses(List<DrugLegalStatus> legalStatuses) {
  	this.legalStatus = legalStatuses;
  }
  
  /**
   * Set the manufacturer property values for this Drug object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers) {
  	this.manufacturer = manufacturers;
  }
  
  /**
   * Set the mechanismOfAction property values for this Drug object; overwriting any existing values.
   *
   * @param mechanismOfActions The list of values to set.
   */
  public void setMechanismOfActions(List<String> mechanismOfActions) {
  	this.mechanismOfAction = mechanismOfActions;
  }
  
  /**
   * Set the medicineSystem property values for this Drug object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this Drug object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the nonProprietaryName property values for this Drug object; overwriting any existing values.
   *
   * @param nonProprietaryNames The list of values to set.
   */
  public void setNonProprietaryNames(List<String> nonProprietaryNames) {
  	this.nonProprietaryName = nonProprietaryNames;
  }
  
  /**
   * Set the overdosage property values for this Drug object; overwriting any existing values.
   *
   * @param overdosages The list of values to set.
   */
  public void setOverdosages(List<String> overdosages) {
  	this.overdosage = overdosages;
  }
  
  /**
   * Set the pregnancyCategory property values for this Drug object; overwriting any existing values.
   *
   * @param pregnancyCategories The list of values to set.
   */
  public void setPregnancyCategories(List<DrugPregnancyCategory> pregnancyCategories) {
  	this.pregnancyCategory = pregnancyCategories;
  }
  
  /**
   * Set the pregnancyWarning property values for this Drug object; overwriting any existing values.
   *
   * @param pregnancyWarnings The list of values to set.
   */
  public void setPregnancyWarnings(List<String> pregnancyWarnings) {
  	this.pregnancyWarning = pregnancyWarnings;
  }
  
  /**
   * Set the prescribingInfo property values for this Drug object; overwriting any existing values.
   *
   * @param prescribingInfoes The list of values to set.
   */
  public void setPrescribingInfoes(List<URL> prescribingInfoes) {
  	this.prescribingInfo = prescribingInfoes;
  }
  
  /**
   * Set the prescriptionStatus property values for this Drug object; overwriting any existing values.
   *
   * @param prescriptionStatuses The list of values to set.
   */
  public void setPrescriptionStatuses(List<DrugPrescriptionStatus> prescriptionStatuses) {
  	this.prescriptionStatus = prescriptionStatuses;
  }
  
  /**
   * Set the recognizingAuthority property values for this Drug object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relatedDrug property values for this Drug object; overwriting any existing values.
   *
   * @param relatedDrugs The list of values to set.
   */
  public void setRelatedDrugs(List<Drug> relatedDrugs) {
  	this.relatedDrug = relatedDrugs;
  }
  
  /**
   * Set the relevantSpecialty property values for this Drug object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this Drug object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seriousAdverseOutcome property values for this Drug object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes) {
    medicalTherapy.setSeriousAdverseOutcomes(seriousAdverseOutcomes);
  }
  
  /**
   * Set the study property values for this Drug object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this Drug object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the warning property values for this Drug object; overwriting any existing values.
   *
   * @param warnings The list of values to set.
   */
  public void setWarnings(List<Thing> warnings) {
  	this.warning = warnings;
  }
  
  /**
   * Adds a activeIngredient property value for this Drug object; appending it to the list of existing values.
   *
   * @param activeIngredient The value to add.
   */
  public void addActiveIngredient(String activeIngredient) {
  	this.activeIngredient.add(activeIngredient);
  }
  
  /**
   * Adds a additionalType property value for this Drug object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a administrationRoute property value for this Drug object; appending it to the list of existing values.
   *
   * @param administrationRoute The value to add.
   */
  public void addAdministrationRoute(String administrationRoute) {
  	this.administrationRoute.add(administrationRoute);
  }
  
  /**
   * Adds a adverseOutcome property value for this Drug object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.addAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Adds a alcoholWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param alcoholWarning The value to add.
   */
  public void addAlcoholWarning(String alcoholWarning) {
  	this.alcoholWarning.add(alcoholWarning);
  }
  
  /**
   * Adds a alternateName property value for this Drug object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a availableStrength property value for this Drug object; appending it to the list of existing values.
   *
   * @param availableStrength The value to add.
   */
  public void addAvailableStrength(DrugStrength availableStrength) {
  	this.availableStrength.add(availableStrength);
  }
  
  /**
   * Adds a breastfeedingWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param breastfeedingWarning The value to add.
   */
  public void addBreastfeedingWarning(String breastfeedingWarning) {
  	this.breastfeedingWarning.add(breastfeedingWarning);
  }
  
  /**
   * Adds a clincalPharmacology property value for this Drug object; appending it to the list of existing values.
   *
   * @param clincalPharmacology The value to add.
   */
  public void addClincalPharmacology(String clincalPharmacology) {
  	this.clincalPharmacology.add(clincalPharmacology);
  }
  
  /**
   * Adds a code property value for this Drug object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a contraindication property value for this Drug object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication) {
    medicalTherapy.addContraindication(contraindication);
  }
  
  /**
   * Adds a cost property value for this Drug object; appending it to the list of existing values.
   *
   * @param cost The value to add.
   */
  public void addCost(DrugCost cost) {
  	this.cost.add(cost);
  }
  
  /**
   * Adds a description property value for this Drug object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a dosageForm property value for this Drug object; appending it to the list of existing values.
   *
   * @param dosageForm The value to add.
   */
  public void addDosageForm(String dosageForm) {
  	this.dosageForm.add(dosageForm);
  }
  
  /**
   * Adds a doseSchedule property value for this Drug object; appending it to the list of existing values.
   *
   * @param doseSchedule The value to add.
   */
  public void addDoseSchedule(DoseSchedule doseSchedule) {
  	this.doseSchedule.add(doseSchedule);
  }
  
  /**
   * Adds a drugClass property value for this Drug object; appending it to the list of existing values.
   *
   * @param drugClass The value to add.
   */
  public void addDrugClass(DrugClass drugClass) {
  	this.drugClass.add(drugClass);
  }
  
  /**
   * Adds a duplicateTherapy property value for this Drug object; appending it to the list of existing values.
   *
   * @param duplicateTherapy The value to add.
   */
  public void addDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.addDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Adds a foodWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param foodWarning The value to add.
   */
  public void addFoodWarning(String foodWarning) {
  	this.foodWarning.add(foodWarning);
  }
  
  /**
   * Adds a guideline property value for this Drug object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this Drug object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a indication property value for this Drug object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication) {
    medicalTherapy.addIndication(indication);
  }
  
  /**
   * Adds a interactingDrug property value for this Drug object; appending it to the list of existing values.
   *
   * @param interactingDrug The value to add.
   */
  public void addInteractingDrug(Drug interactingDrug) {
  	this.interactingDrug.add(interactingDrug);
  }
  
  /**
   * Adds a isAvailableGenerically property value for this Drug object; appending it to the list of existing values.
   *
   * @param isAvailableGenerically The value to add.
   */
  public void addIsAvailableGenerically(Boolean isAvailableGenerically) {
  	this.isAvailableGenerically.add(isAvailableGenerically);
  }
  
  /**
   * Adds a isProprietary property value for this Drug object; appending it to the list of existing values.
   *
   * @param isProprietary The value to add.
   */
  public void addIsProprietary(Boolean isProprietary) {
  	this.isProprietary.add(isProprietary);
  }
  
  /**
   * Adds a labelDetails property value for this Drug object; appending it to the list of existing values.
   *
   * @param labelDetails The value to add.
   */
  public void addLabelDetails(URL labelDetails) {
  	this.labelDetails.add(labelDetails);
  }
  
  /**
   * Adds a legalStatus property value for this Drug object; appending it to the list of existing values.
   *
   * @param legalStatus The value to add.
   */
  public void addLegalStatus(DrugLegalStatus legalStatus) {
  	this.legalStatus.add(legalStatus);
  }
  
  /**
   * Adds a manufacturer property value for this Drug object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer) {
  	this.manufacturer.add(manufacturer);
  }
  
  /**
   * Adds a mechanismOfAction property value for this Drug object; appending it to the list of existing values.
   *
   * @param mechanismOfAction The value to add.
   */
  public void addMechanismOfAction(String mechanismOfAction) {
  	this.mechanismOfAction.add(mechanismOfAction);
  }
  
  /**
   * Adds a medicineSystem property value for this Drug object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this Drug object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a nonProprietaryName property value for this Drug object; appending it to the list of existing values.
   *
   * @param nonProprietaryName The value to add.
   */
  public void addNonProprietaryName(String nonProprietaryName) {
  	this.nonProprietaryName.add(nonProprietaryName);
  }
  
  /**
   * Adds a overdosage property value for this Drug object; appending it to the list of existing values.
   *
   * @param overdosage The value to add.
   */
  public void addOverdosage(String overdosage) {
  	this.overdosage.add(overdosage);
  }
  
  /**
   * Adds a pregnancyCategory property value for this Drug object; appending it to the list of existing values.
   *
   * @param pregnancyCategory The value to add.
   */
  public void addPregnancyCategory(DrugPregnancyCategory pregnancyCategory) {
  	this.pregnancyCategory.add(pregnancyCategory);
  }
  
  /**
   * Adds a pregnancyWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param pregnancyWarning The value to add.
   */
  public void addPregnancyWarning(String pregnancyWarning) {
  	this.pregnancyWarning.add(pregnancyWarning);
  }
  
  /**
   * Adds a prescribingInfo property value for this Drug object; appending it to the list of existing values.
   *
   * @param prescribingInfo The value to add.
   */
  public void addPrescribingInfo(URL prescribingInfo) {
  	this.prescribingInfo.add(prescribingInfo);
  }
  
  /**
   * Adds a prescriptionStatus property value for this Drug object; appending it to the list of existing values.
   *
   * @param prescriptionStatus The value to add.
   */
  public void addPrescriptionStatus(DrugPrescriptionStatus prescriptionStatus) {
  	this.prescriptionStatus.add(prescriptionStatus);
  }
  
  /**
   * Adds a recognizingAuthority property value for this Drug object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relatedDrug property value for this Drug object; appending it to the list of existing values.
   *
   * @param relatedDrug The value to add.
   */
  public void addRelatedDrug(Drug relatedDrug) {
  	this.relatedDrug.add(relatedDrug);
  }
  
  /**
   * Adds a relevantSpecialty property value for this Drug object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this Drug object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seriousAdverseOutcome property value for this Drug object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.addSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Adds a study property value for this Drug object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this Drug object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a warning property value for this Drug object; appending it to the list of existing values.
   *
   * @param warning The value to add.
   */
  public void addWarning(Thing warning) {
  	this.warning.add(warning);
  }
  
}