package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Audience;
import org.schema.Diet;
import org.schema.Distance;
import org.schema.Event;
import org.schema.ExerciseAction;
import org.schema.ExercisePlan;
import org.schema.Person;
import org.schema.Place;
import org.schema.SportsActivityLocation;
import org.schema.SportsEvent;
import org.schema.SportsTeam;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The act of participating in exertive activity for the purposes of improving health and fitness
 */
public class ExerciseActionImpl extends SchemaObjectImpl implements ExerciseAction {


  private ActionImpl action;
  private PlayActionImpl playAction;
  private ThingImpl thing;

  /**
   * A sub property of location. The course where this action was taken.
   */
  private List<Place> course = new LinkedList<Place>();
  
  /**
   * A sub property of instrument. The died used in this action.
   */
  private List<Diet> diet = new LinkedList<Diet>();
  
  /**
   * A sub property of asset. The distance travelled.
   */
  private List<Distance> distance = new LinkedList<Distance>();
  
  /**
   * A sub property of instrument. The exercise plan used on this action.
   */
  private List<ExercisePlan> exercisePlan = new LinkedList<ExercisePlan>();
  
  /**
   * Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.
   */
  private List<String> exerciseType = new LinkedList<String>();
  
  /**
   * A sub property of location. The original location of the object or the agent before the action.
   */
  private List<Thing> fromLocation = new LinkedList<Thing>();
  
  /**
   * A sub property of participant. The oponent on this action.
   */
  private List<Person> oponent = new LinkedList<Person>();
  
  /**
   * A sub property of location. The sports activity location where this action occurred.
   */
  private List<SportsActivityLocation> sportsActivityLocation = new LinkedList<SportsActivityLocation>();
  
  /**
   * A sub property of location. The sports event where this action occurred.
   */
  private List<SportsEvent> sportsEvent = new LinkedList<SportsEvent>();
  
  /**
   * A sub property of participant. The sports team that participated on this action.
   */
  private List<SportsTeam> sportsTeam = new LinkedList<SportsTeam>();
  
  /**
   * A sub property of location. The final location of the object or the agent after the action.
   */
  private List<Thing> toLocation = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ExerciseActionImpl() {
    super("http://schema.org/ExerciseAction");
    playAction = new PlayActionImpl();
  }
  /**
   * Get a single additionalType property value for this ExerciseAction object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single agent property value for this ExerciseAction object.
   *
   * @return The first agent property value.
   */
  public Thing getAgent() {
    return action.getAgent();
  }
  
  /**
   * Get a single alternateName property value for this ExerciseAction object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single audience property value for this ExerciseAction object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience() {
    return playAction.getAudience();
  }
  
  /**
   * Get a single course property value for this ExerciseAction object.
   *
   * @return The first course property value.
   */
  public Place getCourse() {
  	return this.course.isEmpty() ? null : this.course.get(0);
  }
  
  /**
   * Get a single description property value for this ExerciseAction object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single diet property value for this ExerciseAction object.
   *
   * @return The first diet property value.
   */
  public Diet getDiet() {
  	return this.diet.isEmpty() ? null : this.diet.get(0);
  }
  
  /**
   * Get a single distance property value for this ExerciseAction object.
   *
   * @return The first distance property value.
   */
  public Distance getDistance() {
  	return this.distance.isEmpty() ? null : this.distance.get(0);
  }
  
  /**
   * Get a single endTime property value for this ExerciseAction object.
   *
   * @return The first endTime property value.
   */
  public Date getEndTime() {
    return action.getEndTime();
  }
  
  /**
   * Get a single event property value for this ExerciseAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent() {
    return playAction.getEvent();
  }
  
  /**
   * Get a single exercisePlan property value for this ExerciseAction object.
   *
   * @return The first exercisePlan property value.
   */
  public ExercisePlan getExercisePlan() {
  	return this.exercisePlan.isEmpty() ? null : this.exercisePlan.get(0);
  }
  
  /**
   * Get a single exerciseType property value for this ExerciseAction object.
   *
   * @return The first exerciseType property value.
   */
  public String getExerciseType() {
  	return this.exerciseType.isEmpty() ? null : this.exerciseType.get(0);
  }
  
  /**
   * Get a single fromLocation property value for this ExerciseAction object.
   *
   * @return The first fromLocation property value.
   */
  public Thing getFromLocation() {
  	return this.fromLocation.isEmpty() ? null : this.fromLocation.get(0);
  }
  
  /**
   * Get a single image property value for this ExerciseAction object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single instrument property value for this ExerciseAction object.
   *
   * @return The first instrument property value.
   */
  public Thing getInstrument() {
    return action.getInstrument();
  }
  
  /**
   * Get a single location property value for this ExerciseAction object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
    return action.getLocation();
  }
  
  /**
   * Get a single name property value for this ExerciseAction object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single object property value for this ExerciseAction object.
   *
   * @return The first object property value.
   */
  public Thing getObject() {
    return action.getObject();
  }
  
  /**
   * Get a single oponent property value for this ExerciseAction object.
   *
   * @return The first oponent property value.
   */
  public Person getOponent() {
  	return this.oponent.isEmpty() ? null : this.oponent.get(0);
  }
  
  /**
   * Get a single participant property value for this ExerciseAction object.
   *
   * @return The first participant property value.
   */
  public Thing getParticipant() {
    return action.getParticipant();
  }
  
  /**
   * Get a single result property value for this ExerciseAction object.
   *
   * @return The first result property value.
   */
  public Thing getResult() {
    return action.getResult();
  }
  
  /**
   * Get a single sameAs property value for this ExerciseAction object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single sportsActivityLocation property value for this ExerciseAction object.
   *
   * @return The first sportsActivityLocation property value.
   */
  public SportsActivityLocation getSportsActivityLocation() {
  	return this.sportsActivityLocation.isEmpty() ? null : this.sportsActivityLocation.get(0);
  }
  
  /**
   * Get a single sportsEvent property value for this ExerciseAction object.
   *
   * @return The first sportsEvent property value.
   */
  public SportsEvent getSportsEvent() {
  	return this.sportsEvent.isEmpty() ? null : this.sportsEvent.get(0);
  }
  
  /**
   * Get a single sportsTeam property value for this ExerciseAction object.
   *
   * @return The first sportsTeam property value.
   */
  public SportsTeam getSportsTeam() {
  	return this.sportsTeam.isEmpty() ? null : this.sportsTeam.get(0);
  }
  
  /**
   * Get a single startTime property value for this ExerciseAction object.
   *
   * @return The first startTime property value.
   */
  public Date getStartTime() {
    return action.getStartTime();
  }
  
  /**
   * Get a single toLocation property value for this ExerciseAction object.
   *
   * @return The first toLocation property value.
   */
  public Thing getToLocation() {
  	return this.toLocation.isEmpty() ? null : this.toLocation.get(0);
  }
  
  /**
   * Get a single url property value for this ExerciseAction object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this ExerciseAction object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the agent property values for this ExerciseAction object.
   *
   * @return A list of agent property values.
   */
  public List<Thing> getAgents() {
    return action.getAgents();
  }
  
  /**
   * Get all the alternateName property values for this ExerciseAction object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the audience property values for this ExerciseAction object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences() {
    return playAction.getAudiences();
  }
  
  /**
   * Get all the course property values for this ExerciseAction object.
   *
   * @return A list of course property values.
   */
  public List<Place> getCourses() {
  	return this.course;
  }
  
  /**
   * Get all the description property values for this ExerciseAction object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the diet property values for this ExerciseAction object.
   *
   * @return A list of diet property values.
   */
  public List<Diet> getDiets() {
  	return this.diet;
  }
  
  /**
   * Get all the distance property values for this ExerciseAction object.
   *
   * @return A list of distance property values.
   */
  public List<Distance> getDistances() {
  	return this.distance;
  }
  
  /**
   * Get all the endTime property values for this ExerciseAction object.
   *
   * @return A list of endTime property values.
   */
  public List<Date> getEndTimes() {
    return action.getEndTimes();
  }
  
  /**
   * Get all the event property values for this ExerciseAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents() {
    return playAction.getEvents();
  }
  
  /**
   * Get all the exercisePlan property values for this ExerciseAction object.
   *
   * @return A list of exercisePlan property values.
   */
  public List<ExercisePlan> getExercisePlans() {
  	return this.exercisePlan;
  }
  
  /**
   * Get all the exerciseType property values for this ExerciseAction object.
   *
   * @return A list of exerciseType property values.
   */
  public List<String> getExerciseTypes() {
  	return this.exerciseType;
  }
  
  /**
   * Get all the fromLocation property values for this ExerciseAction object.
   *
   * @return A list of fromLocation property values.
   */
  public List<Thing> getFromLocations() {
  	return this.fromLocation;
  }
  
  /**
   * Get all the image property values for this ExerciseAction object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the instrument property values for this ExerciseAction object.
   *
   * @return A list of instrument property values.
   */
  public List<Thing> getInstruments() {
    return action.getInstruments();
  }
  
  /**
   * Get all the location property values for this ExerciseAction object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
    return action.getLocations();
  }
  
  /**
   * Get all the name property values for this ExerciseAction object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the object property values for this ExerciseAction object.
   *
   * @return A list of object property values.
   */
  public List<Thing> getObjects() {
    return action.getObjects();
  }
  
  /**
   * Get all the oponent property values for this ExerciseAction object.
   *
   * @return A list of oponent property values.
   */
  public List<Person> getOponents() {
  	return this.oponent;
  }
  
  /**
   * Get all the participant property values for this ExerciseAction object.
   *
   * @return A list of participant property values.
   */
  public List<Thing> getParticipants() {
    return action.getParticipants();
  }
  
  /**
   * Get all the result property values for this ExerciseAction object.
   *
   * @return A list of result property values.
   */
  public List<Thing> getResults() {
    return action.getResults();
  }
  
  /**
   * Get all the sameAs property values for this ExerciseAction object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the sportsActivityLocation property values for this ExerciseAction object.
   *
   * @return A list of sportsActivityLocation property values.
   */
  public List<SportsActivityLocation> getSportsActivityLocations() {
  	return this.sportsActivityLocation;
  }
  
  /**
   * Get all the sportsEvent property values for this ExerciseAction object.
   *
   * @return A list of sportsEvent property values.
   */
  public List<SportsEvent> getSportsEvents() {
  	return this.sportsEvent;
  }
  
  /**
   * Get all the sportsTeam property values for this ExerciseAction object.
   *
   * @return A list of sportsTeam property values.
   */
  public List<SportsTeam> getSportsTeams() {
  	return this.sportsTeam;
  }
  
  /**
   * Get all the startTime property values for this ExerciseAction object.
   *
   * @return A list of startTime property values.
   */
  public List<Date> getStartTimes() {
    return action.getStartTimes();
  }
  
  /**
   * Get all the toLocation property values for this ExerciseAction object.
   *
   * @return A list of toLocation property values.
   */
  public List<Thing> getToLocations() {
  	return this.toLocation;
  }
  
  /**
   * Get all the url property values for this ExerciseAction object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the agent property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param agent The value to set.
   */
  public void setAgent(Thing agent) {
    action.setAgent(agent);
  }
  
  /**
   * Set the alternateName property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the audience property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience) {
    playAction.setAudience(audience);
  }
  
  /**
   * Set the course property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param course The value to set.
   */
  public void setCourse(Place course) {
  	this.course.clear();
  	this.course.add(course);
  }
  
  /**
   * Set the description property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the diet property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param diet The value to set.
   */
  public void setDiet(Diet diet) {
  	this.diet.clear();
  	this.diet.add(diet);
  }
  
  /**
   * Set the distance property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param distance The value to set.
   */
  public void setDistance(Distance distance) {
  	this.distance.clear();
  	this.distance.add(distance);
  }
  
  /**
   * Set the endTime property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param endTime The value to set.
   */
  public void setEndTime(Date endTime) {
    action.setEndTime(endTime);
  }
  
  /**
   * Set the event property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event) {
    playAction.setEvent(event);
  }
  
  /**
   * Set the exercisePlan property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param exercisePlan The value to set.
   */
  public void setExercisePlan(ExercisePlan exercisePlan) {
  	this.exercisePlan.clear();
  	this.exercisePlan.add(exercisePlan);
  }
  
  /**
   * Set the exerciseType property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param exerciseType The value to set.
   */
  public void setExerciseType(String exerciseType) {
  	this.exerciseType.clear();
  	this.exerciseType.add(exerciseType);
  }
  
  /**
   * Set the fromLocation property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param fromLocation The value to set.
   */
  public void setFromLocation(Thing fromLocation) {
  	this.fromLocation.clear();
  	this.fromLocation.add(fromLocation);
  }
  
  /**
   * Set the image property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the instrument property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param instrument The value to set.
   */
  public void setInstrument(Thing instrument) {
    action.setInstrument(instrument);
  }
  
  /**
   * Set the location property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
    action.setLocation(location);
  }
  
  /**
   * Set the name property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the object property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param object The value to set.
   */
  public void setObject(Thing object) {
    action.setObject(object);
  }
  
  /**
   * Set the oponent property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param oponent The value to set.
   */
  public void setOponent(Person oponent) {
  	this.oponent.clear();
  	this.oponent.add(oponent);
  }
  
  /**
   * Set the participant property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param participant The value to set.
   */
  public void setParticipant(Thing participant) {
    action.setParticipant(participant);
  }
  
  /**
   * Set the result property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param result The value to set.
   */
  public void setResult(Thing result) {
    action.setResult(result);
  }
  
  /**
   * Set the sameAs property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the sportsActivityLocation property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsActivityLocation The value to set.
   */
  public void setSportsActivityLocation(SportsActivityLocation sportsActivityLocation) {
  	this.sportsActivityLocation.clear();
  	this.sportsActivityLocation.add(sportsActivityLocation);
  }
  
  /**
   * Set the sportsEvent property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsEvent The value to set.
   */
  public void setSportsEvent(SportsEvent sportsEvent) {
  	this.sportsEvent.clear();
  	this.sportsEvent.add(sportsEvent);
  }
  
  /**
   * Set the sportsTeam property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsTeam The value to set.
   */
  public void setSportsTeam(SportsTeam sportsTeam) {
  	this.sportsTeam.clear();
  	this.sportsTeam.add(sportsTeam);
  }
  
  /**
   * Set the startTime property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param startTime The value to set.
   */
  public void setStartTime(Date startTime) {
    action.setStartTime(startTime);
  }
  
  /**
   * Set the toLocation property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param toLocation The value to set.
   */
  public void setToLocation(Thing toLocation) {
  	this.toLocation.clear();
  	this.toLocation.add(toLocation);
  }
  
  /**
   * Set the url property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the agent property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param agents The list of values to set.
   */
  public void setAgents(List<Thing> agents) {
    action.setAgents(agents);
  }
  
  /**
   * Set the alternateName property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the audience property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences) {
    playAction.setAudiences(audiences);
  }
  
  /**
   * Set the course property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param courses The list of values to set.
   */
  public void setCourses(List<Place> courses) {
  	this.course = courses;
  }
  
  /**
   * Set the description property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the diet property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param diets The list of values to set.
   */
  public void setDiets(List<Diet> diets) {
  	this.diet = diets;
  }
  
  /**
   * Set the distance property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param distances The list of values to set.
   */
  public void setDistances(List<Distance> distances) {
  	this.distance = distances;
  }
  
  /**
   * Set the endTime property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param endTimes The list of values to set.
   */
  public void setEndTimes(List<Date> endTimes) {
    action.setEndTimes(endTimes);
  }
  
  /**
   * Set the event property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events) {
    playAction.setEvents(events);
  }
  
  /**
   * Set the exercisePlan property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param exercisePlans The list of values to set.
   */
  public void setExercisePlans(List<ExercisePlan> exercisePlans) {
  	this.exercisePlan = exercisePlans;
  }
  
  /**
   * Set the exerciseType property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param exerciseTypes The list of values to set.
   */
  public void setExerciseTypes(List<String> exerciseTypes) {
  	this.exerciseType = exerciseTypes;
  }
  
  /**
   * Set the fromLocation property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param fromLocations The list of values to set.
   */
  public void setFromLocations(List<Thing> fromLocations) {
  	this.fromLocation = fromLocations;
  }
  
  /**
   * Set the image property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the instrument property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param instruments The list of values to set.
   */
  public void setInstruments(List<Thing> instruments) {
    action.setInstruments(instruments);
  }
  
  /**
   * Set the location property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
    action.setLocations(locations);
  }
  
  /**
   * Set the name property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the object property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param objects The list of values to set.
   */
  public void setObjects(List<Thing> objects) {
    action.setObjects(objects);
  }
  
  /**
   * Set the oponent property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param oponents The list of values to set.
   */
  public void setOponents(List<Person> oponents) {
  	this.oponent = oponents;
  }
  
  /**
   * Set the participant property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param participants The list of values to set.
   */
  public void setParticipants(List<Thing> participants) {
    action.setParticipants(participants);
  }
  
  /**
   * Set the result property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param results The list of values to set.
   */
  public void setResults(List<Thing> results) {
    action.setResults(results);
  }
  
  /**
   * Set the sameAs property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the sportsActivityLocation property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsActivityLocations The list of values to set.
   */
  public void setSportsActivityLocations(List<SportsActivityLocation> sportsActivityLocations) {
  	this.sportsActivityLocation = sportsActivityLocations;
  }
  
  /**
   * Set the sportsEvent property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsEvents The list of values to set.
   */
  public void setSportsEvents(List<SportsEvent> sportsEvents) {
  	this.sportsEvent = sportsEvents;
  }
  
  /**
   * Set the sportsTeam property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsTeams The list of values to set.
   */
  public void setSportsTeams(List<SportsTeam> sportsTeams) {
  	this.sportsTeam = sportsTeams;
  }
  
  /**
   * Set the startTime property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param startTimes The list of values to set.
   */
  public void setStartTimes(List<Date> startTimes) {
    action.setStartTimes(startTimes);
  }
  
  /**
   * Set the toLocation property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param toLocations The list of values to set.
   */
  public void setToLocations(List<Thing> toLocations) {
  	this.toLocation = toLocations;
  }
  
  /**
   * Set the url property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a agent property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param agent The value to add.
   */
  public void addAgent(Thing agent) {
    action.addAgent(agent);
  }
  
  /**
   * Adds a alternateName property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a audience property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience) {
    playAction.addAudience(audience);
  }
  
  /**
   * Adds a course property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param course The value to add.
   */
  public void addCourse(Place course) {
  	this.course.add(course);
  }
  
  /**
   * Adds a description property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a diet property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param diet The value to add.
   */
  public void addDiet(Diet diet) {
  	this.diet.add(diet);
  }
  
  /**
   * Adds a distance property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param distance The value to add.
   */
  public void addDistance(Distance distance) {
  	this.distance.add(distance);
  }
  
  /**
   * Adds a endTime property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param endTime The value to add.
   */
  public void addEndTime(Date endTime) {
    action.addEndTime(endTime);
  }
  
  /**
   * Adds a event property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event) {
    playAction.addEvent(event);
  }
  
  /**
   * Adds a exercisePlan property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param exercisePlan The value to add.
   */
  public void addExercisePlan(ExercisePlan exercisePlan) {
  	this.exercisePlan.add(exercisePlan);
  }
  
  /**
   * Adds a exerciseType property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param exerciseType The value to add.
   */
  public void addExerciseType(String exerciseType) {
  	this.exerciseType.add(exerciseType);
  }
  
  /**
   * Adds a fromLocation property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param fromLocation The value to add.
   */
  public void addFromLocation(Thing fromLocation) {
  	this.fromLocation.add(fromLocation);
  }
  
  /**
   * Adds a image property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a instrument property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param instrument The value to add.
   */
  public void addInstrument(Thing instrument) {
    action.addInstrument(instrument);
  }
  
  /**
   * Adds a location property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
    action.addLocation(location);
  }
  
  /**
   * Adds a name property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a object property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param object The value to add.
   */
  public void addObject(Thing object) {
    action.addObject(object);
  }
  
  /**
   * Adds a oponent property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param oponent The value to add.
   */
  public void addOponent(Person oponent) {
  	this.oponent.add(oponent);
  }
  
  /**
   * Adds a participant property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param participant The value to add.
   */
  public void addParticipant(Thing participant) {
    action.addParticipant(participant);
  }
  
  /**
   * Adds a result property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param result The value to add.
   */
  public void addResult(Thing result) {
    action.addResult(result);
  }
  
  /**
   * Adds a sameAs property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a sportsActivityLocation property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sportsActivityLocation The value to add.
   */
  public void addSportsActivityLocation(SportsActivityLocation sportsActivityLocation) {
  	this.sportsActivityLocation.add(sportsActivityLocation);
  }
  
  /**
   * Adds a sportsEvent property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sportsEvent The value to add.
   */
  public void addSportsEvent(SportsEvent sportsEvent) {
  	this.sportsEvent.add(sportsEvent);
  }
  
  /**
   * Adds a sportsTeam property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sportsTeam The value to add.
   */
  public void addSportsTeam(SportsTeam sportsTeam) {
  	this.sportsTeam.add(sportsTeam);
  }
  
  /**
   * Adds a startTime property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param startTime The value to add.
   */
  public void addStartTime(Date startTime) {
    action.addStartTime(startTime);
  }
  
  /**
   * Adds a toLocation property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param toLocation The value to add.
   */
  public void addToLocation(Thing toLocation) {
  	this.toLocation.add(toLocation);
  }
  
  /**
   * Adds a url property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}