package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.AlignmentObject;
import org.schema.Audience;
import org.schema.AudioObject;
import org.schema.Duration;
import org.schema.Energy;
import org.schema.ExercisePlan;
import org.schema.MediaObject;
import org.schema.MedicalCode;
import org.schema.MedicalContraindication;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalIndication;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Number;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.Review;
import org.schema.Thing;
import org.schema.VideoObject;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician.
 */
public class ExercisePlanImpl extends SchemaObjectImpl implements ExercisePlan {


  private CreativeWorkImpl creativeWork;
  private MedicalEntityImpl medicalEntity;
  private MedicalTherapyImpl medicalTherapy;
  private PhysicalActivityImpl physicalActivity;
  private ThingImpl thing;

  /**
   * Length of time to engage in the activity.
   */
  private List<Duration> activityDuration = new LinkedList<Duration>();
  
  /**
   * How often one should engage in the activity.
   */
  private List<String> activityFrequency = new LinkedList<String>();
  
  /**
   * Any additional component of the exercise prescription that may need to be articulated to the patient. This may include the order of exercises, the number of repetitions of movement, quantitative distance, progressions over time, etc.
   */
  private List<String> additionalVariable = new LinkedList<String>();
  
  /**
   * Type(s) of exercise or activity, such as strength training, flexibility training, aerobics, cardiac rehabilitation, etc.
   */
  private List<String> exerciseType = new LinkedList<String>();
  
  /**
   * Quantitative measure gauging the degree of force involved in the exercise, for example, heartbeats per minute. May include the velocity of the movement.
   */
  private List<String> intensity = new LinkedList<String>();
  
  /**
   * Number of times one should repeat the activity.
   */
  private List<Number> repetitions = new LinkedList<Number>();
  
  /**
   * How often one should break from the activity.
   */
  private List<String> restPeriods = new LinkedList<String>();
  
  /**
   * Quantitative measure of the physiologic output of the exercise; also referred to as energy expenditure.
   */
  private List<Energy> workload = new LinkedList<Energy>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ExercisePlanImpl() {
    super("http://schema.org/ExercisePlan");
    creativeWork = new CreativeWorkImpl();
    physicalActivity = new PhysicalActivityImpl();
  }
  /**
   * Get a single about property value for this ExercisePlan object.
   *
   * @return The first about property value.
   */
  public Thing getAbout() {
    return creativeWork.getAbout();
  }
  
  /**
   * Get a single accessibilityAPI property value for this ExercisePlan object.
   *
   * @return The first accessibilityAPI property value.
   */
  public String getAccessibilityAPI() {
    return creativeWork.getAccessibilityAPI();
  }
  
  /**
   * Get a single accessibilityControl property value for this ExercisePlan object.
   *
   * @return The first accessibilityControl property value.
   */
  public String getAccessibilityControl() {
    return creativeWork.getAccessibilityControl();
  }
  
  /**
   * Get a single accessibilityFeature property value for this ExercisePlan object.
   *
   * @return The first accessibilityFeature property value.
   */
  public String getAccessibilityFeature() {
    return creativeWork.getAccessibilityFeature();
  }
  
  /**
   * Get a single accessibilityHazard property value for this ExercisePlan object.
   *
   * @return The first accessibilityHazard property value.
   */
  public String getAccessibilityHazard() {
    return creativeWork.getAccessibilityHazard();
  }
  
  /**
   * Get a single accountablePerson property value for this ExercisePlan object.
   *
   * @return The first accountablePerson property value.
   */
  public Person getAccountablePerson() {
    return creativeWork.getAccountablePerson();
  }
  
  /**
   * Get a single activityDuration property value for this ExercisePlan object.
   *
   * @return The first activityDuration property value.
   */
  public Duration getActivityDuration() {
  	return this.activityDuration.isEmpty() ? null : this.activityDuration.get(0);
  }
  
  /**
   * Get a single activityFrequency property value for this ExercisePlan object.
   *
   * @return The first activityFrequency property value.
   */
  public String getActivityFrequency() {
  	return this.activityFrequency.isEmpty() ? null : this.activityFrequency.get(0);
  }
  
  /**
   * Get a single additionalType property value for this ExercisePlan object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single additionalVariable property value for this ExercisePlan object.
   *
   * @return The first additionalVariable property value.
   */
  public String getAdditionalVariable() {
  	return this.additionalVariable.isEmpty() ? null : this.additionalVariable.get(0);
  }
  
  /**
   * Get a single adverseOutcome property value for this ExercisePlan object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome() {
    return medicalTherapy.getAdverseOutcome();
  }
  
  /**
   * Get a single aggregateRating property value for this ExercisePlan object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
    return creativeWork.getAggregateRating();
  }
  
  /**
   * Get a single alternateName property value for this ExercisePlan object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single alternativeHeadline property value for this ExercisePlan object.
   *
   * @return The first alternativeHeadline property value.
   */
  public String getAlternativeHeadline() {
    return creativeWork.getAlternativeHeadline();
  }
  
  /**
   * Get a single associatedAnatomy property value for this ExercisePlan object.
   *
   * @return The first associatedAnatomy property value.
   */
  public Thing getAssociatedAnatomy() {
    return physicalActivity.getAssociatedAnatomy();
  }
  
  /**
   * Get a single associatedMedia property value for this ExercisePlan object.
   *
   * @return The first associatedMedia property value.
   */
  public MediaObject getAssociatedMedia() {
    return creativeWork.getAssociatedMedia();
  }
  
  /**
   * Get a single audience property value for this ExercisePlan object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience() {
    return creativeWork.getAudience();
  }
  
  /**
   * Get a single audio property value for this ExercisePlan object.
   *
   * @return The first audio property value.
   */
  public AudioObject getAudio() {
    return creativeWork.getAudio();
  }
  
  /**
   * Get a single author property value for this ExercisePlan object.
   *
   * @return The first author property value.
   */
  public Thing getAuthor() {
    return creativeWork.getAuthor();
  }
  
  /**
   * Get a single award property value for this ExercisePlan object.
   *
   * @return The first award property value.
   */
  public String getAward() {
    return creativeWork.getAward();
  }
  
  /**
   * Get a single category property value for this ExercisePlan object.
   *
   * @return The first category property value.
   */
  public Thing getCategory() {
    return physicalActivity.getCategory();
  }
  
  /**
   * Get a single citation property value for this ExercisePlan object.
   *
   * @return The first citation property value.
   */
  public Thing getCitation() {
    return creativeWork.getCitation();
  }
  
  /**
   * Get a single code property value for this ExercisePlan object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single comment property value for this ExercisePlan object.
   *
   * @return The first comment property value.
   */
  public Thing getComment() {
    return creativeWork.getComment();
  }
  
  /**
   * Get a single commentCount property value for this ExercisePlan object.
   *
   * @return The first commentCount property value.
   */
  public Long getCommentCount() {
    return creativeWork.getCommentCount();
  }
  
  /**
   * Get a single contentLocation property value for this ExercisePlan object.
   *
   * @return The first contentLocation property value.
   */
  public Place getContentLocation() {
    return creativeWork.getContentLocation();
  }
  
  /**
   * Get a single contentRating property value for this ExercisePlan object.
   *
   * @return The first contentRating property value.
   */
  public String getContentRating() {
    return creativeWork.getContentRating();
  }
  
  /**
   * Get a single contraindication property value for this ExercisePlan object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication() {
    return medicalTherapy.getContraindication();
  }
  
  /**
   * Get a single contributor property value for this ExercisePlan object.
   *
   * @return The first contributor property value.
   */
  public Thing getContributor() {
    return creativeWork.getContributor();
  }
  
  /**
   * Get a single copyrightHolder property value for this ExercisePlan object.
   *
   * @return The first copyrightHolder property value.
   */
  public Thing getCopyrightHolder() {
    return creativeWork.getCopyrightHolder();
  }
  
  /**
   * Get a single copyrightYear property value for this ExercisePlan object.
   *
   * @return The first copyrightYear property value.
   */
  public Number getCopyrightYear() {
    return creativeWork.getCopyrightYear();
  }
  
  /**
   * Get a single creator property value for this ExercisePlan object.
   *
   * @return The first creator property value.
   */
  public Thing getCreator() {
    return creativeWork.getCreator();
  }
  
  /**
   * Get a single dateCreated property value for this ExercisePlan object.
   *
   * @return The first dateCreated property value.
   */
  public Date getDateCreated() {
    return creativeWork.getDateCreated();
  }
  
  /**
   * Get a single dateModified property value for this ExercisePlan object.
   *
   * @return The first dateModified property value.
   */
  public Date getDateModified() {
    return creativeWork.getDateModified();
  }
  
  /**
   * Get a single datePublished property value for this ExercisePlan object.
   *
   * @return The first datePublished property value.
   */
  public Date getDatePublished() {
    return creativeWork.getDatePublished();
  }
  
  /**
   * Get a single description property value for this ExercisePlan object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single discussionUrl property value for this ExercisePlan object.
   *
   * @return The first discussionUrl property value.
   */
  public URL getDiscussionUrl() {
    return creativeWork.getDiscussionUrl();
  }
  
  /**
   * Get a single duplicateTherapy property value for this ExercisePlan object.
   *
   * @return The first duplicateTherapy property value.
   */
  public MedicalTherapy getDuplicateTherapy() {
    return medicalTherapy.getDuplicateTherapy();
  }
  
  /**
   * Get a single editor property value for this ExercisePlan object.
   *
   * @return The first editor property value.
   */
  public Person getEditor() {
    return creativeWork.getEditor();
  }
  
  /**
   * Get a single educationalAlignment property value for this ExercisePlan object.
   *
   * @return The first educationalAlignment property value.
   */
  public AlignmentObject getEducationalAlignment() {
    return creativeWork.getEducationalAlignment();
  }
  
  /**
   * Get a single educationalUse property value for this ExercisePlan object.
   *
   * @return The first educationalUse property value.
   */
  public String getEducationalUse() {
    return creativeWork.getEducationalUse();
  }
  
  /**
   * Get a single encoding property value for this ExercisePlan object.
   *
   * @return The first encoding property value.
   */
  public MediaObject getEncoding() {
    return creativeWork.getEncoding();
  }
  
  /**
   * Get a single epidemiology property value for this ExercisePlan object.
   *
   * @return The first epidemiology property value.
   */
  public String getEpidemiology() {
    return physicalActivity.getEpidemiology();
  }
  
  /**
   * Get a single exerciseType property value for this ExercisePlan object.
   *
   * @return The first exerciseType property value.
   */
  public String getExerciseType() {
  	return this.exerciseType.isEmpty() ? null : this.exerciseType.get(0);
  }
  
  /**
   * Get a single genre property value for this ExercisePlan object.
   *
   * @return The first genre property value.
   */
  public String getGenre() {
    return creativeWork.getGenre();
  }
  
  /**
   * Get a single guideline property value for this ExercisePlan object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single headline property value for this ExercisePlan object.
   *
   * @return The first headline property value.
   */
  public String getHeadline() {
    return creativeWork.getHeadline();
  }
  
  /**
   * Get a single image property value for this ExercisePlan object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single inLanguage property value for this ExercisePlan object.
   *
   * @return The first inLanguage property value.
   */
  public String getInLanguage() {
    return creativeWork.getInLanguage();
  }
  
  /**
   * Get a single indication property value for this ExercisePlan object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication() {
    return medicalTherapy.getIndication();
  }
  
  /**
   * Get a single intensity property value for this ExercisePlan object.
   *
   * @return The first intensity property value.
   */
  public String getIntensity() {
  	return this.intensity.isEmpty() ? null : this.intensity.get(0);
  }
  
  /**
   * Get a single interactionCount property value for this ExercisePlan object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
    return creativeWork.getInteractionCount();
  }
  
  /**
   * Get a single interactivityType property value for this ExercisePlan object.
   *
   * @return The first interactivityType property value.
   */
  public String getInteractivityType() {
    return creativeWork.getInteractivityType();
  }
  
  /**
   * Get a single isBasedOnUrl property value for this ExercisePlan object.
   *
   * @return The first isBasedOnUrl property value.
   */
  public URL getIsBasedOnUrl() {
    return creativeWork.getIsBasedOnUrl();
  }
  
  /**
   * Get a single isFamilyFriendly property value for this ExercisePlan object.
   *
   * @return The first isFamilyFriendly property value.
   */
  public Boolean getIsFamilyFriendly() {
    return creativeWork.getIsFamilyFriendly();
  }
  
  /**
   * Get a single keywords property value for this ExercisePlan object.
   *
   * @return The first keywords property value.
   */
  public String getKeywords() {
    return creativeWork.getKeywords();
  }
  
  /**
   * Get a single learningResourceType property value for this ExercisePlan object.
   *
   * @return The first learningResourceType property value.
   */
  public String getLearningResourceType() {
    return creativeWork.getLearningResourceType();
  }
  
  /**
   * Get a single medicineSystem property value for this ExercisePlan object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single mentions property value for this ExercisePlan object.
   *
   * @return The first mentions property value.
   */
  public Thing getMentions() {
    return creativeWork.getMentions();
  }
  
  /**
   * Get a single name property value for this ExercisePlan object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offers property value for this ExercisePlan object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers() {
    return creativeWork.getOffers();
  }
  
  /**
   * Get a single pathophysiology property value for this ExercisePlan object.
   *
   * @return The first pathophysiology property value.
   */
  public String getPathophysiology() {
    return physicalActivity.getPathophysiology();
  }
  
  /**
   * Get a single provider property value for this ExercisePlan object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
    return creativeWork.getProvider();
  }
  
  /**
   * Get a single publisher property value for this ExercisePlan object.
   *
   * @return The first publisher property value.
   */
  public Organization getPublisher() {
    return creativeWork.getPublisher();
  }
  
  /**
   * Get a single publishingPrinciples property value for this ExercisePlan object.
   *
   * @return The first publishingPrinciples property value.
   */
  public URL getPublishingPrinciples() {
    return creativeWork.getPublishingPrinciples();
  }
  
  /**
   * Get a single recognizingAuthority property value for this ExercisePlan object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this ExercisePlan object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single repetitions property value for this ExercisePlan object.
   *
   * @return The first repetitions property value.
   */
  public Number getRepetitions() {
  	return this.repetitions.isEmpty() ? null : this.repetitions.get(0);
  }
  
  /**
   * Get a single restPeriods property value for this ExercisePlan object.
   *
   * @return The first restPeriods property value.
   */
  public String getRestPeriods() {
  	return this.restPeriods.isEmpty() ? null : this.restPeriods.get(0);
  }
  
  /**
   * Get a single review property value for this ExercisePlan object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
    return creativeWork.getReview();
  }
  
  /**
   * Get a single sameAs property value for this ExercisePlan object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seriousAdverseOutcome property value for this ExercisePlan object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome() {
    return medicalTherapy.getSeriousAdverseOutcome();
  }
  
  /**
   * Get a single sourceOrganization property value for this ExercisePlan object.
   *
   * @return The first sourceOrganization property value.
   */
  public Organization getSourceOrganization() {
    return creativeWork.getSourceOrganization();
  }
  
  /**
   * Get a single study property value for this ExercisePlan object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single text property value for this ExercisePlan object.
   *
   * @return The first text property value.
   */
  public String getText() {
    return creativeWork.getText();
  }
  
  /**
   * Get a single thumbnailUrl property value for this ExercisePlan object.
   *
   * @return The first thumbnailUrl property value.
   */
  public URL getThumbnailUrl() {
    return creativeWork.getThumbnailUrl();
  }
  
  /**
   * Get a single timeRequired property value for this ExercisePlan object.
   *
   * @return The first timeRequired property value.
   */
  public Duration getTimeRequired() {
    return creativeWork.getTimeRequired();
  }
  
  /**
   * Get a single typicalAgeRange property value for this ExercisePlan object.
   *
   * @return The first typicalAgeRange property value.
   */
  public String getTypicalAgeRange() {
    return creativeWork.getTypicalAgeRange();
  }
  
  /**
   * Get a single url property value for this ExercisePlan object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single version property value for this ExercisePlan object.
   *
   * @return The first version property value.
   */
  public Number getVersion() {
    return creativeWork.getVersion();
  }
  
  /**
   * Get a single video property value for this ExercisePlan object.
   *
   * @return The first video property value.
   */
  public VideoObject getVideo() {
    return creativeWork.getVideo();
  }
  
  /**
   * Get a single workload property value for this ExercisePlan object.
   *
   * @return The first workload property value.
   */
  public Energy getWorkload() {
  	return this.workload.isEmpty() ? null : this.workload.get(0);
  }
  
  /**
   * Get all the about property values for this ExercisePlan object.
   *
   * @return A list of about property values.
   */
  public List<Thing> getAbouts() {
    return creativeWork.getAbouts();
  }
  
  /**
   * Get all the accessibilityAPI property values for this ExercisePlan object.
   *
   * @return A list of accessibilityAPI property values.
   */
  public List<String> getAccessibilityAPIs() {
    return creativeWork.getAccessibilityAPIs();
  }
  
  /**
   * Get all the accessibilityControl property values for this ExercisePlan object.
   *
   * @return A list of accessibilityControl property values.
   */
  public List<String> getAccessibilityControls() {
    return creativeWork.getAccessibilityControls();
  }
  
  /**
   * Get all the accessibilityFeature property values for this ExercisePlan object.
   *
   * @return A list of accessibilityFeature property values.
   */
  public List<String> getAccessibilityFeatures() {
    return creativeWork.getAccessibilityFeatures();
  }
  
  /**
   * Get all the accessibilityHazard property values for this ExercisePlan object.
   *
   * @return A list of accessibilityHazard property values.
   */
  public List<String> getAccessibilityHazards() {
    return creativeWork.getAccessibilityHazards();
  }
  
  /**
   * Get all the accountablePerson property values for this ExercisePlan object.
   *
   * @return A list of accountablePerson property values.
   */
  public List<Person> getAccountablePersons() {
    return creativeWork.getAccountablePersons();
  }
  
  /**
   * Get all the activityDuration property values for this ExercisePlan object.
   *
   * @return A list of activityDuration property values.
   */
  public List<Duration> getActivityDurations() {
  	return this.activityDuration;
  }
  
  /**
   * Get all the activityFrequency property values for this ExercisePlan object.
   *
   * @return A list of activityFrequency property values.
   */
  public List<String> getActivityFrequencies() {
  	return this.activityFrequency;
  }
  
  /**
   * Get all the additionalType property values for this ExercisePlan object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the additionalVariable property values for this ExercisePlan object.
   *
   * @return A list of additionalVariable property values.
   */
  public List<String> getAdditionalVariables() {
  	return this.additionalVariable;
  }
  
  /**
   * Get all the adverseOutcome property values for this ExercisePlan object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes() {
    return medicalTherapy.getAdverseOutcomes();
  }
  
  /**
   * Get all the aggregateRating property values for this ExercisePlan object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
    return creativeWork.getAggregateRatings();
  }
  
  /**
   * Get all the alternateName property values for this ExercisePlan object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the alternativeHeadline property values for this ExercisePlan object.
   *
   * @return A list of alternativeHeadline property values.
   */
  public List<String> getAlternativeHeadlines() {
    return creativeWork.getAlternativeHeadlines();
  }
  
  /**
   * Get all the associatedAnatomy property values for this ExercisePlan object.
   *
   * @return A list of associatedAnatomy property values.
   */
  public List<Thing> getAssociatedAnatomies() {
    return physicalActivity.getAssociatedAnatomies();
  }
  
  /**
   * Get all the associatedMedia property values for this ExercisePlan object.
   *
   * @return A list of associatedMedia property values.
   */
  public List<MediaObject> getAssociatedMedias() {
    return creativeWork.getAssociatedMedias();
  }
  
  /**
   * Get all the audience property values for this ExercisePlan object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences() {
    return creativeWork.getAudiences();
  }
  
  /**
   * Get all the audio property values for this ExercisePlan object.
   *
   * @return A list of audio property values.
   */
  public List<AudioObject> getAudios() {
    return creativeWork.getAudios();
  }
  
  /**
   * Get all the author property values for this ExercisePlan object.
   *
   * @return A list of author property values.
   */
  public List<Thing> getAuthors() {
    return creativeWork.getAuthors();
  }
  
  /**
   * Get all the award property values for this ExercisePlan object.
   *
   * @return A list of award property values.
   */
  public List<String> getAwards() {
    return creativeWork.getAwards();
  }
  
  /**
   * Get all the category property values for this ExercisePlan object.
   *
   * @return A list of category property values.
   */
  public List<Thing> getCategories() {
    return physicalActivity.getCategories();
  }
  
  /**
   * Get all the citation property values for this ExercisePlan object.
   *
   * @return A list of citation property values.
   */
  public List<Thing> getCitations() {
    return creativeWork.getCitations();
  }
  
  /**
   * Get all the code property values for this ExercisePlan object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the comment property values for this ExercisePlan object.
   *
   * @return A list of comment property values.
   */
  public List<Thing> getComments() {
    return creativeWork.getComments();
  }
  
  /**
   * Get all the commentCount property values for this ExercisePlan object.
   *
   * @return A list of commentCount property values.
   */
  public List<Long> getCommentCounts() {
    return creativeWork.getCommentCounts();
  }
  
  /**
   * Get all the contentLocation property values for this ExercisePlan object.
   *
   * @return A list of contentLocation property values.
   */
  public List<Place> getContentLocations() {
    return creativeWork.getContentLocations();
  }
  
  /**
   * Get all the contentRating property values for this ExercisePlan object.
   *
   * @return A list of contentRating property values.
   */
  public List<String> getContentRatings() {
    return creativeWork.getContentRatings();
  }
  
  /**
   * Get all the contraindication property values for this ExercisePlan object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications() {
    return medicalTherapy.getContraindications();
  }
  
  /**
   * Get all the contributor property values for this ExercisePlan object.
   *
   * @return A list of contributor property values.
   */
  public List<Thing> getContributors() {
    return creativeWork.getContributors();
  }
  
  /**
   * Get all the copyrightHolder property values for this ExercisePlan object.
   *
   * @return A list of copyrightHolder property values.
   */
  public List<Thing> getCopyrightHolders() {
    return creativeWork.getCopyrightHolders();
  }
  
  /**
   * Get all the copyrightYear property values for this ExercisePlan object.
   *
   * @return A list of copyrightYear property values.
   */
  public List<Number> getCopyrightYears() {
    return creativeWork.getCopyrightYears();
  }
  
  /**
   * Get all the creator property values for this ExercisePlan object.
   *
   * @return A list of creator property values.
   */
  public List<Thing> getCreators() {
    return creativeWork.getCreators();
  }
  
  /**
   * Get all the dateCreated property values for this ExercisePlan object.
   *
   * @return A list of dateCreated property values.
   */
  public List<Date> getDateCreateds() {
    return creativeWork.getDateCreateds();
  }
  
  /**
   * Get all the dateModified property values for this ExercisePlan object.
   *
   * @return A list of dateModified property values.
   */
  public List<Date> getDateModifieds() {
    return creativeWork.getDateModifieds();
  }
  
  /**
   * Get all the datePublished property values for this ExercisePlan object.
   *
   * @return A list of datePublished property values.
   */
  public List<Date> getDatePublisheds() {
    return creativeWork.getDatePublisheds();
  }
  
  /**
   * Get all the description property values for this ExercisePlan object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the discussionUrl property values for this ExercisePlan object.
   *
   * @return A list of discussionUrl property values.
   */
  public List<URL> getDiscussionUrls() {
    return creativeWork.getDiscussionUrls();
  }
  
  /**
   * Get all the duplicateTherapy property values for this ExercisePlan object.
   *
   * @return A list of duplicateTherapy property values.
   */
  public List<MedicalTherapy> getDuplicateTherapies() {
    return medicalTherapy.getDuplicateTherapies();
  }
  
  /**
   * Get all the editor property values for this ExercisePlan object.
   *
   * @return A list of editor property values.
   */
  public List<Person> getEditors() {
    return creativeWork.getEditors();
  }
  
  /**
   * Get all the educationalAlignment property values for this ExercisePlan object.
   *
   * @return A list of educationalAlignment property values.
   */
  public List<AlignmentObject> getEducationalAlignments() {
    return creativeWork.getEducationalAlignments();
  }
  
  /**
   * Get all the educationalUse property values for this ExercisePlan object.
   *
   * @return A list of educationalUse property values.
   */
  public List<String> getEducationalUses() {
    return creativeWork.getEducationalUses();
  }
  
  /**
   * Get all the encoding property values for this ExercisePlan object.
   *
   * @return A list of encoding property values.
   */
  public List<MediaObject> getEncodings() {
    return creativeWork.getEncodings();
  }
  
  /**
   * Get all the epidemiology property values for this ExercisePlan object.
   *
   * @return A list of epidemiology property values.
   */
  public List<String> getEpidemiologies() {
    return physicalActivity.getEpidemiologies();
  }
  
  /**
   * Get all the exerciseType property values for this ExercisePlan object.
   *
   * @return A list of exerciseType property values.
   */
  public List<String> getExerciseTypes() {
  	return this.exerciseType;
  }
  
  /**
   * Get all the genre property values for this ExercisePlan object.
   *
   * @return A list of genre property values.
   */
  public List<String> getGenres() {
    return creativeWork.getGenres();
  }
  
  /**
   * Get all the guideline property values for this ExercisePlan object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the headline property values for this ExercisePlan object.
   *
   * @return A list of headline property values.
   */
  public List<String> getHeadlines() {
    return creativeWork.getHeadlines();
  }
  
  /**
   * Get all the image property values for this ExercisePlan object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the inLanguage property values for this ExercisePlan object.
   *
   * @return A list of inLanguage property values.
   */
  public List<String> getInLanguages() {
    return creativeWork.getInLanguages();
  }
  
  /**
   * Get all the indication property values for this ExercisePlan object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications() {
    return medicalTherapy.getIndications();
  }
  
  /**
   * Get all the intensity property values for this ExercisePlan object.
   *
   * @return A list of intensity property values.
   */
  public List<String> getIntensities() {
  	return this.intensity;
  }
  
  /**
   * Get all the interactionCount property values for this ExercisePlan object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
    return creativeWork.getInteractionCounts();
  }
  
  /**
   * Get all the interactivityType property values for this ExercisePlan object.
   *
   * @return A list of interactivityType property values.
   */
  public List<String> getInteractivityTypes() {
    return creativeWork.getInteractivityTypes();
  }
  
  /**
   * Get all the isBasedOnUrl property values for this ExercisePlan object.
   *
   * @return A list of isBasedOnUrl property values.
   */
  public List<URL> getIsBasedOnUrls() {
    return creativeWork.getIsBasedOnUrls();
  }
  
  /**
   * Get all the isFamilyFriendly property values for this ExercisePlan object.
   *
   * @return A list of isFamilyFriendly property values.
   */
  public List<Boolean> getIsFamilyFriendlies() {
    return creativeWork.getIsFamilyFriendlies();
  }
  
  /**
   * Get all the keywords property values for this ExercisePlan object.
   *
   * @return A list of keywords property values.
   */
  public List<String> getKeywordss() {
    return creativeWork.getKeywordss();
  }
  
  /**
   * Get all the learningResourceType property values for this ExercisePlan object.
   *
   * @return A list of learningResourceType property values.
   */
  public List<String> getLearningResourceTypes() {
    return creativeWork.getLearningResourceTypes();
  }
  
  /**
   * Get all the medicineSystem property values for this ExercisePlan object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the mentions property values for this ExercisePlan object.
   *
   * @return A list of mentions property values.
   */
  public List<Thing> getMentionss() {
    return creativeWork.getMentionss();
  }
  
  /**
   * Get all the name property values for this ExercisePlan object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offers property values for this ExercisePlan object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss() {
    return creativeWork.getOfferss();
  }
  
  /**
   * Get all the pathophysiology property values for this ExercisePlan object.
   *
   * @return A list of pathophysiology property values.
   */
  public List<String> getPathophysiologies() {
    return physicalActivity.getPathophysiologies();
  }
  
  /**
   * Get all the provider property values for this ExercisePlan object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
    return creativeWork.getProviders();
  }
  
  /**
   * Get all the publisher property values for this ExercisePlan object.
   *
   * @return A list of publisher property values.
   */
  public List<Organization> getPublishers() {
    return creativeWork.getPublishers();
  }
  
  /**
   * Get all the publishingPrinciples property values for this ExercisePlan object.
   *
   * @return A list of publishingPrinciples property values.
   */
  public List<URL> getPublishingPrincipless() {
    return creativeWork.getPublishingPrincipless();
  }
  
  /**
   * Get all the recognizingAuthority property values for this ExercisePlan object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this ExercisePlan object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the repetitions property values for this ExercisePlan object.
   *
   * @return A list of repetitions property values.
   */
  public List<Number> getRepetitionss() {
  	return this.repetitions;
  }
  
  /**
   * Get all the restPeriods property values for this ExercisePlan object.
   *
   * @return A list of restPeriods property values.
   */
  public List<String> getRestPeriodss() {
  	return this.restPeriods;
  }
  
  /**
   * Get all the review property values for this ExercisePlan object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
    return creativeWork.getReviews();
  }
  
  /**
   * Get all the sameAs property values for this ExercisePlan object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seriousAdverseOutcome property values for this ExercisePlan object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes() {
    return medicalTherapy.getSeriousAdverseOutcomes();
  }
  
  /**
   * Get all the sourceOrganization property values for this ExercisePlan object.
   *
   * @return A list of sourceOrganization property values.
   */
  public List<Organization> getSourceOrganizations() {
    return creativeWork.getSourceOrganizations();
  }
  
  /**
   * Get all the study property values for this ExercisePlan object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the text property values for this ExercisePlan object.
   *
   * @return A list of text property values.
   */
  public List<String> getTexts() {
    return creativeWork.getTexts();
  }
  
  /**
   * Get all the thumbnailUrl property values for this ExercisePlan object.
   *
   * @return A list of thumbnailUrl property values.
   */
  public List<URL> getThumbnailUrls() {
    return creativeWork.getThumbnailUrls();
  }
  
  /**
   * Get all the timeRequired property values for this ExercisePlan object.
   *
   * @return A list of timeRequired property values.
   */
  public List<Duration> getTimeRequireds() {
    return creativeWork.getTimeRequireds();
  }
  
  /**
   * Get all the typicalAgeRange property values for this ExercisePlan object.
   *
   * @return A list of typicalAgeRange property values.
   */
  public List<String> getTypicalAgeRanges() {
    return creativeWork.getTypicalAgeRanges();
  }
  
  /**
   * Get all the url property values for this ExercisePlan object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the version property values for this ExercisePlan object.
   *
   * @return A list of version property values.
   */
  public List<Number> getVersions() {
    return creativeWork.getVersions();
  }
  
  /**
   * Get all the video property values for this ExercisePlan object.
   *
   * @return A list of video property values.
   */
  public List<VideoObject> getVideos() {
    return creativeWork.getVideos();
  }
  
  /**
   * Get all the workload property values for this ExercisePlan object.
   *
   * @return A list of workload property values.
   */
  public List<Energy> getWorkloads() {
  	return this.workload;
  }
  
  /**
   * Set the about property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param about The value to set.
   */
  public void setAbout(Thing about) {
    creativeWork.setAbout(about);
  }
  
  /**
   * Set the accessibilityAPI property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityAPI The value to set.
   */
  public void setAccessibilityAPI(String accessibilityAPI) {
    creativeWork.setAccessibilityAPI(accessibilityAPI);
  }
  
  /**
   * Set the accessibilityControl property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityControl The value to set.
   */
  public void setAccessibilityControl(String accessibilityControl) {
    creativeWork.setAccessibilityControl(accessibilityControl);
  }
  
  /**
   * Set the accessibilityFeature property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityFeature The value to set.
   */
  public void setAccessibilityFeature(String accessibilityFeature) {
    creativeWork.setAccessibilityFeature(accessibilityFeature);
  }
  
  /**
   * Set the accessibilityHazard property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityHazard The value to set.
   */
  public void setAccessibilityHazard(String accessibilityHazard) {
    creativeWork.setAccessibilityHazard(accessibilityHazard);
  }
  
  /**
   * Set the accountablePerson property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param accountablePerson The value to set.
   */
  public void setAccountablePerson(Person accountablePerson) {
    creativeWork.setAccountablePerson(accountablePerson);
  }
  
  /**
   * Set the activityDuration property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityDuration The value to set.
   */
  public void setActivityDuration(Duration activityDuration) {
  	this.activityDuration.clear();
  	this.activityDuration.add(activityDuration);
  }
  
  /**
   * Set the activityFrequency property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityFrequency The value to set.
   */
  public void setActivityFrequency(String activityFrequency) {
  	this.activityFrequency.clear();
  	this.activityFrequency.add(activityFrequency);
  }
  
  /**
   * Set the additionalType property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the additionalVariable property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param additionalVariable The value to set.
   */
  public void setAdditionalVariable(String additionalVariable) {
  	this.additionalVariable.clear();
  	this.additionalVariable.add(additionalVariable);
  }
  
  /**
   * Set the adverseOutcome property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.setAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Set the aggregateRating property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
    creativeWork.setAggregateRating(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the alternativeHeadline property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param alternativeHeadline The value to set.
   */
  public void setAlternativeHeadline(String alternativeHeadline) {
    creativeWork.setAlternativeHeadline(alternativeHeadline);
  }
  
  /**
   * Set the associatedAnatomy property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param associatedAnatomy The value to set.
   */
  public void setAssociatedAnatomy(Thing associatedAnatomy) {
    physicalActivity.setAssociatedAnatomy(associatedAnatomy);
  }
  
  /**
   * Set the associatedMedia property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param associatedMedia The value to set.
   */
  public void setAssociatedMedia(MediaObject associatedMedia) {
    creativeWork.setAssociatedMedia(associatedMedia);
  }
  
  /**
   * Set the audience property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience) {
    creativeWork.setAudience(audience);
  }
  
  /**
   * Set the audio property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param audio The value to set.
   */
  public void setAudio(AudioObject audio) {
    creativeWork.setAudio(audio);
  }
  
  /**
   * Set the author property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param author The value to set.
   */
  public void setAuthor(Thing author) {
    creativeWork.setAuthor(author);
  }
  
  /**
   * Set the award property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param award The value to set.
   */
  public void setAward(String award) {
    creativeWork.setAward(award);
  }
  
  /**
   * Set the category property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param category The value to set.
   */
  public void setCategory(Thing category) {
    physicalActivity.setCategory(category);
  }
  
  /**
   * Set the citation property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param citation The value to set.
   */
  public void setCitation(Thing citation) {
    creativeWork.setCitation(citation);
  }
  
  /**
   * Set the code property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the comment property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param comment The value to set.
   */
  public void setComment(Thing comment) {
    creativeWork.setComment(comment);
  }
  
  /**
   * Set the commentCount property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param commentCount The value to set.
   */
  public void setCommentCount(Long commentCount) {
    creativeWork.setCommentCount(commentCount);
  }
  
  /**
   * Set the contentLocation property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param contentLocation The value to set.
   */
  public void setContentLocation(Place contentLocation) {
    creativeWork.setContentLocation(contentLocation);
  }
  
  /**
   * Set the contentRating property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param contentRating The value to set.
   */
  public void setContentRating(String contentRating) {
    creativeWork.setContentRating(contentRating);
  }
  
  /**
   * Set the contraindication property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication) {
    medicalTherapy.setContraindication(contraindication);
  }
  
  /**
   * Set the contributor property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param contributor The value to set.
   */
  public void setContributor(Thing contributor) {
    creativeWork.setContributor(contributor);
  }
  
  /**
   * Set the copyrightHolder property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param copyrightHolder The value to set.
   */
  public void setCopyrightHolder(Thing copyrightHolder) {
    creativeWork.setCopyrightHolder(copyrightHolder);
  }
  
  /**
   * Set the copyrightYear property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param copyrightYear The value to set.
   */
  public void setCopyrightYear(Number copyrightYear) {
    creativeWork.setCopyrightYear(copyrightYear);
  }
  
  /**
   * Set the creator property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param creator The value to set.
   */
  public void setCreator(Thing creator) {
    creativeWork.setCreator(creator);
  }
  
  /**
   * Set the dateCreated property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param dateCreated The value to set.
   */
  public void setDateCreated(Date dateCreated) {
    creativeWork.setDateCreated(dateCreated);
  }
  
  /**
   * Set the dateModified property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param dateModified The value to set.
   */
  public void setDateModified(Date dateModified) {
    creativeWork.setDateModified(dateModified);
  }
  
  /**
   * Set the datePublished property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param datePublished The value to set.
   */
  public void setDatePublished(Date datePublished) {
    creativeWork.setDatePublished(datePublished);
  }
  
  /**
   * Set the description property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the discussionUrl property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param discussionUrl The value to set.
   */
  public void setDiscussionUrl(URL discussionUrl) {
    creativeWork.setDiscussionUrl(discussionUrl);
  }
  
  /**
   * Set the duplicateTherapy property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param duplicateTherapy The value to set.
   */
  public void setDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.setDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Set the editor property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param editor The value to set.
   */
  public void setEditor(Person editor) {
    creativeWork.setEditor(editor);
  }
  
  /**
   * Set the educationalAlignment property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param educationalAlignment The value to set.
   */
  public void setEducationalAlignment(AlignmentObject educationalAlignment) {
    creativeWork.setEducationalAlignment(educationalAlignment);
  }
  
  /**
   * Set the educationalUse property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param educationalUse The value to set.
   */
  public void setEducationalUse(String educationalUse) {
    creativeWork.setEducationalUse(educationalUse);
  }
  
  /**
   * Set the encoding property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param encoding The value to set.
   */
  public void setEncoding(MediaObject encoding) {
    creativeWork.setEncoding(encoding);
  }
  
  /**
   * Set the epidemiology property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param epidemiology The value to set.
   */
  public void setEpidemiology(String epidemiology) {
    physicalActivity.setEpidemiology(epidemiology);
  }
  
  /**
   * Set the exerciseType property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param exerciseType The value to set.
   */
  public void setExerciseType(String exerciseType) {
  	this.exerciseType.clear();
  	this.exerciseType.add(exerciseType);
  }
  
  /**
   * Set the genre property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param genre The value to set.
   */
  public void setGenre(String genre) {
    creativeWork.setGenre(genre);
  }
  
  /**
   * Set the guideline property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the headline property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param headline The value to set.
   */
  public void setHeadline(String headline) {
    creativeWork.setHeadline(headline);
  }
  
  /**
   * Set the image property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the inLanguage property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param inLanguage The value to set.
   */
  public void setInLanguage(String inLanguage) {
    creativeWork.setInLanguage(inLanguage);
  }
  
  /**
   * Set the indication property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication) {
    medicalTherapy.setIndication(indication);
  }
  
  /**
   * Set the intensity property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param intensity The value to set.
   */
  public void setIntensity(String intensity) {
  	this.intensity.clear();
  	this.intensity.add(intensity);
  }
  
  /**
   * Set the interactionCount property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
    creativeWork.setInteractionCount(interactionCount);
  }
  
  /**
   * Set the interactivityType property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param interactivityType The value to set.
   */
  public void setInteractivityType(String interactivityType) {
    creativeWork.setInteractivityType(interactivityType);
  }
  
  /**
   * Set the isBasedOnUrl property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param isBasedOnUrl The value to set.
   */
  public void setIsBasedOnUrl(URL isBasedOnUrl) {
    creativeWork.setIsBasedOnUrl(isBasedOnUrl);
  }
  
  /**
   * Set the isFamilyFriendly property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param isFamilyFriendly The value to set.
   */
  public void setIsFamilyFriendly(Boolean isFamilyFriendly) {
    creativeWork.setIsFamilyFriendly(isFamilyFriendly);
  }
  
  /**
   * Set the keywords property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param keywords The value to set.
   */
  public void setKeywords(String keywords) {
    creativeWork.setKeywords(keywords);
  }
  
  /**
   * Set the learningResourceType property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param learningResourceType The value to set.
   */
  public void setLearningResourceType(String learningResourceType) {
    creativeWork.setLearningResourceType(learningResourceType);
  }
  
  /**
   * Set the medicineSystem property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the mentions property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param mentions The value to set.
   */
  public void setMentions(Thing mentions) {
    creativeWork.setMentions(mentions);
  }
  
  /**
   * Set the name property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offers property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers) {
    creativeWork.setOffers(offers);
  }
  
  /**
   * Set the pathophysiology property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param pathophysiology The value to set.
   */
  public void setPathophysiology(String pathophysiology) {
    physicalActivity.setPathophysiology(pathophysiology);
  }
  
  /**
   * Set the provider property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
    creativeWork.setProvider(provider);
  }
  
  /**
   * Set the publisher property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param publisher The value to set.
   */
  public void setPublisher(Organization publisher) {
    creativeWork.setPublisher(publisher);
  }
  
  /**
   * Set the publishingPrinciples property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param publishingPrinciples The value to set.
   */
  public void setPublishingPrinciples(URL publishingPrinciples) {
    creativeWork.setPublishingPrinciples(publishingPrinciples);
  }
  
  /**
   * Set the recognizingAuthority property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the repetitions property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param repetitions The value to set.
   */
  public void setRepetitions(Number repetitions) {
  	this.repetitions.clear();
  	this.repetitions.add(repetitions);
  }
  
  /**
   * Set the restPeriods property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param restPeriods The value to set.
   */
  public void setRestPeriods(String restPeriods) {
  	this.restPeriods.clear();
  	this.restPeriods.add(restPeriods);
  }
  
  /**
   * Set the review property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
    creativeWork.setReview(review);
  }
  
  /**
   * Set the sameAs property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seriousAdverseOutcome property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.setSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Set the sourceOrganization property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param sourceOrganization The value to set.
   */
  public void setSourceOrganization(Organization sourceOrganization) {
    creativeWork.setSourceOrganization(sourceOrganization);
  }
  
  /**
   * Set the study property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the text property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param text The value to set.
   */
  public void setText(String text) {
    creativeWork.setText(text);
  }
  
  /**
   * Set the thumbnailUrl property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param thumbnailUrl The value to set.
   */
  public void setThumbnailUrl(URL thumbnailUrl) {
    creativeWork.setThumbnailUrl(thumbnailUrl);
  }
  
  /**
   * Set the timeRequired property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param timeRequired The value to set.
   */
  public void setTimeRequired(Duration timeRequired) {
    creativeWork.setTimeRequired(timeRequired);
  }
  
  /**
   * Set the typicalAgeRange property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param typicalAgeRange The value to set.
   */
  public void setTypicalAgeRange(String typicalAgeRange) {
    creativeWork.setTypicalAgeRange(typicalAgeRange);
  }
  
  /**
   * Set the url property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the version property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param version The value to set.
   */
  public void setVersion(Number version) {
    creativeWork.setVersion(version);
  }
  
  /**
   * Set the video property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param video The value to set.
   */
  public void setVideo(VideoObject video) {
    creativeWork.setVideo(video);
  }
  
  /**
   * Set the workload property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param workload The value to set.
   */
  public void setWorkload(Energy workload) {
  	this.workload.clear();
  	this.workload.add(workload);
  }
  
  /**
   * Set the about property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param abouts The list of values to set.
   */
  public void setAbouts(List<Thing> abouts) {
    creativeWork.setAbouts(abouts);
  }
  
  /**
   * Set the accessibilityAPI property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityAPIs The list of values to set.
   */
  public void setAccessibilityAPIs(List<String> accessibilityAPIs) {
    creativeWork.setAccessibilityAPIs(accessibilityAPIs);
  }
  
  /**
   * Set the accessibilityControl property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityControls The list of values to set.
   */
  public void setAccessibilityControls(List<String> accessibilityControls) {
    creativeWork.setAccessibilityControls(accessibilityControls);
  }
  
  /**
   * Set the accessibilityFeature property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityFeatures The list of values to set.
   */
  public void setAccessibilityFeatures(List<String> accessibilityFeatures) {
    creativeWork.setAccessibilityFeatures(accessibilityFeatures);
  }
  
  /**
   * Set the accessibilityHazard property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param accessibilityHazards The list of values to set.
   */
  public void setAccessibilityHazards(List<String> accessibilityHazards) {
    creativeWork.setAccessibilityHazards(accessibilityHazards);
  }
  
  /**
   * Set the accountablePerson property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param accountablePersons The list of values to set.
   */
  public void setAccountablePersons(List<Person> accountablePersons) {
    creativeWork.setAccountablePersons(accountablePersons);
  }
  
  /**
   * Set the activityDuration property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityDurations The list of values to set.
   */
  public void setActivityDurations(List<Duration> activityDurations) {
  	this.activityDuration = activityDurations;
  }
  
  /**
   * Set the activityFrequency property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityFrequencies The list of values to set.
   */
  public void setActivityFrequencies(List<String> activityFrequencies) {
  	this.activityFrequency = activityFrequencies;
  }
  
  /**
   * Set the additionalType property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the additionalVariable property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param additionalVariables The list of values to set.
   */
  public void setAdditionalVariables(List<String> additionalVariables) {
  	this.additionalVariable = additionalVariables;
  }
  
  /**
   * Set the adverseOutcome property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes) {
    medicalTherapy.setAdverseOutcomes(adverseOutcomes);
  }
  
  /**
   * Set the aggregateRating property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
    creativeWork.setAggregateRatings(aggregateRatings);
  }
  
  /**
   * Set the alternateName property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the alternativeHeadline property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param alternativeHeadlines The list of values to set.
   */
  public void setAlternativeHeadlines(List<String> alternativeHeadlines) {
    creativeWork.setAlternativeHeadlines(alternativeHeadlines);
  }
  
  /**
   * Set the associatedAnatomy property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param associatedAnatomies The list of values to set.
   */
  public void setAssociatedAnatomies(List<Thing> associatedAnatomies) {
    physicalActivity.setAssociatedAnatomies(associatedAnatomies);
  }
  
  /**
   * Set the associatedMedia property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param associatedMedias The list of values to set.
   */
  public void setAssociatedMedias(List<MediaObject> associatedMedias) {
    creativeWork.setAssociatedMedias(associatedMedias);
  }
  
  /**
   * Set the audience property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences) {
    creativeWork.setAudiences(audiences);
  }
  
  /**
   * Set the audio property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param audios The list of values to set.
   */
  public void setAudios(List<AudioObject> audios) {
    creativeWork.setAudios(audios);
  }
  
  /**
   * Set the author property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param authors The list of values to set.
   */
  public void setAuthors(List<Thing> authors) {
    creativeWork.setAuthors(authors);
  }
  
  /**
   * Set the award property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param awards The list of values to set.
   */
  public void setAwards(List<String> awards) {
    creativeWork.setAwards(awards);
  }
  
  /**
   * Set the category property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param categories The list of values to set.
   */
  public void setCategories(List<Thing> categories) {
    physicalActivity.setCategories(categories);
  }
  
  /**
   * Set the citation property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param citations The list of values to set.
   */
  public void setCitations(List<Thing> citations) {
    creativeWork.setCitations(citations);
  }
  
  /**
   * Set the code property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the comment property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param comments The list of values to set.
   */
  public void setComments(List<Thing> comments) {
    creativeWork.setComments(comments);
  }
  
  /**
   * Set the commentCount property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param commentCounts The list of values to set.
   */
  public void setCommentCounts(List<Long> commentCounts) {
    creativeWork.setCommentCounts(commentCounts);
  }
  
  /**
   * Set the contentLocation property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param contentLocations The list of values to set.
   */
  public void setContentLocations(List<Place> contentLocations) {
    creativeWork.setContentLocations(contentLocations);
  }
  
  /**
   * Set the contentRating property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param contentRatings The list of values to set.
   */
  public void setContentRatings(List<String> contentRatings) {
    creativeWork.setContentRatings(contentRatings);
  }
  
  /**
   * Set the contraindication property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications) {
    medicalTherapy.setContraindications(contraindications);
  }
  
  /**
   * Set the contributor property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param contributors The list of values to set.
   */
  public void setContributors(List<Thing> contributors) {
    creativeWork.setContributors(contributors);
  }
  
  /**
   * Set the copyrightHolder property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param copyrightHolders The list of values to set.
   */
  public void setCopyrightHolders(List<Thing> copyrightHolders) {
    creativeWork.setCopyrightHolders(copyrightHolders);
  }
  
  /**
   * Set the copyrightYear property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param copyrightYears The list of values to set.
   */
  public void setCopyrightYears(List<Number> copyrightYears) {
    creativeWork.setCopyrightYears(copyrightYears);
  }
  
  /**
   * Set the creator property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param creators The list of values to set.
   */
  public void setCreators(List<Thing> creators) {
    creativeWork.setCreators(creators);
  }
  
  /**
   * Set the dateCreated property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param dateCreateds The list of values to set.
   */
  public void setDateCreateds(List<Date> dateCreateds) {
    creativeWork.setDateCreateds(dateCreateds);
  }
  
  /**
   * Set the dateModified property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param dateModifieds The list of values to set.
   */
  public void setDateModifieds(List<Date> dateModifieds) {
    creativeWork.setDateModifieds(dateModifieds);
  }
  
  /**
   * Set the datePublished property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param datePublisheds The list of values to set.
   */
  public void setDatePublisheds(List<Date> datePublisheds) {
    creativeWork.setDatePublisheds(datePublisheds);
  }
  
  /**
   * Set the description property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the discussionUrl property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param discussionUrls The list of values to set.
   */
  public void setDiscussionUrls(List<URL> discussionUrls) {
    creativeWork.setDiscussionUrls(discussionUrls);
  }
  
  /**
   * Set the duplicateTherapy property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param duplicateTherapies The list of values to set.
   */
  public void setDuplicateTherapies(List<MedicalTherapy> duplicateTherapies) {
    medicalTherapy.setDuplicateTherapies(duplicateTherapies);
  }
  
  /**
   * Set the editor property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param editors The list of values to set.
   */
  public void setEditors(List<Person> editors) {
    creativeWork.setEditors(editors);
  }
  
  /**
   * Set the educationalAlignment property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param educationalAlignments The list of values to set.
   */
  public void setEducationalAlignments(List<AlignmentObject> educationalAlignments) {
    creativeWork.setEducationalAlignments(educationalAlignments);
  }
  
  /**
   * Set the educationalUse property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param educationalUses The list of values to set.
   */
  public void setEducationalUses(List<String> educationalUses) {
    creativeWork.setEducationalUses(educationalUses);
  }
  
  /**
   * Set the encoding property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param encodings The list of values to set.
   */
  public void setEncodings(List<MediaObject> encodings) {
    creativeWork.setEncodings(encodings);
  }
  
  /**
   * Set the epidemiology property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param epidemiologies The list of values to set.
   */
  public void setEpidemiologies(List<String> epidemiologies) {
    physicalActivity.setEpidemiologies(epidemiologies);
  }
  
  /**
   * Set the exerciseType property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param exerciseTypes The list of values to set.
   */
  public void setExerciseTypes(List<String> exerciseTypes) {
  	this.exerciseType = exerciseTypes;
  }
  
  /**
   * Set the genre property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param genres The list of values to set.
   */
  public void setGenres(List<String> genres) {
    creativeWork.setGenres(genres);
  }
  
  /**
   * Set the guideline property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the headline property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param headlines The list of values to set.
   */
  public void setHeadlines(List<String> headlines) {
    creativeWork.setHeadlines(headlines);
  }
  
  /**
   * Set the image property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the inLanguage property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param inLanguages The list of values to set.
   */
  public void setInLanguages(List<String> inLanguages) {
    creativeWork.setInLanguages(inLanguages);
  }
  
  /**
   * Set the indication property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications) {
    medicalTherapy.setIndications(indications);
  }
  
  /**
   * Set the intensity property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param intensities The list of values to set.
   */
  public void setIntensities(List<String> intensities) {
  	this.intensity = intensities;
  }
  
  /**
   * Set the interactionCount property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
    creativeWork.setInteractionCounts(interactionCounts);
  }
  
  /**
   * Set the interactivityType property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param interactivityTypes The list of values to set.
   */
  public void setInteractivityTypes(List<String> interactivityTypes) {
    creativeWork.setInteractivityTypes(interactivityTypes);
  }
  
  /**
   * Set the isBasedOnUrl property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param isBasedOnUrls The list of values to set.
   */
  public void setIsBasedOnUrls(List<URL> isBasedOnUrls) {
    creativeWork.setIsBasedOnUrls(isBasedOnUrls);
  }
  
  /**
   * Set the isFamilyFriendly property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param isFamilyFriendlies The list of values to set.
   */
  public void setIsFamilyFriendlies(List<Boolean> isFamilyFriendlies) {
    creativeWork.setIsFamilyFriendlies(isFamilyFriendlies);
  }
  
  /**
   * Set the keywords property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param keywordss The list of values to set.
   */
  public void setKeywordss(List<String> keywordss) {
    creativeWork.setKeywordss(keywordss);
  }
  
  /**
   * Set the learningResourceType property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param learningResourceTypes The list of values to set.
   */
  public void setLearningResourceTypes(List<String> learningResourceTypes) {
    creativeWork.setLearningResourceTypes(learningResourceTypes);
  }
  
  /**
   * Set the medicineSystem property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the mentions property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param mentionss The list of values to set.
   */
  public void setMentionss(List<Thing> mentionss) {
    creativeWork.setMentionss(mentionss);
  }
  
  /**
   * Set the name property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offers property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss) {
    creativeWork.setOfferss(offerss);
  }
  
  /**
   * Set the pathophysiology property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param pathophysiologies The list of values to set.
   */
  public void setPathophysiologies(List<String> pathophysiologies) {
    physicalActivity.setPathophysiologies(pathophysiologies);
  }
  
  /**
   * Set the provider property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
    creativeWork.setProviders(providers);
  }
  
  /**
   * Set the publisher property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param publishers The list of values to set.
   */
  public void setPublishers(List<Organization> publishers) {
    creativeWork.setPublishers(publishers);
  }
  
  /**
   * Set the publishingPrinciples property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param publishingPrincipless The list of values to set.
   */
  public void setPublishingPrincipless(List<URL> publishingPrincipless) {
    creativeWork.setPublishingPrincipless(publishingPrincipless);
  }
  
  /**
   * Set the recognizingAuthority property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the repetitions property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param repetitionss The list of values to set.
   */
  public void setRepetitionss(List<Number> repetitionss) {
  	this.repetitions = repetitionss;
  }
  
  /**
   * Set the restPeriods property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param restPeriodss The list of values to set.
   */
  public void setRestPeriodss(List<String> restPeriodss) {
  	this.restPeriods = restPeriodss;
  }
  
  /**
   * Set the review property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
    creativeWork.setReviews(reviews);
  }
  
  /**
   * Set the sameAs property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seriousAdverseOutcome property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes) {
    medicalTherapy.setSeriousAdverseOutcomes(seriousAdverseOutcomes);
  }
  
  /**
   * Set the sourceOrganization property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param sourceOrganizations The list of values to set.
   */
  public void setSourceOrganizations(List<Organization> sourceOrganizations) {
    creativeWork.setSourceOrganizations(sourceOrganizations);
  }
  
  /**
   * Set the study property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the text property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param texts The list of values to set.
   */
  public void setTexts(List<String> texts) {
    creativeWork.setTexts(texts);
  }
  
  /**
   * Set the thumbnailUrl property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param thumbnailUrls The list of values to set.
   */
  public void setThumbnailUrls(List<URL> thumbnailUrls) {
    creativeWork.setThumbnailUrls(thumbnailUrls);
  }
  
  /**
   * Set the timeRequired property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param timeRequireds The list of values to set.
   */
  public void setTimeRequireds(List<Duration> timeRequireds) {
    creativeWork.setTimeRequireds(timeRequireds);
  }
  
  /**
   * Set the typicalAgeRange property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param typicalAgeRanges The list of values to set.
   */
  public void setTypicalAgeRanges(List<String> typicalAgeRanges) {
    creativeWork.setTypicalAgeRanges(typicalAgeRanges);
  }
  
  /**
   * Set the url property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the version property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param versions The list of values to set.
   */
  public void setVersions(List<Number> versions) {
    creativeWork.setVersions(versions);
  }
  
  /**
   * Set the video property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param videos The list of values to set.
   */
  public void setVideos(List<VideoObject> videos) {
    creativeWork.setVideos(videos);
  }
  
  /**
   * Set the workload property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param workloads The list of values to set.
   */
  public void setWorkloads(List<Energy> workloads) {
  	this.workload = workloads;
  }
  
  /**
   * Adds a about property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param about The value to add.
   */
  public void addAbout(Thing about) {
    creativeWork.addAbout(about);
  }
  
  /**
   * Adds a accessibilityAPI property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param accessibilityAPI The value to add.
   */
  public void addAccessibilityAPI(String accessibilityAPI) {
    creativeWork.addAccessibilityAPI(accessibilityAPI);
  }
  
  /**
   * Adds a accessibilityControl property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param accessibilityControl The value to add.
   */
  public void addAccessibilityControl(String accessibilityControl) {
    creativeWork.addAccessibilityControl(accessibilityControl);
  }
  
  /**
   * Adds a accessibilityFeature property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param accessibilityFeature The value to add.
   */
  public void addAccessibilityFeature(String accessibilityFeature) {
    creativeWork.addAccessibilityFeature(accessibilityFeature);
  }
  
  /**
   * Adds a accessibilityHazard property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param accessibilityHazard The value to add.
   */
  public void addAccessibilityHazard(String accessibilityHazard) {
    creativeWork.addAccessibilityHazard(accessibilityHazard);
  }
  
  /**
   * Adds a accountablePerson property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param accountablePerson The value to add.
   */
  public void addAccountablePerson(Person accountablePerson) {
    creativeWork.addAccountablePerson(accountablePerson);
  }
  
  /**
   * Adds a activityDuration property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param activityDuration The value to add.
   */
  public void addActivityDuration(Duration activityDuration) {
  	this.activityDuration.add(activityDuration);
  }
  
  /**
   * Adds a activityFrequency property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param activityFrequency The value to add.
   */
  public void addActivityFrequency(String activityFrequency) {
  	this.activityFrequency.add(activityFrequency);
  }
  
  /**
   * Adds a additionalType property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a additionalVariable property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param additionalVariable The value to add.
   */
  public void addAdditionalVariable(String additionalVariable) {
  	this.additionalVariable.add(additionalVariable);
  }
  
  /**
   * Adds a adverseOutcome property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.addAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Adds a aggregateRating property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
    creativeWork.addAggregateRating(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a alternativeHeadline property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param alternativeHeadline The value to add.
   */
  public void addAlternativeHeadline(String alternativeHeadline) {
    creativeWork.addAlternativeHeadline(alternativeHeadline);
  }
  
  /**
   * Adds a associatedAnatomy property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param associatedAnatomy The value to add.
   */
  public void addAssociatedAnatomy(Thing associatedAnatomy) {
    physicalActivity.addAssociatedAnatomy(associatedAnatomy);
  }
  
  /**
   * Adds a associatedMedia property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param associatedMedia The value to add.
   */
  public void addAssociatedMedia(MediaObject associatedMedia) {
    creativeWork.addAssociatedMedia(associatedMedia);
  }
  
  /**
   * Adds a audience property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience) {
    creativeWork.addAudience(audience);
  }
  
  /**
   * Adds a audio property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param audio The value to add.
   */
  public void addAudio(AudioObject audio) {
    creativeWork.addAudio(audio);
  }
  
  /**
   * Adds a author property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param author The value to add.
   */
  public void addAuthor(Thing author) {
    creativeWork.addAuthor(author);
  }
  
  /**
   * Adds a award property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param award The value to add.
   */
  public void addAward(String award) {
    creativeWork.addAward(award);
  }
  
  /**
   * Adds a category property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param category The value to add.
   */
  public void addCategory(Thing category) {
    physicalActivity.addCategory(category);
  }
  
  /**
   * Adds a citation property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param citation The value to add.
   */
  public void addCitation(Thing citation) {
    creativeWork.addCitation(citation);
  }
  
  /**
   * Adds a code property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a comment property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param comment The value to add.
   */
  public void addComment(Thing comment) {
    creativeWork.addComment(comment);
  }
  
  /**
   * Adds a commentCount property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param commentCount The value to add.
   */
  public void addCommentCount(Long commentCount) {
    creativeWork.addCommentCount(commentCount);
  }
  
  /**
   * Adds a contentLocation property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param contentLocation The value to add.
   */
  public void addContentLocation(Place contentLocation) {
    creativeWork.addContentLocation(contentLocation);
  }
  
  /**
   * Adds a contentRating property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param contentRating The value to add.
   */
  public void addContentRating(String contentRating) {
    creativeWork.addContentRating(contentRating);
  }
  
  /**
   * Adds a contraindication property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication) {
    medicalTherapy.addContraindication(contraindication);
  }
  
  /**
   * Adds a contributor property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param contributor The value to add.
   */
  public void addContributor(Thing contributor) {
    creativeWork.addContributor(contributor);
  }
  
  /**
   * Adds a copyrightHolder property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param copyrightHolder The value to add.
   */
  public void addCopyrightHolder(Thing copyrightHolder) {
    creativeWork.addCopyrightHolder(copyrightHolder);
  }
  
  /**
   * Adds a copyrightYear property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param copyrightYear The value to add.
   */
  public void addCopyrightYear(Number copyrightYear) {
    creativeWork.addCopyrightYear(copyrightYear);
  }
  
  /**
   * Adds a creator property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param creator The value to add.
   */
  public void addCreator(Thing creator) {
    creativeWork.addCreator(creator);
  }
  
  /**
   * Adds a dateCreated property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param dateCreated The value to add.
   */
  public void addDateCreated(Date dateCreated) {
    creativeWork.addDateCreated(dateCreated);
  }
  
  /**
   * Adds a dateModified property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param dateModified The value to add.
   */
  public void addDateModified(Date dateModified) {
    creativeWork.addDateModified(dateModified);
  }
  
  /**
   * Adds a datePublished property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param datePublished The value to add.
   */
  public void addDatePublished(Date datePublished) {
    creativeWork.addDatePublished(datePublished);
  }
  
  /**
   * Adds a description property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a discussionUrl property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param discussionUrl The value to add.
   */
  public void addDiscussionUrl(URL discussionUrl) {
    creativeWork.addDiscussionUrl(discussionUrl);
  }
  
  /**
   * Adds a duplicateTherapy property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param duplicateTherapy The value to add.
   */
  public void addDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.addDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Adds a editor property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param editor The value to add.
   */
  public void addEditor(Person editor) {
    creativeWork.addEditor(editor);
  }
  
  /**
   * Adds a educationalAlignment property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param educationalAlignment The value to add.
   */
  public void addEducationalAlignment(AlignmentObject educationalAlignment) {
    creativeWork.addEducationalAlignment(educationalAlignment);
  }
  
  /**
   * Adds a educationalUse property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param educationalUse The value to add.
   */
  public void addEducationalUse(String educationalUse) {
    creativeWork.addEducationalUse(educationalUse);
  }
  
  /**
   * Adds a encoding property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param encoding The value to add.
   */
  public void addEncoding(MediaObject encoding) {
    creativeWork.addEncoding(encoding);
  }
  
  /**
   * Adds a epidemiology property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param epidemiology The value to add.
   */
  public void addEpidemiology(String epidemiology) {
    physicalActivity.addEpidemiology(epidemiology);
  }
  
  /**
   * Adds a exerciseType property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param exerciseType The value to add.
   */
  public void addExerciseType(String exerciseType) {
  	this.exerciseType.add(exerciseType);
  }
  
  /**
   * Adds a genre property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param genre The value to add.
   */
  public void addGenre(String genre) {
    creativeWork.addGenre(genre);
  }
  
  /**
   * Adds a guideline property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a headline property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param headline The value to add.
   */
  public void addHeadline(String headline) {
    creativeWork.addHeadline(headline);
  }
  
  /**
   * Adds a image property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a inLanguage property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param inLanguage The value to add.
   */
  public void addInLanguage(String inLanguage) {
    creativeWork.addInLanguage(inLanguage);
  }
  
  /**
   * Adds a indication property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication) {
    medicalTherapy.addIndication(indication);
  }
  
  /**
   * Adds a intensity property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param intensity The value to add.
   */
  public void addIntensity(String intensity) {
  	this.intensity.add(intensity);
  }
  
  /**
   * Adds a interactionCount property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
    creativeWork.addInteractionCount(interactionCount);
  }
  
  /**
   * Adds a interactivityType property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param interactivityType The value to add.
   */
  public void addInteractivityType(String interactivityType) {
    creativeWork.addInteractivityType(interactivityType);
  }
  
  /**
   * Adds a isBasedOnUrl property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param isBasedOnUrl The value to add.
   */
  public void addIsBasedOnUrl(URL isBasedOnUrl) {
    creativeWork.addIsBasedOnUrl(isBasedOnUrl);
  }
  
  /**
   * Adds a isFamilyFriendly property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param isFamilyFriendly The value to add.
   */
  public void addIsFamilyFriendly(Boolean isFamilyFriendly) {
    creativeWork.addIsFamilyFriendly(isFamilyFriendly);
  }
  
  /**
   * Adds a keywords property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param keywords The value to add.
   */
  public void addKeywords(String keywords) {
    creativeWork.addKeywords(keywords);
  }
  
  /**
   * Adds a learningResourceType property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param learningResourceType The value to add.
   */
  public void addLearningResourceType(String learningResourceType) {
    creativeWork.addLearningResourceType(learningResourceType);
  }
  
  /**
   * Adds a medicineSystem property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a mentions property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param mentions The value to add.
   */
  public void addMentions(Thing mentions) {
    creativeWork.addMentions(mentions);
  }
  
  /**
   * Adds a name property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offers property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers) {
    creativeWork.addOffers(offers);
  }
  
  /**
   * Adds a pathophysiology property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param pathophysiology The value to add.
   */
  public void addPathophysiology(String pathophysiology) {
    physicalActivity.addPathophysiology(pathophysiology);
  }
  
  /**
   * Adds a provider property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
    creativeWork.addProvider(provider);
  }
  
  /**
   * Adds a publisher property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param publisher The value to add.
   */
  public void addPublisher(Organization publisher) {
    creativeWork.addPublisher(publisher);
  }
  
  /**
   * Adds a publishingPrinciples property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param publishingPrinciples The value to add.
   */
  public void addPublishingPrinciples(URL publishingPrinciples) {
    creativeWork.addPublishingPrinciples(publishingPrinciples);
  }
  
  /**
   * Adds a recognizingAuthority property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a repetitions property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param repetitions The value to add.
   */
  public void addRepetitions(Number repetitions) {
  	this.repetitions.add(repetitions);
  }
  
  /**
   * Adds a restPeriods property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param restPeriods The value to add.
   */
  public void addRestPeriods(String restPeriods) {
  	this.restPeriods.add(restPeriods);
  }
  
  /**
   * Adds a review property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
    creativeWork.addReview(review);
  }
  
  /**
   * Adds a sameAs property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seriousAdverseOutcome property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.addSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Adds a sourceOrganization property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param sourceOrganization The value to add.
   */
  public void addSourceOrganization(Organization sourceOrganization) {
    creativeWork.addSourceOrganization(sourceOrganization);
  }
  
  /**
   * Adds a study property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a text property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param text The value to add.
   */
  public void addText(String text) {
    creativeWork.addText(text);
  }
  
  /**
   * Adds a thumbnailUrl property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param thumbnailUrl The value to add.
   */
  public void addThumbnailUrl(URL thumbnailUrl) {
    creativeWork.addThumbnailUrl(thumbnailUrl);
  }
  
  /**
   * Adds a timeRequired property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param timeRequired The value to add.
   */
  public void addTimeRequired(Duration timeRequired) {
    creativeWork.addTimeRequired(timeRequired);
  }
  
  /**
   * Adds a typicalAgeRange property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param typicalAgeRange The value to add.
   */
  public void addTypicalAgeRange(String typicalAgeRange) {
    creativeWork.addTypicalAgeRange(typicalAgeRange);
  }
  
  /**
   * Adds a url property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a version property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param version The value to add.
   */
  public void addVersion(Number version) {
    creativeWork.addVersion(version);
  }
  
  /**
   * Adds a video property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param video The value to add.
   */
  public void addVideo(VideoObject video) {
    creativeWork.addVideo(video);
  }
  
  /**
   * Adds a workload property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param workload The value to add.
   */
  public void addWorkload(Energy workload) {
  	this.workload.add(workload);
  }
  
}