package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Airport;
import org.schema.Flight;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An airline flight.
 */
public class FlightImpl extends SchemaObjectImpl implements Flight {


  private ThingImpl thing;

  /**
   * The kind of aircraft (e.g., "Boeing 747??").
   */
  private List<Thing> aircraft = new LinkedList<Thing>();
  
  /**
   * The airport where the flight terminates.
   */
  private List<Airport> arrivalAirport = new LinkedList<Airport>();
  
  /**
   * Identifier of the flight's arrival gate.
   */
  private List<String> arrivalGate = new LinkedList<String>();
  
  /**
   * Identifier of the flight's arrival terminal.
   */
  private List<String> arrivalTerminal = new LinkedList<String>();
  
  /**
   * The expected arrival time.
   */
  private List<Date> arrivalTime = new LinkedList<Date>();
  
  /**
   * The airline designated as the carrier for the flight.
   */
  private List<Thing> carrier = new LinkedList<Thing>();
  
  /**
   * The airport where the flight originates.
   */
  private List<Airport> departureAirport = new LinkedList<Airport>();
  
  /**
   * Identifier of the flight's departure gate.
   */
  private List<String> departureGate = new LinkedList<String>();
  
  /**
   * Identifier of the flight's departure terminal.
   */
  private List<String> departureTerminal = new LinkedList<String>();
  
  /**
   * The expected departure time.
   */
  private List<Date> departureTime = new LinkedList<Date>();
  
  /**
   * The estimated time the flight will take.
   */
  private List<Thing> estimatedFlightDuration = new LinkedList<Thing>();
  
  /**
   * The distance of the flight.
   */
  private List<Thing> flightDistance = new LinkedList<Thing>();
  
  /**
   * The unique identifier for a flight.
   */
  private List<String> flightNumber = new LinkedList<String>();
  
  /**
   * Description of the meals that will be provided or available for purchase.
   */
  private List<String> mealService = new LinkedList<String>();
  
  /**
   * The organization or agency that is providing the service.
   */
  private List<Thing> provider = new LinkedList<Thing>();
  
  /**
   * The time when a passenger can check into the flight online.
   */
  private List<Date> webCheckinTime = new LinkedList<Date>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public FlightImpl() {
    super("http://schema.org/Flight");
  }
  /**
   * Get a single additionalType property value for this Flight object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single aircraft property value for this Flight object.
   *
   * @return The first aircraft property value.
   */
  public Thing getAircraft() {
  	return this.aircraft.isEmpty() ? null : this.aircraft.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Flight object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single arrivalAirport property value for this Flight object.
   *
   * @return The first arrivalAirport property value.
   */
  public Airport getArrivalAirport() {
  	return this.arrivalAirport.isEmpty() ? null : this.arrivalAirport.get(0);
  }
  
  /**
   * Get a single arrivalGate property value for this Flight object.
   *
   * @return The first arrivalGate property value.
   */
  public String getArrivalGate() {
  	return this.arrivalGate.isEmpty() ? null : this.arrivalGate.get(0);
  }
  
  /**
   * Get a single arrivalTerminal property value for this Flight object.
   *
   * @return The first arrivalTerminal property value.
   */
  public String getArrivalTerminal() {
  	return this.arrivalTerminal.isEmpty() ? null : this.arrivalTerminal.get(0);
  }
  
  /**
   * Get a single arrivalTime property value for this Flight object.
   *
   * @return The first arrivalTime property value.
   */
  public Date getArrivalTime() {
  	return this.arrivalTime.isEmpty() ? null : this.arrivalTime.get(0);
  }
  
  /**
   * Get a single carrier property value for this Flight object.
   *
   * @return The first carrier property value.
   */
  public Thing getCarrier() {
  	return this.carrier.isEmpty() ? null : this.carrier.get(0);
  }
  
  /**
   * Get a single departureAirport property value for this Flight object.
   *
   * @return The first departureAirport property value.
   */
  public Airport getDepartureAirport() {
  	return this.departureAirport.isEmpty() ? null : this.departureAirport.get(0);
  }
  
  /**
   * Get a single departureGate property value for this Flight object.
   *
   * @return The first departureGate property value.
   */
  public String getDepartureGate() {
  	return this.departureGate.isEmpty() ? null : this.departureGate.get(0);
  }
  
  /**
   * Get a single departureTerminal property value for this Flight object.
   *
   * @return The first departureTerminal property value.
   */
  public String getDepartureTerminal() {
  	return this.departureTerminal.isEmpty() ? null : this.departureTerminal.get(0);
  }
  
  /**
   * Get a single departureTime property value for this Flight object.
   *
   * @return The first departureTime property value.
   */
  public Date getDepartureTime() {
  	return this.departureTime.isEmpty() ? null : this.departureTime.get(0);
  }
  
  /**
   * Get a single description property value for this Flight object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single estimatedFlightDuration property value for this Flight object.
   *
   * @return The first estimatedFlightDuration property value.
   */
  public Thing getEstimatedFlightDuration() {
  	return this.estimatedFlightDuration.isEmpty() ? null : this.estimatedFlightDuration.get(0);
  }
  
  /**
   * Get a single flightDistance property value for this Flight object.
   *
   * @return The first flightDistance property value.
   */
  public Thing getFlightDistance() {
  	return this.flightDistance.isEmpty() ? null : this.flightDistance.get(0);
  }
  
  /**
   * Get a single flightNumber property value for this Flight object.
   *
   * @return The first flightNumber property value.
   */
  public String getFlightNumber() {
  	return this.flightNumber.isEmpty() ? null : this.flightNumber.get(0);
  }
  
  /**
   * Get a single image property value for this Flight object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single mealService property value for this Flight object.
   *
   * @return The first mealService property value.
   */
  public String getMealService() {
  	return this.mealService.isEmpty() ? null : this.mealService.get(0);
  }
  
  /**
   * Get a single name property value for this Flight object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single provider property value for this Flight object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
  	return this.provider.isEmpty() ? null : this.provider.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Flight object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this Flight object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single webCheckinTime property value for this Flight object.
   *
   * @return The first webCheckinTime property value.
   */
  public Date getWebCheckinTime() {
  	return this.webCheckinTime.isEmpty() ? null : this.webCheckinTime.get(0);
  }
  
  /**
   * Get all the additionalType property values for this Flight object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the aircraft property values for this Flight object.
   *
   * @return A list of aircraft property values.
   */
  public List<Thing> getAircrafts() {
  	return this.aircraft;
  }
  
  /**
   * Get all the alternateName property values for this Flight object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the arrivalAirport property values for this Flight object.
   *
   * @return A list of arrivalAirport property values.
   */
  public List<Airport> getArrivalAirports() {
  	return this.arrivalAirport;
  }
  
  /**
   * Get all the arrivalGate property values for this Flight object.
   *
   * @return A list of arrivalGate property values.
   */
  public List<String> getArrivalGates() {
  	return this.arrivalGate;
  }
  
  /**
   * Get all the arrivalTerminal property values for this Flight object.
   *
   * @return A list of arrivalTerminal property values.
   */
  public List<String> getArrivalTerminals() {
  	return this.arrivalTerminal;
  }
  
  /**
   * Get all the arrivalTime property values for this Flight object.
   *
   * @return A list of arrivalTime property values.
   */
  public List<Date> getArrivalTimes() {
  	return this.arrivalTime;
  }
  
  /**
   * Get all the carrier property values for this Flight object.
   *
   * @return A list of carrier property values.
   */
  public List<Thing> getCarriers() {
  	return this.carrier;
  }
  
  /**
   * Get all the departureAirport property values for this Flight object.
   *
   * @return A list of departureAirport property values.
   */
  public List<Airport> getDepartureAirports() {
  	return this.departureAirport;
  }
  
  /**
   * Get all the departureGate property values for this Flight object.
   *
   * @return A list of departureGate property values.
   */
  public List<String> getDepartureGates() {
  	return this.departureGate;
  }
  
  /**
   * Get all the departureTerminal property values for this Flight object.
   *
   * @return A list of departureTerminal property values.
   */
  public List<String> getDepartureTerminals() {
  	return this.departureTerminal;
  }
  
  /**
   * Get all the departureTime property values for this Flight object.
   *
   * @return A list of departureTime property values.
   */
  public List<Date> getDepartureTimes() {
  	return this.departureTime;
  }
  
  /**
   * Get all the description property values for this Flight object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the estimatedFlightDuration property values for this Flight object.
   *
   * @return A list of estimatedFlightDuration property values.
   */
  public List<Thing> getEstimatedFlightDurations() {
  	return this.estimatedFlightDuration;
  }
  
  /**
   * Get all the flightDistance property values for this Flight object.
   *
   * @return A list of flightDistance property values.
   */
  public List<Thing> getFlightDistances() {
  	return this.flightDistance;
  }
  
  /**
   * Get all the flightNumber property values for this Flight object.
   *
   * @return A list of flightNumber property values.
   */
  public List<String> getFlightNumbers() {
  	return this.flightNumber;
  }
  
  /**
   * Get all the image property values for this Flight object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the mealService property values for this Flight object.
   *
   * @return A list of mealService property values.
   */
  public List<String> getMealServices() {
  	return this.mealService;
  }
  
  /**
   * Get all the name property values for this Flight object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the provider property values for this Flight object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
  	return this.provider;
  }
  
  /**
   * Get all the sameAs property values for this Flight object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this Flight object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the webCheckinTime property values for this Flight object.
   *
   * @return A list of webCheckinTime property values.
   */
  public List<Date> getWebCheckinTimes() {
  	return this.webCheckinTime;
  }
  
  /**
   * Set the additionalType property value for this Flight object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the aircraft property value for this Flight object; overwriting any existing values.
   *
   * @param aircraft The value to set.
   */
  public void setAircraft(Thing aircraft) {
  	this.aircraft.clear();
  	this.aircraft.add(aircraft);
  }
  
  /**
   * Set the alternateName property value for this Flight object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the arrivalAirport property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalAirport The value to set.
   */
  public void setArrivalAirport(Airport arrivalAirport) {
  	this.arrivalAirport.clear();
  	this.arrivalAirport.add(arrivalAirport);
  }
  
  /**
   * Set the arrivalGate property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalGate The value to set.
   */
  public void setArrivalGate(String arrivalGate) {
  	this.arrivalGate.clear();
  	this.arrivalGate.add(arrivalGate);
  }
  
  /**
   * Set the arrivalTerminal property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalTerminal The value to set.
   */
  public void setArrivalTerminal(String arrivalTerminal) {
  	this.arrivalTerminal.clear();
  	this.arrivalTerminal.add(arrivalTerminal);
  }
  
  /**
   * Set the arrivalTime property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalTime The value to set.
   */
  public void setArrivalTime(Date arrivalTime) {
  	this.arrivalTime.clear();
  	this.arrivalTime.add(arrivalTime);
  }
  
  /**
   * Set the carrier property value for this Flight object; overwriting any existing values.
   *
   * @param carrier The value to set.
   */
  public void setCarrier(Thing carrier) {
  	this.carrier.clear();
  	this.carrier.add(carrier);
  }
  
  /**
   * Set the departureAirport property value for this Flight object; overwriting any existing values.
   *
   * @param departureAirport The value to set.
   */
  public void setDepartureAirport(Airport departureAirport) {
  	this.departureAirport.clear();
  	this.departureAirport.add(departureAirport);
  }
  
  /**
   * Set the departureGate property value for this Flight object; overwriting any existing values.
   *
   * @param departureGate The value to set.
   */
  public void setDepartureGate(String departureGate) {
  	this.departureGate.clear();
  	this.departureGate.add(departureGate);
  }
  
  /**
   * Set the departureTerminal property value for this Flight object; overwriting any existing values.
   *
   * @param departureTerminal The value to set.
   */
  public void setDepartureTerminal(String departureTerminal) {
  	this.departureTerminal.clear();
  	this.departureTerminal.add(departureTerminal);
  }
  
  /**
   * Set the departureTime property value for this Flight object; overwriting any existing values.
   *
   * @param departureTime The value to set.
   */
  public void setDepartureTime(Date departureTime) {
  	this.departureTime.clear();
  	this.departureTime.add(departureTime);
  }
  
  /**
   * Set the description property value for this Flight object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the estimatedFlightDuration property value for this Flight object; overwriting any existing values.
   *
   * @param estimatedFlightDuration The value to set.
   */
  public void setEstimatedFlightDuration(Thing estimatedFlightDuration) {
  	this.estimatedFlightDuration.clear();
  	this.estimatedFlightDuration.add(estimatedFlightDuration);
  }
  
  /**
   * Set the flightDistance property value for this Flight object; overwriting any existing values.
   *
   * @param flightDistance The value to set.
   */
  public void setFlightDistance(Thing flightDistance) {
  	this.flightDistance.clear();
  	this.flightDistance.add(flightDistance);
  }
  
  /**
   * Set the flightNumber property value for this Flight object; overwriting any existing values.
   *
   * @param flightNumber The value to set.
   */
  public void setFlightNumber(String flightNumber) {
  	this.flightNumber.clear();
  	this.flightNumber.add(flightNumber);
  }
  
  /**
   * Set the image property value for this Flight object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the mealService property value for this Flight object; overwriting any existing values.
   *
   * @param mealService The value to set.
   */
  public void setMealService(String mealService) {
  	this.mealService.clear();
  	this.mealService.add(mealService);
  }
  
  /**
   * Set the name property value for this Flight object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the provider property value for this Flight object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
  	this.provider.clear();
  	this.provider.add(provider);
  }
  
  /**
   * Set the sameAs property value for this Flight object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this Flight object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the webCheckinTime property value for this Flight object; overwriting any existing values.
   *
   * @param webCheckinTime The value to set.
   */
  public void setWebCheckinTime(Date webCheckinTime) {
  	this.webCheckinTime.clear();
  	this.webCheckinTime.add(webCheckinTime);
  }
  
  /**
   * Set the additionalType property values for this Flight object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the aircraft property values for this Flight object; overwriting any existing values.
   *
   * @param aircrafts The list of values to set.
   */
  public void setAircrafts(List<Thing> aircrafts) {
  	this.aircraft = aircrafts;
  }
  
  /**
   * Set the alternateName property values for this Flight object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the arrivalAirport property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalAirports The list of values to set.
   */
  public void setArrivalAirports(List<Airport> arrivalAirports) {
  	this.arrivalAirport = arrivalAirports;
  }
  
  /**
   * Set the arrivalGate property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalGates The list of values to set.
   */
  public void setArrivalGates(List<String> arrivalGates) {
  	this.arrivalGate = arrivalGates;
  }
  
  /**
   * Set the arrivalTerminal property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalTerminals The list of values to set.
   */
  public void setArrivalTerminals(List<String> arrivalTerminals) {
  	this.arrivalTerminal = arrivalTerminals;
  }
  
  /**
   * Set the arrivalTime property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalTimes The list of values to set.
   */
  public void setArrivalTimes(List<Date> arrivalTimes) {
  	this.arrivalTime = arrivalTimes;
  }
  
  /**
   * Set the carrier property values for this Flight object; overwriting any existing values.
   *
   * @param carriers The list of values to set.
   */
  public void setCarriers(List<Thing> carriers) {
  	this.carrier = carriers;
  }
  
  /**
   * Set the departureAirport property values for this Flight object; overwriting any existing values.
   *
   * @param departureAirports The list of values to set.
   */
  public void setDepartureAirports(List<Airport> departureAirports) {
  	this.departureAirport = departureAirports;
  }
  
  /**
   * Set the departureGate property values for this Flight object; overwriting any existing values.
   *
   * @param departureGates The list of values to set.
   */
  public void setDepartureGates(List<String> departureGates) {
  	this.departureGate = departureGates;
  }
  
  /**
   * Set the departureTerminal property values for this Flight object; overwriting any existing values.
   *
   * @param departureTerminals The list of values to set.
   */
  public void setDepartureTerminals(List<String> departureTerminals) {
  	this.departureTerminal = departureTerminals;
  }
  
  /**
   * Set the departureTime property values for this Flight object; overwriting any existing values.
   *
   * @param departureTimes The list of values to set.
   */
  public void setDepartureTimes(List<Date> departureTimes) {
  	this.departureTime = departureTimes;
  }
  
  /**
   * Set the description property values for this Flight object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the estimatedFlightDuration property values for this Flight object; overwriting any existing values.
   *
   * @param estimatedFlightDurations The list of values to set.
   */
  public void setEstimatedFlightDurations(List<Thing> estimatedFlightDurations) {
  	this.estimatedFlightDuration = estimatedFlightDurations;
  }
  
  /**
   * Set the flightDistance property values for this Flight object; overwriting any existing values.
   *
   * @param flightDistances The list of values to set.
   */
  public void setFlightDistances(List<Thing> flightDistances) {
  	this.flightDistance = flightDistances;
  }
  
  /**
   * Set the flightNumber property values for this Flight object; overwriting any existing values.
   *
   * @param flightNumbers The list of values to set.
   */
  public void setFlightNumbers(List<String> flightNumbers) {
  	this.flightNumber = flightNumbers;
  }
  
  /**
   * Set the image property values for this Flight object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the mealService property values for this Flight object; overwriting any existing values.
   *
   * @param mealServices The list of values to set.
   */
  public void setMealServices(List<String> mealServices) {
  	this.mealService = mealServices;
  }
  
  /**
   * Set the name property values for this Flight object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the provider property values for this Flight object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
  	this.provider = providers;
  }
  
  /**
   * Set the sameAs property values for this Flight object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this Flight object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the webCheckinTime property values for this Flight object; overwriting any existing values.
   *
   * @param webCheckinTimes The list of values to set.
   */
  public void setWebCheckinTimes(List<Date> webCheckinTimes) {
  	this.webCheckinTime = webCheckinTimes;
  }
  
  /**
   * Adds a additionalType property value for this Flight object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a aircraft property value for this Flight object; appending it to the list of existing values.
   *
   * @param aircraft The value to add.
   */
  public void addAircraft(Thing aircraft) {
  	this.aircraft.add(aircraft);
  }
  
  /**
   * Adds a alternateName property value for this Flight object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a arrivalAirport property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalAirport The value to add.
   */
  public void addArrivalAirport(Airport arrivalAirport) {
  	this.arrivalAirport.add(arrivalAirport);
  }
  
  /**
   * Adds a arrivalGate property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalGate The value to add.
   */
  public void addArrivalGate(String arrivalGate) {
  	this.arrivalGate.add(arrivalGate);
  }
  
  /**
   * Adds a arrivalTerminal property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalTerminal The value to add.
   */
  public void addArrivalTerminal(String arrivalTerminal) {
  	this.arrivalTerminal.add(arrivalTerminal);
  }
  
  /**
   * Adds a arrivalTime property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalTime The value to add.
   */
  public void addArrivalTime(Date arrivalTime) {
  	this.arrivalTime.add(arrivalTime);
  }
  
  /**
   * Adds a carrier property value for this Flight object; appending it to the list of existing values.
   *
   * @param carrier The value to add.
   */
  public void addCarrier(Thing carrier) {
  	this.carrier.add(carrier);
  }
  
  /**
   * Adds a departureAirport property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureAirport The value to add.
   */
  public void addDepartureAirport(Airport departureAirport) {
  	this.departureAirport.add(departureAirport);
  }
  
  /**
   * Adds a departureGate property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureGate The value to add.
   */
  public void addDepartureGate(String departureGate) {
  	this.departureGate.add(departureGate);
  }
  
  /**
   * Adds a departureTerminal property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureTerminal The value to add.
   */
  public void addDepartureTerminal(String departureTerminal) {
  	this.departureTerminal.add(departureTerminal);
  }
  
  /**
   * Adds a departureTime property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureTime The value to add.
   */
  public void addDepartureTime(Date departureTime) {
  	this.departureTime.add(departureTime);
  }
  
  /**
   * Adds a description property value for this Flight object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a estimatedFlightDuration property value for this Flight object; appending it to the list of existing values.
   *
   * @param estimatedFlightDuration The value to add.
   */
  public void addEstimatedFlightDuration(Thing estimatedFlightDuration) {
  	this.estimatedFlightDuration.add(estimatedFlightDuration);
  }
  
  /**
   * Adds a flightDistance property value for this Flight object; appending it to the list of existing values.
   *
   * @param flightDistance The value to add.
   */
  public void addFlightDistance(Thing flightDistance) {
  	this.flightDistance.add(flightDistance);
  }
  
  /**
   * Adds a flightNumber property value for this Flight object; appending it to the list of existing values.
   *
   * @param flightNumber The value to add.
   */
  public void addFlightNumber(String flightNumber) {
  	this.flightNumber.add(flightNumber);
  }
  
  /**
   * Adds a image property value for this Flight object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a mealService property value for this Flight object; appending it to the list of existing values.
   *
   * @param mealService The value to add.
   */
  public void addMealService(String mealService) {
  	this.mealService.add(mealService);
  }
  
  /**
   * Adds a name property value for this Flight object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a provider property value for this Flight object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
  	this.provider.add(provider);
  }
  
  /**
   * Adds a sameAs property value for this Flight object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this Flight object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a webCheckinTime property value for this Flight object; appending it to the list of existing values.
   *
   * @param webCheckinTime The value to add.
   */
  public void addWebCheckinTime(Date webCheckinTime) {
  	this.webCheckinTime.add(webCheckinTime);
  }
  
}