package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.ContactPoint;
import org.schema.Demand;
import org.schema.Duration;
import org.schema.Event;
import org.schema.Florist;
import org.schema.Offer;
import org.schema.OpeningHoursSpecification;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Review;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A florist.
 */
public class FloristImpl extends SchemaObjectImpl implements Florist {


  private LocalBusinessImpl localBusiness;
  private OrganizationImpl organization;
  private PlaceImpl place;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public FloristImpl() {
    super("http://schema.org/Florist");
  }
  /**
   * Get a single additionalType property value for this Florist object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single address property value for this Florist object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress() {
    return place.getAddress();
  }
  
  /**
   * Get a single aggregateRating property value for this Florist object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
    return place.getAggregateRating();
  }
  
  /**
   * Get a single alternateName property value for this Florist object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single branchOf property value for this Florist object.
   *
   * @return The first branchOf property value.
   */
  public Organization getBranchOf() {
    return localBusiness.getBranchOf();
  }
  
  /**
   * Get a single brand property value for this Florist object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand() {
    return organization.getBrand();
  }
  
  /**
   * Get a single contactPoint property value for this Florist object.
   *
   * @return The first contactPoint property value.
   */
  public ContactPoint getContactPoint() {
    return organization.getContactPoint();
  }
  
  /**
   * Get a single containedIn property value for this Florist object.
   *
   * @return The first containedIn property value.
   */
  public Place getContainedIn() {
    return place.getContainedIn();
  }
  
  /**
   * Get a single currenciesAccepted property value for this Florist object.
   *
   * @return The first currenciesAccepted property value.
   */
  public String getCurrenciesAccepted() {
    return localBusiness.getCurrenciesAccepted();
  }
  
  /**
   * Get a single department property value for this Florist object.
   *
   * @return The first department property value.
   */
  public Organization getDepartment() {
    return organization.getDepartment();
  }
  
  /**
   * Get a single description property value for this Florist object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single duns property value for this Florist object.
   *
   * @return The first duns property value.
   */
  public String getDuns() {
    return organization.getDuns();
  }
  
  /**
   * Get a single email property value for this Florist object.
   *
   * @return The first email property value.
   */
  public String getEmail() {
    return organization.getEmail();
  }
  
  /**
   * Get a single employee property value for this Florist object.
   *
   * @return The first employee property value.
   */
  public Person getEmployee() {
    return organization.getEmployee();
  }
  
  /**
   * Get a single event property value for this Florist object.
   *
   * @return The first event property value.
   */
  public Event getEvent() {
    return place.getEvent();
  }
  
  /**
   * Get a single faxNumber property value for this Florist object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
    return place.getFaxNumber();
  }
  
  /**
   * Get a single founder property value for this Florist object.
   *
   * @return The first founder property value.
   */
  public Person getFounder() {
    return organization.getFounder();
  }
  
  /**
   * Get a single foundingDate property value for this Florist object.
   *
   * @return The first foundingDate property value.
   */
  public Date getFoundingDate() {
    return organization.getFoundingDate();
  }
  
  /**
   * Get a single geo property value for this Florist object.
   *
   * @return The first geo property value.
   */
  public Thing getGeo() {
    return place.getGeo();
  }
  
  /**
   * Get a single globalLocationNumber property value for this Florist object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber() {
    return place.getGlobalLocationNumber();
  }
  
  /**
   * Get a single hasPOS property value for this Florist object.
   *
   * @return The first hasPOS property value.
   */
  public Place getHasPOS() {
    return organization.getHasPOS();
  }
  
  /**
   * Get a single image property value for this Florist object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single interactionCount property value for this Florist object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
    return place.getInteractionCount();
  }
  
  /**
   * Get a single isicV4 property value for this Florist object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4() {
    return place.getIsicV4();
  }
  
  /**
   * Get a single legalName property value for this Florist object.
   *
   * @return The first legalName property value.
   */
  public String getLegalName() {
    return organization.getLegalName();
  }
  
  /**
   * Get a single location property value for this Florist object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
    return organization.getLocation();
  }
  
  /**
   * Get a single logo property value for this Florist object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo() {
    return place.getLogo();
  }
  
  /**
   * Get a single makesOffer property value for this Florist object.
   *
   * @return The first makesOffer property value.
   */
  public Offer getMakesOffer() {
    return organization.getMakesOffer();
  }
  
  /**
   * Get a single map property value for this Florist object.
   *
   * @return The first map property value.
   */
  public URL getMap() {
    return place.getMap();
  }
  
  /**
   * Get a single member property value for this Florist object.
   *
   * @return The first member property value.
   */
  public Thing getMember() {
    return organization.getMember();
  }
  
  /**
   * Get a single naics property value for this Florist object.
   *
   * @return The first naics property value.
   */
  public String getNaics() {
    return organization.getNaics();
  }
  
  /**
   * Get a single name property value for this Florist object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single openingHours property value for this Florist object.
   *
   * @return The first openingHours property value.
   */
  public Duration getOpeningHours() {
    return localBusiness.getOpeningHours();
  }
  
  /**
   * Get a single openingHoursSpecification property value for this Florist object.
   *
   * @return The first openingHoursSpecification property value.
   */
  public OpeningHoursSpecification getOpeningHoursSpecification() {
    return place.getOpeningHoursSpecification();
  }
  
  /**
   * Get a single owns property value for this Florist object.
   *
   * @return The first owns property value.
   */
  public Thing getOwns() {
    return organization.getOwns();
  }
  
  /**
   * Get a single paymentAccepted property value for this Florist object.
   *
   * @return The first paymentAccepted property value.
   */
  public String getPaymentAccepted() {
    return localBusiness.getPaymentAccepted();
  }
  
  /**
   * Get a single photo property value for this Florist object.
   *
   * @return The first photo property value.
   */
  public Thing getPhoto() {
    return place.getPhoto();
  }
  
  /**
   * Get a single priceRange property value for this Florist object.
   *
   * @return The first priceRange property value.
   */
  public String getPriceRange() {
    return localBusiness.getPriceRange();
  }
  
  /**
   * Get a single review property value for this Florist object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
    return place.getReview();
  }
  
  /**
   * Get a single sameAs property value for this Florist object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seeks property value for this Florist object.
   *
   * @return The first seeks property value.
   */
  public Demand getSeeks() {
    return organization.getSeeks();
  }
  
  /**
   * Get a single subOrganization property value for this Florist object.
   *
   * @return The first subOrganization property value.
   */
  public Organization getSubOrganization() {
    return organization.getSubOrganization();
  }
  
  /**
   * Get a single taxID property value for this Florist object.
   *
   * @return The first taxID property value.
   */
  public String getTaxID() {
    return organization.getTaxID();
  }
  
  /**
   * Get a single telephone property value for this Florist object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
    return place.getTelephone();
  }
  
  /**
   * Get a single url property value for this Florist object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single vatID property value for this Florist object.
   *
   * @return The first vatID property value.
   */
  public String getVatID() {
    return organization.getVatID();
  }
  
  /**
   * Get all the additionalType property values for this Florist object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the address property values for this Florist object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses() {
    return place.getAddresses();
  }
  
  /**
   * Get all the aggregateRating property values for this Florist object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
    return place.getAggregateRatings();
  }
  
  /**
   * Get all the alternateName property values for this Florist object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the branchOf property values for this Florist object.
   *
   * @return A list of branchOf property values.
   */
  public List<Organization> getBranchesOf() {
    return localBusiness.getBranchesOf();
  }
  
  /**
   * Get all the brand property values for this Florist object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands() {
    return organization.getBrands();
  }
  
  /**
   * Get all the contactPoint property values for this Florist object.
   *
   * @return A list of contactPoint property values.
   */
  public List<ContactPoint> getContactPoints() {
    return organization.getContactPoints();
  }
  
  /**
   * Get all the containedIn property values for this Florist object.
   *
   * @return A list of containedIn property values.
   */
  public List<Place> getContainedsIn() {
    return place.getContainedsIn();
  }
  
  /**
   * Get all the currenciesAccepted property values for this Florist object.
   *
   * @return A list of currenciesAccepted property values.
   */
  public List<String> getCurrenciesAccepteds() {
    return localBusiness.getCurrenciesAccepteds();
  }
  
  /**
   * Get all the department property values for this Florist object.
   *
   * @return A list of department property values.
   */
  public List<Organization> getDepartments() {
    return organization.getDepartments();
  }
  
  /**
   * Get all the description property values for this Florist object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the duns property values for this Florist object.
   *
   * @return A list of duns property values.
   */
  public List<String> getDunss() {
    return organization.getDunss();
  }
  
  /**
   * Get all the email property values for this Florist object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails() {
    return organization.getEmails();
  }
  
  /**
   * Get all the employee property values for this Florist object.
   *
   * @return A list of employee property values.
   */
  public List<Person> getEmployees() {
    return organization.getEmployees();
  }
  
  /**
   * Get all the event property values for this Florist object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents() {
    return place.getEvents();
  }
  
  /**
   * Get all the faxNumber property values for this Florist object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
    return place.getFaxNumbers();
  }
  
  /**
   * Get all the founder property values for this Florist object.
   *
   * @return A list of founder property values.
   */
  public List<Person> getFounders() {
    return organization.getFounders();
  }
  
  /**
   * Get all the foundingDate property values for this Florist object.
   *
   * @return A list of foundingDate property values.
   */
  public List<Date> getFoundingDates() {
    return organization.getFoundingDates();
  }
  
  /**
   * Get all the geo property values for this Florist object.
   *
   * @return A list of geo property values.
   */
  public List<Thing> getGeos() {
    return place.getGeos();
  }
  
  /**
   * Get all the globalLocationNumber property values for this Florist object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers() {
    return place.getGlobalLocationNumbers();
  }
  
  /**
   * Get all the hasPOS property values for this Florist object.
   *
   * @return A list of hasPOS property values.
   */
  public List<Place> getHasPOSs() {
    return organization.getHasPOSs();
  }
  
  /**
   * Get all the image property values for this Florist object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the interactionCount property values for this Florist object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
    return place.getInteractionCounts();
  }
  
  /**
   * Get all the isicV4 property values for this Florist object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s() {
    return place.getIsicV4s();
  }
  
  /**
   * Get all the legalName property values for this Florist object.
   *
   * @return A list of legalName property values.
   */
  public List<String> getLegalNames() {
    return organization.getLegalNames();
  }
  
  /**
   * Get all the location property values for this Florist object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
    return organization.getLocations();
  }
  
  /**
   * Get all the logo property values for this Florist object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes() {
    return place.getLogoes();
  }
  
  /**
   * Get all the makesOffer property values for this Florist object.
   *
   * @return A list of makesOffer property values.
   */
  public List<Offer> getMakesOffers() {
    return organization.getMakesOffers();
  }
  
  /**
   * Get all the map property values for this Florist object.
   *
   * @return A list of map property values.
   */
  public List<URL> getMaps() {
    return place.getMaps();
  }
  
  /**
   * Get all the member property values for this Florist object.
   *
   * @return A list of member property values.
   */
  public List<Thing> getMembers() {
    return organization.getMembers();
  }
  
  /**
   * Get all the naics property values for this Florist object.
   *
   * @return A list of naics property values.
   */
  public List<String> getNaicss() {
    return organization.getNaicss();
  }
  
  /**
   * Get all the name property values for this Florist object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the openingHours property values for this Florist object.
   *
   * @return A list of openingHours property values.
   */
  public List<Duration> getOpeningHourss() {
    return localBusiness.getOpeningHourss();
  }
  
  /**
   * Get all the openingHoursSpecification property values for this Florist object.
   *
   * @return A list of openingHoursSpecification property values.
   */
  public List<OpeningHoursSpecification> getOpeningHoursSpecifications() {
    return place.getOpeningHoursSpecifications();
  }
  
  /**
   * Get all the owns property values for this Florist object.
   *
   * @return A list of owns property values.
   */
  public List<Thing> getOwnss() {
    return organization.getOwnss();
  }
  
  /**
   * Get all the paymentAccepted property values for this Florist object.
   *
   * @return A list of paymentAccepted property values.
   */
  public List<String> getPaymentAccepteds() {
    return localBusiness.getPaymentAccepteds();
  }
  
  /**
   * Get all the photo property values for this Florist object.
   *
   * @return A list of photo property values.
   */
  public List<Thing> getPhotos() {
    return place.getPhotos();
  }
  
  /**
   * Get all the priceRange property values for this Florist object.
   *
   * @return A list of priceRange property values.
   */
  public List<String> getPriceRanges() {
    return localBusiness.getPriceRanges();
  }
  
  /**
   * Get all the review property values for this Florist object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
    return place.getReviews();
  }
  
  /**
   * Get all the sameAs property values for this Florist object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seeks property values for this Florist object.
   *
   * @return A list of seeks property values.
   */
  public List<Demand> getSeekss() {
    return organization.getSeekss();
  }
  
  /**
   * Get all the subOrganization property values for this Florist object.
   *
   * @return A list of subOrganization property values.
   */
  public List<Organization> getSubOrganizations() {
    return organization.getSubOrganizations();
  }
  
  /**
   * Get all the taxID property values for this Florist object.
   *
   * @return A list of taxID property values.
   */
  public List<String> getTaxIDs() {
    return organization.getTaxIDs();
  }
  
  /**
   * Get all the telephone property values for this Florist object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
    return place.getTelephones();
  }
  
  /**
   * Get all the url property values for this Florist object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the vatID property values for this Florist object.
   *
   * @return A list of vatID property values.
   */
  public List<String> getVatIDs() {
    return organization.getVatIDs();
  }
  
  /**
   * Set the additionalType property value for this Florist object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the address property value for this Florist object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address) {
    place.setAddress(address);
  }
  
  /**
   * Set the aggregateRating property value for this Florist object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
    place.setAggregateRating(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this Florist object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the branchOf property value for this Florist object; overwriting any existing values.
   *
   * @param branchOf The value to set.
   */
  public void setBranchOf(Organization branchOf) {
    localBusiness.setBranchOf(branchOf);
  }
  
  /**
   * Set the brand property value for this Florist object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand) {
    organization.setBrand(brand);
  }
  
  /**
   * Set the contactPoint property value for this Florist object; overwriting any existing values.
   *
   * @param contactPoint The value to set.
   */
  public void setContactPoint(ContactPoint contactPoint) {
    organization.setContactPoint(contactPoint);
  }
  
  /**
   * Set the containedIn property value for this Florist object; overwriting any existing values.
   *
   * @param containedIn The value to set.
   */
  public void setContainedIn(Place containedIn) {
    place.setContainedIn(containedIn);
  }
  
  /**
   * Set the currenciesAccepted property value for this Florist object; overwriting any existing values.
   *
   * @param currenciesAccepted The value to set.
   */
  public void setCurrenciesAccepted(String currenciesAccepted) {
    localBusiness.setCurrenciesAccepted(currenciesAccepted);
  }
  
  /**
   * Set the department property value for this Florist object; overwriting any existing values.
   *
   * @param department The value to set.
   */
  public void setDepartment(Organization department) {
    organization.setDepartment(department);
  }
  
  /**
   * Set the description property value for this Florist object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the duns property value for this Florist object; overwriting any existing values.
   *
   * @param duns The value to set.
   */
  public void setDuns(String duns) {
    organization.setDuns(duns);
  }
  
  /**
   * Set the email property value for this Florist object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email) {
    organization.setEmail(email);
  }
  
  /**
   * Set the employee property value for this Florist object; overwriting any existing values.
   *
   * @param employee The value to set.
   */
  public void setEmployee(Person employee) {
    organization.setEmployee(employee);
  }
  
  /**
   * Set the event property value for this Florist object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event) {
    place.setEvent(event);
  }
  
  /**
   * Set the faxNumber property value for this Florist object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
    place.setFaxNumber(faxNumber);
  }
  
  /**
   * Set the founder property value for this Florist object; overwriting any existing values.
   *
   * @param founder The value to set.
   */
  public void setFounder(Person founder) {
    organization.setFounder(founder);
  }
  
  /**
   * Set the foundingDate property value for this Florist object; overwriting any existing values.
   *
   * @param foundingDate The value to set.
   */
  public void setFoundingDate(Date foundingDate) {
    organization.setFoundingDate(foundingDate);
  }
  
  /**
   * Set the geo property value for this Florist object; overwriting any existing values.
   *
   * @param geo The value to set.
   */
  public void setGeo(Thing geo) {
    place.setGeo(geo);
  }
  
  /**
   * Set the globalLocationNumber property value for this Florist object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber) {
    place.setGlobalLocationNumber(globalLocationNumber);
  }
  
  /**
   * Set the hasPOS property value for this Florist object; overwriting any existing values.
   *
   * @param hasPOS The value to set.
   */
  public void setHasPOS(Place hasPOS) {
    organization.setHasPOS(hasPOS);
  }
  
  /**
   * Set the image property value for this Florist object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the interactionCount property value for this Florist object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
    place.setInteractionCount(interactionCount);
  }
  
  /**
   * Set the isicV4 property value for this Florist object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4) {
    place.setIsicV4(isicV4);
  }
  
  /**
   * Set the legalName property value for this Florist object; overwriting any existing values.
   *
   * @param legalName The value to set.
   */
  public void setLegalName(String legalName) {
    organization.setLegalName(legalName);
  }
  
  /**
   * Set the location property value for this Florist object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
    organization.setLocation(location);
  }
  
  /**
   * Set the logo property value for this Florist object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo) {
    place.setLogo(logo);
  }
  
  /**
   * Set the makesOffer property value for this Florist object; overwriting any existing values.
   *
   * @param makesOffer The value to set.
   */
  public void setMakesOffer(Offer makesOffer) {
    organization.setMakesOffer(makesOffer);
  }
  
  /**
   * Set the map property value for this Florist object; overwriting any existing values.
   *
   * @param map The value to set.
   */
  public void setMap(URL map) {
    place.setMap(map);
  }
  
  /**
   * Set the member property value for this Florist object; overwriting any existing values.
   *
   * @param member The value to set.
   */
  public void setMember(Thing member) {
    organization.setMember(member);
  }
  
  /**
   * Set the naics property value for this Florist object; overwriting any existing values.
   *
   * @param naics The value to set.
   */
  public void setNaics(String naics) {
    organization.setNaics(naics);
  }
  
  /**
   * Set the name property value for this Florist object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the openingHours property value for this Florist object; overwriting any existing values.
   *
   * @param openingHours The value to set.
   */
  public void setOpeningHours(Duration openingHours) {
    localBusiness.setOpeningHours(openingHours);
  }
  
  /**
   * Set the openingHoursSpecification property value for this Florist object; overwriting any existing values.
   *
   * @param openingHoursSpecification The value to set.
   */
  public void setOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification) {
    place.setOpeningHoursSpecification(openingHoursSpecification);
  }
  
  /**
   * Set the owns property value for this Florist object; overwriting any existing values.
   *
   * @param owns The value to set.
   */
  public void setOwns(Thing owns) {
    organization.setOwns(owns);
  }
  
  /**
   * Set the paymentAccepted property value for this Florist object; overwriting any existing values.
   *
   * @param paymentAccepted The value to set.
   */
  public void setPaymentAccepted(String paymentAccepted) {
    localBusiness.setPaymentAccepted(paymentAccepted);
  }
  
  /**
   * Set the photo property value for this Florist object; overwriting any existing values.
   *
   * @param photo The value to set.
   */
  public void setPhoto(Thing photo) {
    place.setPhoto(photo);
  }
  
  /**
   * Set the priceRange property value for this Florist object; overwriting any existing values.
   *
   * @param priceRange The value to set.
   */
  public void setPriceRange(String priceRange) {
    localBusiness.setPriceRange(priceRange);
  }
  
  /**
   * Set the review property value for this Florist object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
    place.setReview(review);
  }
  
  /**
   * Set the sameAs property value for this Florist object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seeks property value for this Florist object; overwriting any existing values.
   *
   * @param seeks The value to set.
   */
  public void setSeeks(Demand seeks) {
    organization.setSeeks(seeks);
  }
  
  /**
   * Set the subOrganization property value for this Florist object; overwriting any existing values.
   *
   * @param subOrganization The value to set.
   */
  public void setSubOrganization(Organization subOrganization) {
    organization.setSubOrganization(subOrganization);
  }
  
  /**
   * Set the taxID property value for this Florist object; overwriting any existing values.
   *
   * @param taxID The value to set.
   */
  public void setTaxID(String taxID) {
    organization.setTaxID(taxID);
  }
  
  /**
   * Set the telephone property value for this Florist object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
    place.setTelephone(telephone);
  }
  
  /**
   * Set the url property value for this Florist object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the vatID property value for this Florist object; overwriting any existing values.
   *
   * @param vatID The value to set.
   */
  public void setVatID(String vatID) {
    organization.setVatID(vatID);
  }
  
  /**
   * Set the additionalType property values for this Florist object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the address property values for this Florist object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses) {
    place.setAddresses(addresses);
  }
  
  /**
   * Set the aggregateRating property values for this Florist object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
    place.setAggregateRatings(aggregateRatings);
  }
  
  /**
   * Set the alternateName property values for this Florist object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the branchOf property values for this Florist object; overwriting any existing values.
   *
   * @param branchesOf The list of values to set.
   */
  public void setBranchesOf(List<Organization> branchesOf) {
    localBusiness.setBranchesOf(branchesOf);
  }
  
  /**
   * Set the brand property values for this Florist object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands) {
    organization.setBrands(brands);
  }
  
  /**
   * Set the contactPoint property values for this Florist object; overwriting any existing values.
   *
   * @param contactPoints The list of values to set.
   */
  public void setContactPoints(List<ContactPoint> contactPoints) {
    organization.setContactPoints(contactPoints);
  }
  
  /**
   * Set the containedIn property values for this Florist object; overwriting any existing values.
   *
   * @param containedsIn The list of values to set.
   */
  public void setContainedsIn(List<Place> containedsIn) {
    place.setContainedsIn(containedsIn);
  }
  
  /**
   * Set the currenciesAccepted property values for this Florist object; overwriting any existing values.
   *
   * @param currenciesAccepteds The list of values to set.
   */
  public void setCurrenciesAccepteds(List<String> currenciesAccepteds) {
    localBusiness.setCurrenciesAccepteds(currenciesAccepteds);
  }
  
  /**
   * Set the department property values for this Florist object; overwriting any existing values.
   *
   * @param departments The list of values to set.
   */
  public void setDepartments(List<Organization> departments) {
    organization.setDepartments(departments);
  }
  
  /**
   * Set the description property values for this Florist object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the duns property values for this Florist object; overwriting any existing values.
   *
   * @param dunss The list of values to set.
   */
  public void setDunss(List<String> dunss) {
    organization.setDunss(dunss);
  }
  
  /**
   * Set the email property values for this Florist object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails) {
    organization.setEmails(emails);
  }
  
  /**
   * Set the employee property values for this Florist object; overwriting any existing values.
   *
   * @param employees The list of values to set.
   */
  public void setEmployees(List<Person> employees) {
    organization.setEmployees(employees);
  }
  
  /**
   * Set the event property values for this Florist object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events) {
    place.setEvents(events);
  }
  
  /**
   * Set the faxNumber property values for this Florist object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
    place.setFaxNumbers(faxNumbers);
  }
  
  /**
   * Set the founder property values for this Florist object; overwriting any existing values.
   *
   * @param founders The list of values to set.
   */
  public void setFounders(List<Person> founders) {
    organization.setFounders(founders);
  }
  
  /**
   * Set the foundingDate property values for this Florist object; overwriting any existing values.
   *
   * @param foundingDates The list of values to set.
   */
  public void setFoundingDates(List<Date> foundingDates) {
    organization.setFoundingDates(foundingDates);
  }
  
  /**
   * Set the geo property values for this Florist object; overwriting any existing values.
   *
   * @param geos The list of values to set.
   */
  public void setGeos(List<Thing> geos) {
    place.setGeos(geos);
  }
  
  /**
   * Set the globalLocationNumber property values for this Florist object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers) {
    place.setGlobalLocationNumbers(globalLocationNumbers);
  }
  
  /**
   * Set the hasPOS property values for this Florist object; overwriting any existing values.
   *
   * @param hasPOSs The list of values to set.
   */
  public void setHasPOSs(List<Place> hasPOSs) {
    organization.setHasPOSs(hasPOSs);
  }
  
  /**
   * Set the image property values for this Florist object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the interactionCount property values for this Florist object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
    place.setInteractionCounts(interactionCounts);
  }
  
  /**
   * Set the isicV4 property values for this Florist object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s) {
    place.setIsicV4s(isicV4s);
  }
  
  /**
   * Set the legalName property values for this Florist object; overwriting any existing values.
   *
   * @param legalNames The list of values to set.
   */
  public void setLegalNames(List<String> legalNames) {
    organization.setLegalNames(legalNames);
  }
  
  /**
   * Set the location property values for this Florist object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
    organization.setLocations(locations);
  }
  
  /**
   * Set the logo property values for this Florist object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes) {
    place.setLogoes(logoes);
  }
  
  /**
   * Set the makesOffer property values for this Florist object; overwriting any existing values.
   *
   * @param makesOffers The list of values to set.
   */
  public void setMakesOffers(List<Offer> makesOffers) {
    organization.setMakesOffers(makesOffers);
  }
  
  /**
   * Set the map property values for this Florist object; overwriting any existing values.
   *
   * @param maps The list of values to set.
   */
  public void setMaps(List<URL> maps) {
    place.setMaps(maps);
  }
  
  /**
   * Set the member property values for this Florist object; overwriting any existing values.
   *
   * @param members The list of values to set.
   */
  public void setMembers(List<Thing> members) {
    organization.setMembers(members);
  }
  
  /**
   * Set the naics property values for this Florist object; overwriting any existing values.
   *
   * @param naicss The list of values to set.
   */
  public void setNaicss(List<String> naicss) {
    organization.setNaicss(naicss);
  }
  
  /**
   * Set the name property values for this Florist object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the openingHours property values for this Florist object; overwriting any existing values.
   *
   * @param openingHourss The list of values to set.
   */
  public void setOpeningHourss(List<Duration> openingHourss) {
    localBusiness.setOpeningHourss(openingHourss);
  }
  
  /**
   * Set the openingHoursSpecification property values for this Florist object; overwriting any existing values.
   *
   * @param openingHoursSpecifications The list of values to set.
   */
  public void setOpeningHoursSpecifications(List<OpeningHoursSpecification> openingHoursSpecifications) {
    place.setOpeningHoursSpecifications(openingHoursSpecifications);
  }
  
  /**
   * Set the owns property values for this Florist object; overwriting any existing values.
   *
   * @param ownss The list of values to set.
   */
  public void setOwnss(List<Thing> ownss) {
    organization.setOwnss(ownss);
  }
  
  /**
   * Set the paymentAccepted property values for this Florist object; overwriting any existing values.
   *
   * @param paymentAccepteds The list of values to set.
   */
  public void setPaymentAccepteds(List<String> paymentAccepteds) {
    localBusiness.setPaymentAccepteds(paymentAccepteds);
  }
  
  /**
   * Set the photo property values for this Florist object; overwriting any existing values.
   *
   * @param photos The list of values to set.
   */
  public void setPhotos(List<Thing> photos) {
    place.setPhotos(photos);
  }
  
  /**
   * Set the priceRange property values for this Florist object; overwriting any existing values.
   *
   * @param priceRanges The list of values to set.
   */
  public void setPriceRanges(List<String> priceRanges) {
    localBusiness.setPriceRanges(priceRanges);
  }
  
  /**
   * Set the review property values for this Florist object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
    place.setReviews(reviews);
  }
  
  /**
   * Set the sameAs property values for this Florist object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seeks property values for this Florist object; overwriting any existing values.
   *
   * @param seekss The list of values to set.
   */
  public void setSeekss(List<Demand> seekss) {
    organization.setSeekss(seekss);
  }
  
  /**
   * Set the subOrganization property values for this Florist object; overwriting any existing values.
   *
   * @param subOrganizations The list of values to set.
   */
  public void setSubOrganizations(List<Organization> subOrganizations) {
    organization.setSubOrganizations(subOrganizations);
  }
  
  /**
   * Set the taxID property values for this Florist object; overwriting any existing values.
   *
   * @param taxIDs The list of values to set.
   */
  public void setTaxIDs(List<String> taxIDs) {
    organization.setTaxIDs(taxIDs);
  }
  
  /**
   * Set the telephone property values for this Florist object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
    place.setTelephones(telephones);
  }
  
  /**
   * Set the url property values for this Florist object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the vatID property values for this Florist object; overwriting any existing values.
   *
   * @param vatIDs The list of values to set.
   */
  public void setVatIDs(List<String> vatIDs) {
    organization.setVatIDs(vatIDs);
  }
  
  /**
   * Adds a additionalType property value for this Florist object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a address property value for this Florist object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address) {
    place.addAddress(address);
  }
  
  /**
   * Adds a aggregateRating property value for this Florist object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
    place.addAggregateRating(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this Florist object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a branchOf property value for this Florist object; appending it to the list of existing values.
   *
   * @param branchOf The value to add.
   */
  public void addBranchOf(Organization branchOf) {
    localBusiness.addBranchOf(branchOf);
  }
  
  /**
   * Adds a brand property value for this Florist object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand) {
    organization.addBrand(brand);
  }
  
  /**
   * Adds a contactPoint property value for this Florist object; appending it to the list of existing values.
   *
   * @param contactPoint The value to add.
   */
  public void addContactPoint(ContactPoint contactPoint) {
    organization.addContactPoint(contactPoint);
  }
  
  /**
   * Adds a containedIn property value for this Florist object; appending it to the list of existing values.
   *
   * @param containedIn The value to add.
   */
  public void addContainedIn(Place containedIn) {
    place.addContainedIn(containedIn);
  }
  
  /**
   * Adds a currenciesAccepted property value for this Florist object; appending it to the list of existing values.
   *
   * @param currenciesAccepted The value to add.
   */
  public void addCurrenciesAccepted(String currenciesAccepted) {
    localBusiness.addCurrenciesAccepted(currenciesAccepted);
  }
  
  /**
   * Adds a department property value for this Florist object; appending it to the list of existing values.
   *
   * @param department The value to add.
   */
  public void addDepartment(Organization department) {
    organization.addDepartment(department);
  }
  
  /**
   * Adds a description property value for this Florist object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a duns property value for this Florist object; appending it to the list of existing values.
   *
   * @param duns The value to add.
   */
  public void addDuns(String duns) {
    organization.addDuns(duns);
  }
  
  /**
   * Adds a email property value for this Florist object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email) {
    organization.addEmail(email);
  }
  
  /**
   * Adds a employee property value for this Florist object; appending it to the list of existing values.
   *
   * @param employee The value to add.
   */
  public void addEmployee(Person employee) {
    organization.addEmployee(employee);
  }
  
  /**
   * Adds a event property value for this Florist object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event) {
    place.addEvent(event);
  }
  
  /**
   * Adds a faxNumber property value for this Florist object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
    place.addFaxNumber(faxNumber);
  }
  
  /**
   * Adds a founder property value for this Florist object; appending it to the list of existing values.
   *
   * @param founder The value to add.
   */
  public void addFounder(Person founder) {
    organization.addFounder(founder);
  }
  
  /**
   * Adds a foundingDate property value for this Florist object; appending it to the list of existing values.
   *
   * @param foundingDate The value to add.
   */
  public void addFoundingDate(Date foundingDate) {
    organization.addFoundingDate(foundingDate);
  }
  
  /**
   * Adds a geo property value for this Florist object; appending it to the list of existing values.
   *
   * @param geo The value to add.
   */
  public void addGeo(Thing geo) {
    place.addGeo(geo);
  }
  
  /**
   * Adds a globalLocationNumber property value for this Florist object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber) {
    place.addGlobalLocationNumber(globalLocationNumber);
  }
  
  /**
   * Adds a hasPOS property value for this Florist object; appending it to the list of existing values.
   *
   * @param hasPOS The value to add.
   */
  public void addHasPOS(Place hasPOS) {
    organization.addHasPOS(hasPOS);
  }
  
  /**
   * Adds a image property value for this Florist object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a interactionCount property value for this Florist object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
    place.addInteractionCount(interactionCount);
  }
  
  /**
   * Adds a isicV4 property value for this Florist object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4) {
    place.addIsicV4(isicV4);
  }
  
  /**
   * Adds a legalName property value for this Florist object; appending it to the list of existing values.
   *
   * @param legalName The value to add.
   */
  public void addLegalName(String legalName) {
    organization.addLegalName(legalName);
  }
  
  /**
   * Adds a location property value for this Florist object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
    organization.addLocation(location);
  }
  
  /**
   * Adds a logo property value for this Florist object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo) {
    place.addLogo(logo);
  }
  
  /**
   * Adds a makesOffer property value for this Florist object; appending it to the list of existing values.
   *
   * @param makesOffer The value to add.
   */
  public void addMakesOffer(Offer makesOffer) {
    organization.addMakesOffer(makesOffer);
  }
  
  /**
   * Adds a map property value for this Florist object; appending it to the list of existing values.
   *
   * @param map The value to add.
   */
  public void addMap(URL map) {
    place.addMap(map);
  }
  
  /**
   * Adds a member property value for this Florist object; appending it to the list of existing values.
   *
   * @param member The value to add.
   */
  public void addMember(Thing member) {
    organization.addMember(member);
  }
  
  /**
   * Adds a naics property value for this Florist object; appending it to the list of existing values.
   *
   * @param naics The value to add.
   */
  public void addNaics(String naics) {
    organization.addNaics(naics);
  }
  
  /**
   * Adds a name property value for this Florist object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a openingHours property value for this Florist object; appending it to the list of existing values.
   *
   * @param openingHours The value to add.
   */
  public void addOpeningHours(Duration openingHours) {
    localBusiness.addOpeningHours(openingHours);
  }
  
  /**
   * Adds a openingHoursSpecification property value for this Florist object; appending it to the list of existing values.
   *
   * @param openingHoursSpecification The value to add.
   */
  public void addOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification) {
    place.addOpeningHoursSpecification(openingHoursSpecification);
  }
  
  /**
   * Adds a owns property value for this Florist object; appending it to the list of existing values.
   *
   * @param owns The value to add.
   */
  public void addOwns(Thing owns) {
    organization.addOwns(owns);
  }
  
  /**
   * Adds a paymentAccepted property value for this Florist object; appending it to the list of existing values.
   *
   * @param paymentAccepted The value to add.
   */
  public void addPaymentAccepted(String paymentAccepted) {
    localBusiness.addPaymentAccepted(paymentAccepted);
  }
  
  /**
   * Adds a photo property value for this Florist object; appending it to the list of existing values.
   *
   * @param photo The value to add.
   */
  public void addPhoto(Thing photo) {
    place.addPhoto(photo);
  }
  
  /**
   * Adds a priceRange property value for this Florist object; appending it to the list of existing values.
   *
   * @param priceRange The value to add.
   */
  public void addPriceRange(String priceRange) {
    localBusiness.addPriceRange(priceRange);
  }
  
  /**
   * Adds a review property value for this Florist object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
    place.addReview(review);
  }
  
  /**
   * Adds a sameAs property value for this Florist object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seeks property value for this Florist object; appending it to the list of existing values.
   *
   * @param seeks The value to add.
   */
  public void addSeeks(Demand seeks) {
    organization.addSeeks(seeks);
  }
  
  /**
   * Adds a subOrganization property value for this Florist object; appending it to the list of existing values.
   *
   * @param subOrganization The value to add.
   */
  public void addSubOrganization(Organization subOrganization) {
    organization.addSubOrganization(subOrganization);
  }
  
  /**
   * Adds a taxID property value for this Florist object; appending it to the list of existing values.
   *
   * @param taxID The value to add.
   */
  public void addTaxID(String taxID) {
    organization.addTaxID(taxID);
  }
  
  /**
   * Adds a telephone property value for this Florist object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
    place.addTelephone(telephone);
  }
  
  /**
   * Adds a url property value for this Florist object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a vatID property value for this Florist object; appending it to the list of existing values.
   *
   * @param vatID The value to add.
   */
  public void addVatID(String vatID) {
    organization.addVatID(vatID);
  }
  
}