package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.GeoCoordinates;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The geographic coordinates of a place or event.
 */
public class GeoCoordinatesImpl extends SchemaObjectImpl implements GeoCoordinates {


  private ThingImpl thing;

  /**
   * The elevation of a location.
   */
  private List<Thing> elevation = new LinkedList<Thing>();
  
  /**
   * The latitude of a location. For example <code>37.42242</code>.
   */
  private List<Thing> latitude = new LinkedList<Thing>();
  
  /**
   * The longitude of a location. For example <code>-122.08585</code>.
   */
  private List<Thing> longitude = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public GeoCoordinatesImpl() {
    super("http://schema.org/GeoCoordinates");
  }
  /**
   * Get a single additionalType property value for this GeoCoordinates object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this GeoCoordinates object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this GeoCoordinates object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single elevation property value for this GeoCoordinates object.
   *
   * @return The first elevation property value.
   */
  public Thing getElevation() {
  	return this.elevation.isEmpty() ? null : this.elevation.get(0);
  }
  
  /**
   * Get a single image property value for this GeoCoordinates object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single latitude property value for this GeoCoordinates object.
   *
   * @return The first latitude property value.
   */
  public Thing getLatitude() {
  	return this.latitude.isEmpty() ? null : this.latitude.get(0);
  }
  
  /**
   * Get a single longitude property value for this GeoCoordinates object.
   *
   * @return The first longitude property value.
   */
  public Thing getLongitude() {
  	return this.longitude.isEmpty() ? null : this.longitude.get(0);
  }
  
  /**
   * Get a single name property value for this GeoCoordinates object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single sameAs property value for this GeoCoordinates object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this GeoCoordinates object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this GeoCoordinates object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this GeoCoordinates object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this GeoCoordinates object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the elevation property values for this GeoCoordinates object.
   *
   * @return A list of elevation property values.
   */
  public List<Thing> getElevations() {
  	return this.elevation;
  }
  
  /**
   * Get all the image property values for this GeoCoordinates object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the latitude property values for this GeoCoordinates object.
   *
   * @return A list of latitude property values.
   */
  public List<Thing> getLatitudes() {
  	return this.latitude;
  }
  
  /**
   * Get all the longitude property values for this GeoCoordinates object.
   *
   * @return A list of longitude property values.
   */
  public List<Thing> getLongitudes() {
  	return this.longitude;
  }
  
  /**
   * Get all the name property values for this GeoCoordinates object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the sameAs property values for this GeoCoordinates object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this GeoCoordinates object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the elevation property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param elevation The value to set.
   */
  public void setElevation(Thing elevation) {
  	this.elevation.clear();
  	this.elevation.add(elevation);
  }
  
  /**
   * Set the image property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the latitude property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param latitude The value to set.
   */
  public void setLatitude(Thing latitude) {
  	this.latitude.clear();
  	this.latitude.add(latitude);
  }
  
  /**
   * Set the longitude property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param longitude The value to set.
   */
  public void setLongitude(Thing longitude) {
  	this.longitude.clear();
  	this.longitude.add(longitude);
  }
  
  /**
   * Set the name property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the sameAs property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the elevation property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param elevations The list of values to set.
   */
  public void setElevations(List<Thing> elevations) {
  	this.elevation = elevations;
  }
  
  /**
   * Set the image property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the latitude property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param latitudes The list of values to set.
   */
  public void setLatitudes(List<Thing> latitudes) {
  	this.latitude = latitudes;
  }
  
  /**
   * Set the longitude property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param longitudes The list of values to set.
   */
  public void setLongitudes(List<Thing> longitudes) {
  	this.longitude = longitudes;
  }
  
  /**
   * Set the name property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the sameAs property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a elevation property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param elevation The value to add.
   */
  public void addElevation(Thing elevation) {
  	this.elevation.add(elevation);
  }
  
  /**
   * Adds a image property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a latitude property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param latitude The value to add.
   */
  public void addLatitude(Thing latitude) {
  	this.latitude.add(latitude);
  }
  
  /**
   * Adds a longitude property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param longitude The value to add.
   */
  public void addLongitude(Thing longitude) {
  	this.longitude.add(longitude);
  }
  
  /**
   * Adds a name property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a sameAs property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}