package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.GeoShape;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The geographic shape of a place.
 */
public class GeoShapeImpl extends SchemaObjectImpl implements GeoShape {


  private ThingImpl thing;

  /**
   * A polygon is the area enclosed by a point-to-point path for which the starting and ending points are the same. A polygon is expressed as a series of four or more spacedelimited points where the first and final points are identical.
   */
  private List<String> box = new LinkedList<String>();
  
  /**
   * A circle is the circular region of a specified radius centered at a specified latitude and longitude. A circle is expressed as a pair followed by a radius in meters.
   */
  private List<String> circle = new LinkedList<String>();
  
  /**
   * The elevation of a location.
   */
  private List<Thing> elevation = new LinkedList<Thing>();
  
  /**
   * A line is a point-to-point path consisting of two or more points. A line is expressed as a series of two or more point objects separated by space.
   */
  private List<String> line = new LinkedList<String>();
  
  /**
   * A polygon is the area enclosed by a point-to-point path for which the starting and ending points are the same. A polygon is expressed as a series of four or more spacedelimited points where the first and final points are identical.
   */
  private List<String> polygon = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public GeoShapeImpl() {
    super("http://schema.org/GeoShape");
  }
  /**
   * Get a single additionalType property value for this GeoShape object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this GeoShape object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single box property value for this GeoShape object.
   *
   * @return The first box property value.
   */
  public String getBox() {
  	return this.box.isEmpty() ? null : this.box.get(0);
  }
  
  /**
   * Get a single circle property value for this GeoShape object.
   *
   * @return The first circle property value.
   */
  public String getCircle() {
  	return this.circle.isEmpty() ? null : this.circle.get(0);
  }
  
  /**
   * Get a single description property value for this GeoShape object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single elevation property value for this GeoShape object.
   *
   * @return The first elevation property value.
   */
  public Thing getElevation() {
  	return this.elevation.isEmpty() ? null : this.elevation.get(0);
  }
  
  /**
   * Get a single image property value for this GeoShape object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single line property value for this GeoShape object.
   *
   * @return The first line property value.
   */
  public String getLine() {
  	return this.line.isEmpty() ? null : this.line.get(0);
  }
  
  /**
   * Get a single name property value for this GeoShape object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single polygon property value for this GeoShape object.
   *
   * @return The first polygon property value.
   */
  public String getPolygon() {
  	return this.polygon.isEmpty() ? null : this.polygon.get(0);
  }
  
  /**
   * Get a single sameAs property value for this GeoShape object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this GeoShape object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this GeoShape object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this GeoShape object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the box property values for this GeoShape object.
   *
   * @return A list of box property values.
   */
  public List<String> getBoxes() {
  	return this.box;
  }
  
  /**
   * Get all the circle property values for this GeoShape object.
   *
   * @return A list of circle property values.
   */
  public List<String> getCircles() {
  	return this.circle;
  }
  
  /**
   * Get all the description property values for this GeoShape object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the elevation property values for this GeoShape object.
   *
   * @return A list of elevation property values.
   */
  public List<Thing> getElevations() {
  	return this.elevation;
  }
  
  /**
   * Get all the image property values for this GeoShape object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the line property values for this GeoShape object.
   *
   * @return A list of line property values.
   */
  public List<String> getLines() {
  	return this.line;
  }
  
  /**
   * Get all the name property values for this GeoShape object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the polygon property values for this GeoShape object.
   *
   * @return A list of polygon property values.
   */
  public List<String> getPolygons() {
  	return this.polygon;
  }
  
  /**
   * Get all the sameAs property values for this GeoShape object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this GeoShape object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this GeoShape object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this GeoShape object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the box property value for this GeoShape object; overwriting any existing values.
   *
   * @param box The value to set.
   */
  public void setBox(String box) {
  	this.box.clear();
  	this.box.add(box);
  }
  
  /**
   * Set the circle property value for this GeoShape object; overwriting any existing values.
   *
   * @param circle The value to set.
   */
  public void setCircle(String circle) {
  	this.circle.clear();
  	this.circle.add(circle);
  }
  
  /**
   * Set the description property value for this GeoShape object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the elevation property value for this GeoShape object; overwriting any existing values.
   *
   * @param elevation The value to set.
   */
  public void setElevation(Thing elevation) {
  	this.elevation.clear();
  	this.elevation.add(elevation);
  }
  
  /**
   * Set the image property value for this GeoShape object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the line property value for this GeoShape object; overwriting any existing values.
   *
   * @param line The value to set.
   */
  public void setLine(String line) {
  	this.line.clear();
  	this.line.add(line);
  }
  
  /**
   * Set the name property value for this GeoShape object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the polygon property value for this GeoShape object; overwriting any existing values.
   *
   * @param polygon The value to set.
   */
  public void setPolygon(String polygon) {
  	this.polygon.clear();
  	this.polygon.add(polygon);
  }
  
  /**
   * Set the sameAs property value for this GeoShape object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this GeoShape object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this GeoShape object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this GeoShape object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the box property values for this GeoShape object; overwriting any existing values.
   *
   * @param boxes The list of values to set.
   */
  public void setBoxes(List<String> boxes) {
  	this.box = boxes;
  }
  
  /**
   * Set the circle property values for this GeoShape object; overwriting any existing values.
   *
   * @param circles The list of values to set.
   */
  public void setCircles(List<String> circles) {
  	this.circle = circles;
  }
  
  /**
   * Set the description property values for this GeoShape object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the elevation property values for this GeoShape object; overwriting any existing values.
   *
   * @param elevations The list of values to set.
   */
  public void setElevations(List<Thing> elevations) {
  	this.elevation = elevations;
  }
  
  /**
   * Set the image property values for this GeoShape object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the line property values for this GeoShape object; overwriting any existing values.
   *
   * @param lines The list of values to set.
   */
  public void setLines(List<String> lines) {
  	this.line = lines;
  }
  
  /**
   * Set the name property values for this GeoShape object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the polygon property values for this GeoShape object; overwriting any existing values.
   *
   * @param polygons The list of values to set.
   */
  public void setPolygons(List<String> polygons) {
  	this.polygon = polygons;
  }
  
  /**
   * Set the sameAs property values for this GeoShape object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this GeoShape object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a box property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param box The value to add.
   */
  public void addBox(String box) {
  	this.box.add(box);
  }
  
  /**
   * Adds a circle property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param circle The value to add.
   */
  public void addCircle(String circle) {
  	this.circle.add(circle);
  }
  
  /**
   * Adds a description property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a elevation property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param elevation The value to add.
   */
  public void addElevation(Thing elevation) {
  	this.elevation.add(elevation);
  }
  
  /**
   * Adds a image property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a line property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param line The value to add.
   */
  public void addLine(String line) {
  	this.line.add(line);
  }
  
  /**
   * Adds a name property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a polygon property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param polygon The value to add.
   */
  public void addPolygon(String polygon) {
  	this.polygon.add(polygon);
  }
  
  /**
   * Adds a sameAs property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}