package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.Audience;
import org.schema.GovernmentService;
import org.schema.Organization;
import org.schema.ServiceChannel;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A service provided by a government organization, e.g. food stamps, veterans benefits, etc.
 */
public class GovernmentServiceImpl extends SchemaObjectImpl implements GovernmentService {


  private ServiceImpl service;
  private ThingImpl thing;

  /**
   * The operating organization, if different from the provider.  This enables the representation of services that are provided by an organization, but operated by another organization like a subcontractor.
   */
  private List<Organization> serviceOperator = new LinkedList<Organization>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public GovernmentServiceImpl() {
    super("http://schema.org/GovernmentService");
    service = new ServiceImpl();
  }
  /**
   * Get a single additionalType property value for this GovernmentService object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this GovernmentService object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single availableChannel property value for this GovernmentService object.
   *
   * @return The first availableChannel property value.
   */
  public ServiceChannel getAvailableChannel() {
    return service.getAvailableChannel();
  }
  
  /**
   * Get a single description property value for this GovernmentService object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this GovernmentService object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this GovernmentService object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single produces property value for this GovernmentService object.
   *
   * @return The first produces property value.
   */
  public Thing getProduces() {
    return service.getProduces();
  }
  
  /**
   * Get a single provider property value for this GovernmentService object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
    return service.getProvider();
  }
  
  /**
   * Get a single sameAs property value for this GovernmentService object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single serviceArea property value for this GovernmentService object.
   *
   * @return The first serviceArea property value.
   */
  public AdministrativeArea getServiceArea() {
    return service.getServiceArea();
  }
  
  /**
   * Get a single serviceAudience property value for this GovernmentService object.
   *
   * @return The first serviceAudience property value.
   */
  public Audience getServiceAudience() {
    return service.getServiceAudience();
  }
  
  /**
   * Get a single serviceOperator property value for this GovernmentService object.
   *
   * @return The first serviceOperator property value.
   */
  public Organization getServiceOperator() {
  	return this.serviceOperator.isEmpty() ? null : this.serviceOperator.get(0);
  }
  
  /**
   * Get a single serviceType property value for this GovernmentService object.
   *
   * @return The first serviceType property value.
   */
  public String getServiceType() {
    return service.getServiceType();
  }
  
  /**
   * Get a single url property value for this GovernmentService object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this GovernmentService object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this GovernmentService object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the availableChannel property values for this GovernmentService object.
   *
   * @return A list of availableChannel property values.
   */
  public List<ServiceChannel> getAvailableChannels() {
    return service.getAvailableChannels();
  }
  
  /**
   * Get all the description property values for this GovernmentService object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this GovernmentService object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this GovernmentService object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the produces property values for this GovernmentService object.
   *
   * @return A list of produces property values.
   */
  public List<Thing> getProducess() {
    return service.getProducess();
  }
  
  /**
   * Get all the provider property values for this GovernmentService object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
    return service.getProviders();
  }
  
  /**
   * Get all the sameAs property values for this GovernmentService object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the serviceArea property values for this GovernmentService object.
   *
   * @return A list of serviceArea property values.
   */
  public List<AdministrativeArea> getServiceAreas() {
    return service.getServiceAreas();
  }
  
  /**
   * Get all the serviceAudience property values for this GovernmentService object.
   *
   * @return A list of serviceAudience property values.
   */
  public List<Audience> getServiceAudiences() {
    return service.getServiceAudiences();
  }
  
  /**
   * Get all the serviceOperator property values for this GovernmentService object.
   *
   * @return A list of serviceOperator property values.
   */
  public List<Organization> getServiceOperators() {
  	return this.serviceOperator;
  }
  
  /**
   * Get all the serviceType property values for this GovernmentService object.
   *
   * @return A list of serviceType property values.
   */
  public List<String> getServiceTypes() {
    return service.getServiceTypes();
  }
  
  /**
   * Get all the url property values for this GovernmentService object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this GovernmentService object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this GovernmentService object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the availableChannel property value for this GovernmentService object; overwriting any existing values.
   *
   * @param availableChannel The value to set.
   */
  public void setAvailableChannel(ServiceChannel availableChannel) {
    service.setAvailableChannel(availableChannel);
  }
  
  /**
   * Set the description property value for this GovernmentService object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this GovernmentService object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this GovernmentService object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the produces property value for this GovernmentService object; overwriting any existing values.
   *
   * @param produces The value to set.
   */
  public void setProduces(Thing produces) {
    service.setProduces(produces);
  }
  
  /**
   * Set the provider property value for this GovernmentService object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
    service.setProvider(provider);
  }
  
  /**
   * Set the sameAs property value for this GovernmentService object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the serviceArea property value for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceArea The value to set.
   */
  public void setServiceArea(AdministrativeArea serviceArea) {
    service.setServiceArea(serviceArea);
  }
  
  /**
   * Set the serviceAudience property value for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceAudience The value to set.
   */
  public void setServiceAudience(Audience serviceAudience) {
    service.setServiceAudience(serviceAudience);
  }
  
  /**
   * Set the serviceOperator property value for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceOperator The value to set.
   */
  public void setServiceOperator(Organization serviceOperator) {
  	this.serviceOperator.clear();
  	this.serviceOperator.add(serviceOperator);
  }
  
  /**
   * Set the serviceType property value for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceType The value to set.
   */
  public void setServiceType(String serviceType) {
    service.setServiceType(serviceType);
  }
  
  /**
   * Set the url property value for this GovernmentService object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this GovernmentService object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this GovernmentService object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the availableChannel property values for this GovernmentService object; overwriting any existing values.
   *
   * @param availableChannels The list of values to set.
   */
  public void setAvailableChannels(List<ServiceChannel> availableChannels) {
    service.setAvailableChannels(availableChannels);
  }
  
  /**
   * Set the description property values for this GovernmentService object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this GovernmentService object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this GovernmentService object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the produces property values for this GovernmentService object; overwriting any existing values.
   *
   * @param producess The list of values to set.
   */
  public void setProducess(List<Thing> producess) {
    service.setProducess(producess);
  }
  
  /**
   * Set the provider property values for this GovernmentService object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
    service.setProviders(providers);
  }
  
  /**
   * Set the sameAs property values for this GovernmentService object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the serviceArea property values for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceAreas The list of values to set.
   */
  public void setServiceAreas(List<AdministrativeArea> serviceAreas) {
    service.setServiceAreas(serviceAreas);
  }
  
  /**
   * Set the serviceAudience property values for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceAudiences The list of values to set.
   */
  public void setServiceAudiences(List<Audience> serviceAudiences) {
    service.setServiceAudiences(serviceAudiences);
  }
  
  /**
   * Set the serviceOperator property values for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceOperators The list of values to set.
   */
  public void setServiceOperators(List<Organization> serviceOperators) {
  	this.serviceOperator = serviceOperators;
  }
  
  /**
   * Set the serviceType property values for this GovernmentService object; overwriting any existing values.
   *
   * @param serviceTypes The list of values to set.
   */
  public void setServiceTypes(List<String> serviceTypes) {
    service.setServiceTypes(serviceTypes);
  }
  
  /**
   * Set the url property values for this GovernmentService object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a availableChannel property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param availableChannel The value to add.
   */
  public void addAvailableChannel(ServiceChannel availableChannel) {
    service.addAvailableChannel(availableChannel);
  }
  
  /**
   * Adds a description property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a produces property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param produces The value to add.
   */
  public void addProduces(Thing produces) {
    service.addProduces(produces);
  }
  
  /**
   * Adds a provider property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
    service.addProvider(provider);
  }
  
  /**
   * Adds a sameAs property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a serviceArea property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param serviceArea The value to add.
   */
  public void addServiceArea(AdministrativeArea serviceArea) {
    service.addServiceArea(serviceArea);
  }
  
  /**
   * Adds a serviceAudience property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param serviceAudience The value to add.
   */
  public void addServiceAudience(Audience serviceAudience) {
    service.addServiceAudience(serviceAudience);
  }
  
  /**
   * Adds a serviceOperator property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param serviceOperator The value to add.
   */
  public void addServiceOperator(Organization serviceOperator) {
  	this.serviceOperator.add(serviceOperator);
  }
  
  /**
   * Adds a serviceType property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param serviceType The value to add.
   */
  public void addServiceType(String serviceType) {
    service.addServiceType(serviceType);
  }
  
  /**
   * Adds a url property value for this GovernmentService object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}