package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.AlignmentObject;
import org.schema.Audience;
import org.schema.AudioObject;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.ImageObject;
import org.schema.MediaObject;
import org.schema.NewsArticle;
import org.schema.Number;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.PublicationEvent;
import org.schema.Review;
import org.schema.Thing;
import org.schema.VideoObject;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An image file.
 */
public class ImageObjectImpl extends SchemaObjectImpl implements ImageObject {


  private CreativeWorkImpl creativeWork;
  private MediaObjectImpl mediaObject;
  private ThingImpl thing;

  /**
   * The caption for this object.
   */
  private List<String> caption = new LinkedList<String>();
  
  /**
   * exif data for this object.
   */
  private List<String> exifData = new LinkedList<String>();
  
  /**
   * Indicates whether this image is representative of the content of the page.
   */
  private List<Boolean> representativeOfPage = new LinkedList<Boolean>();
  
  /**
   * Thumbnail image for an image or video.
   */
  private List<ImageObject> thumbnail = new LinkedList<ImageObject>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ImageObjectImpl() {
    super("http://schema.org/ImageObject");
    mediaObject = new MediaObjectImpl();
  }
  /**
   * Get a single about property value for this ImageObject object.
   *
   * @return The first about property value.
   */
  public Thing getAbout() {
    return creativeWork.getAbout();
  }
  
  /**
   * Get a single accessibilityAPI property value for this ImageObject object.
   *
   * @return The first accessibilityAPI property value.
   */
  public String getAccessibilityAPI() {
    return creativeWork.getAccessibilityAPI();
  }
  
  /**
   * Get a single accessibilityControl property value for this ImageObject object.
   *
   * @return The first accessibilityControl property value.
   */
  public String getAccessibilityControl() {
    return creativeWork.getAccessibilityControl();
  }
  
  /**
   * Get a single accessibilityFeature property value for this ImageObject object.
   *
   * @return The first accessibilityFeature property value.
   */
  public String getAccessibilityFeature() {
    return creativeWork.getAccessibilityFeature();
  }
  
  /**
   * Get a single accessibilityHazard property value for this ImageObject object.
   *
   * @return The first accessibilityHazard property value.
   */
  public String getAccessibilityHazard() {
    return creativeWork.getAccessibilityHazard();
  }
  
  /**
   * Get a single accountablePerson property value for this ImageObject object.
   *
   * @return The first accountablePerson property value.
   */
  public Person getAccountablePerson() {
    return creativeWork.getAccountablePerson();
  }
  
  /**
   * Get a single additionalType property value for this ImageObject object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single aggregateRating property value for this ImageObject object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
    return creativeWork.getAggregateRating();
  }
  
  /**
   * Get a single alternateName property value for this ImageObject object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single alternativeHeadline property value for this ImageObject object.
   *
   * @return The first alternativeHeadline property value.
   */
  public String getAlternativeHeadline() {
    return creativeWork.getAlternativeHeadline();
  }
  
  /**
   * Get a single associatedArticle property value for this ImageObject object.
   *
   * @return The first associatedArticle property value.
   */
  public NewsArticle getAssociatedArticle() {
    return mediaObject.getAssociatedArticle();
  }
  
  /**
   * Get a single associatedMedia property value for this ImageObject object.
   *
   * @return The first associatedMedia property value.
   */
  public MediaObject getAssociatedMedia() {
    return creativeWork.getAssociatedMedia();
  }
  
  /**
   * Get a single audience property value for this ImageObject object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience() {
    return creativeWork.getAudience();
  }
  
  /**
   * Get a single audio property value for this ImageObject object.
   *
   * @return The first audio property value.
   */
  public AudioObject getAudio() {
    return creativeWork.getAudio();
  }
  
  /**
   * Get a single author property value for this ImageObject object.
   *
   * @return The first author property value.
   */
  public Thing getAuthor() {
    return creativeWork.getAuthor();
  }
  
  /**
   * Get a single award property value for this ImageObject object.
   *
   * @return The first award property value.
   */
  public String getAward() {
    return creativeWork.getAward();
  }
  
  /**
   * Get a single bitrate property value for this ImageObject object.
   *
   * @return The first bitrate property value.
   */
  public String getBitrate() {
    return mediaObject.getBitrate();
  }
  
  /**
   * Get a single caption property value for this ImageObject object.
   *
   * @return The first caption property value.
   */
  public String getCaption() {
  	return this.caption.isEmpty() ? null : this.caption.get(0);
  }
  
  /**
   * Get a single citation property value for this ImageObject object.
   *
   * @return The first citation property value.
   */
  public Thing getCitation() {
    return creativeWork.getCitation();
  }
  
  /**
   * Get a single comment property value for this ImageObject object.
   *
   * @return The first comment property value.
   */
  public Thing getComment() {
    return creativeWork.getComment();
  }
  
  /**
   * Get a single commentCount property value for this ImageObject object.
   *
   * @return The first commentCount property value.
   */
  public Long getCommentCount() {
    return creativeWork.getCommentCount();
  }
  
  /**
   * Get a single contentLocation property value for this ImageObject object.
   *
   * @return The first contentLocation property value.
   */
  public Place getContentLocation() {
    return creativeWork.getContentLocation();
  }
  
  /**
   * Get a single contentRating property value for this ImageObject object.
   *
   * @return The first contentRating property value.
   */
  public String getContentRating() {
    return creativeWork.getContentRating();
  }
  
  /**
   * Get a single contentSize property value for this ImageObject object.
   *
   * @return The first contentSize property value.
   */
  public String getContentSize() {
    return mediaObject.getContentSize();
  }
  
  /**
   * Get a single contentUrl property value for this ImageObject object.
   *
   * @return The first contentUrl property value.
   */
  public URL getContentUrl() {
    return mediaObject.getContentUrl();
  }
  
  /**
   * Get a single contributor property value for this ImageObject object.
   *
   * @return The first contributor property value.
   */
  public Thing getContributor() {
    return creativeWork.getContributor();
  }
  
  /**
   * Get a single copyrightHolder property value for this ImageObject object.
   *
   * @return The first copyrightHolder property value.
   */
  public Thing getCopyrightHolder() {
    return creativeWork.getCopyrightHolder();
  }
  
  /**
   * Get a single copyrightYear property value for this ImageObject object.
   *
   * @return The first copyrightYear property value.
   */
  public Number getCopyrightYear() {
    return creativeWork.getCopyrightYear();
  }
  
  /**
   * Get a single creator property value for this ImageObject object.
   *
   * @return The first creator property value.
   */
  public Thing getCreator() {
    return creativeWork.getCreator();
  }
  
  /**
   * Get a single dateCreated property value for this ImageObject object.
   *
   * @return The first dateCreated property value.
   */
  public Date getDateCreated() {
    return creativeWork.getDateCreated();
  }
  
  /**
   * Get a single dateModified property value for this ImageObject object.
   *
   * @return The first dateModified property value.
   */
  public Date getDateModified() {
    return creativeWork.getDateModified();
  }
  
  /**
   * Get a single datePublished property value for this ImageObject object.
   *
   * @return The first datePublished property value.
   */
  public Date getDatePublished() {
    return creativeWork.getDatePublished();
  }
  
  /**
   * Get a single description property value for this ImageObject object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single discussionUrl property value for this ImageObject object.
   *
   * @return The first discussionUrl property value.
   */
  public URL getDiscussionUrl() {
    return creativeWork.getDiscussionUrl();
  }
  
  /**
   * Get a single duration property value for this ImageObject object.
   *
   * @return The first duration property value.
   */
  public Duration getDuration() {
    return mediaObject.getDuration();
  }
  
  /**
   * Get a single editor property value for this ImageObject object.
   *
   * @return The first editor property value.
   */
  public Person getEditor() {
    return creativeWork.getEditor();
  }
  
  /**
   * Get a single educationalAlignment property value for this ImageObject object.
   *
   * @return The first educationalAlignment property value.
   */
  public AlignmentObject getEducationalAlignment() {
    return creativeWork.getEducationalAlignment();
  }
  
  /**
   * Get a single educationalUse property value for this ImageObject object.
   *
   * @return The first educationalUse property value.
   */
  public String getEducationalUse() {
    return creativeWork.getEducationalUse();
  }
  
  /**
   * Get a single embedUrl property value for this ImageObject object.
   *
   * @return The first embedUrl property value.
   */
  public URL getEmbedUrl() {
    return mediaObject.getEmbedUrl();
  }
  
  /**
   * Get a single encodesCreativeWork property value for this ImageObject object.
   *
   * @return The first encodesCreativeWork property value.
   */
  public CreativeWork getEncodesCreativeWork() {
    return mediaObject.getEncodesCreativeWork();
  }
  
  /**
   * Get a single encoding property value for this ImageObject object.
   *
   * @return The first encoding property value.
   */
  public MediaObject getEncoding() {
    return creativeWork.getEncoding();
  }
  
  /**
   * Get a single encodingFormat property value for this ImageObject object.
   *
   * @return The first encodingFormat property value.
   */
  public String getEncodingFormat() {
    return mediaObject.getEncodingFormat();
  }
  
  /**
   * Get a single exifData property value for this ImageObject object.
   *
   * @return The first exifData property value.
   */
  public String getExifData() {
  	return this.exifData.isEmpty() ? null : this.exifData.get(0);
  }
  
  /**
   * Get a single expires property value for this ImageObject object.
   *
   * @return The first expires property value.
   */
  public Date getExpires() {
    return mediaObject.getExpires();
  }
  
  /**
   * Get a single genre property value for this ImageObject object.
   *
   * @return The first genre property value.
   */
  public String getGenre() {
    return creativeWork.getGenre();
  }
  
  /**
   * Get a single headline property value for this ImageObject object.
   *
   * @return The first headline property value.
   */
  public String getHeadline() {
    return creativeWork.getHeadline();
  }
  
  /**
   * Get a single height property value for this ImageObject object.
   *
   * @return The first height property value.
   */
  public Thing getHeight() {
    return mediaObject.getHeight();
  }
  
  /**
   * Get a single image property value for this ImageObject object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single inLanguage property value for this ImageObject object.
   *
   * @return The first inLanguage property value.
   */
  public String getInLanguage() {
    return creativeWork.getInLanguage();
  }
  
  /**
   * Get a single interactionCount property value for this ImageObject object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
    return mediaObject.getInteractionCount();
  }
  
  /**
   * Get a single interactivityType property value for this ImageObject object.
   *
   * @return The first interactivityType property value.
   */
  public String getInteractivityType() {
    return creativeWork.getInteractivityType();
  }
  
  /**
   * Get a single isBasedOnUrl property value for this ImageObject object.
   *
   * @return The first isBasedOnUrl property value.
   */
  public URL getIsBasedOnUrl() {
    return creativeWork.getIsBasedOnUrl();
  }
  
  /**
   * Get a single isFamilyFriendly property value for this ImageObject object.
   *
   * @return The first isFamilyFriendly property value.
   */
  public Boolean getIsFamilyFriendly() {
    return creativeWork.getIsFamilyFriendly();
  }
  
  /**
   * Get a single keywords property value for this ImageObject object.
   *
   * @return The first keywords property value.
   */
  public String getKeywords() {
    return creativeWork.getKeywords();
  }
  
  /**
   * Get a single learningResourceType property value for this ImageObject object.
   *
   * @return The first learningResourceType property value.
   */
  public String getLearningResourceType() {
    return creativeWork.getLearningResourceType();
  }
  
  /**
   * Get a single mentions property value for this ImageObject object.
   *
   * @return The first mentions property value.
   */
  public Thing getMentions() {
    return creativeWork.getMentions();
  }
  
  /**
   * Get a single name property value for this ImageObject object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offers property value for this ImageObject object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers() {
    return mediaObject.getOffers();
  }
  
  /**
   * Get a single playerType property value for this ImageObject object.
   *
   * @return The first playerType property value.
   */
  public String getPlayerType() {
    return mediaObject.getPlayerType();
  }
  
  /**
   * Get a single productionCompany property value for this ImageObject object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany() {
    return mediaObject.getProductionCompany();
  }
  
  /**
   * Get a single provider property value for this ImageObject object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
    return creativeWork.getProvider();
  }
  
  /**
   * Get a single publication property value for this ImageObject object.
   *
   * @return The first publication property value.
   */
  public PublicationEvent getPublication() {
    return mediaObject.getPublication();
  }
  
  /**
   * Get a single publisher property value for this ImageObject object.
   *
   * @return The first publisher property value.
   */
  public Organization getPublisher() {
    return creativeWork.getPublisher();
  }
  
  /**
   * Get a single publishingPrinciples property value for this ImageObject object.
   *
   * @return The first publishingPrinciples property value.
   */
  public URL getPublishingPrinciples() {
    return creativeWork.getPublishingPrinciples();
  }
  
  /**
   * Get a single regionsAllowed property value for this ImageObject object.
   *
   * @return The first regionsAllowed property value.
   */
  public Place getRegionsAllowed() {
    return mediaObject.getRegionsAllowed();
  }
  
  /**
   * Get a single representativeOfPage property value for this ImageObject object.
   *
   * @return The first representativeOfPage property value.
   */
  public Boolean getRepresentativeOfPage() {
  	return this.representativeOfPage.isEmpty() ? null : this.representativeOfPage.get(0);
  }
  
  /**
   * Get a single requiresSubscription property value for this ImageObject object.
   *
   * @return The first requiresSubscription property value.
   */
  public Boolean getRequiresSubscription() {
    return mediaObject.getRequiresSubscription();
  }
  
  /**
   * Get a single review property value for this ImageObject object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
    return creativeWork.getReview();
  }
  
  /**
   * Get a single sameAs property value for this ImageObject object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single sourceOrganization property value for this ImageObject object.
   *
   * @return The first sourceOrganization property value.
   */
  public Organization getSourceOrganization() {
    return creativeWork.getSourceOrganization();
  }
  
  /**
   * Get a single text property value for this ImageObject object.
   *
   * @return The first text property value.
   */
  public String getText() {
    return creativeWork.getText();
  }
  
  /**
   * Get a single thumbnail property value for this ImageObject object.
   *
   * @return The first thumbnail property value.
   */
  public ImageObject getThumbnail() {
  	return this.thumbnail.isEmpty() ? null : this.thumbnail.get(0);
  }
  
  /**
   * Get a single thumbnailUrl property value for this ImageObject object.
   *
   * @return The first thumbnailUrl property value.
   */
  public URL getThumbnailUrl() {
    return creativeWork.getThumbnailUrl();
  }
  
  /**
   * Get a single timeRequired property value for this ImageObject object.
   *
   * @return The first timeRequired property value.
   */
  public Duration getTimeRequired() {
    return creativeWork.getTimeRequired();
  }
  
  /**
   * Get a single typicalAgeRange property value for this ImageObject object.
   *
   * @return The first typicalAgeRange property value.
   */
  public String getTypicalAgeRange() {
    return creativeWork.getTypicalAgeRange();
  }
  
  /**
   * Get a single uploadDate property value for this ImageObject object.
   *
   * @return The first uploadDate property value.
   */
  public Date getUploadDate() {
    return mediaObject.getUploadDate();
  }
  
  /**
   * Get a single url property value for this ImageObject object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single version property value for this ImageObject object.
   *
   * @return The first version property value.
   */
  public Number getVersion() {
    return creativeWork.getVersion();
  }
  
  /**
   * Get a single video property value for this ImageObject object.
   *
   * @return The first video property value.
   */
  public VideoObject getVideo() {
    return creativeWork.getVideo();
  }
  
  /**
   * Get a single width property value for this ImageObject object.
   *
   * @return The first width property value.
   */
  public Thing getWidth() {
    return mediaObject.getWidth();
  }
  
  /**
   * Get all the about property values for this ImageObject object.
   *
   * @return A list of about property values.
   */
  public List<Thing> getAbouts() {
    return creativeWork.getAbouts();
  }
  
  /**
   * Get all the accessibilityAPI property values for this ImageObject object.
   *
   * @return A list of accessibilityAPI property values.
   */
  public List<String> getAccessibilityAPIs() {
    return creativeWork.getAccessibilityAPIs();
  }
  
  /**
   * Get all the accessibilityControl property values for this ImageObject object.
   *
   * @return A list of accessibilityControl property values.
   */
  public List<String> getAccessibilityControls() {
    return creativeWork.getAccessibilityControls();
  }
  
  /**
   * Get all the accessibilityFeature property values for this ImageObject object.
   *
   * @return A list of accessibilityFeature property values.
   */
  public List<String> getAccessibilityFeatures() {
    return creativeWork.getAccessibilityFeatures();
  }
  
  /**
   * Get all the accessibilityHazard property values for this ImageObject object.
   *
   * @return A list of accessibilityHazard property values.
   */
  public List<String> getAccessibilityHazards() {
    return creativeWork.getAccessibilityHazards();
  }
  
  /**
   * Get all the accountablePerson property values for this ImageObject object.
   *
   * @return A list of accountablePerson property values.
   */
  public List<Person> getAccountablePersons() {
    return creativeWork.getAccountablePersons();
  }
  
  /**
   * Get all the additionalType property values for this ImageObject object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the aggregateRating property values for this ImageObject object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
    return creativeWork.getAggregateRatings();
  }
  
  /**
   * Get all the alternateName property values for this ImageObject object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the alternativeHeadline property values for this ImageObject object.
   *
   * @return A list of alternativeHeadline property values.
   */
  public List<String> getAlternativeHeadlines() {
    return creativeWork.getAlternativeHeadlines();
  }
  
  /**
   * Get all the associatedArticle property values for this ImageObject object.
   *
   * @return A list of associatedArticle property values.
   */
  public List<NewsArticle> getAssociatedArticles() {
    return mediaObject.getAssociatedArticles();
  }
  
  /**
   * Get all the associatedMedia property values for this ImageObject object.
   *
   * @return A list of associatedMedia property values.
   */
  public List<MediaObject> getAssociatedMedias() {
    return creativeWork.getAssociatedMedias();
  }
  
  /**
   * Get all the audience property values for this ImageObject object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences() {
    return creativeWork.getAudiences();
  }
  
  /**
   * Get all the audio property values for this ImageObject object.
   *
   * @return A list of audio property values.
   */
  public List<AudioObject> getAudios() {
    return creativeWork.getAudios();
  }
  
  /**
   * Get all the author property values for this ImageObject object.
   *
   * @return A list of author property values.
   */
  public List<Thing> getAuthors() {
    return creativeWork.getAuthors();
  }
  
  /**
   * Get all the award property values for this ImageObject object.
   *
   * @return A list of award property values.
   */
  public List<String> getAwards() {
    return creativeWork.getAwards();
  }
  
  /**
   * Get all the bitrate property values for this ImageObject object.
   *
   * @return A list of bitrate property values.
   */
  public List<String> getBitrates() {
    return mediaObject.getBitrates();
  }
  
  /**
   * Get all the caption property values for this ImageObject object.
   *
   * @return A list of caption property values.
   */
  public List<String> getCaptions() {
  	return this.caption;
  }
  
  /**
   * Get all the citation property values for this ImageObject object.
   *
   * @return A list of citation property values.
   */
  public List<Thing> getCitations() {
    return creativeWork.getCitations();
  }
  
  /**
   * Get all the comment property values for this ImageObject object.
   *
   * @return A list of comment property values.
   */
  public List<Thing> getComments() {
    return creativeWork.getComments();
  }
  
  /**
   * Get all the commentCount property values for this ImageObject object.
   *
   * @return A list of commentCount property values.
   */
  public List<Long> getCommentCounts() {
    return creativeWork.getCommentCounts();
  }
  
  /**
   * Get all the contentLocation property values for this ImageObject object.
   *
   * @return A list of contentLocation property values.
   */
  public List<Place> getContentLocations() {
    return creativeWork.getContentLocations();
  }
  
  /**
   * Get all the contentRating property values for this ImageObject object.
   *
   * @return A list of contentRating property values.
   */
  public List<String> getContentRatings() {
    return creativeWork.getContentRatings();
  }
  
  /**
   * Get all the contentSize property values for this ImageObject object.
   *
   * @return A list of contentSize property values.
   */
  public List<String> getContentSizes() {
    return mediaObject.getContentSizes();
  }
  
  /**
   * Get all the contentUrl property values for this ImageObject object.
   *
   * @return A list of contentUrl property values.
   */
  public List<URL> getContentUrls() {
    return mediaObject.getContentUrls();
  }
  
  /**
   * Get all the contributor property values for this ImageObject object.
   *
   * @return A list of contributor property values.
   */
  public List<Thing> getContributors() {
    return creativeWork.getContributors();
  }
  
  /**
   * Get all the copyrightHolder property values for this ImageObject object.
   *
   * @return A list of copyrightHolder property values.
   */
  public List<Thing> getCopyrightHolders() {
    return creativeWork.getCopyrightHolders();
  }
  
  /**
   * Get all the copyrightYear property values for this ImageObject object.
   *
   * @return A list of copyrightYear property values.
   */
  public List<Number> getCopyrightYears() {
    return creativeWork.getCopyrightYears();
  }
  
  /**
   * Get all the creator property values for this ImageObject object.
   *
   * @return A list of creator property values.
   */
  public List<Thing> getCreators() {
    return creativeWork.getCreators();
  }
  
  /**
   * Get all the dateCreated property values for this ImageObject object.
   *
   * @return A list of dateCreated property values.
   */
  public List<Date> getDateCreateds() {
    return creativeWork.getDateCreateds();
  }
  
  /**
   * Get all the dateModified property values for this ImageObject object.
   *
   * @return A list of dateModified property values.
   */
  public List<Date> getDateModifieds() {
    return creativeWork.getDateModifieds();
  }
  
  /**
   * Get all the datePublished property values for this ImageObject object.
   *
   * @return A list of datePublished property values.
   */
  public List<Date> getDatePublisheds() {
    return creativeWork.getDatePublisheds();
  }
  
  /**
   * Get all the description property values for this ImageObject object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the discussionUrl property values for this ImageObject object.
   *
   * @return A list of discussionUrl property values.
   */
  public List<URL> getDiscussionUrls() {
    return creativeWork.getDiscussionUrls();
  }
  
  /**
   * Get all the duration property values for this ImageObject object.
   *
   * @return A list of duration property values.
   */
  public List<Duration> getDurations() {
    return mediaObject.getDurations();
  }
  
  /**
   * Get all the editor property values for this ImageObject object.
   *
   * @return A list of editor property values.
   */
  public List<Person> getEditors() {
    return creativeWork.getEditors();
  }
  
  /**
   * Get all the educationalAlignment property values for this ImageObject object.
   *
   * @return A list of educationalAlignment property values.
   */
  public List<AlignmentObject> getEducationalAlignments() {
    return creativeWork.getEducationalAlignments();
  }
  
  /**
   * Get all the educationalUse property values for this ImageObject object.
   *
   * @return A list of educationalUse property values.
   */
  public List<String> getEducationalUses() {
    return creativeWork.getEducationalUses();
  }
  
  /**
   * Get all the embedUrl property values for this ImageObject object.
   *
   * @return A list of embedUrl property values.
   */
  public List<URL> getEmbedUrls() {
    return mediaObject.getEmbedUrls();
  }
  
  /**
   * Get all the encodesCreativeWork property values for this ImageObject object.
   *
   * @return A list of encodesCreativeWork property values.
   */
  public List<CreativeWork> getEncodesCreativeWorks() {
    return mediaObject.getEncodesCreativeWorks();
  }
  
  /**
   * Get all the encoding property values for this ImageObject object.
   *
   * @return A list of encoding property values.
   */
  public List<MediaObject> getEncodings() {
    return creativeWork.getEncodings();
  }
  
  /**
   * Get all the encodingFormat property values for this ImageObject object.
   *
   * @return A list of encodingFormat property values.
   */
  public List<String> getEncodingFormats() {
    return mediaObject.getEncodingFormats();
  }
  
  /**
   * Get all the exifData property values for this ImageObject object.
   *
   * @return A list of exifData property values.
   */
  public List<String> getExifDatas() {
  	return this.exifData;
  }
  
  /**
   * Get all the expires property values for this ImageObject object.
   *
   * @return A list of expires property values.
   */
  public List<Date> getExpiress() {
    return mediaObject.getExpiress();
  }
  
  /**
   * Get all the genre property values for this ImageObject object.
   *
   * @return A list of genre property values.
   */
  public List<String> getGenres() {
    return creativeWork.getGenres();
  }
  
  /**
   * Get all the headline property values for this ImageObject object.
   *
   * @return A list of headline property values.
   */
  public List<String> getHeadlines() {
    return creativeWork.getHeadlines();
  }
  
  /**
   * Get all the height property values for this ImageObject object.
   *
   * @return A list of height property values.
   */
  public List<Thing> getHeights() {
    return mediaObject.getHeights();
  }
  
  /**
   * Get all the image property values for this ImageObject object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the inLanguage property values for this ImageObject object.
   *
   * @return A list of inLanguage property values.
   */
  public List<String> getInLanguages() {
    return creativeWork.getInLanguages();
  }
  
  /**
   * Get all the interactionCount property values for this ImageObject object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
    return mediaObject.getInteractionCounts();
  }
  
  /**
   * Get all the interactivityType property values for this ImageObject object.
   *
   * @return A list of interactivityType property values.
   */
  public List<String> getInteractivityTypes() {
    return creativeWork.getInteractivityTypes();
  }
  
  /**
   * Get all the isBasedOnUrl property values for this ImageObject object.
   *
   * @return A list of isBasedOnUrl property values.
   */
  public List<URL> getIsBasedOnUrls() {
    return creativeWork.getIsBasedOnUrls();
  }
  
  /**
   * Get all the isFamilyFriendly property values for this ImageObject object.
   *
   * @return A list of isFamilyFriendly property values.
   */
  public List<Boolean> getIsFamilyFriendlies() {
    return creativeWork.getIsFamilyFriendlies();
  }
  
  /**
   * Get all the keywords property values for this ImageObject object.
   *
   * @return A list of keywords property values.
   */
  public List<String> getKeywordss() {
    return creativeWork.getKeywordss();
  }
  
  /**
   * Get all the learningResourceType property values for this ImageObject object.
   *
   * @return A list of learningResourceType property values.
   */
  public List<String> getLearningResourceTypes() {
    return creativeWork.getLearningResourceTypes();
  }
  
  /**
   * Get all the mentions property values for this ImageObject object.
   *
   * @return A list of mentions property values.
   */
  public List<Thing> getMentionss() {
    return creativeWork.getMentionss();
  }
  
  /**
   * Get all the name property values for this ImageObject object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offers property values for this ImageObject object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss() {
    return mediaObject.getOfferss();
  }
  
  /**
   * Get all the playerType property values for this ImageObject object.
   *
   * @return A list of playerType property values.
   */
  public List<String> getPlayerTypes() {
    return mediaObject.getPlayerTypes();
  }
  
  /**
   * Get all the productionCompany property values for this ImageObject object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies() {
    return mediaObject.getProductionCompanies();
  }
  
  /**
   * Get all the provider property values for this ImageObject object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
    return creativeWork.getProviders();
  }
  
  /**
   * Get all the publication property values for this ImageObject object.
   *
   * @return A list of publication property values.
   */
  public List<PublicationEvent> getPublications() {
    return mediaObject.getPublications();
  }
  
  /**
   * Get all the publisher property values for this ImageObject object.
   *
   * @return A list of publisher property values.
   */
  public List<Organization> getPublishers() {
    return creativeWork.getPublishers();
  }
  
  /**
   * Get all the publishingPrinciples property values for this ImageObject object.
   *
   * @return A list of publishingPrinciples property values.
   */
  public List<URL> getPublishingPrincipless() {
    return creativeWork.getPublishingPrincipless();
  }
  
  /**
   * Get all the regionsAllowed property values for this ImageObject object.
   *
   * @return A list of regionsAllowed property values.
   */
  public List<Place> getRegionsAlloweds() {
    return mediaObject.getRegionsAlloweds();
  }
  
  /**
   * Get all the representativeOfPage property values for this ImageObject object.
   *
   * @return A list of representativeOfPage property values.
   */
  public List<Boolean> getRepresentativeOfPages() {
  	return this.representativeOfPage;
  }
  
  /**
   * Get all the requiresSubscription property values for this ImageObject object.
   *
   * @return A list of requiresSubscription property values.
   */
  public List<Boolean> getRequiresSubscriptions() {
    return mediaObject.getRequiresSubscriptions();
  }
  
  /**
   * Get all the review property values for this ImageObject object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
    return creativeWork.getReviews();
  }
  
  /**
   * Get all the sameAs property values for this ImageObject object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the sourceOrganization property values for this ImageObject object.
   *
   * @return A list of sourceOrganization property values.
   */
  public List<Organization> getSourceOrganizations() {
    return creativeWork.getSourceOrganizations();
  }
  
  /**
   * Get all the text property values for this ImageObject object.
   *
   * @return A list of text property values.
   */
  public List<String> getTexts() {
    return creativeWork.getTexts();
  }
  
  /**
   * Get all the thumbnail property values for this ImageObject object.
   *
   * @return A list of thumbnail property values.
   */
  public List<ImageObject> getThumbnails() {
  	return this.thumbnail;
  }
  
  /**
   * Get all the thumbnailUrl property values for this ImageObject object.
   *
   * @return A list of thumbnailUrl property values.
   */
  public List<URL> getThumbnailUrls() {
    return creativeWork.getThumbnailUrls();
  }
  
  /**
   * Get all the timeRequired property values for this ImageObject object.
   *
   * @return A list of timeRequired property values.
   */
  public List<Duration> getTimeRequireds() {
    return creativeWork.getTimeRequireds();
  }
  
  /**
   * Get all the typicalAgeRange property values for this ImageObject object.
   *
   * @return A list of typicalAgeRange property values.
   */
  public List<String> getTypicalAgeRanges() {
    return creativeWork.getTypicalAgeRanges();
  }
  
  /**
   * Get all the uploadDate property values for this ImageObject object.
   *
   * @return A list of uploadDate property values.
   */
  public List<Date> getUploadDates() {
    return mediaObject.getUploadDates();
  }
  
  /**
   * Get all the url property values for this ImageObject object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the version property values for this ImageObject object.
   *
   * @return A list of version property values.
   */
  public List<Number> getVersions() {
    return creativeWork.getVersions();
  }
  
  /**
   * Get all the video property values for this ImageObject object.
   *
   * @return A list of video property values.
   */
  public List<VideoObject> getVideos() {
    return creativeWork.getVideos();
  }
  
  /**
   * Get all the width property values for this ImageObject object.
   *
   * @return A list of width property values.
   */
  public List<Thing> getWidths() {
    return mediaObject.getWidths();
  }
  
  /**
   * Set the about property value for this ImageObject object; overwriting any existing values.
   *
   * @param about The value to set.
   */
  public void setAbout(Thing about) {
    creativeWork.setAbout(about);
  }
  
  /**
   * Set the accessibilityAPI property value for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityAPI The value to set.
   */
  public void setAccessibilityAPI(String accessibilityAPI) {
    creativeWork.setAccessibilityAPI(accessibilityAPI);
  }
  
  /**
   * Set the accessibilityControl property value for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityControl The value to set.
   */
  public void setAccessibilityControl(String accessibilityControl) {
    creativeWork.setAccessibilityControl(accessibilityControl);
  }
  
  /**
   * Set the accessibilityFeature property value for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityFeature The value to set.
   */
  public void setAccessibilityFeature(String accessibilityFeature) {
    creativeWork.setAccessibilityFeature(accessibilityFeature);
  }
  
  /**
   * Set the accessibilityHazard property value for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityHazard The value to set.
   */
  public void setAccessibilityHazard(String accessibilityHazard) {
    creativeWork.setAccessibilityHazard(accessibilityHazard);
  }
  
  /**
   * Set the accountablePerson property value for this ImageObject object; overwriting any existing values.
   *
   * @param accountablePerson The value to set.
   */
  public void setAccountablePerson(Person accountablePerson) {
    creativeWork.setAccountablePerson(accountablePerson);
  }
  
  /**
   * Set the additionalType property value for this ImageObject object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the aggregateRating property value for this ImageObject object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
    creativeWork.setAggregateRating(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this ImageObject object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the alternativeHeadline property value for this ImageObject object; overwriting any existing values.
   *
   * @param alternativeHeadline The value to set.
   */
  public void setAlternativeHeadline(String alternativeHeadline) {
    creativeWork.setAlternativeHeadline(alternativeHeadline);
  }
  
  /**
   * Set the associatedArticle property value for this ImageObject object; overwriting any existing values.
   *
   * @param associatedArticle The value to set.
   */
  public void setAssociatedArticle(NewsArticle associatedArticle) {
    mediaObject.setAssociatedArticle(associatedArticle);
  }
  
  /**
   * Set the associatedMedia property value for this ImageObject object; overwriting any existing values.
   *
   * @param associatedMedia The value to set.
   */
  public void setAssociatedMedia(MediaObject associatedMedia) {
    creativeWork.setAssociatedMedia(associatedMedia);
  }
  
  /**
   * Set the audience property value for this ImageObject object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience) {
    creativeWork.setAudience(audience);
  }
  
  /**
   * Set the audio property value for this ImageObject object; overwriting any existing values.
   *
   * @param audio The value to set.
   */
  public void setAudio(AudioObject audio) {
    creativeWork.setAudio(audio);
  }
  
  /**
   * Set the author property value for this ImageObject object; overwriting any existing values.
   *
   * @param author The value to set.
   */
  public void setAuthor(Thing author) {
    creativeWork.setAuthor(author);
  }
  
  /**
   * Set the award property value for this ImageObject object; overwriting any existing values.
   *
   * @param award The value to set.
   */
  public void setAward(String award) {
    creativeWork.setAward(award);
  }
  
  /**
   * Set the bitrate property value for this ImageObject object; overwriting any existing values.
   *
   * @param bitrate The value to set.
   */
  public void setBitrate(String bitrate) {
    mediaObject.setBitrate(bitrate);
  }
  
  /**
   * Set the caption property value for this ImageObject object; overwriting any existing values.
   *
   * @param caption The value to set.
   */
  public void setCaption(String caption) {
  	this.caption.clear();
  	this.caption.add(caption);
  }
  
  /**
   * Set the citation property value for this ImageObject object; overwriting any existing values.
   *
   * @param citation The value to set.
   */
  public void setCitation(Thing citation) {
    creativeWork.setCitation(citation);
  }
  
  /**
   * Set the comment property value for this ImageObject object; overwriting any existing values.
   *
   * @param comment The value to set.
   */
  public void setComment(Thing comment) {
    creativeWork.setComment(comment);
  }
  
  /**
   * Set the commentCount property value for this ImageObject object; overwriting any existing values.
   *
   * @param commentCount The value to set.
   */
  public void setCommentCount(Long commentCount) {
    creativeWork.setCommentCount(commentCount);
  }
  
  /**
   * Set the contentLocation property value for this ImageObject object; overwriting any existing values.
   *
   * @param contentLocation The value to set.
   */
  public void setContentLocation(Place contentLocation) {
    creativeWork.setContentLocation(contentLocation);
  }
  
  /**
   * Set the contentRating property value for this ImageObject object; overwriting any existing values.
   *
   * @param contentRating The value to set.
   */
  public void setContentRating(String contentRating) {
    creativeWork.setContentRating(contentRating);
  }
  
  /**
   * Set the contentSize property value for this ImageObject object; overwriting any existing values.
   *
   * @param contentSize The value to set.
   */
  public void setContentSize(String contentSize) {
    mediaObject.setContentSize(contentSize);
  }
  
  /**
   * Set the contentUrl property value for this ImageObject object; overwriting any existing values.
   *
   * @param contentUrl The value to set.
   */
  public void setContentUrl(URL contentUrl) {
    mediaObject.setContentUrl(contentUrl);
  }
  
  /**
   * Set the contributor property value for this ImageObject object; overwriting any existing values.
   *
   * @param contributor The value to set.
   */
  public void setContributor(Thing contributor) {
    creativeWork.setContributor(contributor);
  }
  
  /**
   * Set the copyrightHolder property value for this ImageObject object; overwriting any existing values.
   *
   * @param copyrightHolder The value to set.
   */
  public void setCopyrightHolder(Thing copyrightHolder) {
    creativeWork.setCopyrightHolder(copyrightHolder);
  }
  
  /**
   * Set the copyrightYear property value for this ImageObject object; overwriting any existing values.
   *
   * @param copyrightYear The value to set.
   */
  public void setCopyrightYear(Number copyrightYear) {
    creativeWork.setCopyrightYear(copyrightYear);
  }
  
  /**
   * Set the creator property value for this ImageObject object; overwriting any existing values.
   *
   * @param creator The value to set.
   */
  public void setCreator(Thing creator) {
    creativeWork.setCreator(creator);
  }
  
  /**
   * Set the dateCreated property value for this ImageObject object; overwriting any existing values.
   *
   * @param dateCreated The value to set.
   */
  public void setDateCreated(Date dateCreated) {
    creativeWork.setDateCreated(dateCreated);
  }
  
  /**
   * Set the dateModified property value for this ImageObject object; overwriting any existing values.
   *
   * @param dateModified The value to set.
   */
  public void setDateModified(Date dateModified) {
    creativeWork.setDateModified(dateModified);
  }
  
  /**
   * Set the datePublished property value for this ImageObject object; overwriting any existing values.
   *
   * @param datePublished The value to set.
   */
  public void setDatePublished(Date datePublished) {
    creativeWork.setDatePublished(datePublished);
  }
  
  /**
   * Set the description property value for this ImageObject object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the discussionUrl property value for this ImageObject object; overwriting any existing values.
   *
   * @param discussionUrl The value to set.
   */
  public void setDiscussionUrl(URL discussionUrl) {
    creativeWork.setDiscussionUrl(discussionUrl);
  }
  
  /**
   * Set the duration property value for this ImageObject object; overwriting any existing values.
   *
   * @param duration The value to set.
   */
  public void setDuration(Duration duration) {
    mediaObject.setDuration(duration);
  }
  
  /**
   * Set the editor property value for this ImageObject object; overwriting any existing values.
   *
   * @param editor The value to set.
   */
  public void setEditor(Person editor) {
    creativeWork.setEditor(editor);
  }
  
  /**
   * Set the educationalAlignment property value for this ImageObject object; overwriting any existing values.
   *
   * @param educationalAlignment The value to set.
   */
  public void setEducationalAlignment(AlignmentObject educationalAlignment) {
    creativeWork.setEducationalAlignment(educationalAlignment);
  }
  
  /**
   * Set the educationalUse property value for this ImageObject object; overwriting any existing values.
   *
   * @param educationalUse The value to set.
   */
  public void setEducationalUse(String educationalUse) {
    creativeWork.setEducationalUse(educationalUse);
  }
  
  /**
   * Set the embedUrl property value for this ImageObject object; overwriting any existing values.
   *
   * @param embedUrl The value to set.
   */
  public void setEmbedUrl(URL embedUrl) {
    mediaObject.setEmbedUrl(embedUrl);
  }
  
  /**
   * Set the encodesCreativeWork property value for this ImageObject object; overwriting any existing values.
   *
   * @param encodesCreativeWork The value to set.
   */
  public void setEncodesCreativeWork(CreativeWork encodesCreativeWork) {
    mediaObject.setEncodesCreativeWork(encodesCreativeWork);
  }
  
  /**
   * Set the encoding property value for this ImageObject object; overwriting any existing values.
   *
   * @param encoding The value to set.
   */
  public void setEncoding(MediaObject encoding) {
    creativeWork.setEncoding(encoding);
  }
  
  /**
   * Set the encodingFormat property value for this ImageObject object; overwriting any existing values.
   *
   * @param encodingFormat The value to set.
   */
  public void setEncodingFormat(String encodingFormat) {
    mediaObject.setEncodingFormat(encodingFormat);
  }
  
  /**
   * Set the exifData property value for this ImageObject object; overwriting any existing values.
   *
   * @param exifData The value to set.
   */
  public void setExifData(String exifData) {
  	this.exifData.clear();
  	this.exifData.add(exifData);
  }
  
  /**
   * Set the expires property value for this ImageObject object; overwriting any existing values.
   *
   * @param expires The value to set.
   */
  public void setExpires(Date expires) {
    mediaObject.setExpires(expires);
  }
  
  /**
   * Set the genre property value for this ImageObject object; overwriting any existing values.
   *
   * @param genre The value to set.
   */
  public void setGenre(String genre) {
    creativeWork.setGenre(genre);
  }
  
  /**
   * Set the headline property value for this ImageObject object; overwriting any existing values.
   *
   * @param headline The value to set.
   */
  public void setHeadline(String headline) {
    creativeWork.setHeadline(headline);
  }
  
  /**
   * Set the height property value for this ImageObject object; overwriting any existing values.
   *
   * @param height The value to set.
   */
  public void setHeight(Thing height) {
    mediaObject.setHeight(height);
  }
  
  /**
   * Set the image property value for this ImageObject object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the inLanguage property value for this ImageObject object; overwriting any existing values.
   *
   * @param inLanguage The value to set.
   */
  public void setInLanguage(String inLanguage) {
    creativeWork.setInLanguage(inLanguage);
  }
  
  /**
   * Set the interactionCount property value for this ImageObject object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
    mediaObject.setInteractionCount(interactionCount);
  }
  
  /**
   * Set the interactivityType property value for this ImageObject object; overwriting any existing values.
   *
   * @param interactivityType The value to set.
   */
  public void setInteractivityType(String interactivityType) {
    creativeWork.setInteractivityType(interactivityType);
  }
  
  /**
   * Set the isBasedOnUrl property value for this ImageObject object; overwriting any existing values.
   *
   * @param isBasedOnUrl The value to set.
   */
  public void setIsBasedOnUrl(URL isBasedOnUrl) {
    creativeWork.setIsBasedOnUrl(isBasedOnUrl);
  }
  
  /**
   * Set the isFamilyFriendly property value for this ImageObject object; overwriting any existing values.
   *
   * @param isFamilyFriendly The value to set.
   */
  public void setIsFamilyFriendly(Boolean isFamilyFriendly) {
    creativeWork.setIsFamilyFriendly(isFamilyFriendly);
  }
  
  /**
   * Set the keywords property value for this ImageObject object; overwriting any existing values.
   *
   * @param keywords The value to set.
   */
  public void setKeywords(String keywords) {
    creativeWork.setKeywords(keywords);
  }
  
  /**
   * Set the learningResourceType property value for this ImageObject object; overwriting any existing values.
   *
   * @param learningResourceType The value to set.
   */
  public void setLearningResourceType(String learningResourceType) {
    creativeWork.setLearningResourceType(learningResourceType);
  }
  
  /**
   * Set the mentions property value for this ImageObject object; overwriting any existing values.
   *
   * @param mentions The value to set.
   */
  public void setMentions(Thing mentions) {
    creativeWork.setMentions(mentions);
  }
  
  /**
   * Set the name property value for this ImageObject object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offers property value for this ImageObject object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers) {
    mediaObject.setOffers(offers);
  }
  
  /**
   * Set the playerType property value for this ImageObject object; overwriting any existing values.
   *
   * @param playerType The value to set.
   */
  public void setPlayerType(String playerType) {
    mediaObject.setPlayerType(playerType);
  }
  
  /**
   * Set the productionCompany property value for this ImageObject object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany) {
    mediaObject.setProductionCompany(productionCompany);
  }
  
  /**
   * Set the provider property value for this ImageObject object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
    creativeWork.setProvider(provider);
  }
  
  /**
   * Set the publication property value for this ImageObject object; overwriting any existing values.
   *
   * @param publication The value to set.
   */
  public void setPublication(PublicationEvent publication) {
    mediaObject.setPublication(publication);
  }
  
  /**
   * Set the publisher property value for this ImageObject object; overwriting any existing values.
   *
   * @param publisher The value to set.
   */
  public void setPublisher(Organization publisher) {
    creativeWork.setPublisher(publisher);
  }
  
  /**
   * Set the publishingPrinciples property value for this ImageObject object; overwriting any existing values.
   *
   * @param publishingPrinciples The value to set.
   */
  public void setPublishingPrinciples(URL publishingPrinciples) {
    creativeWork.setPublishingPrinciples(publishingPrinciples);
  }
  
  /**
   * Set the regionsAllowed property value for this ImageObject object; overwriting any existing values.
   *
   * @param regionsAllowed The value to set.
   */
  public void setRegionsAllowed(Place regionsAllowed) {
    mediaObject.setRegionsAllowed(regionsAllowed);
  }
  
  /**
   * Set the representativeOfPage property value for this ImageObject object; overwriting any existing values.
   *
   * @param representativeOfPage The value to set.
   */
  public void setRepresentativeOfPage(Boolean representativeOfPage) {
  	this.representativeOfPage.clear();
  	this.representativeOfPage.add(representativeOfPage);
  }
  
  /**
   * Set the requiresSubscription property value for this ImageObject object; overwriting any existing values.
   *
   * @param requiresSubscription The value to set.
   */
  public void setRequiresSubscription(Boolean requiresSubscription) {
    mediaObject.setRequiresSubscription(requiresSubscription);
  }
  
  /**
   * Set the review property value for this ImageObject object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
    creativeWork.setReview(review);
  }
  
  /**
   * Set the sameAs property value for this ImageObject object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the sourceOrganization property value for this ImageObject object; overwriting any existing values.
   *
   * @param sourceOrganization The value to set.
   */
  public void setSourceOrganization(Organization sourceOrganization) {
    creativeWork.setSourceOrganization(sourceOrganization);
  }
  
  /**
   * Set the text property value for this ImageObject object; overwriting any existing values.
   *
   * @param text The value to set.
   */
  public void setText(String text) {
    creativeWork.setText(text);
  }
  
  /**
   * Set the thumbnail property value for this ImageObject object; overwriting any existing values.
   *
   * @param thumbnail The value to set.
   */
  public void setThumbnail(ImageObject thumbnail) {
  	this.thumbnail.clear();
  	this.thumbnail.add(thumbnail);
  }
  
  /**
   * Set the thumbnailUrl property value for this ImageObject object; overwriting any existing values.
   *
   * @param thumbnailUrl The value to set.
   */
  public void setThumbnailUrl(URL thumbnailUrl) {
    creativeWork.setThumbnailUrl(thumbnailUrl);
  }
  
  /**
   * Set the timeRequired property value for this ImageObject object; overwriting any existing values.
   *
   * @param timeRequired The value to set.
   */
  public void setTimeRequired(Duration timeRequired) {
    creativeWork.setTimeRequired(timeRequired);
  }
  
  /**
   * Set the typicalAgeRange property value for this ImageObject object; overwriting any existing values.
   *
   * @param typicalAgeRange The value to set.
   */
  public void setTypicalAgeRange(String typicalAgeRange) {
    creativeWork.setTypicalAgeRange(typicalAgeRange);
  }
  
  /**
   * Set the uploadDate property value for this ImageObject object; overwriting any existing values.
   *
   * @param uploadDate The value to set.
   */
  public void setUploadDate(Date uploadDate) {
    mediaObject.setUploadDate(uploadDate);
  }
  
  /**
   * Set the url property value for this ImageObject object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the version property value for this ImageObject object; overwriting any existing values.
   *
   * @param version The value to set.
   */
  public void setVersion(Number version) {
    creativeWork.setVersion(version);
  }
  
  /**
   * Set the video property value for this ImageObject object; overwriting any existing values.
   *
   * @param video The value to set.
   */
  public void setVideo(VideoObject video) {
    creativeWork.setVideo(video);
  }
  
  /**
   * Set the width property value for this ImageObject object; overwriting any existing values.
   *
   * @param width The value to set.
   */
  public void setWidth(Thing width) {
    mediaObject.setWidth(width);
  }
  
  /**
   * Set the about property values for this ImageObject object; overwriting any existing values.
   *
   * @param abouts The list of values to set.
   */
  public void setAbouts(List<Thing> abouts) {
    creativeWork.setAbouts(abouts);
  }
  
  /**
   * Set the accessibilityAPI property values for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityAPIs The list of values to set.
   */
  public void setAccessibilityAPIs(List<String> accessibilityAPIs) {
    creativeWork.setAccessibilityAPIs(accessibilityAPIs);
  }
  
  /**
   * Set the accessibilityControl property values for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityControls The list of values to set.
   */
  public void setAccessibilityControls(List<String> accessibilityControls) {
    creativeWork.setAccessibilityControls(accessibilityControls);
  }
  
  /**
   * Set the accessibilityFeature property values for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityFeatures The list of values to set.
   */
  public void setAccessibilityFeatures(List<String> accessibilityFeatures) {
    creativeWork.setAccessibilityFeatures(accessibilityFeatures);
  }
  
  /**
   * Set the accessibilityHazard property values for this ImageObject object; overwriting any existing values.
   *
   * @param accessibilityHazards The list of values to set.
   */
  public void setAccessibilityHazards(List<String> accessibilityHazards) {
    creativeWork.setAccessibilityHazards(accessibilityHazards);
  }
  
  /**
   * Set the accountablePerson property values for this ImageObject object; overwriting any existing values.
   *
   * @param accountablePersons The list of values to set.
   */
  public void setAccountablePersons(List<Person> accountablePersons) {
    creativeWork.setAccountablePersons(accountablePersons);
  }
  
  /**
   * Set the additionalType property values for this ImageObject object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the aggregateRating property values for this ImageObject object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
    creativeWork.setAggregateRatings(aggregateRatings);
  }
  
  /**
   * Set the alternateName property values for this ImageObject object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the alternativeHeadline property values for this ImageObject object; overwriting any existing values.
   *
   * @param alternativeHeadlines The list of values to set.
   */
  public void setAlternativeHeadlines(List<String> alternativeHeadlines) {
    creativeWork.setAlternativeHeadlines(alternativeHeadlines);
  }
  
  /**
   * Set the associatedArticle property values for this ImageObject object; overwriting any existing values.
   *
   * @param associatedArticles The list of values to set.
   */
  public void setAssociatedArticles(List<NewsArticle> associatedArticles) {
    mediaObject.setAssociatedArticles(associatedArticles);
  }
  
  /**
   * Set the associatedMedia property values for this ImageObject object; overwriting any existing values.
   *
   * @param associatedMedias The list of values to set.
   */
  public void setAssociatedMedias(List<MediaObject> associatedMedias) {
    creativeWork.setAssociatedMedias(associatedMedias);
  }
  
  /**
   * Set the audience property values for this ImageObject object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences) {
    creativeWork.setAudiences(audiences);
  }
  
  /**
   * Set the audio property values for this ImageObject object; overwriting any existing values.
   *
   * @param audios The list of values to set.
   */
  public void setAudios(List<AudioObject> audios) {
    creativeWork.setAudios(audios);
  }
  
  /**
   * Set the author property values for this ImageObject object; overwriting any existing values.
   *
   * @param authors The list of values to set.
   */
  public void setAuthors(List<Thing> authors) {
    creativeWork.setAuthors(authors);
  }
  
  /**
   * Set the award property values for this ImageObject object; overwriting any existing values.
   *
   * @param awards The list of values to set.
   */
  public void setAwards(List<String> awards) {
    creativeWork.setAwards(awards);
  }
  
  /**
   * Set the bitrate property values for this ImageObject object; overwriting any existing values.
   *
   * @param bitrates The list of values to set.
   */
  public void setBitrates(List<String> bitrates) {
    mediaObject.setBitrates(bitrates);
  }
  
  /**
   * Set the caption property values for this ImageObject object; overwriting any existing values.
   *
   * @param captions The list of values to set.
   */
  public void setCaptions(List<String> captions) {
  	this.caption = captions;
  }
  
  /**
   * Set the citation property values for this ImageObject object; overwriting any existing values.
   *
   * @param citations The list of values to set.
   */
  public void setCitations(List<Thing> citations) {
    creativeWork.setCitations(citations);
  }
  
  /**
   * Set the comment property values for this ImageObject object; overwriting any existing values.
   *
   * @param comments The list of values to set.
   */
  public void setComments(List<Thing> comments) {
    creativeWork.setComments(comments);
  }
  
  /**
   * Set the commentCount property values for this ImageObject object; overwriting any existing values.
   *
   * @param commentCounts The list of values to set.
   */
  public void setCommentCounts(List<Long> commentCounts) {
    creativeWork.setCommentCounts(commentCounts);
  }
  
  /**
   * Set the contentLocation property values for this ImageObject object; overwriting any existing values.
   *
   * @param contentLocations The list of values to set.
   */
  public void setContentLocations(List<Place> contentLocations) {
    creativeWork.setContentLocations(contentLocations);
  }
  
  /**
   * Set the contentRating property values for this ImageObject object; overwriting any existing values.
   *
   * @param contentRatings The list of values to set.
   */
  public void setContentRatings(List<String> contentRatings) {
    creativeWork.setContentRatings(contentRatings);
  }
  
  /**
   * Set the contentSize property values for this ImageObject object; overwriting any existing values.
   *
   * @param contentSizes The list of values to set.
   */
  public void setContentSizes(List<String> contentSizes) {
    mediaObject.setContentSizes(contentSizes);
  }
  
  /**
   * Set the contentUrl property values for this ImageObject object; overwriting any existing values.
   *
   * @param contentUrls The list of values to set.
   */
  public void setContentUrls(List<URL> contentUrls) {
    mediaObject.setContentUrls(contentUrls);
  }
  
  /**
   * Set the contributor property values for this ImageObject object; overwriting any existing values.
   *
   * @param contributors The list of values to set.
   */
  public void setContributors(List<Thing> contributors) {
    creativeWork.setContributors(contributors);
  }
  
  /**
   * Set the copyrightHolder property values for this ImageObject object; overwriting any existing values.
   *
   * @param copyrightHolders The list of values to set.
   */
  public void setCopyrightHolders(List<Thing> copyrightHolders) {
    creativeWork.setCopyrightHolders(copyrightHolders);
  }
  
  /**
   * Set the copyrightYear property values for this ImageObject object; overwriting any existing values.
   *
   * @param copyrightYears The list of values to set.
   */
  public void setCopyrightYears(List<Number> copyrightYears) {
    creativeWork.setCopyrightYears(copyrightYears);
  }
  
  /**
   * Set the creator property values for this ImageObject object; overwriting any existing values.
   *
   * @param creators The list of values to set.
   */
  public void setCreators(List<Thing> creators) {
    creativeWork.setCreators(creators);
  }
  
  /**
   * Set the dateCreated property values for this ImageObject object; overwriting any existing values.
   *
   * @param dateCreateds The list of values to set.
   */
  public void setDateCreateds(List<Date> dateCreateds) {
    creativeWork.setDateCreateds(dateCreateds);
  }
  
  /**
   * Set the dateModified property values for this ImageObject object; overwriting any existing values.
   *
   * @param dateModifieds The list of values to set.
   */
  public void setDateModifieds(List<Date> dateModifieds) {
    creativeWork.setDateModifieds(dateModifieds);
  }
  
  /**
   * Set the datePublished property values for this ImageObject object; overwriting any existing values.
   *
   * @param datePublisheds The list of values to set.
   */
  public void setDatePublisheds(List<Date> datePublisheds) {
    creativeWork.setDatePublisheds(datePublisheds);
  }
  
  /**
   * Set the description property values for this ImageObject object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the discussionUrl property values for this ImageObject object; overwriting any existing values.
   *
   * @param discussionUrls The list of values to set.
   */
  public void setDiscussionUrls(List<URL> discussionUrls) {
    creativeWork.setDiscussionUrls(discussionUrls);
  }
  
  /**
   * Set the duration property values for this ImageObject object; overwriting any existing values.
   *
   * @param durations The list of values to set.
   */
  public void setDurations(List<Duration> durations) {
    mediaObject.setDurations(durations);
  }
  
  /**
   * Set the editor property values for this ImageObject object; overwriting any existing values.
   *
   * @param editors The list of values to set.
   */
  public void setEditors(List<Person> editors) {
    creativeWork.setEditors(editors);
  }
  
  /**
   * Set the educationalAlignment property values for this ImageObject object; overwriting any existing values.
   *
   * @param educationalAlignments The list of values to set.
   */
  public void setEducationalAlignments(List<AlignmentObject> educationalAlignments) {
    creativeWork.setEducationalAlignments(educationalAlignments);
  }
  
  /**
   * Set the educationalUse property values for this ImageObject object; overwriting any existing values.
   *
   * @param educationalUses The list of values to set.
   */
  public void setEducationalUses(List<String> educationalUses) {
    creativeWork.setEducationalUses(educationalUses);
  }
  
  /**
   * Set the embedUrl property values for this ImageObject object; overwriting any existing values.
   *
   * @param embedUrls The list of values to set.
   */
  public void setEmbedUrls(List<URL> embedUrls) {
    mediaObject.setEmbedUrls(embedUrls);
  }
  
  /**
   * Set the encodesCreativeWork property values for this ImageObject object; overwriting any existing values.
   *
   * @param encodesCreativeWorks The list of values to set.
   */
  public void setEncodesCreativeWorks(List<CreativeWork> encodesCreativeWorks) {
    mediaObject.setEncodesCreativeWorks(encodesCreativeWorks);
  }
  
  /**
   * Set the encoding property values for this ImageObject object; overwriting any existing values.
   *
   * @param encodings The list of values to set.
   */
  public void setEncodings(List<MediaObject> encodings) {
    creativeWork.setEncodings(encodings);
  }
  
  /**
   * Set the encodingFormat property values for this ImageObject object; overwriting any existing values.
   *
   * @param encodingFormats The list of values to set.
   */
  public void setEncodingFormats(List<String> encodingFormats) {
    mediaObject.setEncodingFormats(encodingFormats);
  }
  
  /**
   * Set the exifData property values for this ImageObject object; overwriting any existing values.
   *
   * @param exifDatas The list of values to set.
   */
  public void setExifDatas(List<String> exifDatas) {
  	this.exifData = exifDatas;
  }
  
  /**
   * Set the expires property values for this ImageObject object; overwriting any existing values.
   *
   * @param expiress The list of values to set.
   */
  public void setExpiress(List<Date> expiress) {
    mediaObject.setExpiress(expiress);
  }
  
  /**
   * Set the genre property values for this ImageObject object; overwriting any existing values.
   *
   * @param genres The list of values to set.
   */
  public void setGenres(List<String> genres) {
    creativeWork.setGenres(genres);
  }
  
  /**
   * Set the headline property values for this ImageObject object; overwriting any existing values.
   *
   * @param headlines The list of values to set.
   */
  public void setHeadlines(List<String> headlines) {
    creativeWork.setHeadlines(headlines);
  }
  
  /**
   * Set the height property values for this ImageObject object; overwriting any existing values.
   *
   * @param heights The list of values to set.
   */
  public void setHeights(List<Thing> heights) {
    mediaObject.setHeights(heights);
  }
  
  /**
   * Set the image property values for this ImageObject object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the inLanguage property values for this ImageObject object; overwriting any existing values.
   *
   * @param inLanguages The list of values to set.
   */
  public void setInLanguages(List<String> inLanguages) {
    creativeWork.setInLanguages(inLanguages);
  }
  
  /**
   * Set the interactionCount property values for this ImageObject object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
    mediaObject.setInteractionCounts(interactionCounts);
  }
  
  /**
   * Set the interactivityType property values for this ImageObject object; overwriting any existing values.
   *
   * @param interactivityTypes The list of values to set.
   */
  public void setInteractivityTypes(List<String> interactivityTypes) {
    creativeWork.setInteractivityTypes(interactivityTypes);
  }
  
  /**
   * Set the isBasedOnUrl property values for this ImageObject object; overwriting any existing values.
   *
   * @param isBasedOnUrls The list of values to set.
   */
  public void setIsBasedOnUrls(List<URL> isBasedOnUrls) {
    creativeWork.setIsBasedOnUrls(isBasedOnUrls);
  }
  
  /**
   * Set the isFamilyFriendly property values for this ImageObject object; overwriting any existing values.
   *
   * @param isFamilyFriendlies The list of values to set.
   */
  public void setIsFamilyFriendlies(List<Boolean> isFamilyFriendlies) {
    creativeWork.setIsFamilyFriendlies(isFamilyFriendlies);
  }
  
  /**
   * Set the keywords property values for this ImageObject object; overwriting any existing values.
   *
   * @param keywordss The list of values to set.
   */
  public void setKeywordss(List<String> keywordss) {
    creativeWork.setKeywordss(keywordss);
  }
  
  /**
   * Set the learningResourceType property values for this ImageObject object; overwriting any existing values.
   *
   * @param learningResourceTypes The list of values to set.
   */
  public void setLearningResourceTypes(List<String> learningResourceTypes) {
    creativeWork.setLearningResourceTypes(learningResourceTypes);
  }
  
  /**
   * Set the mentions property values for this ImageObject object; overwriting any existing values.
   *
   * @param mentionss The list of values to set.
   */
  public void setMentionss(List<Thing> mentionss) {
    creativeWork.setMentionss(mentionss);
  }
  
  /**
   * Set the name property values for this ImageObject object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offers property values for this ImageObject object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss) {
    mediaObject.setOfferss(offerss);
  }
  
  /**
   * Set the playerType property values for this ImageObject object; overwriting any existing values.
   *
   * @param playerTypes The list of values to set.
   */
  public void setPlayerTypes(List<String> playerTypes) {
    mediaObject.setPlayerTypes(playerTypes);
  }
  
  /**
   * Set the productionCompany property values for this ImageObject object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies) {
    mediaObject.setProductionCompanies(productionCompanies);
  }
  
  /**
   * Set the provider property values for this ImageObject object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
    creativeWork.setProviders(providers);
  }
  
  /**
   * Set the publication property values for this ImageObject object; overwriting any existing values.
   *
   * @param publications The list of values to set.
   */
  public void setPublications(List<PublicationEvent> publications) {
    mediaObject.setPublications(publications);
  }
  
  /**
   * Set the publisher property values for this ImageObject object; overwriting any existing values.
   *
   * @param publishers The list of values to set.
   */
  public void setPublishers(List<Organization> publishers) {
    creativeWork.setPublishers(publishers);
  }
  
  /**
   * Set the publishingPrinciples property values for this ImageObject object; overwriting any existing values.
   *
   * @param publishingPrincipless The list of values to set.
   */
  public void setPublishingPrincipless(List<URL> publishingPrincipless) {
    creativeWork.setPublishingPrincipless(publishingPrincipless);
  }
  
  /**
   * Set the regionsAllowed property values for this ImageObject object; overwriting any existing values.
   *
   * @param regionsAlloweds The list of values to set.
   */
  public void setRegionsAlloweds(List<Place> regionsAlloweds) {
    mediaObject.setRegionsAlloweds(regionsAlloweds);
  }
  
  /**
   * Set the representativeOfPage property values for this ImageObject object; overwriting any existing values.
   *
   * @param representativeOfPages The list of values to set.
   */
  public void setRepresentativeOfPages(List<Boolean> representativeOfPages) {
  	this.representativeOfPage = representativeOfPages;
  }
  
  /**
   * Set the requiresSubscription property values for this ImageObject object; overwriting any existing values.
   *
   * @param requiresSubscriptions The list of values to set.
   */
  public void setRequiresSubscriptions(List<Boolean> requiresSubscriptions) {
    mediaObject.setRequiresSubscriptions(requiresSubscriptions);
  }
  
  /**
   * Set the review property values for this ImageObject object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
    creativeWork.setReviews(reviews);
  }
  
  /**
   * Set the sameAs property values for this ImageObject object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the sourceOrganization property values for this ImageObject object; overwriting any existing values.
   *
   * @param sourceOrganizations The list of values to set.
   */
  public void setSourceOrganizations(List<Organization> sourceOrganizations) {
    creativeWork.setSourceOrganizations(sourceOrganizations);
  }
  
  /**
   * Set the text property values for this ImageObject object; overwriting any existing values.
   *
   * @param texts The list of values to set.
   */
  public void setTexts(List<String> texts) {
    creativeWork.setTexts(texts);
  }
  
  /**
   * Set the thumbnail property values for this ImageObject object; overwriting any existing values.
   *
   * @param thumbnails The list of values to set.
   */
  public void setThumbnails(List<ImageObject> thumbnails) {
  	this.thumbnail = thumbnails;
  }
  
  /**
   * Set the thumbnailUrl property values for this ImageObject object; overwriting any existing values.
   *
   * @param thumbnailUrls The list of values to set.
   */
  public void setThumbnailUrls(List<URL> thumbnailUrls) {
    creativeWork.setThumbnailUrls(thumbnailUrls);
  }
  
  /**
   * Set the timeRequired property values for this ImageObject object; overwriting any existing values.
   *
   * @param timeRequireds The list of values to set.
   */
  public void setTimeRequireds(List<Duration> timeRequireds) {
    creativeWork.setTimeRequireds(timeRequireds);
  }
  
  /**
   * Set the typicalAgeRange property values for this ImageObject object; overwriting any existing values.
   *
   * @param typicalAgeRanges The list of values to set.
   */
  public void setTypicalAgeRanges(List<String> typicalAgeRanges) {
    creativeWork.setTypicalAgeRanges(typicalAgeRanges);
  }
  
  /**
   * Set the uploadDate property values for this ImageObject object; overwriting any existing values.
   *
   * @param uploadDates The list of values to set.
   */
  public void setUploadDates(List<Date> uploadDates) {
    mediaObject.setUploadDates(uploadDates);
  }
  
  /**
   * Set the url property values for this ImageObject object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the version property values for this ImageObject object; overwriting any existing values.
   *
   * @param versions The list of values to set.
   */
  public void setVersions(List<Number> versions) {
    creativeWork.setVersions(versions);
  }
  
  /**
   * Set the video property values for this ImageObject object; overwriting any existing values.
   *
   * @param videos The list of values to set.
   */
  public void setVideos(List<VideoObject> videos) {
    creativeWork.setVideos(videos);
  }
  
  /**
   * Set the width property values for this ImageObject object; overwriting any existing values.
   *
   * @param widths The list of values to set.
   */
  public void setWidths(List<Thing> widths) {
    mediaObject.setWidths(widths);
  }
  
  /**
   * Adds a about property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param about The value to add.
   */
  public void addAbout(Thing about) {
    creativeWork.addAbout(about);
  }
  
  /**
   * Adds a accessibilityAPI property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param accessibilityAPI The value to add.
   */
  public void addAccessibilityAPI(String accessibilityAPI) {
    creativeWork.addAccessibilityAPI(accessibilityAPI);
  }
  
  /**
   * Adds a accessibilityControl property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param accessibilityControl The value to add.
   */
  public void addAccessibilityControl(String accessibilityControl) {
    creativeWork.addAccessibilityControl(accessibilityControl);
  }
  
  /**
   * Adds a accessibilityFeature property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param accessibilityFeature The value to add.
   */
  public void addAccessibilityFeature(String accessibilityFeature) {
    creativeWork.addAccessibilityFeature(accessibilityFeature);
  }
  
  /**
   * Adds a accessibilityHazard property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param accessibilityHazard The value to add.
   */
  public void addAccessibilityHazard(String accessibilityHazard) {
    creativeWork.addAccessibilityHazard(accessibilityHazard);
  }
  
  /**
   * Adds a accountablePerson property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param accountablePerson The value to add.
   */
  public void addAccountablePerson(Person accountablePerson) {
    creativeWork.addAccountablePerson(accountablePerson);
  }
  
  /**
   * Adds a additionalType property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a aggregateRating property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
    creativeWork.addAggregateRating(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a alternativeHeadline property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param alternativeHeadline The value to add.
   */
  public void addAlternativeHeadline(String alternativeHeadline) {
    creativeWork.addAlternativeHeadline(alternativeHeadline);
  }
  
  /**
   * Adds a associatedArticle property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param associatedArticle The value to add.
   */
  public void addAssociatedArticle(NewsArticle associatedArticle) {
    mediaObject.addAssociatedArticle(associatedArticle);
  }
  
  /**
   * Adds a associatedMedia property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param associatedMedia The value to add.
   */
  public void addAssociatedMedia(MediaObject associatedMedia) {
    creativeWork.addAssociatedMedia(associatedMedia);
  }
  
  /**
   * Adds a audience property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience) {
    creativeWork.addAudience(audience);
  }
  
  /**
   * Adds a audio property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param audio The value to add.
   */
  public void addAudio(AudioObject audio) {
    creativeWork.addAudio(audio);
  }
  
  /**
   * Adds a author property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param author The value to add.
   */
  public void addAuthor(Thing author) {
    creativeWork.addAuthor(author);
  }
  
  /**
   * Adds a award property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param award The value to add.
   */
  public void addAward(String award) {
    creativeWork.addAward(award);
  }
  
  /**
   * Adds a bitrate property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param bitrate The value to add.
   */
  public void addBitrate(String bitrate) {
    mediaObject.addBitrate(bitrate);
  }
  
  /**
   * Adds a caption property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param caption The value to add.
   */
  public void addCaption(String caption) {
  	this.caption.add(caption);
  }
  
  /**
   * Adds a citation property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param citation The value to add.
   */
  public void addCitation(Thing citation) {
    creativeWork.addCitation(citation);
  }
  
  /**
   * Adds a comment property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param comment The value to add.
   */
  public void addComment(Thing comment) {
    creativeWork.addComment(comment);
  }
  
  /**
   * Adds a commentCount property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param commentCount The value to add.
   */
  public void addCommentCount(Long commentCount) {
    creativeWork.addCommentCount(commentCount);
  }
  
  /**
   * Adds a contentLocation property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param contentLocation The value to add.
   */
  public void addContentLocation(Place contentLocation) {
    creativeWork.addContentLocation(contentLocation);
  }
  
  /**
   * Adds a contentRating property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param contentRating The value to add.
   */
  public void addContentRating(String contentRating) {
    creativeWork.addContentRating(contentRating);
  }
  
  /**
   * Adds a contentSize property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param contentSize The value to add.
   */
  public void addContentSize(String contentSize) {
    mediaObject.addContentSize(contentSize);
  }
  
  /**
   * Adds a contentUrl property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param contentUrl The value to add.
   */
  public void addContentUrl(URL contentUrl) {
    mediaObject.addContentUrl(contentUrl);
  }
  
  /**
   * Adds a contributor property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param contributor The value to add.
   */
  public void addContributor(Thing contributor) {
    creativeWork.addContributor(contributor);
  }
  
  /**
   * Adds a copyrightHolder property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param copyrightHolder The value to add.
   */
  public void addCopyrightHolder(Thing copyrightHolder) {
    creativeWork.addCopyrightHolder(copyrightHolder);
  }
  
  /**
   * Adds a copyrightYear property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param copyrightYear The value to add.
   */
  public void addCopyrightYear(Number copyrightYear) {
    creativeWork.addCopyrightYear(copyrightYear);
  }
  
  /**
   * Adds a creator property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param creator The value to add.
   */
  public void addCreator(Thing creator) {
    creativeWork.addCreator(creator);
  }
  
  /**
   * Adds a dateCreated property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param dateCreated The value to add.
   */
  public void addDateCreated(Date dateCreated) {
    creativeWork.addDateCreated(dateCreated);
  }
  
  /**
   * Adds a dateModified property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param dateModified The value to add.
   */
  public void addDateModified(Date dateModified) {
    creativeWork.addDateModified(dateModified);
  }
  
  /**
   * Adds a datePublished property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param datePublished The value to add.
   */
  public void addDatePublished(Date datePublished) {
    creativeWork.addDatePublished(datePublished);
  }
  
  /**
   * Adds a description property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a discussionUrl property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param discussionUrl The value to add.
   */
  public void addDiscussionUrl(URL discussionUrl) {
    creativeWork.addDiscussionUrl(discussionUrl);
  }
  
  /**
   * Adds a duration property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param duration The value to add.
   */
  public void addDuration(Duration duration) {
    mediaObject.addDuration(duration);
  }
  
  /**
   * Adds a editor property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param editor The value to add.
   */
  public void addEditor(Person editor) {
    creativeWork.addEditor(editor);
  }
  
  /**
   * Adds a educationalAlignment property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param educationalAlignment The value to add.
   */
  public void addEducationalAlignment(AlignmentObject educationalAlignment) {
    creativeWork.addEducationalAlignment(educationalAlignment);
  }
  
  /**
   * Adds a educationalUse property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param educationalUse The value to add.
   */
  public void addEducationalUse(String educationalUse) {
    creativeWork.addEducationalUse(educationalUse);
  }
  
  /**
   * Adds a embedUrl property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param embedUrl The value to add.
   */
  public void addEmbedUrl(URL embedUrl) {
    mediaObject.addEmbedUrl(embedUrl);
  }
  
  /**
   * Adds a encodesCreativeWork property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param encodesCreativeWork The value to add.
   */
  public void addEncodesCreativeWork(CreativeWork encodesCreativeWork) {
    mediaObject.addEncodesCreativeWork(encodesCreativeWork);
  }
  
  /**
   * Adds a encoding property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param encoding The value to add.
   */
  public void addEncoding(MediaObject encoding) {
    creativeWork.addEncoding(encoding);
  }
  
  /**
   * Adds a encodingFormat property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param encodingFormat The value to add.
   */
  public void addEncodingFormat(String encodingFormat) {
    mediaObject.addEncodingFormat(encodingFormat);
  }
  
  /**
   * Adds a exifData property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param exifData The value to add.
   */
  public void addExifData(String exifData) {
  	this.exifData.add(exifData);
  }
  
  /**
   * Adds a expires property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param expires The value to add.
   */
  public void addExpires(Date expires) {
    mediaObject.addExpires(expires);
  }
  
  /**
   * Adds a genre property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param genre The value to add.
   */
  public void addGenre(String genre) {
    creativeWork.addGenre(genre);
  }
  
  /**
   * Adds a headline property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param headline The value to add.
   */
  public void addHeadline(String headline) {
    creativeWork.addHeadline(headline);
  }
  
  /**
   * Adds a height property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param height The value to add.
   */
  public void addHeight(Thing height) {
    mediaObject.addHeight(height);
  }
  
  /**
   * Adds a image property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a inLanguage property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param inLanguage The value to add.
   */
  public void addInLanguage(String inLanguage) {
    creativeWork.addInLanguage(inLanguage);
  }
  
  /**
   * Adds a interactionCount property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
    mediaObject.addInteractionCount(interactionCount);
  }
  
  /**
   * Adds a interactivityType property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param interactivityType The value to add.
   */
  public void addInteractivityType(String interactivityType) {
    creativeWork.addInteractivityType(interactivityType);
  }
  
  /**
   * Adds a isBasedOnUrl property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param isBasedOnUrl The value to add.
   */
  public void addIsBasedOnUrl(URL isBasedOnUrl) {
    creativeWork.addIsBasedOnUrl(isBasedOnUrl);
  }
  
  /**
   * Adds a isFamilyFriendly property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param isFamilyFriendly The value to add.
   */
  public void addIsFamilyFriendly(Boolean isFamilyFriendly) {
    creativeWork.addIsFamilyFriendly(isFamilyFriendly);
  }
  
  /**
   * Adds a keywords property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param keywords The value to add.
   */
  public void addKeywords(String keywords) {
    creativeWork.addKeywords(keywords);
  }
  
  /**
   * Adds a learningResourceType property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param learningResourceType The value to add.
   */
  public void addLearningResourceType(String learningResourceType) {
    creativeWork.addLearningResourceType(learningResourceType);
  }
  
  /**
   * Adds a mentions property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param mentions The value to add.
   */
  public void addMentions(Thing mentions) {
    creativeWork.addMentions(mentions);
  }
  
  /**
   * Adds a name property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offers property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers) {
    mediaObject.addOffers(offers);
  }
  
  /**
   * Adds a playerType property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param playerType The value to add.
   */
  public void addPlayerType(String playerType) {
    mediaObject.addPlayerType(playerType);
  }
  
  /**
   * Adds a productionCompany property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany) {
    mediaObject.addProductionCompany(productionCompany);
  }
  
  /**
   * Adds a provider property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
    creativeWork.addProvider(provider);
  }
  
  /**
   * Adds a publication property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param publication The value to add.
   */
  public void addPublication(PublicationEvent publication) {
    mediaObject.addPublication(publication);
  }
  
  /**
   * Adds a publisher property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param publisher The value to add.
   */
  public void addPublisher(Organization publisher) {
    creativeWork.addPublisher(publisher);
  }
  
  /**
   * Adds a publishingPrinciples property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param publishingPrinciples The value to add.
   */
  public void addPublishingPrinciples(URL publishingPrinciples) {
    creativeWork.addPublishingPrinciples(publishingPrinciples);
  }
  
  /**
   * Adds a regionsAllowed property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param regionsAllowed The value to add.
   */
  public void addRegionsAllowed(Place regionsAllowed) {
    mediaObject.addRegionsAllowed(regionsAllowed);
  }
  
  /**
   * Adds a representativeOfPage property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param representativeOfPage The value to add.
   */
  public void addRepresentativeOfPage(Boolean representativeOfPage) {
  	this.representativeOfPage.add(representativeOfPage);
  }
  
  /**
   * Adds a requiresSubscription property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param requiresSubscription The value to add.
   */
  public void addRequiresSubscription(Boolean requiresSubscription) {
    mediaObject.addRequiresSubscription(requiresSubscription);
  }
  
  /**
   * Adds a review property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
    creativeWork.addReview(review);
  }
  
  /**
   * Adds a sameAs property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a sourceOrganization property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param sourceOrganization The value to add.
   */
  public void addSourceOrganization(Organization sourceOrganization) {
    creativeWork.addSourceOrganization(sourceOrganization);
  }
  
  /**
   * Adds a text property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param text The value to add.
   */
  public void addText(String text) {
    creativeWork.addText(text);
  }
  
  /**
   * Adds a thumbnail property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param thumbnail The value to add.
   */
  public void addThumbnail(ImageObject thumbnail) {
  	this.thumbnail.add(thumbnail);
  }
  
  /**
   * Adds a thumbnailUrl property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param thumbnailUrl The value to add.
   */
  public void addThumbnailUrl(URL thumbnailUrl) {
    creativeWork.addThumbnailUrl(thumbnailUrl);
  }
  
  /**
   * Adds a timeRequired property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param timeRequired The value to add.
   */
  public void addTimeRequired(Duration timeRequired) {
    creativeWork.addTimeRequired(timeRequired);
  }
  
  /**
   * Adds a typicalAgeRange property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param typicalAgeRange The value to add.
   */
  public void addTypicalAgeRange(String typicalAgeRange) {
    creativeWork.addTypicalAgeRange(typicalAgeRange);
  }
  
  /**
   * Adds a uploadDate property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param uploadDate The value to add.
   */
  public void addUploadDate(Date uploadDate) {
    mediaObject.addUploadDate(uploadDate);
  }
  
  /**
   * Adds a url property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a version property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param version The value to add.
   */
  public void addVersion(Number version) {
    creativeWork.addVersion(version);
  }
  
  /**
   * Adds a video property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param video The value to add.
   */
  public void addVideo(VideoObject video) {
    creativeWork.addVideo(video);
  }
  
  /**
   * Adds a width property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param width The value to add.
   */
  public void addWidth(Thing width) {
    mediaObject.addWidth(width);
  }
  
}