package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.DDxElement;
import org.schema.InfectiousAgentClass;
import org.schema.InfectiousDisease;
import org.schema.MedicalCause;
import org.schema.MedicalCode;
import org.schema.MedicalConditionStage;
import org.schema.MedicalGuideline;
import org.schema.MedicalRiskFactor;
import org.schema.MedicalSignOrSymptom;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTest;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease.
 */
public class InfectiousDiseaseImpl extends SchemaObjectImpl implements InfectiousDisease {


  private MedicalConditionImpl medicalCondition;
  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * The actual infectious agent, such as a specific bacterium.
   */
  private List<String> infectiousAgent = new LinkedList<String>();
  
  /**
   * The class of infectious agent (bacteria, prion, etc.) that causes the disease.
   */
  private List<InfectiousAgentClass> infectiousAgentClass = new LinkedList<InfectiousAgentClass>();
  
  /**
   * How the disease spreads, either as a route or vector, for example 'direct contact', 'Aedes aegypti', etc.
   */
  private List<String> transmissionMethod = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public InfectiousDiseaseImpl() {
    super("http://schema.org/InfectiousDisease");
    medicalCondition = new MedicalConditionImpl();
  }
  /**
   * Get a single additionalType property value for this InfectiousDisease object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this InfectiousDisease object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single associatedAnatomy property value for this InfectiousDisease object.
   *
   * @return The first associatedAnatomy property value.
   */
  public Thing getAssociatedAnatomy() {
    return medicalCondition.getAssociatedAnatomy();
  }
  
  /**
   * Get a single cause property value for this InfectiousDisease object.
   *
   * @return The first cause property value.
   */
  public MedicalCause getCause() {
    return medicalCondition.getCause();
  }
  
  /**
   * Get a single code property value for this InfectiousDisease object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this InfectiousDisease object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single differentialDiagnosis property value for this InfectiousDisease object.
   *
   * @return The first differentialDiagnosis property value.
   */
  public DDxElement getDifferentialDiagnosis() {
    return medicalCondition.getDifferentialDiagnosis();
  }
  
  /**
   * Get a single epidemiology property value for this InfectiousDisease object.
   *
   * @return The first epidemiology property value.
   */
  public String getEpidemiology() {
    return medicalCondition.getEpidemiology();
  }
  
  /**
   * Get a single expectedPrognosis property value for this InfectiousDisease object.
   *
   * @return The first expectedPrognosis property value.
   */
  public String getExpectedPrognosis() {
    return medicalCondition.getExpectedPrognosis();
  }
  
  /**
   * Get a single guideline property value for this InfectiousDisease object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this InfectiousDisease object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single infectiousAgent property value for this InfectiousDisease object.
   *
   * @return The first infectiousAgent property value.
   */
  public String getInfectiousAgent() {
  	return this.infectiousAgent.isEmpty() ? null : this.infectiousAgent.get(0);
  }
  
  /**
   * Get a single infectiousAgentClass property value for this InfectiousDisease object.
   *
   * @return The first infectiousAgentClass property value.
   */
  public InfectiousAgentClass getInfectiousAgentClass() {
  	return this.infectiousAgentClass.isEmpty() ? null : this.infectiousAgentClass.get(0);
  }
  
  /**
   * Get a single medicineSystem property value for this InfectiousDisease object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this InfectiousDisease object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single naturalProgression property value for this InfectiousDisease object.
   *
   * @return The first naturalProgression property value.
   */
  public String getNaturalProgression() {
    return medicalCondition.getNaturalProgression();
  }
  
  /**
   * Get a single pathophysiology property value for this InfectiousDisease object.
   *
   * @return The first pathophysiology property value.
   */
  public String getPathophysiology() {
    return medicalCondition.getPathophysiology();
  }
  
  /**
   * Get a single possibleComplication property value for this InfectiousDisease object.
   *
   * @return The first possibleComplication property value.
   */
  public String getPossibleComplication() {
    return medicalCondition.getPossibleComplication();
  }
  
  /**
   * Get a single possibleTreatment property value for this InfectiousDisease object.
   *
   * @return The first possibleTreatment property value.
   */
  public MedicalTherapy getPossibleTreatment() {
    return medicalCondition.getPossibleTreatment();
  }
  
  /**
   * Get a single primaryPrevention property value for this InfectiousDisease object.
   *
   * @return The first primaryPrevention property value.
   */
  public MedicalTherapy getPrimaryPrevention() {
    return medicalCondition.getPrimaryPrevention();
  }
  
  /**
   * Get a single recognizingAuthority property value for this InfectiousDisease object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this InfectiousDisease object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single riskFactor property value for this InfectiousDisease object.
   *
   * @return The first riskFactor property value.
   */
  public MedicalRiskFactor getRiskFactor() {
    return medicalCondition.getRiskFactor();
  }
  
  /**
   * Get a single sameAs property value for this InfectiousDisease object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single secondaryPrevention property value for this InfectiousDisease object.
   *
   * @return The first secondaryPrevention property value.
   */
  public MedicalTherapy getSecondaryPrevention() {
    return medicalCondition.getSecondaryPrevention();
  }
  
  /**
   * Get a single signOrSymptom property value for this InfectiousDisease object.
   *
   * @return The first signOrSymptom property value.
   */
  public MedicalSignOrSymptom getSignOrSymptom() {
    return medicalCondition.getSignOrSymptom();
  }
  
  /**
   * Get a single stage property value for this InfectiousDisease object.
   *
   * @return The first stage property value.
   */
  public MedicalConditionStage getStage() {
    return medicalCondition.getStage();
  }
  
  /**
   * Get a single study property value for this InfectiousDisease object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single subtype property value for this InfectiousDisease object.
   *
   * @return The first subtype property value.
   */
  public String getSubtype() {
    return medicalCondition.getSubtype();
  }
  
  /**
   * Get a single transmissionMethod property value for this InfectiousDisease object.
   *
   * @return The first transmissionMethod property value.
   */
  public String getTransmissionMethod() {
  	return this.transmissionMethod.isEmpty() ? null : this.transmissionMethod.get(0);
  }
  
  /**
   * Get a single typicalTest property value for this InfectiousDisease object.
   *
   * @return The first typicalTest property value.
   */
  public MedicalTest getTypicalTest() {
    return medicalCondition.getTypicalTest();
  }
  
  /**
   * Get a single url property value for this InfectiousDisease object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this InfectiousDisease object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this InfectiousDisease object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the associatedAnatomy property values for this InfectiousDisease object.
   *
   * @return A list of associatedAnatomy property values.
   */
  public List<Thing> getAssociatedAnatomies() {
    return medicalCondition.getAssociatedAnatomies();
  }
  
  /**
   * Get all the cause property values for this InfectiousDisease object.
   *
   * @return A list of cause property values.
   */
  public List<MedicalCause> getCauses() {
    return medicalCondition.getCauses();
  }
  
  /**
   * Get all the code property values for this InfectiousDisease object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this InfectiousDisease object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the differentialDiagnosis property values for this InfectiousDisease object.
   *
   * @return A list of differentialDiagnosis property values.
   */
  public List<DDxElement> getDifferentialDiagnoses() {
    return medicalCondition.getDifferentialDiagnoses();
  }
  
  /**
   * Get all the epidemiology property values for this InfectiousDisease object.
   *
   * @return A list of epidemiology property values.
   */
  public List<String> getEpidemiologies() {
    return medicalCondition.getEpidemiologies();
  }
  
  /**
   * Get all the expectedPrognosis property values for this InfectiousDisease object.
   *
   * @return A list of expectedPrognosis property values.
   */
  public List<String> getExpectedPrognoses() {
    return medicalCondition.getExpectedPrognoses();
  }
  
  /**
   * Get all the guideline property values for this InfectiousDisease object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this InfectiousDisease object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the infectiousAgent property values for this InfectiousDisease object.
   *
   * @return A list of infectiousAgent property values.
   */
  public List<String> getInfectiousAgents() {
  	return this.infectiousAgent;
  }
  
  /**
   * Get all the infectiousAgentClass property values for this InfectiousDisease object.
   *
   * @return A list of infectiousAgentClass property values.
   */
  public List<InfectiousAgentClass> getInfectiousAgentClasses() {
  	return this.infectiousAgentClass;
  }
  
  /**
   * Get all the medicineSystem property values for this InfectiousDisease object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this InfectiousDisease object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the naturalProgression property values for this InfectiousDisease object.
   *
   * @return A list of naturalProgression property values.
   */
  public List<String> getNaturalProgressions() {
    return medicalCondition.getNaturalProgressions();
  }
  
  /**
   * Get all the pathophysiology property values for this InfectiousDisease object.
   *
   * @return A list of pathophysiology property values.
   */
  public List<String> getPathophysiologies() {
    return medicalCondition.getPathophysiologies();
  }
  
  /**
   * Get all the possibleComplication property values for this InfectiousDisease object.
   *
   * @return A list of possibleComplication property values.
   */
  public List<String> getPossibleComplications() {
    return medicalCondition.getPossibleComplications();
  }
  
  /**
   * Get all the possibleTreatment property values for this InfectiousDisease object.
   *
   * @return A list of possibleTreatment property values.
   */
  public List<MedicalTherapy> getPossibleTreatments() {
    return medicalCondition.getPossibleTreatments();
  }
  
  /**
   * Get all the primaryPrevention property values for this InfectiousDisease object.
   *
   * @return A list of primaryPrevention property values.
   */
  public List<MedicalTherapy> getPrimaryPreventions() {
    return medicalCondition.getPrimaryPreventions();
  }
  
  /**
   * Get all the recognizingAuthority property values for this InfectiousDisease object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this InfectiousDisease object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the riskFactor property values for this InfectiousDisease object.
   *
   * @return A list of riskFactor property values.
   */
  public List<MedicalRiskFactor> getRiskFactors() {
    return medicalCondition.getRiskFactors();
  }
  
  /**
   * Get all the sameAs property values for this InfectiousDisease object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the secondaryPrevention property values for this InfectiousDisease object.
   *
   * @return A list of secondaryPrevention property values.
   */
  public List<MedicalTherapy> getSecondaryPreventions() {
    return medicalCondition.getSecondaryPreventions();
  }
  
  /**
   * Get all the signOrSymptom property values for this InfectiousDisease object.
   *
   * @return A list of signOrSymptom property values.
   */
  public List<MedicalSignOrSymptom> getSignOrSymptoms() {
    return medicalCondition.getSignOrSymptoms();
  }
  
  /**
   * Get all the stage property values for this InfectiousDisease object.
   *
   * @return A list of stage property values.
   */
  public List<MedicalConditionStage> getStages() {
    return medicalCondition.getStages();
  }
  
  /**
   * Get all the study property values for this InfectiousDisease object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the subtype property values for this InfectiousDisease object.
   *
   * @return A list of subtype property values.
   */
  public List<String> getSubtypes() {
    return medicalCondition.getSubtypes();
  }
  
  /**
   * Get all the transmissionMethod property values for this InfectiousDisease object.
   *
   * @return A list of transmissionMethod property values.
   */
  public List<String> getTransmissionMethods() {
  	return this.transmissionMethod;
  }
  
  /**
   * Get all the typicalTest property values for this InfectiousDisease object.
   *
   * @return A list of typicalTest property values.
   */
  public List<MedicalTest> getTypicalTests() {
    return medicalCondition.getTypicalTests();
  }
  
  /**
   * Get all the url property values for this InfectiousDisease object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the associatedAnatomy property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param associatedAnatomy The value to set.
   */
  public void setAssociatedAnatomy(Thing associatedAnatomy) {
    medicalCondition.setAssociatedAnatomy(associatedAnatomy);
  }
  
  /**
   * Set the cause property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param cause The value to set.
   */
  public void setCause(MedicalCause cause) {
    medicalCondition.setCause(cause);
  }
  
  /**
   * Set the code property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the differentialDiagnosis property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param differentialDiagnosis The value to set.
   */
  public void setDifferentialDiagnosis(DDxElement differentialDiagnosis) {
    medicalCondition.setDifferentialDiagnosis(differentialDiagnosis);
  }
  
  /**
   * Set the epidemiology property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param epidemiology The value to set.
   */
  public void setEpidemiology(String epidemiology) {
    medicalCondition.setEpidemiology(epidemiology);
  }
  
  /**
   * Set the expectedPrognosis property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param expectedPrognosis The value to set.
   */
  public void setExpectedPrognosis(String expectedPrognosis) {
    medicalCondition.setExpectedPrognosis(expectedPrognosis);
  }
  
  /**
   * Set the guideline property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the infectiousAgent property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgent The value to set.
   */
  public void setInfectiousAgent(String infectiousAgent) {
  	this.infectiousAgent.clear();
  	this.infectiousAgent.add(infectiousAgent);
  }
  
  /**
   * Set the infectiousAgentClass property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgentClass The value to set.
   */
  public void setInfectiousAgentClass(InfectiousAgentClass infectiousAgentClass) {
  	this.infectiousAgentClass.clear();
  	this.infectiousAgentClass.add(infectiousAgentClass);
  }
  
  /**
   * Set the medicineSystem property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the naturalProgression property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param naturalProgression The value to set.
   */
  public void setNaturalProgression(String naturalProgression) {
    medicalCondition.setNaturalProgression(naturalProgression);
  }
  
  /**
   * Set the pathophysiology property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param pathophysiology The value to set.
   */
  public void setPathophysiology(String pathophysiology) {
    medicalCondition.setPathophysiology(pathophysiology);
  }
  
  /**
   * Set the possibleComplication property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param possibleComplication The value to set.
   */
  public void setPossibleComplication(String possibleComplication) {
    medicalCondition.setPossibleComplication(possibleComplication);
  }
  
  /**
   * Set the possibleTreatment property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param possibleTreatment The value to set.
   */
  public void setPossibleTreatment(MedicalTherapy possibleTreatment) {
    medicalCondition.setPossibleTreatment(possibleTreatment);
  }
  
  /**
   * Set the primaryPrevention property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param primaryPrevention The value to set.
   */
  public void setPrimaryPrevention(MedicalTherapy primaryPrevention) {
    medicalCondition.setPrimaryPrevention(primaryPrevention);
  }
  
  /**
   * Set the recognizingAuthority property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the riskFactor property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param riskFactor The value to set.
   */
  public void setRiskFactor(MedicalRiskFactor riskFactor) {
    medicalCondition.setRiskFactor(riskFactor);
  }
  
  /**
   * Set the sameAs property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the secondaryPrevention property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param secondaryPrevention The value to set.
   */
  public void setSecondaryPrevention(MedicalTherapy secondaryPrevention) {
    medicalCondition.setSecondaryPrevention(secondaryPrevention);
  }
  
  /**
   * Set the signOrSymptom property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param signOrSymptom The value to set.
   */
  public void setSignOrSymptom(MedicalSignOrSymptom signOrSymptom) {
    medicalCondition.setSignOrSymptom(signOrSymptom);
  }
  
  /**
   * Set the stage property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param stage The value to set.
   */
  public void setStage(MedicalConditionStage stage) {
    medicalCondition.setStage(stage);
  }
  
  /**
   * Set the study property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the subtype property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param subtype The value to set.
   */
  public void setSubtype(String subtype) {
    medicalCondition.setSubtype(subtype);
  }
  
  /**
   * Set the transmissionMethod property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param transmissionMethod The value to set.
   */
  public void setTransmissionMethod(String transmissionMethod) {
  	this.transmissionMethod.clear();
  	this.transmissionMethod.add(transmissionMethod);
  }
  
  /**
   * Set the typicalTest property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param typicalTest The value to set.
   */
  public void setTypicalTest(MedicalTest typicalTest) {
    medicalCondition.setTypicalTest(typicalTest);
  }
  
  /**
   * Set the url property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the associatedAnatomy property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param associatedAnatomies The list of values to set.
   */
  public void setAssociatedAnatomies(List<Thing> associatedAnatomies) {
    medicalCondition.setAssociatedAnatomies(associatedAnatomies);
  }
  
  /**
   * Set the cause property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param causes The list of values to set.
   */
  public void setCauses(List<MedicalCause> causes) {
    medicalCondition.setCauses(causes);
  }
  
  /**
   * Set the code property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the differentialDiagnosis property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param differentialDiagnoses The list of values to set.
   */
  public void setDifferentialDiagnoses(List<DDxElement> differentialDiagnoses) {
    medicalCondition.setDifferentialDiagnoses(differentialDiagnoses);
  }
  
  /**
   * Set the epidemiology property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param epidemiologies The list of values to set.
   */
  public void setEpidemiologies(List<String> epidemiologies) {
    medicalCondition.setEpidemiologies(epidemiologies);
  }
  
  /**
   * Set the expectedPrognosis property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param expectedPrognoses The list of values to set.
   */
  public void setExpectedPrognoses(List<String> expectedPrognoses) {
    medicalCondition.setExpectedPrognoses(expectedPrognoses);
  }
  
  /**
   * Set the guideline property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the infectiousAgent property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgents The list of values to set.
   */
  public void setInfectiousAgents(List<String> infectiousAgents) {
  	this.infectiousAgent = infectiousAgents;
  }
  
  /**
   * Set the infectiousAgentClass property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgentClasses The list of values to set.
   */
  public void setInfectiousAgentClasses(List<InfectiousAgentClass> infectiousAgentClasses) {
  	this.infectiousAgentClass = infectiousAgentClasses;
  }
  
  /**
   * Set the medicineSystem property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the naturalProgression property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param naturalProgressions The list of values to set.
   */
  public void setNaturalProgressions(List<String> naturalProgressions) {
    medicalCondition.setNaturalProgressions(naturalProgressions);
  }
  
  /**
   * Set the pathophysiology property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param pathophysiologies The list of values to set.
   */
  public void setPathophysiologies(List<String> pathophysiologies) {
    medicalCondition.setPathophysiologies(pathophysiologies);
  }
  
  /**
   * Set the possibleComplication property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param possibleComplications The list of values to set.
   */
  public void setPossibleComplications(List<String> possibleComplications) {
    medicalCondition.setPossibleComplications(possibleComplications);
  }
  
  /**
   * Set the possibleTreatment property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param possibleTreatments The list of values to set.
   */
  public void setPossibleTreatments(List<MedicalTherapy> possibleTreatments) {
    medicalCondition.setPossibleTreatments(possibleTreatments);
  }
  
  /**
   * Set the primaryPrevention property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param primaryPreventions The list of values to set.
   */
  public void setPrimaryPreventions(List<MedicalTherapy> primaryPreventions) {
    medicalCondition.setPrimaryPreventions(primaryPreventions);
  }
  
  /**
   * Set the recognizingAuthority property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the riskFactor property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param riskFactors The list of values to set.
   */
  public void setRiskFactors(List<MedicalRiskFactor> riskFactors) {
    medicalCondition.setRiskFactors(riskFactors);
  }
  
  /**
   * Set the sameAs property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the secondaryPrevention property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param secondaryPreventions The list of values to set.
   */
  public void setSecondaryPreventions(List<MedicalTherapy> secondaryPreventions) {
    medicalCondition.setSecondaryPreventions(secondaryPreventions);
  }
  
  /**
   * Set the signOrSymptom property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param signOrSymptoms The list of values to set.
   */
  public void setSignOrSymptoms(List<MedicalSignOrSymptom> signOrSymptoms) {
    medicalCondition.setSignOrSymptoms(signOrSymptoms);
  }
  
  /**
   * Set the stage property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param stages The list of values to set.
   */
  public void setStages(List<MedicalConditionStage> stages) {
    medicalCondition.setStages(stages);
  }
  
  /**
   * Set the study property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the subtype property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param subtypes The list of values to set.
   */
  public void setSubtypes(List<String> subtypes) {
    medicalCondition.setSubtypes(subtypes);
  }
  
  /**
   * Set the transmissionMethod property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param transmissionMethods The list of values to set.
   */
  public void setTransmissionMethods(List<String> transmissionMethods) {
  	this.transmissionMethod = transmissionMethods;
  }
  
  /**
   * Set the typicalTest property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param typicalTests The list of values to set.
   */
  public void setTypicalTests(List<MedicalTest> typicalTests) {
    medicalCondition.setTypicalTests(typicalTests);
  }
  
  /**
   * Set the url property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a associatedAnatomy property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param associatedAnatomy The value to add.
   */
  public void addAssociatedAnatomy(Thing associatedAnatomy) {
    medicalCondition.addAssociatedAnatomy(associatedAnatomy);
  }
  
  /**
   * Adds a cause property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param cause The value to add.
   */
  public void addCause(MedicalCause cause) {
    medicalCondition.addCause(cause);
  }
  
  /**
   * Adds a code property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a differentialDiagnosis property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param differentialDiagnosis The value to add.
   */
  public void addDifferentialDiagnosis(DDxElement differentialDiagnosis) {
    medicalCondition.addDifferentialDiagnosis(differentialDiagnosis);
  }
  
  /**
   * Adds a epidemiology property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param epidemiology The value to add.
   */
  public void addEpidemiology(String epidemiology) {
    medicalCondition.addEpidemiology(epidemiology);
  }
  
  /**
   * Adds a expectedPrognosis property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param expectedPrognosis The value to add.
   */
  public void addExpectedPrognosis(String expectedPrognosis) {
    medicalCondition.addExpectedPrognosis(expectedPrognosis);
  }
  
  /**
   * Adds a guideline property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a infectiousAgent property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param infectiousAgent The value to add.
   */
  public void addInfectiousAgent(String infectiousAgent) {
  	this.infectiousAgent.add(infectiousAgent);
  }
  
  /**
   * Adds a infectiousAgentClass property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param infectiousAgentClass The value to add.
   */
  public void addInfectiousAgentClass(InfectiousAgentClass infectiousAgentClass) {
  	this.infectiousAgentClass.add(infectiousAgentClass);
  }
  
  /**
   * Adds a medicineSystem property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a naturalProgression property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param naturalProgression The value to add.
   */
  public void addNaturalProgression(String naturalProgression) {
    medicalCondition.addNaturalProgression(naturalProgression);
  }
  
  /**
   * Adds a pathophysiology property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param pathophysiology The value to add.
   */
  public void addPathophysiology(String pathophysiology) {
    medicalCondition.addPathophysiology(pathophysiology);
  }
  
  /**
   * Adds a possibleComplication property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param possibleComplication The value to add.
   */
  public void addPossibleComplication(String possibleComplication) {
    medicalCondition.addPossibleComplication(possibleComplication);
  }
  
  /**
   * Adds a possibleTreatment property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param possibleTreatment The value to add.
   */
  public void addPossibleTreatment(MedicalTherapy possibleTreatment) {
    medicalCondition.addPossibleTreatment(possibleTreatment);
  }
  
  /**
   * Adds a primaryPrevention property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param primaryPrevention The value to add.
   */
  public void addPrimaryPrevention(MedicalTherapy primaryPrevention) {
    medicalCondition.addPrimaryPrevention(primaryPrevention);
  }
  
  /**
   * Adds a recognizingAuthority property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a riskFactor property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param riskFactor The value to add.
   */
  public void addRiskFactor(MedicalRiskFactor riskFactor) {
    medicalCondition.addRiskFactor(riskFactor);
  }
  
  /**
   * Adds a sameAs property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a secondaryPrevention property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param secondaryPrevention The value to add.
   */
  public void addSecondaryPrevention(MedicalTherapy secondaryPrevention) {
    medicalCondition.addSecondaryPrevention(secondaryPrevention);
  }
  
  /**
   * Adds a signOrSymptom property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param signOrSymptom The value to add.
   */
  public void addSignOrSymptom(MedicalSignOrSymptom signOrSymptom) {
    medicalCondition.addSignOrSymptom(signOrSymptom);
  }
  
  /**
   * Adds a stage property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param stage The value to add.
   */
  public void addStage(MedicalConditionStage stage) {
    medicalCondition.addStage(stage);
  }
  
  /**
   * Adds a study property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a subtype property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param subtype The value to add.
   */
  public void addSubtype(String subtype) {
    medicalCondition.addSubtype(subtype);
  }
  
  /**
   * Adds a transmissionMethod property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param transmissionMethod The value to add.
   */
  public void addTransmissionMethod(String transmissionMethod) {
  	this.transmissionMethod.add(transmissionMethod);
  }
  
  /**
   * Adds a typicalTest property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param typicalTest The value to add.
   */
  public void addTypicalTest(MedicalTest typicalTest) {
    medicalCondition.addTypicalTest(typicalTest);
  }
  
  /**
   * Adds a url property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}