package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.InsertAction;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The act of adding at a specific location in an ordered collection.
 */
public class InsertActionImpl extends SchemaObjectImpl implements InsertAction {


  private ActionImpl action;
  private ThingImpl thing;
  private UpdateActionImpl updateAction;

  /**
   * A sub property of location. The final location of the object or the agent after the action.
   */
  private List<Thing> toLocation = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public InsertActionImpl() {
    super("http://schema.org/InsertAction");
  }
  /**
   * Get a single additionalType property value for this InsertAction object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single agent property value for this InsertAction object.
   *
   * @return The first agent property value.
   */
  public Thing getAgent() {
    return action.getAgent();
  }
  
  /**
   * Get a single alternateName property value for this InsertAction object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single collection property value for this InsertAction object.
   *
   * @return The first collection property value.
   */
  public Thing getCollection() {
    return updateAction.getCollection();
  }
  
  /**
   * Get a single description property value for this InsertAction object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single endTime property value for this InsertAction object.
   *
   * @return The first endTime property value.
   */
  public Date getEndTime() {
    return action.getEndTime();
  }
  
  /**
   * Get a single image property value for this InsertAction object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single instrument property value for this InsertAction object.
   *
   * @return The first instrument property value.
   */
  public Thing getInstrument() {
    return action.getInstrument();
  }
  
  /**
   * Get a single location property value for this InsertAction object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
    return action.getLocation();
  }
  
  /**
   * Get a single name property value for this InsertAction object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single object property value for this InsertAction object.
   *
   * @return The first object property value.
   */
  public Thing getObject() {
    return action.getObject();
  }
  
  /**
   * Get a single participant property value for this InsertAction object.
   *
   * @return The first participant property value.
   */
  public Thing getParticipant() {
    return action.getParticipant();
  }
  
  /**
   * Get a single result property value for this InsertAction object.
   *
   * @return The first result property value.
   */
  public Thing getResult() {
    return action.getResult();
  }
  
  /**
   * Get a single sameAs property value for this InsertAction object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single startTime property value for this InsertAction object.
   *
   * @return The first startTime property value.
   */
  public Date getStartTime() {
    return action.getStartTime();
  }
  
  /**
   * Get a single toLocation property value for this InsertAction object.
   *
   * @return The first toLocation property value.
   */
  public Thing getToLocation() {
  	return this.toLocation.isEmpty() ? null : this.toLocation.get(0);
  }
  
  /**
   * Get a single url property value for this InsertAction object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this InsertAction object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the agent property values for this InsertAction object.
   *
   * @return A list of agent property values.
   */
  public List<Thing> getAgents() {
    return action.getAgents();
  }
  
  /**
   * Get all the alternateName property values for this InsertAction object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the collection property values for this InsertAction object.
   *
   * @return A list of collection property values.
   */
  public List<Thing> getCollections() {
    return updateAction.getCollections();
  }
  
  /**
   * Get all the description property values for this InsertAction object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the endTime property values for this InsertAction object.
   *
   * @return A list of endTime property values.
   */
  public List<Date> getEndTimes() {
    return action.getEndTimes();
  }
  
  /**
   * Get all the image property values for this InsertAction object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the instrument property values for this InsertAction object.
   *
   * @return A list of instrument property values.
   */
  public List<Thing> getInstruments() {
    return action.getInstruments();
  }
  
  /**
   * Get all the location property values for this InsertAction object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
    return action.getLocations();
  }
  
  /**
   * Get all the name property values for this InsertAction object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the object property values for this InsertAction object.
   *
   * @return A list of object property values.
   */
  public List<Thing> getObjects() {
    return action.getObjects();
  }
  
  /**
   * Get all the participant property values for this InsertAction object.
   *
   * @return A list of participant property values.
   */
  public List<Thing> getParticipants() {
    return action.getParticipants();
  }
  
  /**
   * Get all the result property values for this InsertAction object.
   *
   * @return A list of result property values.
   */
  public List<Thing> getResults() {
    return action.getResults();
  }
  
  /**
   * Get all the sameAs property values for this InsertAction object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the startTime property values for this InsertAction object.
   *
   * @return A list of startTime property values.
   */
  public List<Date> getStartTimes() {
    return action.getStartTimes();
  }
  
  /**
   * Get all the toLocation property values for this InsertAction object.
   *
   * @return A list of toLocation property values.
   */
  public List<Thing> getToLocations() {
  	return this.toLocation;
  }
  
  /**
   * Get all the url property values for this InsertAction object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this InsertAction object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the agent property value for this InsertAction object; overwriting any existing values.
   *
   * @param agent The value to set.
   */
  public void setAgent(Thing agent) {
    action.setAgent(agent);
  }
  
  /**
   * Set the alternateName property value for this InsertAction object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the collection property value for this InsertAction object; overwriting any existing values.
   *
   * @param collection The value to set.
   */
  public void setCollection(Thing collection) {
    updateAction.setCollection(collection);
  }
  
  /**
   * Set the description property value for this InsertAction object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the endTime property value for this InsertAction object; overwriting any existing values.
   *
   * @param endTime The value to set.
   */
  public void setEndTime(Date endTime) {
    action.setEndTime(endTime);
  }
  
  /**
   * Set the image property value for this InsertAction object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the instrument property value for this InsertAction object; overwriting any existing values.
   *
   * @param instrument The value to set.
   */
  public void setInstrument(Thing instrument) {
    action.setInstrument(instrument);
  }
  
  /**
   * Set the location property value for this InsertAction object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
    action.setLocation(location);
  }
  
  /**
   * Set the name property value for this InsertAction object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the object property value for this InsertAction object; overwriting any existing values.
   *
   * @param object The value to set.
   */
  public void setObject(Thing object) {
    action.setObject(object);
  }
  
  /**
   * Set the participant property value for this InsertAction object; overwriting any existing values.
   *
   * @param participant The value to set.
   */
  public void setParticipant(Thing participant) {
    action.setParticipant(participant);
  }
  
  /**
   * Set the result property value for this InsertAction object; overwriting any existing values.
   *
   * @param result The value to set.
   */
  public void setResult(Thing result) {
    action.setResult(result);
  }
  
  /**
   * Set the sameAs property value for this InsertAction object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the startTime property value for this InsertAction object; overwriting any existing values.
   *
   * @param startTime The value to set.
   */
  public void setStartTime(Date startTime) {
    action.setStartTime(startTime);
  }
  
  /**
   * Set the toLocation property value for this InsertAction object; overwriting any existing values.
   *
   * @param toLocation The value to set.
   */
  public void setToLocation(Thing toLocation) {
  	this.toLocation.clear();
  	this.toLocation.add(toLocation);
  }
  
  /**
   * Set the url property value for this InsertAction object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this InsertAction object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the agent property values for this InsertAction object; overwriting any existing values.
   *
   * @param agents The list of values to set.
   */
  public void setAgents(List<Thing> agents) {
    action.setAgents(agents);
  }
  
  /**
   * Set the alternateName property values for this InsertAction object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the collection property values for this InsertAction object; overwriting any existing values.
   *
   * @param collections The list of values to set.
   */
  public void setCollections(List<Thing> collections) {
    updateAction.setCollections(collections);
  }
  
  /**
   * Set the description property values for this InsertAction object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the endTime property values for this InsertAction object; overwriting any existing values.
   *
   * @param endTimes The list of values to set.
   */
  public void setEndTimes(List<Date> endTimes) {
    action.setEndTimes(endTimes);
  }
  
  /**
   * Set the image property values for this InsertAction object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the instrument property values for this InsertAction object; overwriting any existing values.
   *
   * @param instruments The list of values to set.
   */
  public void setInstruments(List<Thing> instruments) {
    action.setInstruments(instruments);
  }
  
  /**
   * Set the location property values for this InsertAction object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
    action.setLocations(locations);
  }
  
  /**
   * Set the name property values for this InsertAction object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the object property values for this InsertAction object; overwriting any existing values.
   *
   * @param objects The list of values to set.
   */
  public void setObjects(List<Thing> objects) {
    action.setObjects(objects);
  }
  
  /**
   * Set the participant property values for this InsertAction object; overwriting any existing values.
   *
   * @param participants The list of values to set.
   */
  public void setParticipants(List<Thing> participants) {
    action.setParticipants(participants);
  }
  
  /**
   * Set the result property values for this InsertAction object; overwriting any existing values.
   *
   * @param results The list of values to set.
   */
  public void setResults(List<Thing> results) {
    action.setResults(results);
  }
  
  /**
   * Set the sameAs property values for this InsertAction object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the startTime property values for this InsertAction object; overwriting any existing values.
   *
   * @param startTimes The list of values to set.
   */
  public void setStartTimes(List<Date> startTimes) {
    action.setStartTimes(startTimes);
  }
  
  /**
   * Set the toLocation property values for this InsertAction object; overwriting any existing values.
   *
   * @param toLocations The list of values to set.
   */
  public void setToLocations(List<Thing> toLocations) {
  	this.toLocation = toLocations;
  }
  
  /**
   * Set the url property values for this InsertAction object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a agent property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param agent The value to add.
   */
  public void addAgent(Thing agent) {
    action.addAgent(agent);
  }
  
  /**
   * Adds a alternateName property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a collection property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param collection The value to add.
   */
  public void addCollection(Thing collection) {
    updateAction.addCollection(collection);
  }
  
  /**
   * Adds a description property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a endTime property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param endTime The value to add.
   */
  public void addEndTime(Date endTime) {
    action.addEndTime(endTime);
  }
  
  /**
   * Adds a image property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a instrument property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param instrument The value to add.
   */
  public void addInstrument(Thing instrument) {
    action.addInstrument(instrument);
  }
  
  /**
   * Adds a location property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
    action.addLocation(location);
  }
  
  /**
   * Adds a name property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a object property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param object The value to add.
   */
  public void addObject(Thing object) {
    action.addObject(object);
  }
  
  /**
   * Adds a participant property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param participant The value to add.
   */
  public void addParticipant(Thing participant) {
    action.addParticipant(participant);
  }
  
  /**
   * Adds a result property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param result The value to add.
   */
  public void addResult(Thing result) {
    action.addResult(result);
  }
  
  /**
   * Adds a sameAs property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a startTime property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param startTime The value to add.
   */
  public void addStartTime(Date startTime) {
    action.addStartTime(startTime);
  }
  
  /**
   * Adds a toLocation property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param toLocation The value to add.
   */
  public void addToLocation(Thing toLocation) {
  	this.toLocation.add(toLocation);
  }
  
  /**
   * Adds a url property value for this InsertAction object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}