package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.JobPosting;
import org.schema.Number;
import org.schema.Organization;
import org.schema.Place;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A listing that describes a job opening in a certain organization.
 */
public class JobPostingImpl extends SchemaObjectImpl implements JobPosting {


  private ThingImpl thing;

  /**
   * The base salary of the job.
   */
  private List<Number> baseSalary = new LinkedList<Number>();
  
  /**
   * Description of benefits associated with the job.
   */
  private List<String> benefits = new LinkedList<String>();
  
  /**
   * Publication date for the job posting.
   */
  private List<Date> datePosted = new LinkedList<Date>();
  
  /**
   * Educational background needed for the position.
   */
  private List<String> educationRequirements = new LinkedList<String>();
  
  /**
   * Type of employment (e.g. full-time, part-time, contract, temporary, seasonal, internship).
   */
  private List<String> employmentType = new LinkedList<String>();
  
  /**
   * Description of skills and experience needed for the position.
   */
  private List<String> experienceRequirements = new LinkedList<String>();
  
  /**
   * Organization offering the job position.
   */
  private List<Organization> hiringOrganization = new LinkedList<Organization>();
  
  /**
   * Description of bonus and commission compensation aspects of the job.
   */
  private List<String> incentives = new LinkedList<String>();
  
  /**
   * The industry associated with the job position.
   */
  private List<String> industry = new LinkedList<String>();
  
  /**
   * A (typically single) geographic location associated with the job position.
   */
  private List<Place> jobLocation = new LinkedList<Place>();
  
  /**
   * Category or categories describing the job. Use BLS O*NET-SOC taxonomy: http://www.onetcenter.org/taxonomy.html. Ideally includes textual label and formal code, with the property repeated for each applicable value.
   */
  private List<String> occupationalCategory = new LinkedList<String>();
  
  /**
   * Specific qualifications required for this role.
   */
  private List<String> qualifications = new LinkedList<String>();
  
  /**
   * Responsibilities associated with this role.
   */
  private List<String> responsibilities = new LinkedList<String>();
  
  /**
   * The currency (coded using ISO 4217, http://en.wikipedia.org/wiki/ISO_4217 used for the main salary information in this job posting.
   */
  private List<String> salaryCurrency = new LinkedList<String>();
  
  /**
   * Skills required to fulfill this role.
   */
  private List<String> skills = new LinkedList<String>();
  
  /**
   * Any special commitments associated with this job posting. Valid entries include VeteranCommit, MilitarySpouseCommit, etc.
   */
  private List<String> specialCommitments = new LinkedList<String>();
  
  /**
   * The title of the job.
   */
  private List<String> title = new LinkedList<String>();
  
  /**
   * The typical working hours for this job (e.g. 1st shift, night shift, 8am-5pm).
   */
  private List<String> workHours = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public JobPostingImpl() {
    super("http://schema.org/JobPosting");
  }
  /**
   * Get a single additionalType property value for this JobPosting object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this JobPosting object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single baseSalary property value for this JobPosting object.
   *
   * @return The first baseSalary property value.
   */
  public Number getBaseSalary() {
  	return this.baseSalary.isEmpty() ? null : this.baseSalary.get(0);
  }
  
  /**
   * Get a single benefits property value for this JobPosting object.
   *
   * @return The first benefits property value.
   */
  public String getBenefits() {
  	return this.benefits.isEmpty() ? null : this.benefits.get(0);
  }
  
  /**
   * Get a single datePosted property value for this JobPosting object.
   *
   * @return The first datePosted property value.
   */
  public Date getDatePosted() {
  	return this.datePosted.isEmpty() ? null : this.datePosted.get(0);
  }
  
  /**
   * Get a single description property value for this JobPosting object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single educationRequirements property value for this JobPosting object.
   *
   * @return The first educationRequirements property value.
   */
  public String getEducationRequirements() {
  	return this.educationRequirements.isEmpty() ? null : this.educationRequirements.get(0);
  }
  
  /**
   * Get a single employmentType property value for this JobPosting object.
   *
   * @return The first employmentType property value.
   */
  public String getEmploymentType() {
  	return this.employmentType.isEmpty() ? null : this.employmentType.get(0);
  }
  
  /**
   * Get a single experienceRequirements property value for this JobPosting object.
   *
   * @return The first experienceRequirements property value.
   */
  public String getExperienceRequirements() {
  	return this.experienceRequirements.isEmpty() ? null : this.experienceRequirements.get(0);
  }
  
  /**
   * Get a single hiringOrganization property value for this JobPosting object.
   *
   * @return The first hiringOrganization property value.
   */
  public Organization getHiringOrganization() {
  	return this.hiringOrganization.isEmpty() ? null : this.hiringOrganization.get(0);
  }
  
  /**
   * Get a single image property value for this JobPosting object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single incentives property value for this JobPosting object.
   *
   * @return The first incentives property value.
   */
  public String getIncentives() {
  	return this.incentives.isEmpty() ? null : this.incentives.get(0);
  }
  
  /**
   * Get a single industry property value for this JobPosting object.
   *
   * @return The first industry property value.
   */
  public String getIndustry() {
  	return this.industry.isEmpty() ? null : this.industry.get(0);
  }
  
  /**
   * Get a single jobLocation property value for this JobPosting object.
   *
   * @return The first jobLocation property value.
   */
  public Place getJobLocation() {
  	return this.jobLocation.isEmpty() ? null : this.jobLocation.get(0);
  }
  
  /**
   * Get a single name property value for this JobPosting object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single occupationalCategory property value for this JobPosting object.
   *
   * @return The first occupationalCategory property value.
   */
  public String getOccupationalCategory() {
  	return this.occupationalCategory.isEmpty() ? null : this.occupationalCategory.get(0);
  }
  
  /**
   * Get a single qualifications property value for this JobPosting object.
   *
   * @return The first qualifications property value.
   */
  public String getQualifications() {
  	return this.qualifications.isEmpty() ? null : this.qualifications.get(0);
  }
  
  /**
   * Get a single responsibilities property value for this JobPosting object.
   *
   * @return The first responsibilities property value.
   */
  public String getResponsibilities() {
  	return this.responsibilities.isEmpty() ? null : this.responsibilities.get(0);
  }
  
  /**
   * Get a single salaryCurrency property value for this JobPosting object.
   *
   * @return The first salaryCurrency property value.
   */
  public String getSalaryCurrency() {
  	return this.salaryCurrency.isEmpty() ? null : this.salaryCurrency.get(0);
  }
  
  /**
   * Get a single sameAs property value for this JobPosting object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single skills property value for this JobPosting object.
   *
   * @return The first skills property value.
   */
  public String getSkills() {
  	return this.skills.isEmpty() ? null : this.skills.get(0);
  }
  
  /**
   * Get a single specialCommitments property value for this JobPosting object.
   *
   * @return The first specialCommitments property value.
   */
  public String getSpecialCommitments() {
  	return this.specialCommitments.isEmpty() ? null : this.specialCommitments.get(0);
  }
  
  /**
   * Get a single title property value for this JobPosting object.
   *
   * @return The first title property value.
   */
  public String getTitle() {
  	return this.title.isEmpty() ? null : this.title.get(0);
  }
  
  /**
   * Get a single url property value for this JobPosting object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single workHours property value for this JobPosting object.
   *
   * @return The first workHours property value.
   */
  public String getWorkHours() {
  	return this.workHours.isEmpty() ? null : this.workHours.get(0);
  }
  
  /**
   * Get all the additionalType property values for this JobPosting object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this JobPosting object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the baseSalary property values for this JobPosting object.
   *
   * @return A list of baseSalary property values.
   */
  public List<Number> getBaseSalaries() {
  	return this.baseSalary;
  }
  
  /**
   * Get all the benefits property values for this JobPosting object.
   *
   * @return A list of benefits property values.
   */
  public List<String> getBenefitss() {
  	return this.benefits;
  }
  
  /**
   * Get all the datePosted property values for this JobPosting object.
   *
   * @return A list of datePosted property values.
   */
  public List<Date> getDatePosteds() {
  	return this.datePosted;
  }
  
  /**
   * Get all the description property values for this JobPosting object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the educationRequirements property values for this JobPosting object.
   *
   * @return A list of educationRequirements property values.
   */
  public List<String> getEducationRequirementss() {
  	return this.educationRequirements;
  }
  
  /**
   * Get all the employmentType property values for this JobPosting object.
   *
   * @return A list of employmentType property values.
   */
  public List<String> getEmploymentTypes() {
  	return this.employmentType;
  }
  
  /**
   * Get all the experienceRequirements property values for this JobPosting object.
   *
   * @return A list of experienceRequirements property values.
   */
  public List<String> getExperienceRequirementss() {
  	return this.experienceRequirements;
  }
  
  /**
   * Get all the hiringOrganization property values for this JobPosting object.
   *
   * @return A list of hiringOrganization property values.
   */
  public List<Organization> getHiringOrganizations() {
  	return this.hiringOrganization;
  }
  
  /**
   * Get all the image property values for this JobPosting object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the incentives property values for this JobPosting object.
   *
   * @return A list of incentives property values.
   */
  public List<String> getIncentivess() {
  	return this.incentives;
  }
  
  /**
   * Get all the industry property values for this JobPosting object.
   *
   * @return A list of industry property values.
   */
  public List<String> getIndustries() {
  	return this.industry;
  }
  
  /**
   * Get all the jobLocation property values for this JobPosting object.
   *
   * @return A list of jobLocation property values.
   */
  public List<Place> getJobLocations() {
  	return this.jobLocation;
  }
  
  /**
   * Get all the name property values for this JobPosting object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the occupationalCategory property values for this JobPosting object.
   *
   * @return A list of occupationalCategory property values.
   */
  public List<String> getOccupationalCategories() {
  	return this.occupationalCategory;
  }
  
  /**
   * Get all the qualifications property values for this JobPosting object.
   *
   * @return A list of qualifications property values.
   */
  public List<String> getQualificationss() {
  	return this.qualifications;
  }
  
  /**
   * Get all the responsibilities property values for this JobPosting object.
   *
   * @return A list of responsibilities property values.
   */
  public List<String> getResponsibilitiess() {
  	return this.responsibilities;
  }
  
  /**
   * Get all the salaryCurrency property values for this JobPosting object.
   *
   * @return A list of salaryCurrency property values.
   */
  public List<String> getSalaryCurrencies() {
  	return this.salaryCurrency;
  }
  
  /**
   * Get all the sameAs property values for this JobPosting object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the skills property values for this JobPosting object.
   *
   * @return A list of skills property values.
   */
  public List<String> getSkillss() {
  	return this.skills;
  }
  
  /**
   * Get all the specialCommitments property values for this JobPosting object.
   *
   * @return A list of specialCommitments property values.
   */
  public List<String> getSpecialCommitmentss() {
  	return this.specialCommitments;
  }
  
  /**
   * Get all the title property values for this JobPosting object.
   *
   * @return A list of title property values.
   */
  public List<String> getTitles() {
  	return this.title;
  }
  
  /**
   * Get all the url property values for this JobPosting object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the workHours property values for this JobPosting object.
   *
   * @return A list of workHours property values.
   */
  public List<String> getWorkHourss() {
  	return this.workHours;
  }
  
  /**
   * Set the additionalType property value for this JobPosting object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this JobPosting object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the baseSalary property value for this JobPosting object; overwriting any existing values.
   *
   * @param baseSalary The value to set.
   */
  public void setBaseSalary(Number baseSalary) {
  	this.baseSalary.clear();
  	this.baseSalary.add(baseSalary);
  }
  
  /**
   * Set the benefits property value for this JobPosting object; overwriting any existing values.
   *
   * @param benefits The value to set.
   */
  public void setBenefits(String benefits) {
  	this.benefits.clear();
  	this.benefits.add(benefits);
  }
  
  /**
   * Set the datePosted property value for this JobPosting object; overwriting any existing values.
   *
   * @param datePosted The value to set.
   */
  public void setDatePosted(Date datePosted) {
  	this.datePosted.clear();
  	this.datePosted.add(datePosted);
  }
  
  /**
   * Set the description property value for this JobPosting object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the educationRequirements property value for this JobPosting object; overwriting any existing values.
   *
   * @param educationRequirements The value to set.
   */
  public void setEducationRequirements(String educationRequirements) {
  	this.educationRequirements.clear();
  	this.educationRequirements.add(educationRequirements);
  }
  
  /**
   * Set the employmentType property value for this JobPosting object; overwriting any existing values.
   *
   * @param employmentType The value to set.
   */
  public void setEmploymentType(String employmentType) {
  	this.employmentType.clear();
  	this.employmentType.add(employmentType);
  }
  
  /**
   * Set the experienceRequirements property value for this JobPosting object; overwriting any existing values.
   *
   * @param experienceRequirements The value to set.
   */
  public void setExperienceRequirements(String experienceRequirements) {
  	this.experienceRequirements.clear();
  	this.experienceRequirements.add(experienceRequirements);
  }
  
  /**
   * Set the hiringOrganization property value for this JobPosting object; overwriting any existing values.
   *
   * @param hiringOrganization The value to set.
   */
  public void setHiringOrganization(Organization hiringOrganization) {
  	this.hiringOrganization.clear();
  	this.hiringOrganization.add(hiringOrganization);
  }
  
  /**
   * Set the image property value for this JobPosting object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the incentives property value for this JobPosting object; overwriting any existing values.
   *
   * @param incentives The value to set.
   */
  public void setIncentives(String incentives) {
  	this.incentives.clear();
  	this.incentives.add(incentives);
  }
  
  /**
   * Set the industry property value for this JobPosting object; overwriting any existing values.
   *
   * @param industry The value to set.
   */
  public void setIndustry(String industry) {
  	this.industry.clear();
  	this.industry.add(industry);
  }
  
  /**
   * Set the jobLocation property value for this JobPosting object; overwriting any existing values.
   *
   * @param jobLocation The value to set.
   */
  public void setJobLocation(Place jobLocation) {
  	this.jobLocation.clear();
  	this.jobLocation.add(jobLocation);
  }
  
  /**
   * Set the name property value for this JobPosting object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the occupationalCategory property value for this JobPosting object; overwriting any existing values.
   *
   * @param occupationalCategory The value to set.
   */
  public void setOccupationalCategory(String occupationalCategory) {
  	this.occupationalCategory.clear();
  	this.occupationalCategory.add(occupationalCategory);
  }
  
  /**
   * Set the qualifications property value for this JobPosting object; overwriting any existing values.
   *
   * @param qualifications The value to set.
   */
  public void setQualifications(String qualifications) {
  	this.qualifications.clear();
  	this.qualifications.add(qualifications);
  }
  
  /**
   * Set the responsibilities property value for this JobPosting object; overwriting any existing values.
   *
   * @param responsibilities The value to set.
   */
  public void setResponsibilities(String responsibilities) {
  	this.responsibilities.clear();
  	this.responsibilities.add(responsibilities);
  }
  
  /**
   * Set the salaryCurrency property value for this JobPosting object; overwriting any existing values.
   *
   * @param salaryCurrency The value to set.
   */
  public void setSalaryCurrency(String salaryCurrency) {
  	this.salaryCurrency.clear();
  	this.salaryCurrency.add(salaryCurrency);
  }
  
  /**
   * Set the sameAs property value for this JobPosting object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the skills property value for this JobPosting object; overwriting any existing values.
   *
   * @param skills The value to set.
   */
  public void setSkills(String skills) {
  	this.skills.clear();
  	this.skills.add(skills);
  }
  
  /**
   * Set the specialCommitments property value for this JobPosting object; overwriting any existing values.
   *
   * @param specialCommitments The value to set.
   */
  public void setSpecialCommitments(String specialCommitments) {
  	this.specialCommitments.clear();
  	this.specialCommitments.add(specialCommitments);
  }
  
  /**
   * Set the title property value for this JobPosting object; overwriting any existing values.
   *
   * @param title The value to set.
   */
  public void setTitle(String title) {
  	this.title.clear();
  	this.title.add(title);
  }
  
  /**
   * Set the url property value for this JobPosting object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the workHours property value for this JobPosting object; overwriting any existing values.
   *
   * @param workHours The value to set.
   */
  public void setWorkHours(String workHours) {
  	this.workHours.clear();
  	this.workHours.add(workHours);
  }
  
  /**
   * Set the additionalType property values for this JobPosting object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this JobPosting object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the baseSalary property values for this JobPosting object; overwriting any existing values.
   *
   * @param baseSalaries The list of values to set.
   */
  public void setBaseSalaries(List<Number> baseSalaries) {
  	this.baseSalary = baseSalaries;
  }
  
  /**
   * Set the benefits property values for this JobPosting object; overwriting any existing values.
   *
   * @param benefitss The list of values to set.
   */
  public void setBenefitss(List<String> benefitss) {
  	this.benefits = benefitss;
  }
  
  /**
   * Set the datePosted property values for this JobPosting object; overwriting any existing values.
   *
   * @param datePosteds The list of values to set.
   */
  public void setDatePosteds(List<Date> datePosteds) {
  	this.datePosted = datePosteds;
  }
  
  /**
   * Set the description property values for this JobPosting object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the educationRequirements property values for this JobPosting object; overwriting any existing values.
   *
   * @param educationRequirementss The list of values to set.
   */
  public void setEducationRequirementss(List<String> educationRequirementss) {
  	this.educationRequirements = educationRequirementss;
  }
  
  /**
   * Set the employmentType property values for this JobPosting object; overwriting any existing values.
   *
   * @param employmentTypes The list of values to set.
   */
  public void setEmploymentTypes(List<String> employmentTypes) {
  	this.employmentType = employmentTypes;
  }
  
  /**
   * Set the experienceRequirements property values for this JobPosting object; overwriting any existing values.
   *
   * @param experienceRequirementss The list of values to set.
   */
  public void setExperienceRequirementss(List<String> experienceRequirementss) {
  	this.experienceRequirements = experienceRequirementss;
  }
  
  /**
   * Set the hiringOrganization property values for this JobPosting object; overwriting any existing values.
   *
   * @param hiringOrganizations The list of values to set.
   */
  public void setHiringOrganizations(List<Organization> hiringOrganizations) {
  	this.hiringOrganization = hiringOrganizations;
  }
  
  /**
   * Set the image property values for this JobPosting object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the incentives property values for this JobPosting object; overwriting any existing values.
   *
   * @param incentivess The list of values to set.
   */
  public void setIncentivess(List<String> incentivess) {
  	this.incentives = incentivess;
  }
  
  /**
   * Set the industry property values for this JobPosting object; overwriting any existing values.
   *
   * @param industries The list of values to set.
   */
  public void setIndustries(List<String> industries) {
  	this.industry = industries;
  }
  
  /**
   * Set the jobLocation property values for this JobPosting object; overwriting any existing values.
   *
   * @param jobLocations The list of values to set.
   */
  public void setJobLocations(List<Place> jobLocations) {
  	this.jobLocation = jobLocations;
  }
  
  /**
   * Set the name property values for this JobPosting object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the occupationalCategory property values for this JobPosting object; overwriting any existing values.
   *
   * @param occupationalCategories The list of values to set.
   */
  public void setOccupationalCategories(List<String> occupationalCategories) {
  	this.occupationalCategory = occupationalCategories;
  }
  
  /**
   * Set the qualifications property values for this JobPosting object; overwriting any existing values.
   *
   * @param qualificationss The list of values to set.
   */
  public void setQualificationss(List<String> qualificationss) {
  	this.qualifications = qualificationss;
  }
  
  /**
   * Set the responsibilities property values for this JobPosting object; overwriting any existing values.
   *
   * @param responsibilitiess The list of values to set.
   */
  public void setResponsibilitiess(List<String> responsibilitiess) {
  	this.responsibilities = responsibilitiess;
  }
  
  /**
   * Set the salaryCurrency property values for this JobPosting object; overwriting any existing values.
   *
   * @param salaryCurrencies The list of values to set.
   */
  public void setSalaryCurrencies(List<String> salaryCurrencies) {
  	this.salaryCurrency = salaryCurrencies;
  }
  
  /**
   * Set the sameAs property values for this JobPosting object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the skills property values for this JobPosting object; overwriting any existing values.
   *
   * @param skillss The list of values to set.
   */
  public void setSkillss(List<String> skillss) {
  	this.skills = skillss;
  }
  
  /**
   * Set the specialCommitments property values for this JobPosting object; overwriting any existing values.
   *
   * @param specialCommitmentss The list of values to set.
   */
  public void setSpecialCommitmentss(List<String> specialCommitmentss) {
  	this.specialCommitments = specialCommitmentss;
  }
  
  /**
   * Set the title property values for this JobPosting object; overwriting any existing values.
   *
   * @param titles The list of values to set.
   */
  public void setTitles(List<String> titles) {
  	this.title = titles;
  }
  
  /**
   * Set the url property values for this JobPosting object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the workHours property values for this JobPosting object; overwriting any existing values.
   *
   * @param workHourss The list of values to set.
   */
  public void setWorkHourss(List<String> workHourss) {
  	this.workHours = workHourss;
  }
  
  /**
   * Adds a additionalType property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a baseSalary property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param baseSalary The value to add.
   */
  public void addBaseSalary(Number baseSalary) {
  	this.baseSalary.add(baseSalary);
  }
  
  /**
   * Adds a benefits property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param benefits The value to add.
   */
  public void addBenefits(String benefits) {
  	this.benefits.add(benefits);
  }
  
  /**
   * Adds a datePosted property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param datePosted The value to add.
   */
  public void addDatePosted(Date datePosted) {
  	this.datePosted.add(datePosted);
  }
  
  /**
   * Adds a description property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a educationRequirements property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param educationRequirements The value to add.
   */
  public void addEducationRequirements(String educationRequirements) {
  	this.educationRequirements.add(educationRequirements);
  }
  
  /**
   * Adds a employmentType property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param employmentType The value to add.
   */
  public void addEmploymentType(String employmentType) {
  	this.employmentType.add(employmentType);
  }
  
  /**
   * Adds a experienceRequirements property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param experienceRequirements The value to add.
   */
  public void addExperienceRequirements(String experienceRequirements) {
  	this.experienceRequirements.add(experienceRequirements);
  }
  
  /**
   * Adds a hiringOrganization property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param hiringOrganization The value to add.
   */
  public void addHiringOrganization(Organization hiringOrganization) {
  	this.hiringOrganization.add(hiringOrganization);
  }
  
  /**
   * Adds a image property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a incentives property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param incentives The value to add.
   */
  public void addIncentives(String incentives) {
  	this.incentives.add(incentives);
  }
  
  /**
   * Adds a industry property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param industry The value to add.
   */
  public void addIndustry(String industry) {
  	this.industry.add(industry);
  }
  
  /**
   * Adds a jobLocation property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param jobLocation The value to add.
   */
  public void addJobLocation(Place jobLocation) {
  	this.jobLocation.add(jobLocation);
  }
  
  /**
   * Adds a name property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a occupationalCategory property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param occupationalCategory The value to add.
   */
  public void addOccupationalCategory(String occupationalCategory) {
  	this.occupationalCategory.add(occupationalCategory);
  }
  
  /**
   * Adds a qualifications property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param qualifications The value to add.
   */
  public void addQualifications(String qualifications) {
  	this.qualifications.add(qualifications);
  }
  
  /**
   * Adds a responsibilities property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param responsibilities The value to add.
   */
  public void addResponsibilities(String responsibilities) {
  	this.responsibilities.add(responsibilities);
  }
  
  /**
   * Adds a salaryCurrency property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param salaryCurrency The value to add.
   */
  public void addSalaryCurrency(String salaryCurrency) {
  	this.salaryCurrency.add(salaryCurrency);
  }
  
  /**
   * Adds a sameAs property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a skills property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param skills The value to add.
   */
  public void addSkills(String skills) {
  	this.skills.add(skills);
  }
  
  /**
   * Adds a specialCommitments property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param specialCommitments The value to add.
   */
  public void addSpecialCommitments(String specialCommitments) {
  	this.specialCommitments.add(specialCommitments);
  }
  
  /**
   * Adds a title property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param title The value to add.
   */
  public void addTitle(String title) {
  	this.title.add(title);
  }
  
  /**
   * Adds a url property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a workHours property value for this JobPosting object; appending it to the list of existing values.
   *
   * @param workHours The value to add.
   */
  public void addWorkHours(String workHours) {
  	this.workHours.add(workHours);
  }
  
}