package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.LodgingReservation;
import org.schema.ProgramMembership;
import org.schema.ReservationStatusType;
import org.schema.Thing;
import org.schema.Ticket;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A reservation for lodging at a hotel, motel, inn, etc.Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations.
 */
public class LodgingReservationImpl extends SchemaObjectImpl implements LodgingReservation {


  private ReservationImpl reservation;
  private ThingImpl thing;

  /**
   * The earliest someone may check into a lodging establishment.
   */
  private List<Date> checkinTime = new LinkedList<Date>();
  
  /**
   * The latest someone may check out of a lodging establishment.
   */
  private List<Date> checkoutTime = new LinkedList<Date>();
  
  /**
   * A full description of the lodging unit.
   */
  private List<String> lodgingUnitDescription = new LinkedList<String>();
  
  /**
   * Textual description of the unit type (including suite vs. room, size of bed, etc.).
   */
  private List<Thing> lodgingUnitType = new LinkedList<Thing>();
  
  /**
   * The number of adults staying in the unit.
   */
  private List<Thing> numAdults = new LinkedList<Thing>();
  
  /**
   * The number of children staying in the unit.
   */
  private List<Thing> numChildren = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public LodgingReservationImpl() {
    super("http://schema.org/LodgingReservation");
    reservation = new ReservationImpl();
  }
  /**
   * Get a single additionalType property value for this LodgingReservation object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this LodgingReservation object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single bookingAgent property value for this LodgingReservation object.
   *
   * @return The first bookingAgent property value.
   */
  public Thing getBookingAgent() {
    return reservation.getBookingAgent();
  }
  
  /**
   * Get a single bookingTime property value for this LodgingReservation object.
   *
   * @return The first bookingTime property value.
   */
  public Date getBookingTime() {
    return reservation.getBookingTime();
  }
  
  /**
   * Get a single checkinTime property value for this LodgingReservation object.
   *
   * @return The first checkinTime property value.
   */
  public Date getCheckinTime() {
  	return this.checkinTime.isEmpty() ? null : this.checkinTime.get(0);
  }
  
  /**
   * Get a single checkoutTime property value for this LodgingReservation object.
   *
   * @return The first checkoutTime property value.
   */
  public Date getCheckoutTime() {
  	return this.checkoutTime.isEmpty() ? null : this.checkoutTime.get(0);
  }
  
  /**
   * Get a single description property value for this LodgingReservation object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this LodgingReservation object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single lodgingUnitDescription property value for this LodgingReservation object.
   *
   * @return The first lodgingUnitDescription property value.
   */
  public String getLodgingUnitDescription() {
  	return this.lodgingUnitDescription.isEmpty() ? null : this.lodgingUnitDescription.get(0);
  }
  
  /**
   * Get a single lodgingUnitType property value for this LodgingReservation object.
   *
   * @return The first lodgingUnitType property value.
   */
  public Thing getLodgingUnitType() {
  	return this.lodgingUnitType.isEmpty() ? null : this.lodgingUnitType.get(0);
  }
  
  /**
   * Get a single modifiedTime property value for this LodgingReservation object.
   *
   * @return The first modifiedTime property value.
   */
  public Date getModifiedTime() {
    return reservation.getModifiedTime();
  }
  
  /**
   * Get a single name property value for this LodgingReservation object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single numAdults property value for this LodgingReservation object.
   *
   * @return The first numAdults property value.
   */
  public Thing getNumAdults() {
  	return this.numAdults.isEmpty() ? null : this.numAdults.get(0);
  }
  
  /**
   * Get a single numChildren property value for this LodgingReservation object.
   *
   * @return The first numChildren property value.
   */
  public Thing getNumChildren() {
  	return this.numChildren.isEmpty() ? null : this.numChildren.get(0);
  }
  
  /**
   * Get a single priceCurrency property value for this LodgingReservation object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency() {
    return reservation.getPriceCurrency();
  }
  
  /**
   * Get a single programMembershipUsed property value for this LodgingReservation object.
   *
   * @return The first programMembershipUsed property value.
   */
  public ProgramMembership getProgramMembershipUsed() {
    return reservation.getProgramMembershipUsed();
  }
  
  /**
   * Get a single provider property value for this LodgingReservation object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
    return reservation.getProvider();
  }
  
  /**
   * Get a single reservationFor property value for this LodgingReservation object.
   *
   * @return The first reservationFor property value.
   */
  public Thing getReservationFor() {
    return reservation.getReservationFor();
  }
  
  /**
   * Get a single reservationId property value for this LodgingReservation object.
   *
   * @return The first reservationId property value.
   */
  public String getReservationId() {
    return reservation.getReservationId();
  }
  
  /**
   * Get a single reservationStatus property value for this LodgingReservation object.
   *
   * @return The first reservationStatus property value.
   */
  public ReservationStatusType getReservationStatus() {
    return reservation.getReservationStatus();
  }
  
  /**
   * Get a single reservedTicket property value for this LodgingReservation object.
   *
   * @return The first reservedTicket property value.
   */
  public Ticket getReservedTicket() {
    return reservation.getReservedTicket();
  }
  
  /**
   * Get a single sameAs property value for this LodgingReservation object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single totalPrice property value for this LodgingReservation object.
   *
   * @return The first totalPrice property value.
   */
  public Thing getTotalPrice() {
    return reservation.getTotalPrice();
  }
  
  /**
   * Get a single underName property value for this LodgingReservation object.
   *
   * @return The first underName property value.
   */
  public Thing getUnderName() {
    return reservation.getUnderName();
  }
  
  /**
   * Get a single url property value for this LodgingReservation object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this LodgingReservation object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this LodgingReservation object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the bookingAgent property values for this LodgingReservation object.
   *
   * @return A list of bookingAgent property values.
   */
  public List<Thing> getBookingAgents() {
    return reservation.getBookingAgents();
  }
  
  /**
   * Get all the bookingTime property values for this LodgingReservation object.
   *
   * @return A list of bookingTime property values.
   */
  public List<Date> getBookingTimes() {
    return reservation.getBookingTimes();
  }
  
  /**
   * Get all the checkinTime property values for this LodgingReservation object.
   *
   * @return A list of checkinTime property values.
   */
  public List<Date> getCheckinTimes() {
  	return this.checkinTime;
  }
  
  /**
   * Get all the checkoutTime property values for this LodgingReservation object.
   *
   * @return A list of checkoutTime property values.
   */
  public List<Date> getCheckoutTimes() {
  	return this.checkoutTime;
  }
  
  /**
   * Get all the description property values for this LodgingReservation object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this LodgingReservation object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the lodgingUnitDescription property values for this LodgingReservation object.
   *
   * @return A list of lodgingUnitDescription property values.
   */
  public List<String> getLodgingUnitDescriptions() {
  	return this.lodgingUnitDescription;
  }
  
  /**
   * Get all the lodgingUnitType property values for this LodgingReservation object.
   *
   * @return A list of lodgingUnitType property values.
   */
  public List<Thing> getLodgingUnitTypes() {
  	return this.lodgingUnitType;
  }
  
  /**
   * Get all the modifiedTime property values for this LodgingReservation object.
   *
   * @return A list of modifiedTime property values.
   */
  public List<Date> getModifiedTimes() {
    return reservation.getModifiedTimes();
  }
  
  /**
   * Get all the name property values for this LodgingReservation object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the numAdults property values for this LodgingReservation object.
   *
   * @return A list of numAdults property values.
   */
  public List<Thing> getNumAdultss() {
  	return this.numAdults;
  }
  
  /**
   * Get all the numChildren property values for this LodgingReservation object.
   *
   * @return A list of numChildren property values.
   */
  public List<Thing> getNumChildrens() {
  	return this.numChildren;
  }
  
  /**
   * Get all the priceCurrency property values for this LodgingReservation object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies() {
    return reservation.getPriceCurrencies();
  }
  
  /**
   * Get all the programMembershipUsed property values for this LodgingReservation object.
   *
   * @return A list of programMembershipUsed property values.
   */
  public List<ProgramMembership> getProgramMembershipUseds() {
    return reservation.getProgramMembershipUseds();
  }
  
  /**
   * Get all the provider property values for this LodgingReservation object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
    return reservation.getProviders();
  }
  
  /**
   * Get all the reservationFor property values for this LodgingReservation object.
   *
   * @return A list of reservationFor property values.
   */
  public List<Thing> getReservationFors() {
    return reservation.getReservationFors();
  }
  
  /**
   * Get all the reservationId property values for this LodgingReservation object.
   *
   * @return A list of reservationId property values.
   */
  public List<String> getReservationIds() {
    return reservation.getReservationIds();
  }
  
  /**
   * Get all the reservationStatus property values for this LodgingReservation object.
   *
   * @return A list of reservationStatus property values.
   */
  public List<ReservationStatusType> getReservationStatuses() {
    return reservation.getReservationStatuses();
  }
  
  /**
   * Get all the reservedTicket property values for this LodgingReservation object.
   *
   * @return A list of reservedTicket property values.
   */
  public List<Ticket> getReservedTickets() {
    return reservation.getReservedTickets();
  }
  
  /**
   * Get all the sameAs property values for this LodgingReservation object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the totalPrice property values for this LodgingReservation object.
   *
   * @return A list of totalPrice property values.
   */
  public List<Thing> getTotalPrices() {
    return reservation.getTotalPrices();
  }
  
  /**
   * Get all the underName property values for this LodgingReservation object.
   *
   * @return A list of underName property values.
   */
  public List<Thing> getUnderNames() {
    return reservation.getUnderNames();
  }
  
  /**
   * Get all the url property values for this LodgingReservation object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the bookingAgent property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param bookingAgent The value to set.
   */
  public void setBookingAgent(Thing bookingAgent) {
    reservation.setBookingAgent(bookingAgent);
  }
  
  /**
   * Set the bookingTime property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param bookingTime The value to set.
   */
  public void setBookingTime(Date bookingTime) {
    reservation.setBookingTime(bookingTime);
  }
  
  /**
   * Set the checkinTime property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkinTime The value to set.
   */
  public void setCheckinTime(Date checkinTime) {
  	this.checkinTime.clear();
  	this.checkinTime.add(checkinTime);
  }
  
  /**
   * Set the checkoutTime property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkoutTime The value to set.
   */
  public void setCheckoutTime(Date checkoutTime) {
  	this.checkoutTime.clear();
  	this.checkoutTime.add(checkoutTime);
  }
  
  /**
   * Set the description property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the lodgingUnitDescription property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitDescription The value to set.
   */
  public void setLodgingUnitDescription(String lodgingUnitDescription) {
  	this.lodgingUnitDescription.clear();
  	this.lodgingUnitDescription.add(lodgingUnitDescription);
  }
  
  /**
   * Set the lodgingUnitType property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitType The value to set.
   */
  public void setLodgingUnitType(Thing lodgingUnitType) {
  	this.lodgingUnitType.clear();
  	this.lodgingUnitType.add(lodgingUnitType);
  }
  
  /**
   * Set the modifiedTime property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param modifiedTime The value to set.
   */
  public void setModifiedTime(Date modifiedTime) {
    reservation.setModifiedTime(modifiedTime);
  }
  
  /**
   * Set the name property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the numAdults property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param numAdults The value to set.
   */
  public void setNumAdults(Thing numAdults) {
  	this.numAdults.clear();
  	this.numAdults.add(numAdults);
  }
  
  /**
   * Set the numChildren property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param numChildren The value to set.
   */
  public void setNumChildren(Thing numChildren) {
  	this.numChildren.clear();
  	this.numChildren.add(numChildren);
  }
  
  /**
   * Set the priceCurrency property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency) {
    reservation.setPriceCurrency(priceCurrency);
  }
  
  /**
   * Set the programMembershipUsed property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param programMembershipUsed The value to set.
   */
  public void setProgramMembershipUsed(ProgramMembership programMembershipUsed) {
    reservation.setProgramMembershipUsed(programMembershipUsed);
  }
  
  /**
   * Set the provider property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
    reservation.setProvider(provider);
  }
  
  /**
   * Set the reservationFor property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservationFor The value to set.
   */
  public void setReservationFor(Thing reservationFor) {
    reservation.setReservationFor(reservationFor);
  }
  
  /**
   * Set the reservationId property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservationId The value to set.
   */
  public void setReservationId(String reservationId) {
    reservation.setReservationId(reservationId);
  }
  
  /**
   * Set the reservationStatus property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservationStatus The value to set.
   */
  public void setReservationStatus(ReservationStatusType reservationStatus) {
    reservation.setReservationStatus(reservationStatus);
  }
  
  /**
   * Set the reservedTicket property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservedTicket The value to set.
   */
  public void setReservedTicket(Ticket reservedTicket) {
    reservation.setReservedTicket(reservedTicket);
  }
  
  /**
   * Set the sameAs property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the totalPrice property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param totalPrice The value to set.
   */
  public void setTotalPrice(Thing totalPrice) {
    reservation.setTotalPrice(totalPrice);
  }
  
  /**
   * Set the underName property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param underName The value to set.
   */
  public void setUnderName(Thing underName) {
    reservation.setUnderName(underName);
  }
  
  /**
   * Set the url property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the bookingAgent property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param bookingAgents The list of values to set.
   */
  public void setBookingAgents(List<Thing> bookingAgents) {
    reservation.setBookingAgents(bookingAgents);
  }
  
  /**
   * Set the bookingTime property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param bookingTimes The list of values to set.
   */
  public void setBookingTimes(List<Date> bookingTimes) {
    reservation.setBookingTimes(bookingTimes);
  }
  
  /**
   * Set the checkinTime property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkinTimes The list of values to set.
   */
  public void setCheckinTimes(List<Date> checkinTimes) {
  	this.checkinTime = checkinTimes;
  }
  
  /**
   * Set the checkoutTime property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkoutTimes The list of values to set.
   */
  public void setCheckoutTimes(List<Date> checkoutTimes) {
  	this.checkoutTime = checkoutTimes;
  }
  
  /**
   * Set the description property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the lodgingUnitDescription property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitDescriptions The list of values to set.
   */
  public void setLodgingUnitDescriptions(List<String> lodgingUnitDescriptions) {
  	this.lodgingUnitDescription = lodgingUnitDescriptions;
  }
  
  /**
   * Set the lodgingUnitType property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitTypes The list of values to set.
   */
  public void setLodgingUnitTypes(List<Thing> lodgingUnitTypes) {
  	this.lodgingUnitType = lodgingUnitTypes;
  }
  
  /**
   * Set the modifiedTime property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param modifiedTimes The list of values to set.
   */
  public void setModifiedTimes(List<Date> modifiedTimes) {
    reservation.setModifiedTimes(modifiedTimes);
  }
  
  /**
   * Set the name property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the numAdults property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param numAdultss The list of values to set.
   */
  public void setNumAdultss(List<Thing> numAdultss) {
  	this.numAdults = numAdultss;
  }
  
  /**
   * Set the numChildren property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param numChildrens The list of values to set.
   */
  public void setNumChildrens(List<Thing> numChildrens) {
  	this.numChildren = numChildrens;
  }
  
  /**
   * Set the priceCurrency property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies) {
    reservation.setPriceCurrencies(priceCurrencies);
  }
  
  /**
   * Set the programMembershipUsed property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param programMembershipUseds The list of values to set.
   */
  public void setProgramMembershipUseds(List<ProgramMembership> programMembershipUseds) {
    reservation.setProgramMembershipUseds(programMembershipUseds);
  }
  
  /**
   * Set the provider property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
    reservation.setProviders(providers);
  }
  
  /**
   * Set the reservationFor property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservationFors The list of values to set.
   */
  public void setReservationFors(List<Thing> reservationFors) {
    reservation.setReservationFors(reservationFors);
  }
  
  /**
   * Set the reservationId property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservationIds The list of values to set.
   */
  public void setReservationIds(List<String> reservationIds) {
    reservation.setReservationIds(reservationIds);
  }
  
  /**
   * Set the reservationStatus property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservationStatuses The list of values to set.
   */
  public void setReservationStatuses(List<ReservationStatusType> reservationStatuses) {
    reservation.setReservationStatuses(reservationStatuses);
  }
  
  /**
   * Set the reservedTicket property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param reservedTickets The list of values to set.
   */
  public void setReservedTickets(List<Ticket> reservedTickets) {
    reservation.setReservedTickets(reservedTickets);
  }
  
  /**
   * Set the sameAs property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the totalPrice property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param totalPrices The list of values to set.
   */
  public void setTotalPrices(List<Thing> totalPrices) {
    reservation.setTotalPrices(totalPrices);
  }
  
  /**
   * Set the underName property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param underNames The list of values to set.
   */
  public void setUnderNames(List<Thing> underNames) {
    reservation.setUnderNames(underNames);
  }
  
  /**
   * Set the url property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a bookingAgent property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param bookingAgent The value to add.
   */
  public void addBookingAgent(Thing bookingAgent) {
    reservation.addBookingAgent(bookingAgent);
  }
  
  /**
   * Adds a bookingTime property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param bookingTime The value to add.
   */
  public void addBookingTime(Date bookingTime) {
    reservation.addBookingTime(bookingTime);
  }
  
  /**
   * Adds a checkinTime property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param checkinTime The value to add.
   */
  public void addCheckinTime(Date checkinTime) {
  	this.checkinTime.add(checkinTime);
  }
  
  /**
   * Adds a checkoutTime property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param checkoutTime The value to add.
   */
  public void addCheckoutTime(Date checkoutTime) {
  	this.checkoutTime.add(checkoutTime);
  }
  
  /**
   * Adds a description property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a lodgingUnitDescription property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param lodgingUnitDescription The value to add.
   */
  public void addLodgingUnitDescription(String lodgingUnitDescription) {
  	this.lodgingUnitDescription.add(lodgingUnitDescription);
  }
  
  /**
   * Adds a lodgingUnitType property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param lodgingUnitType The value to add.
   */
  public void addLodgingUnitType(Thing lodgingUnitType) {
  	this.lodgingUnitType.add(lodgingUnitType);
  }
  
  /**
   * Adds a modifiedTime property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param modifiedTime The value to add.
   */
  public void addModifiedTime(Date modifiedTime) {
    reservation.addModifiedTime(modifiedTime);
  }
  
  /**
   * Adds a name property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a numAdults property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param numAdults The value to add.
   */
  public void addNumAdults(Thing numAdults) {
  	this.numAdults.add(numAdults);
  }
  
  /**
   * Adds a numChildren property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param numChildren The value to add.
   */
  public void addNumChildren(Thing numChildren) {
  	this.numChildren.add(numChildren);
  }
  
  /**
   * Adds a priceCurrency property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency) {
    reservation.addPriceCurrency(priceCurrency);
  }
  
  /**
   * Adds a programMembershipUsed property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param programMembershipUsed The value to add.
   */
  public void addProgramMembershipUsed(ProgramMembership programMembershipUsed) {
    reservation.addProgramMembershipUsed(programMembershipUsed);
  }
  
  /**
   * Adds a provider property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
    reservation.addProvider(provider);
  }
  
  /**
   * Adds a reservationFor property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param reservationFor The value to add.
   */
  public void addReservationFor(Thing reservationFor) {
    reservation.addReservationFor(reservationFor);
  }
  
  /**
   * Adds a reservationId property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param reservationId The value to add.
   */
  public void addReservationId(String reservationId) {
    reservation.addReservationId(reservationId);
  }
  
  /**
   * Adds a reservationStatus property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param reservationStatus The value to add.
   */
  public void addReservationStatus(ReservationStatusType reservationStatus) {
    reservation.addReservationStatus(reservationStatus);
  }
  
  /**
   * Adds a reservedTicket property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param reservedTicket The value to add.
   */
  public void addReservedTicket(Ticket reservedTicket) {
    reservation.addReservedTicket(reservedTicket);
  }
  
  /**
   * Adds a sameAs property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a totalPrice property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param totalPrice The value to add.
   */
  public void addTotalPrice(Thing totalPrice) {
    reservation.addTotalPrice(totalPrice);
  }
  
  /**
   * Adds a underName property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param underName The value to add.
   */
  public void addUnderName(Thing underName) {
    reservation.addUnderName(underName);
  }
  
  /**
   * Adds a url property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}