package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.MaximumDoseSchedule;
import org.schema.MedicalCode;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Number;
import org.schema.Organization;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The maximum dosing schedule considered safe for a drug or supplement as recommended by an authority or by the drug/supplement's manufacturer. Capture the recommending authority in the recognizingAuthority property of MedicalEntity.
 */
public class MaximumDoseScheduleImpl extends SchemaObjectImpl implements MaximumDoseSchedule {


  private DoseScheduleImpl doseSchedule;
  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MaximumDoseScheduleImpl() {
    super("http://schema.org/MaximumDoseSchedule");
    doseSchedule = new DoseScheduleImpl();
  }
  /**
   * Get a single additionalType property value for this MaximumDoseSchedule object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this MaximumDoseSchedule object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single code property value for this MaximumDoseSchedule object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this MaximumDoseSchedule object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single doseUnit property value for this MaximumDoseSchedule object.
   *
   * @return The first doseUnit property value.
   */
  public String getDoseUnit() {
    return doseSchedule.getDoseUnit();
  }
  
  /**
   * Get a single doseValue property value for this MaximumDoseSchedule object.
   *
   * @return The first doseValue property value.
   */
  public Number getDoseValue() {
    return doseSchedule.getDoseValue();
  }
  
  /**
   * Get a single frequency property value for this MaximumDoseSchedule object.
   *
   * @return The first frequency property value.
   */
  public String getFrequency() {
    return doseSchedule.getFrequency();
  }
  
  /**
   * Get a single guideline property value for this MaximumDoseSchedule object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this MaximumDoseSchedule object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this MaximumDoseSchedule object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this MaximumDoseSchedule object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single recognizingAuthority property value for this MaximumDoseSchedule object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this MaximumDoseSchedule object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this MaximumDoseSchedule object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this MaximumDoseSchedule object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single targetPopulation property value for this MaximumDoseSchedule object.
   *
   * @return The first targetPopulation property value.
   */
  public String getTargetPopulation() {
    return doseSchedule.getTargetPopulation();
  }
  
  /**
   * Get a single url property value for this MaximumDoseSchedule object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MaximumDoseSchedule object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this MaximumDoseSchedule object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the code property values for this MaximumDoseSchedule object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this MaximumDoseSchedule object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the doseUnit property values for this MaximumDoseSchedule object.
   *
   * @return A list of doseUnit property values.
   */
  public List<String> getDoseUnits() {
    return doseSchedule.getDoseUnits();
  }
  
  /**
   * Get all the doseValue property values for this MaximumDoseSchedule object.
   *
   * @return A list of doseValue property values.
   */
  public List<Number> getDoseValues() {
    return doseSchedule.getDoseValues();
  }
  
  /**
   * Get all the frequency property values for this MaximumDoseSchedule object.
   *
   * @return A list of frequency property values.
   */
  public List<String> getFrequencies() {
    return doseSchedule.getFrequencies();
  }
  
  /**
   * Get all the guideline property values for this MaximumDoseSchedule object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this MaximumDoseSchedule object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this MaximumDoseSchedule object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this MaximumDoseSchedule object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the recognizingAuthority property values for this MaximumDoseSchedule object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this MaximumDoseSchedule object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this MaximumDoseSchedule object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this MaximumDoseSchedule object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the targetPopulation property values for this MaximumDoseSchedule object.
   *
   * @return A list of targetPopulation property values.
   */
  public List<String> getTargetPopulations() {
    return doseSchedule.getTargetPopulations();
  }
  
  /**
   * Get all the url property values for this MaximumDoseSchedule object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the code property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the doseUnit property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param doseUnit The value to set.
   */
  public void setDoseUnit(String doseUnit) {
    doseSchedule.setDoseUnit(doseUnit);
  }
  
  /**
   * Set the doseValue property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param doseValue The value to set.
   */
  public void setDoseValue(Number doseValue) {
    doseSchedule.setDoseValue(doseValue);
  }
  
  /**
   * Set the frequency property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param frequency The value to set.
   */
  public void setFrequency(String frequency) {
    doseSchedule.setFrequency(frequency);
  }
  
  /**
   * Set the guideline property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the recognizingAuthority property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the targetPopulation property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param targetPopulation The value to set.
   */
  public void setTargetPopulation(String targetPopulation) {
    doseSchedule.setTargetPopulation(targetPopulation);
  }
  
  /**
   * Set the url property value for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the code property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the doseUnit property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param doseUnits The list of values to set.
   */
  public void setDoseUnits(List<String> doseUnits) {
    doseSchedule.setDoseUnits(doseUnits);
  }
  
  /**
   * Set the doseValue property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param doseValues The list of values to set.
   */
  public void setDoseValues(List<Number> doseValues) {
    doseSchedule.setDoseValues(doseValues);
  }
  
  /**
   * Set the frequency property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param frequencies The list of values to set.
   */
  public void setFrequencies(List<String> frequencies) {
    doseSchedule.setFrequencies(frequencies);
  }
  
  /**
   * Set the guideline property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the recognizingAuthority property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the targetPopulation property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param targetPopulations The list of values to set.
   */
  public void setTargetPopulations(List<String> targetPopulations) {
    doseSchedule.setTargetPopulations(targetPopulations);
  }
  
  /**
   * Set the url property values for this MaximumDoseSchedule object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a code property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a doseUnit property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param doseUnit The value to add.
   */
  public void addDoseUnit(String doseUnit) {
    doseSchedule.addDoseUnit(doseUnit);
  }
  
  /**
   * Adds a doseValue property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param doseValue The value to add.
   */
  public void addDoseValue(Number doseValue) {
    doseSchedule.addDoseValue(doseValue);
  }
  
  /**
   * Adds a frequency property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param frequency The value to add.
   */
  public void addFrequency(String frequency) {
    doseSchedule.addFrequency(frequency);
  }
  
  /**
   * Adds a guideline property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a targetPopulation property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param targetPopulation The value to add.
   */
  public void addTargetPopulation(String targetPopulation) {
    doseSchedule.addTargetPopulation(targetPopulation);
  }
  
  /**
   * Adds a url property value for this MaximumDoseSchedule object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}