package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.DDxElement;
import org.schema.MedicalCause;
import org.schema.MedicalCode;
import org.schema.MedicalCondition;
import org.schema.MedicalConditionStage;
import org.schema.MedicalGuideline;
import org.schema.MedicalRiskFactor;
import org.schema.MedicalSignOrSymptom;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTest;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc.
 */
public class MedicalConditionImpl extends SchemaObjectImpl implements MedicalCondition {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * The anatomy of the underlying organ system or structures associated with this entity.
   */
  private List<Thing> associatedAnatomy = new LinkedList<Thing>();
  
  /**
   * An underlying cause. More specifically, one of the causative agent(s) that are most directly responsible for the pathophysiologic process that eventually results in the occurrence.
   */
  private List<MedicalCause> cause = new LinkedList<MedicalCause>();
  
  /**
   * One of a set of differential diagnoses for the condition. Specifically, a closely-related or competing diagnosis typically considered later in the cognitive process whereby this medical condition is distinguished from others most likely responsible for a similar collection of signs and symptoms to reach the most parsimonious diagnosis or diagnoses in a patient.
   */
  private List<DDxElement> differentialDiagnosis = new LinkedList<DDxElement>();
  
  /**
   * The characteristics of associated patients, such as age, gender, race etc.
   */
  private List<String> epidemiology = new LinkedList<String>();
  
  /**
   * The likely outcome in either the short term or long term of the medical condition.
   */
  private List<String> expectedPrognosis = new LinkedList<String>();
  
  /**
   * The expected progression of the condition if it is not treated and allowed to progress naturally.
   */
  private List<String> naturalProgression = new LinkedList<String>();
  
  /**
   * Changes in the normal mechanical, physical, and biochemical functions that are associated with this activity or condition.
   */
  private List<String> pathophysiology = new LinkedList<String>();
  
  /**
   * A possible unexpected and unfavorable evolution of a medical condition. Complications may include worsening of the signs or symptoms of the disease, extension of the condition to other organ systems, etc.
   */
  private List<String> possibleComplication = new LinkedList<String>();
  
  /**
   * A possible treatment to address this condition, sign or symptom.
   */
  private List<MedicalTherapy> possibleTreatment = new LinkedList<MedicalTherapy>();
  
  /**
   * A preventative therapy used to prevent an initial occurrence of the medical condition, such as vaccination.
   */
  private List<MedicalTherapy> primaryPrevention = new LinkedList<MedicalTherapy>();
  
  /**
   * A modifiable or non-modifiable factor that increases the risk of a patient contracting this condition, e.g. age,  coexisting condition.
   */
  private List<MedicalRiskFactor> riskFactor = new LinkedList<MedicalRiskFactor>();
  
  /**
   * A preventative therapy used to prevent reoccurrence of the medical condition after an initial episode of the condition.
   */
  private List<MedicalTherapy> secondaryPrevention = new LinkedList<MedicalTherapy>();
  
  /**
   * A sign or symptom of this condition. Signs are objective or physically observable manifestations of the medical condition while symptoms are the subjective experienceof the medical condition.
   */
  private List<MedicalSignOrSymptom> signOrSymptom = new LinkedList<MedicalSignOrSymptom>();
  
  /**
   * The stage of the condition, if applicable.
   */
  private List<MedicalConditionStage> stage = new LinkedList<MedicalConditionStage>();
  
  /**
   * A more specific type of the condition, where applicable, for example 'Type 1 Diabetes', 'Type 2 Diabetes', or 'Gestational Diabetes' for Diabetes.
   */
  private List<String> subtype = new LinkedList<String>();
  
  /**
   * A medical test typically performed given this condition.
   */
  private List<MedicalTest> typicalTest = new LinkedList<MedicalTest>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MedicalConditionImpl() {
    super("http://schema.org/MedicalCondition");
    medicalEntity = new MedicalEntityImpl();
  }
  /**
   * Get a single additionalType property value for this MedicalCondition object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this MedicalCondition object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single associatedAnatomy property value for this MedicalCondition object.
   *
   * @return The first associatedAnatomy property value.
   */
  public Thing getAssociatedAnatomy() {
  	return this.associatedAnatomy.isEmpty() ? null : this.associatedAnatomy.get(0);
  }
  
  /**
   * Get a single cause property value for this MedicalCondition object.
   *
   * @return The first cause property value.
   */
  public MedicalCause getCause() {
  	return this.cause.isEmpty() ? null : this.cause.get(0);
  }
  
  /**
   * Get a single code property value for this MedicalCondition object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this MedicalCondition object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single differentialDiagnosis property value for this MedicalCondition object.
   *
   * @return The first differentialDiagnosis property value.
   */
  public DDxElement getDifferentialDiagnosis() {
  	return this.differentialDiagnosis.isEmpty() ? null : this.differentialDiagnosis.get(0);
  }
  
  /**
   * Get a single epidemiology property value for this MedicalCondition object.
   *
   * @return The first epidemiology property value.
   */
  public String getEpidemiology() {
  	return this.epidemiology.isEmpty() ? null : this.epidemiology.get(0);
  }
  
  /**
   * Get a single expectedPrognosis property value for this MedicalCondition object.
   *
   * @return The first expectedPrognosis property value.
   */
  public String getExpectedPrognosis() {
  	return this.expectedPrognosis.isEmpty() ? null : this.expectedPrognosis.get(0);
  }
  
  /**
   * Get a single guideline property value for this MedicalCondition object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this MedicalCondition object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this MedicalCondition object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this MedicalCondition object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single naturalProgression property value for this MedicalCondition object.
   *
   * @return The first naturalProgression property value.
   */
  public String getNaturalProgression() {
  	return this.naturalProgression.isEmpty() ? null : this.naturalProgression.get(0);
  }
  
  /**
   * Get a single pathophysiology property value for this MedicalCondition object.
   *
   * @return The first pathophysiology property value.
   */
  public String getPathophysiology() {
  	return this.pathophysiology.isEmpty() ? null : this.pathophysiology.get(0);
  }
  
  /**
   * Get a single possibleComplication property value for this MedicalCondition object.
   *
   * @return The first possibleComplication property value.
   */
  public String getPossibleComplication() {
  	return this.possibleComplication.isEmpty() ? null : this.possibleComplication.get(0);
  }
  
  /**
   * Get a single possibleTreatment property value for this MedicalCondition object.
   *
   * @return The first possibleTreatment property value.
   */
  public MedicalTherapy getPossibleTreatment() {
  	return this.possibleTreatment.isEmpty() ? null : this.possibleTreatment.get(0);
  }
  
  /**
   * Get a single primaryPrevention property value for this MedicalCondition object.
   *
   * @return The first primaryPrevention property value.
   */
  public MedicalTherapy getPrimaryPrevention() {
  	return this.primaryPrevention.isEmpty() ? null : this.primaryPrevention.get(0);
  }
  
  /**
   * Get a single recognizingAuthority property value for this MedicalCondition object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this MedicalCondition object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single riskFactor property value for this MedicalCondition object.
   *
   * @return The first riskFactor property value.
   */
  public MedicalRiskFactor getRiskFactor() {
  	return this.riskFactor.isEmpty() ? null : this.riskFactor.get(0);
  }
  
  /**
   * Get a single sameAs property value for this MedicalCondition object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single secondaryPrevention property value for this MedicalCondition object.
   *
   * @return The first secondaryPrevention property value.
   */
  public MedicalTherapy getSecondaryPrevention() {
  	return this.secondaryPrevention.isEmpty() ? null : this.secondaryPrevention.get(0);
  }
  
  /**
   * Get a single signOrSymptom property value for this MedicalCondition object.
   *
   * @return The first signOrSymptom property value.
   */
  public MedicalSignOrSymptom getSignOrSymptom() {
  	return this.signOrSymptom.isEmpty() ? null : this.signOrSymptom.get(0);
  }
  
  /**
   * Get a single stage property value for this MedicalCondition object.
   *
   * @return The first stage property value.
   */
  public MedicalConditionStage getStage() {
  	return this.stage.isEmpty() ? null : this.stage.get(0);
  }
  
  /**
   * Get a single study property value for this MedicalCondition object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single subtype property value for this MedicalCondition object.
   *
   * @return The first subtype property value.
   */
  public String getSubtype() {
  	return this.subtype.isEmpty() ? null : this.subtype.get(0);
  }
  
  /**
   * Get a single typicalTest property value for this MedicalCondition object.
   *
   * @return The first typicalTest property value.
   */
  public MedicalTest getTypicalTest() {
  	return this.typicalTest.isEmpty() ? null : this.typicalTest.get(0);
  }
  
  /**
   * Get a single url property value for this MedicalCondition object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MedicalCondition object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this MedicalCondition object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the associatedAnatomy property values for this MedicalCondition object.
   *
   * @return A list of associatedAnatomy property values.
   */
  public List<Thing> getAssociatedAnatomies() {
  	return this.associatedAnatomy;
  }
  
  /**
   * Get all the cause property values for this MedicalCondition object.
   *
   * @return A list of cause property values.
   */
  public List<MedicalCause> getCauses() {
  	return this.cause;
  }
  
  /**
   * Get all the code property values for this MedicalCondition object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this MedicalCondition object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the differentialDiagnosis property values for this MedicalCondition object.
   *
   * @return A list of differentialDiagnosis property values.
   */
  public List<DDxElement> getDifferentialDiagnoses() {
  	return this.differentialDiagnosis;
  }
  
  /**
   * Get all the epidemiology property values for this MedicalCondition object.
   *
   * @return A list of epidemiology property values.
   */
  public List<String> getEpidemiologies() {
  	return this.epidemiology;
  }
  
  /**
   * Get all the expectedPrognosis property values for this MedicalCondition object.
   *
   * @return A list of expectedPrognosis property values.
   */
  public List<String> getExpectedPrognoses() {
  	return this.expectedPrognosis;
  }
  
  /**
   * Get all the guideline property values for this MedicalCondition object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this MedicalCondition object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this MedicalCondition object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this MedicalCondition object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the naturalProgression property values for this MedicalCondition object.
   *
   * @return A list of naturalProgression property values.
   */
  public List<String> getNaturalProgressions() {
  	return this.naturalProgression;
  }
  
  /**
   * Get all the pathophysiology property values for this MedicalCondition object.
   *
   * @return A list of pathophysiology property values.
   */
  public List<String> getPathophysiologies() {
  	return this.pathophysiology;
  }
  
  /**
   * Get all the possibleComplication property values for this MedicalCondition object.
   *
   * @return A list of possibleComplication property values.
   */
  public List<String> getPossibleComplications() {
  	return this.possibleComplication;
  }
  
  /**
   * Get all the possibleTreatment property values for this MedicalCondition object.
   *
   * @return A list of possibleTreatment property values.
   */
  public List<MedicalTherapy> getPossibleTreatments() {
  	return this.possibleTreatment;
  }
  
  /**
   * Get all the primaryPrevention property values for this MedicalCondition object.
   *
   * @return A list of primaryPrevention property values.
   */
  public List<MedicalTherapy> getPrimaryPreventions() {
  	return this.primaryPrevention;
  }
  
  /**
   * Get all the recognizingAuthority property values for this MedicalCondition object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this MedicalCondition object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the riskFactor property values for this MedicalCondition object.
   *
   * @return A list of riskFactor property values.
   */
  public List<MedicalRiskFactor> getRiskFactors() {
  	return this.riskFactor;
  }
  
  /**
   * Get all the sameAs property values for this MedicalCondition object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the secondaryPrevention property values for this MedicalCondition object.
   *
   * @return A list of secondaryPrevention property values.
   */
  public List<MedicalTherapy> getSecondaryPreventions() {
  	return this.secondaryPrevention;
  }
  
  /**
   * Get all the signOrSymptom property values for this MedicalCondition object.
   *
   * @return A list of signOrSymptom property values.
   */
  public List<MedicalSignOrSymptom> getSignOrSymptoms() {
  	return this.signOrSymptom;
  }
  
  /**
   * Get all the stage property values for this MedicalCondition object.
   *
   * @return A list of stage property values.
   */
  public List<MedicalConditionStage> getStages() {
  	return this.stage;
  }
  
  /**
   * Get all the study property values for this MedicalCondition object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the subtype property values for this MedicalCondition object.
   *
   * @return A list of subtype property values.
   */
  public List<String> getSubtypes() {
  	return this.subtype;
  }
  
  /**
   * Get all the typicalTest property values for this MedicalCondition object.
   *
   * @return A list of typicalTest property values.
   */
  public List<MedicalTest> getTypicalTests() {
  	return this.typicalTest;
  }
  
  /**
   * Get all the url property values for this MedicalCondition object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the associatedAnatomy property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param associatedAnatomy The value to set.
   */
  public void setAssociatedAnatomy(Thing associatedAnatomy) {
  	this.associatedAnatomy.clear();
  	this.associatedAnatomy.add(associatedAnatomy);
  }
  
  /**
   * Set the cause property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param cause The value to set.
   */
  public void setCause(MedicalCause cause) {
  	this.cause.clear();
  	this.cause.add(cause);
  }
  
  /**
   * Set the code property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the differentialDiagnosis property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param differentialDiagnosis The value to set.
   */
  public void setDifferentialDiagnosis(DDxElement differentialDiagnosis) {
  	this.differentialDiagnosis.clear();
  	this.differentialDiagnosis.add(differentialDiagnosis);
  }
  
  /**
   * Set the epidemiology property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param epidemiology The value to set.
   */
  public void setEpidemiology(String epidemiology) {
  	this.epidemiology.clear();
  	this.epidemiology.add(epidemiology);
  }
  
  /**
   * Set the expectedPrognosis property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param expectedPrognosis The value to set.
   */
  public void setExpectedPrognosis(String expectedPrognosis) {
  	this.expectedPrognosis.clear();
  	this.expectedPrognosis.add(expectedPrognosis);
  }
  
  /**
   * Set the guideline property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the naturalProgression property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param naturalProgression The value to set.
   */
  public void setNaturalProgression(String naturalProgression) {
  	this.naturalProgression.clear();
  	this.naturalProgression.add(naturalProgression);
  }
  
  /**
   * Set the pathophysiology property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param pathophysiology The value to set.
   */
  public void setPathophysiology(String pathophysiology) {
  	this.pathophysiology.clear();
  	this.pathophysiology.add(pathophysiology);
  }
  
  /**
   * Set the possibleComplication property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleComplication The value to set.
   */
  public void setPossibleComplication(String possibleComplication) {
  	this.possibleComplication.clear();
  	this.possibleComplication.add(possibleComplication);
  }
  
  /**
   * Set the possibleTreatment property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleTreatment The value to set.
   */
  public void setPossibleTreatment(MedicalTherapy possibleTreatment) {
  	this.possibleTreatment.clear();
  	this.possibleTreatment.add(possibleTreatment);
  }
  
  /**
   * Set the primaryPrevention property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param primaryPrevention The value to set.
   */
  public void setPrimaryPrevention(MedicalTherapy primaryPrevention) {
  	this.primaryPrevention.clear();
  	this.primaryPrevention.add(primaryPrevention);
  }
  
  /**
   * Set the recognizingAuthority property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the riskFactor property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param riskFactor The value to set.
   */
  public void setRiskFactor(MedicalRiskFactor riskFactor) {
  	this.riskFactor.clear();
  	this.riskFactor.add(riskFactor);
  }
  
  /**
   * Set the sameAs property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the secondaryPrevention property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param secondaryPrevention The value to set.
   */
  public void setSecondaryPrevention(MedicalTherapy secondaryPrevention) {
  	this.secondaryPrevention.clear();
  	this.secondaryPrevention.add(secondaryPrevention);
  }
  
  /**
   * Set the signOrSymptom property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param signOrSymptom The value to set.
   */
  public void setSignOrSymptom(MedicalSignOrSymptom signOrSymptom) {
  	this.signOrSymptom.clear();
  	this.signOrSymptom.add(signOrSymptom);
  }
  
  /**
   * Set the stage property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param stage The value to set.
   */
  public void setStage(MedicalConditionStage stage) {
  	this.stage.clear();
  	this.stage.add(stage);
  }
  
  /**
   * Set the study property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the subtype property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param subtype The value to set.
   */
  public void setSubtype(String subtype) {
  	this.subtype.clear();
  	this.subtype.add(subtype);
  }
  
  /**
   * Set the typicalTest property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param typicalTest The value to set.
   */
  public void setTypicalTest(MedicalTest typicalTest) {
  	this.typicalTest.clear();
  	this.typicalTest.add(typicalTest);
  }
  
  /**
   * Set the url property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the associatedAnatomy property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param associatedAnatomies The list of values to set.
   */
  public void setAssociatedAnatomies(List<Thing> associatedAnatomies) {
  	this.associatedAnatomy = associatedAnatomies;
  }
  
  /**
   * Set the cause property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param causes The list of values to set.
   */
  public void setCauses(List<MedicalCause> causes) {
  	this.cause = causes;
  }
  
  /**
   * Set the code property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the differentialDiagnosis property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param differentialDiagnoses The list of values to set.
   */
  public void setDifferentialDiagnoses(List<DDxElement> differentialDiagnoses) {
  	this.differentialDiagnosis = differentialDiagnoses;
  }
  
  /**
   * Set the epidemiology property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param epidemiologies The list of values to set.
   */
  public void setEpidemiologies(List<String> epidemiologies) {
  	this.epidemiology = epidemiologies;
  }
  
  /**
   * Set the expectedPrognosis property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param expectedPrognoses The list of values to set.
   */
  public void setExpectedPrognoses(List<String> expectedPrognoses) {
  	this.expectedPrognosis = expectedPrognoses;
  }
  
  /**
   * Set the guideline property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the naturalProgression property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param naturalProgressions The list of values to set.
   */
  public void setNaturalProgressions(List<String> naturalProgressions) {
  	this.naturalProgression = naturalProgressions;
  }
  
  /**
   * Set the pathophysiology property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param pathophysiologies The list of values to set.
   */
  public void setPathophysiologies(List<String> pathophysiologies) {
  	this.pathophysiology = pathophysiologies;
  }
  
  /**
   * Set the possibleComplication property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleComplications The list of values to set.
   */
  public void setPossibleComplications(List<String> possibleComplications) {
  	this.possibleComplication = possibleComplications;
  }
  
  /**
   * Set the possibleTreatment property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleTreatments The list of values to set.
   */
  public void setPossibleTreatments(List<MedicalTherapy> possibleTreatments) {
  	this.possibleTreatment = possibleTreatments;
  }
  
  /**
   * Set the primaryPrevention property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param primaryPreventions The list of values to set.
   */
  public void setPrimaryPreventions(List<MedicalTherapy> primaryPreventions) {
  	this.primaryPrevention = primaryPreventions;
  }
  
  /**
   * Set the recognizingAuthority property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the riskFactor property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param riskFactors The list of values to set.
   */
  public void setRiskFactors(List<MedicalRiskFactor> riskFactors) {
  	this.riskFactor = riskFactors;
  }
  
  /**
   * Set the sameAs property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the secondaryPrevention property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param secondaryPreventions The list of values to set.
   */
  public void setSecondaryPreventions(List<MedicalTherapy> secondaryPreventions) {
  	this.secondaryPrevention = secondaryPreventions;
  }
  
  /**
   * Set the signOrSymptom property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param signOrSymptoms The list of values to set.
   */
  public void setSignOrSymptoms(List<MedicalSignOrSymptom> signOrSymptoms) {
  	this.signOrSymptom = signOrSymptoms;
  }
  
  /**
   * Set the stage property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param stages The list of values to set.
   */
  public void setStages(List<MedicalConditionStage> stages) {
  	this.stage = stages;
  }
  
  /**
   * Set the study property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the subtype property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param subtypes The list of values to set.
   */
  public void setSubtypes(List<String> subtypes) {
  	this.subtype = subtypes;
  }
  
  /**
   * Set the typicalTest property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param typicalTests The list of values to set.
   */
  public void setTypicalTests(List<MedicalTest> typicalTests) {
  	this.typicalTest = typicalTests;
  }
  
  /**
   * Set the url property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a associatedAnatomy property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param associatedAnatomy The value to add.
   */
  public void addAssociatedAnatomy(Thing associatedAnatomy) {
  	this.associatedAnatomy.add(associatedAnatomy);
  }
  
  /**
   * Adds a cause property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param cause The value to add.
   */
  public void addCause(MedicalCause cause) {
  	this.cause.add(cause);
  }
  
  /**
   * Adds a code property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a differentialDiagnosis property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param differentialDiagnosis The value to add.
   */
  public void addDifferentialDiagnosis(DDxElement differentialDiagnosis) {
  	this.differentialDiagnosis.add(differentialDiagnosis);
  }
  
  /**
   * Adds a epidemiology property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param epidemiology The value to add.
   */
  public void addEpidemiology(String epidemiology) {
  	this.epidemiology.add(epidemiology);
  }
  
  /**
   * Adds a expectedPrognosis property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param expectedPrognosis The value to add.
   */
  public void addExpectedPrognosis(String expectedPrognosis) {
  	this.expectedPrognosis.add(expectedPrognosis);
  }
  
  /**
   * Adds a guideline property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a naturalProgression property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param naturalProgression The value to add.
   */
  public void addNaturalProgression(String naturalProgression) {
  	this.naturalProgression.add(naturalProgression);
  }
  
  /**
   * Adds a pathophysiology property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param pathophysiology The value to add.
   */
  public void addPathophysiology(String pathophysiology) {
  	this.pathophysiology.add(pathophysiology);
  }
  
  /**
   * Adds a possibleComplication property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param possibleComplication The value to add.
   */
  public void addPossibleComplication(String possibleComplication) {
  	this.possibleComplication.add(possibleComplication);
  }
  
  /**
   * Adds a possibleTreatment property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param possibleTreatment The value to add.
   */
  public void addPossibleTreatment(MedicalTherapy possibleTreatment) {
  	this.possibleTreatment.add(possibleTreatment);
  }
  
  /**
   * Adds a primaryPrevention property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param primaryPrevention The value to add.
   */
  public void addPrimaryPrevention(MedicalTherapy primaryPrevention) {
  	this.primaryPrevention.add(primaryPrevention);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a riskFactor property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param riskFactor The value to add.
   */
  public void addRiskFactor(MedicalRiskFactor riskFactor) {
  	this.riskFactor.add(riskFactor);
  }
  
  /**
   * Adds a sameAs property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a secondaryPrevention property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param secondaryPrevention The value to add.
   */
  public void addSecondaryPrevention(MedicalTherapy secondaryPrevention) {
  	this.secondaryPrevention.add(secondaryPrevention);
  }
  
  /**
   * Adds a signOrSymptom property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param signOrSymptom The value to add.
   */
  public void addSignOrSymptom(MedicalSignOrSymptom signOrSymptom) {
  	this.signOrSymptom.add(signOrSymptom);
  }
  
  /**
   * Adds a stage property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param stage The value to add.
   */
  public void addStage(MedicalConditionStage stage) {
  	this.stage.add(stage);
  }
  
  /**
   * Adds a study property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a subtype property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param subtype The value to add.
   */
  public void addSubtype(String subtype) {
  	this.subtype.add(subtype);
  }
  
  /**
   * Adds a typicalTest property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param typicalTest The value to add.
   */
  public void addTypicalTest(MedicalTest typicalTest) {
  	this.typicalTest.add(typicalTest);
  }
  
  /**
   * Adds a url property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}