package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.MedicalCode;
import org.schema.MedicalContraindication;
import org.schema.MedicalDevice;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalIndication;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Any object used in a medical capacity, such as to diagnose or treat a patient.
 */
public class MedicalDeviceImpl extends SchemaObjectImpl implements MedicalDevice {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * A possible complication and/or side effect of this therapy. If it is known that an adverse outcome is serious (resulting in death, disability, or permanent damage; requiring hospitalization; or is otherwise life-threatening or requires immediate medical attention), tag it as a seriouseAdverseOutcome instead.
   */
  private List<MedicalEntity> adverseOutcome = new LinkedList<MedicalEntity>();
  
  /**
   * A contraindication for this therapy.
   */
  private List<MedicalContraindication> contraindication = new LinkedList<MedicalContraindication>();
  
  /**
   * A factor that indicates use of this therapy for treatment and/or prevention of a condition, symptom, etc. For therapies such as drugs, indications can include both officially-approved indications as well as off-label uses. These can be distinguished by using the ApprovedIndication subtype of MedicalIndication.
   */
  private List<MedicalIndication> indication = new LinkedList<MedicalIndication>();
  
  /**
   * A description of the postoperative procedures, care, and/or followups for this device.
   */
  private List<String> postOp = new LinkedList<String>();
  
  /**
   * A description of the workup, testing, and other preparations required before implanting this device.
   */
  private List<String> preOp = new LinkedList<String>();
  
  /**
   * A description of the procedure involved in setting up, using, and/or installing the device.
   */
  private List<String> procedure = new LinkedList<String>();
  
  /**
   * A goal towards an action is taken. Can be concrete or abstract.
   */
  private List<Thing> purpose = new LinkedList<Thing>();
  
  /**
   * A possible serious complication and/or serious side effect of this therapy. Serious adverse outcomes include those that are life-threatening; result in death, disability, or permanent damage; require hospitalization or prolong existing hospitalization; cause congenital anomalies or birth defects; or jeopardize the patient and may require medical or surgical intervention to prevent one of the outcomes in this definition.
   */
  private List<MedicalEntity> seriousAdverseOutcome = new LinkedList<MedicalEntity>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MedicalDeviceImpl() {
    super("http://schema.org/MedicalDevice");
    medicalEntity = new MedicalEntityImpl();
  }
  /**
   * Get a single additionalType property value for this MedicalDevice object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single adverseOutcome property value for this MedicalDevice object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome() {
  	return this.adverseOutcome.isEmpty() ? null : this.adverseOutcome.get(0);
  }
  
  /**
   * Get a single alternateName property value for this MedicalDevice object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single code property value for this MedicalDevice object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single contraindication property value for this MedicalDevice object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication() {
  	return this.contraindication.isEmpty() ? null : this.contraindication.get(0);
  }
  
  /**
   * Get a single description property value for this MedicalDevice object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this MedicalDevice object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this MedicalDevice object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single indication property value for this MedicalDevice object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication() {
  	return this.indication.isEmpty() ? null : this.indication.get(0);
  }
  
  /**
   * Get a single medicineSystem property value for this MedicalDevice object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this MedicalDevice object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single postOp property value for this MedicalDevice object.
   *
   * @return The first postOp property value.
   */
  public String getPostOp() {
  	return this.postOp.isEmpty() ? null : this.postOp.get(0);
  }
  
  /**
   * Get a single preOp property value for this MedicalDevice object.
   *
   * @return The first preOp property value.
   */
  public String getPreOp() {
  	return this.preOp.isEmpty() ? null : this.preOp.get(0);
  }
  
  /**
   * Get a single procedure property value for this MedicalDevice object.
   *
   * @return The first procedure property value.
   */
  public String getProcedure() {
  	return this.procedure.isEmpty() ? null : this.procedure.get(0);
  }
  
  /**
   * Get a single purpose property value for this MedicalDevice object.
   *
   * @return The first purpose property value.
   */
  public Thing getPurpose() {
  	return this.purpose.isEmpty() ? null : this.purpose.get(0);
  }
  
  /**
   * Get a single recognizingAuthority property value for this MedicalDevice object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this MedicalDevice object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this MedicalDevice object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seriousAdverseOutcome property value for this MedicalDevice object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome() {
  	return this.seriousAdverseOutcome.isEmpty() ? null : this.seriousAdverseOutcome.get(0);
  }
  
  /**
   * Get a single study property value for this MedicalDevice object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this MedicalDevice object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MedicalDevice object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the adverseOutcome property values for this MedicalDevice object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes() {
  	return this.adverseOutcome;
  }
  
  /**
   * Get all the alternateName property values for this MedicalDevice object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the code property values for this MedicalDevice object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the contraindication property values for this MedicalDevice object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications() {
  	return this.contraindication;
  }
  
  /**
   * Get all the description property values for this MedicalDevice object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this MedicalDevice object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this MedicalDevice object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the indication property values for this MedicalDevice object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications() {
  	return this.indication;
  }
  
  /**
   * Get all the medicineSystem property values for this MedicalDevice object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this MedicalDevice object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the postOp property values for this MedicalDevice object.
   *
   * @return A list of postOp property values.
   */
  public List<String> getPostOps() {
  	return this.postOp;
  }
  
  /**
   * Get all the preOp property values for this MedicalDevice object.
   *
   * @return A list of preOp property values.
   */
  public List<String> getPreOps() {
  	return this.preOp;
  }
  
  /**
   * Get all the procedure property values for this MedicalDevice object.
   *
   * @return A list of procedure property values.
   */
  public List<String> getProcedures() {
  	return this.procedure;
  }
  
  /**
   * Get all the purpose property values for this MedicalDevice object.
   *
   * @return A list of purpose property values.
   */
  public List<Thing> getPurposes() {
  	return this.purpose;
  }
  
  /**
   * Get all the recognizingAuthority property values for this MedicalDevice object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this MedicalDevice object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this MedicalDevice object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seriousAdverseOutcome property values for this MedicalDevice object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes() {
  	return this.seriousAdverseOutcome;
  }
  
  /**
   * Get all the study property values for this MedicalDevice object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this MedicalDevice object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the adverseOutcome property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome) {
  	this.adverseOutcome.clear();
  	this.adverseOutcome.add(adverseOutcome);
  }
  
  /**
   * Set the alternateName property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the code property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the contraindication property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication) {
  	this.contraindication.clear();
  	this.contraindication.add(contraindication);
  }
  
  /**
   * Set the description property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the indication property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication) {
  	this.indication.clear();
  	this.indication.add(indication);
  }
  
  /**
   * Set the medicineSystem property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the postOp property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param postOp The value to set.
   */
  public void setPostOp(String postOp) {
  	this.postOp.clear();
  	this.postOp.add(postOp);
  }
  
  /**
   * Set the preOp property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param preOp The value to set.
   */
  public void setPreOp(String preOp) {
  	this.preOp.clear();
  	this.preOp.add(preOp);
  }
  
  /**
   * Set the procedure property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param procedure The value to set.
   */
  public void setProcedure(String procedure) {
  	this.procedure.clear();
  	this.procedure.add(procedure);
  }
  
  /**
   * Set the purpose property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param purpose The value to set.
   */
  public void setPurpose(Thing purpose) {
  	this.purpose.clear();
  	this.purpose.add(purpose);
  }
  
  /**
   * Set the recognizingAuthority property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seriousAdverseOutcome property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
  	this.seriousAdverseOutcome.clear();
  	this.seriousAdverseOutcome.add(seriousAdverseOutcome);
  }
  
  /**
   * Set the study property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the adverseOutcome property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes) {
  	this.adverseOutcome = adverseOutcomes;
  }
  
  /**
   * Set the alternateName property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the code property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the contraindication property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications) {
  	this.contraindication = contraindications;
  }
  
  /**
   * Set the description property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the indication property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications) {
  	this.indication = indications;
  }
  
  /**
   * Set the medicineSystem property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the postOp property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param postOps The list of values to set.
   */
  public void setPostOps(List<String> postOps) {
  	this.postOp = postOps;
  }
  
  /**
   * Set the preOp property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param preOps The list of values to set.
   */
  public void setPreOps(List<String> preOps) {
  	this.preOp = preOps;
  }
  
  /**
   * Set the procedure property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param procedures The list of values to set.
   */
  public void setProcedures(List<String> procedures) {
  	this.procedure = procedures;
  }
  
  /**
   * Set the purpose property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param purposes The list of values to set.
   */
  public void setPurposes(List<Thing> purposes) {
  	this.purpose = purposes;
  }
  
  /**
   * Set the recognizingAuthority property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seriousAdverseOutcome property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes) {
  	this.seriousAdverseOutcome = seriousAdverseOutcomes;
  }
  
  /**
   * Set the study property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a adverseOutcome property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome) {
  	this.adverseOutcome.add(adverseOutcome);
  }
  
  /**
   * Adds a alternateName property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a code property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a contraindication property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication) {
  	this.contraindication.add(contraindication);
  }
  
  /**
   * Adds a description property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a indication property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication) {
  	this.indication.add(indication);
  }
  
  /**
   * Adds a medicineSystem property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a postOp property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param postOp The value to add.
   */
  public void addPostOp(String postOp) {
  	this.postOp.add(postOp);
  }
  
  /**
   * Adds a preOp property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param preOp The value to add.
   */
  public void addPreOp(String preOp) {
  	this.preOp.add(preOp);
  }
  
  /**
   * Adds a procedure property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param procedure The value to add.
   */
  public void addProcedure(String procedure) {
  	this.procedure.add(procedure);
  }
  
  /**
   * Adds a purpose property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param purpose The value to add.
   */
  public void addPurpose(Thing purpose) {
  	this.purpose.add(purpose);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seriousAdverseOutcome property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
  	this.seriousAdverseOutcome.add(seriousAdverseOutcome);
  }
  
  /**
   * Adds a study property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}