package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.MedicalCode;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The most generic type of entity related to health and the practice of medicine.
 */
public class MedicalEntityImpl extends SchemaObjectImpl implements MedicalEntity {


  private ThingImpl thing;

  /**
   * An alias for the item.
   */
  private List<String> alternateName = new LinkedList<String>();
  
  /**
   * A medical code for the entity, taken from a controlled vocabulary or ontology such as ICD-9, DiseasesDB, MeSH, SNOMED-CT, RxNorm, etc.
   */
  private List<MedicalCode> code = new LinkedList<MedicalCode>();
  
  /**
   * A medical guideline related to this entity.
   */
  private List<MedicalGuideline> guideline = new LinkedList<MedicalGuideline>();
  
  /**
   * The system of medicine that includes this MedicalEntity, for example 'evidence-based', 'homeopathic', 'chiropractic', etc.
   */
  private List<MedicineSystem> medicineSystem = new LinkedList<MedicineSystem>();
  
  /**
   * If applicable, the organization that officially recognizes this entity as part of its endorsed system of medicine.
   */
  private List<Organization> recognizingAuthority = new LinkedList<Organization>();
  
  /**
   * If applicable, a medical specialty in which this entity is relevant.
   */
  private List<MedicalSpecialty> relevantSpecialty = new LinkedList<MedicalSpecialty>();
  
  /**
   * A medical study or trial related to this entity.
   */
  private List<MedicalStudy> study = new LinkedList<MedicalStudy>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MedicalEntityImpl() {
    super("http://schema.org/MedicalEntity");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this MedicalEntity object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this MedicalEntity object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
  	return this.alternateName.isEmpty() ? null : this.alternateName.get(0);
  }
  
  /**
   * Get a single code property value for this MedicalEntity object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
  	return this.code.isEmpty() ? null : this.code.get(0);
  }
  
  /**
   * Get a single description property value for this MedicalEntity object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this MedicalEntity object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
  	return this.guideline.isEmpty() ? null : this.guideline.get(0);
  }
  
  /**
   * Get a single image property value for this MedicalEntity object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this MedicalEntity object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
  	return this.medicineSystem.isEmpty() ? null : this.medicineSystem.get(0);
  }
  
  /**
   * Get a single name property value for this MedicalEntity object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single recognizingAuthority property value for this MedicalEntity object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
  	return this.recognizingAuthority.isEmpty() ? null : this.recognizingAuthority.get(0);
  }
  
  /**
   * Get a single relevantSpecialty property value for this MedicalEntity object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
  	return this.relevantSpecialty.isEmpty() ? null : this.relevantSpecialty.get(0);
  }
  
  /**
   * Get a single sameAs property value for this MedicalEntity object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this MedicalEntity object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
  	return this.study.isEmpty() ? null : this.study.get(0);
  }
  
  /**
   * Get a single url property value for this MedicalEntity object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MedicalEntity object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this MedicalEntity object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
  	return this.alternateName;
  }
  
  /**
   * Get all the code property values for this MedicalEntity object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
  	return this.code;
  }
  
  /**
   * Get all the description property values for this MedicalEntity object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this MedicalEntity object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
  	return this.guideline;
  }
  
  /**
   * Get all the image property values for this MedicalEntity object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this MedicalEntity object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
  	return this.medicineSystem;
  }
  
  /**
   * Get all the name property values for this MedicalEntity object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the recognizingAuthority property values for this MedicalEntity object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
  	return this.recognizingAuthority;
  }
  
  /**
   * Get all the relevantSpecialty property values for this MedicalEntity object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
  	return this.relevantSpecialty;
  }
  
  /**
   * Get all the sameAs property values for this MedicalEntity object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this MedicalEntity object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
  	return this.study;
  }
  
  /**
   * Get all the url property values for this MedicalEntity object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
  	this.alternateName.clear();
  	this.alternateName.add(alternateName);
  }
  
  /**
   * Set the code property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
  	this.code.clear();
  	this.code.add(code);
  }
  
  /**
   * Set the description property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
  	this.guideline.clear();
  	this.guideline.add(guideline);
  }
  
  /**
   * Set the image property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
  	this.medicineSystem.clear();
  	this.medicineSystem.add(medicineSystem);
  }
  
  /**
   * Set the name property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the recognizingAuthority property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
  	this.recognizingAuthority.clear();
  	this.recognizingAuthority.add(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
  	this.relevantSpecialty.clear();
  	this.relevantSpecialty.add(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
  	this.study.clear();
  	this.study.add(study);
  }
  
  /**
   * Set the url property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
  	this.alternateName = alternateNames;
  }
  
  /**
   * Set the code property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
  	this.code = codes;
  }
  
  /**
   * Set the description property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
  	this.guideline = guidelines;
  }
  
  /**
   * Set the image property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
  	this.medicineSystem = medicineSystems;
  }
  
  /**
   * Set the name property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the recognizingAuthority property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
  	this.recognizingAuthority = recognizingAuthorities;
  }
  
  /**
   * Set the relevantSpecialty property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
  	this.relevantSpecialty = relevantSpecialties;
  }
  
  /**
   * Set the sameAs property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
  	this.study = studies;
  }
  
  /**
   * Set the url property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
  	this.alternateName.add(alternateName);
  }
  
  /**
   * Adds a code property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
  	this.code.add(code);
  }
  
  /**
   * Adds a description property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
  	this.guideline.add(guideline);
  }
  
  /**
   * Adds a image property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
  	this.medicineSystem.add(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
  	this.recognizingAuthority.add(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
  	this.relevantSpecialty.add(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
  	this.study.add(study);
  }
  
  /**
   * Adds a url property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}