package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.MedicalCode;
import org.schema.MedicalEntity;
import org.schema.MedicalEvidenceLevel;
import org.schema.MedicalGuideline;
import org.schema.MedicalGuidelineContraindication;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A guideline contraindication that designates a process as harmful and where quality of the data supporting the contraindication is sound.
 */
public class MedicalGuidelineContraindicationImpl extends SchemaObjectImpl implements MedicalGuidelineContraindication {


  private MedicalEntityImpl medicalEntity;
  private MedicalGuidelineImpl medicalGuideline;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MedicalGuidelineContraindicationImpl() {
    super("http://schema.org/MedicalGuidelineContraindication");
    medicalGuideline = new MedicalGuidelineImpl();
  }
  /**
   * Get a single additionalType property value for this MedicalGuidelineContraindication object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this MedicalGuidelineContraindication object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single code property value for this MedicalGuidelineContraindication object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this MedicalGuidelineContraindication object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single evidenceLevel property value for this MedicalGuidelineContraindication object.
   *
   * @return The first evidenceLevel property value.
   */
  public MedicalEvidenceLevel getEvidenceLevel() {
    return medicalGuideline.getEvidenceLevel();
  }
  
  /**
   * Get a single evidenceOrigin property value for this MedicalGuidelineContraindication object.
   *
   * @return The first evidenceOrigin property value.
   */
  public String getEvidenceOrigin() {
    return medicalGuideline.getEvidenceOrigin();
  }
  
  /**
   * Get a single guideline property value for this MedicalGuidelineContraindication object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single guidelineDate property value for this MedicalGuidelineContraindication object.
   *
   * @return The first guidelineDate property value.
   */
  public Date getGuidelineDate() {
    return medicalGuideline.getGuidelineDate();
  }
  
  /**
   * Get a single guidelineSubject property value for this MedicalGuidelineContraindication object.
   *
   * @return The first guidelineSubject property value.
   */
  public MedicalEntity getGuidelineSubject() {
    return medicalGuideline.getGuidelineSubject();
  }
  
  /**
   * Get a single image property value for this MedicalGuidelineContraindication object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this MedicalGuidelineContraindication object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this MedicalGuidelineContraindication object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single recognizingAuthority property value for this MedicalGuidelineContraindication object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this MedicalGuidelineContraindication object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this MedicalGuidelineContraindication object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this MedicalGuidelineContraindication object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this MedicalGuidelineContraindication object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the code property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the evidenceLevel property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of evidenceLevel property values.
   */
  public List<MedicalEvidenceLevel> getEvidenceLevels() {
    return medicalGuideline.getEvidenceLevels();
  }
  
  /**
   * Get all the evidenceOrigin property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of evidenceOrigin property values.
   */
  public List<String> getEvidenceOrigins() {
    return medicalGuideline.getEvidenceOrigins();
  }
  
  /**
   * Get all the guideline property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the guidelineDate property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of guidelineDate property values.
   */
  public List<Date> getGuidelineDates() {
    return medicalGuideline.getGuidelineDates();
  }
  
  /**
   * Get all the guidelineSubject property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of guidelineSubject property values.
   */
  public List<MedicalEntity> getGuidelineSubjects() {
    return medicalGuideline.getGuidelineSubjects();
  }
  
  /**
   * Get all the image property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the recognizingAuthority property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this MedicalGuidelineContraindication object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the code property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the evidenceLevel property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param evidenceLevel The value to set.
   */
  public void setEvidenceLevel(MedicalEvidenceLevel evidenceLevel) {
    medicalGuideline.setEvidenceLevel(evidenceLevel);
  }
  
  /**
   * Set the evidenceOrigin property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param evidenceOrigin The value to set.
   */
  public void setEvidenceOrigin(String evidenceOrigin) {
    medicalGuideline.setEvidenceOrigin(evidenceOrigin);
  }
  
  /**
   * Set the guideline property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the guidelineDate property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param guidelineDate The value to set.
   */
  public void setGuidelineDate(Date guidelineDate) {
    medicalGuideline.setGuidelineDate(guidelineDate);
  }
  
  /**
   * Set the guidelineSubject property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param guidelineSubject The value to set.
   */
  public void setGuidelineSubject(MedicalEntity guidelineSubject) {
    medicalGuideline.setGuidelineSubject(guidelineSubject);
  }
  
  /**
   * Set the image property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the recognizingAuthority property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the code property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the evidenceLevel property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param evidenceLevels The list of values to set.
   */
  public void setEvidenceLevels(List<MedicalEvidenceLevel> evidenceLevels) {
    medicalGuideline.setEvidenceLevels(evidenceLevels);
  }
  
  /**
   * Set the evidenceOrigin property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param evidenceOrigins The list of values to set.
   */
  public void setEvidenceOrigins(List<String> evidenceOrigins) {
    medicalGuideline.setEvidenceOrigins(evidenceOrigins);
  }
  
  /**
   * Set the guideline property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the guidelineDate property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param guidelineDates The list of values to set.
   */
  public void setGuidelineDates(List<Date> guidelineDates) {
    medicalGuideline.setGuidelineDates(guidelineDates);
  }
  
  /**
   * Set the guidelineSubject property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param guidelineSubjects The list of values to set.
   */
  public void setGuidelineSubjects(List<MedicalEntity> guidelineSubjects) {
    medicalGuideline.setGuidelineSubjects(guidelineSubjects);
  }
  
  /**
   * Set the image property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the recognizingAuthority property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this MedicalGuidelineContraindication object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a code property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a evidenceLevel property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param evidenceLevel The value to add.
   */
  public void addEvidenceLevel(MedicalEvidenceLevel evidenceLevel) {
    medicalGuideline.addEvidenceLevel(evidenceLevel);
  }
  
  /**
   * Adds a evidenceOrigin property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param evidenceOrigin The value to add.
   */
  public void addEvidenceOrigin(String evidenceOrigin) {
    medicalGuideline.addEvidenceOrigin(evidenceOrigin);
  }
  
  /**
   * Adds a guideline property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a guidelineDate property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param guidelineDate The value to add.
   */
  public void addGuidelineDate(Date guidelineDate) {
    medicalGuideline.addGuidelineDate(guidelineDate);
  }
  
  /**
   * Adds a guidelineSubject property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param guidelineSubject The value to add.
   */
  public void addGuidelineSubject(MedicalEntity guidelineSubject) {
    medicalGuideline.addGuidelineSubject(guidelineSubject);
  }
  
  /**
   * Adds a image property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this MedicalGuidelineContraindication object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}