package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.MedicalCause;
import org.schema.MedicalCode;
import org.schema.MedicalGuideline;
import org.schema.MedicalSignOrSymptom;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Any indication of the existence of a medical condition or disease.
 */
public class MedicalSignOrSymptomImpl extends SchemaObjectImpl implements MedicalSignOrSymptom {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * An underlying cause. More specifically, one of the causative agent(s) that are most directly responsible for the pathophysiologic process that eventually results in the occurrence.
   */
  private List<MedicalCause> cause = new LinkedList<MedicalCause>();
  
  /**
   * A possible treatment to address this condition, sign or symptom.
   */
  private List<MedicalTherapy> possibleTreatment = new LinkedList<MedicalTherapy>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MedicalSignOrSymptomImpl() {
    super("http://schema.org/MedicalSignOrSymptom");
    medicalEntity = new MedicalEntityImpl();
  }
  /**
   * Get a single additionalType property value for this MedicalSignOrSymptom object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this MedicalSignOrSymptom object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single cause property value for this MedicalSignOrSymptom object.
   *
   * @return The first cause property value.
   */
  public MedicalCause getCause() {
  	return this.cause.isEmpty() ? null : this.cause.get(0);
  }
  
  /**
   * Get a single code property value for this MedicalSignOrSymptom object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this MedicalSignOrSymptom object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this MedicalSignOrSymptom object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this MedicalSignOrSymptom object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this MedicalSignOrSymptom object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this MedicalSignOrSymptom object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single possibleTreatment property value for this MedicalSignOrSymptom object.
   *
   * @return The first possibleTreatment property value.
   */
  public MedicalTherapy getPossibleTreatment() {
  	return this.possibleTreatment.isEmpty() ? null : this.possibleTreatment.get(0);
  }
  
  /**
   * Get a single recognizingAuthority property value for this MedicalSignOrSymptom object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this MedicalSignOrSymptom object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this MedicalSignOrSymptom object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this MedicalSignOrSymptom object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this MedicalSignOrSymptom object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MedicalSignOrSymptom object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this MedicalSignOrSymptom object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the cause property values for this MedicalSignOrSymptom object.
   *
   * @return A list of cause property values.
   */
  public List<MedicalCause> getCauses() {
  	return this.cause;
  }
  
  /**
   * Get all the code property values for this MedicalSignOrSymptom object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this MedicalSignOrSymptom object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this MedicalSignOrSymptom object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this MedicalSignOrSymptom object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this MedicalSignOrSymptom object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this MedicalSignOrSymptom object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the possibleTreatment property values for this MedicalSignOrSymptom object.
   *
   * @return A list of possibleTreatment property values.
   */
  public List<MedicalTherapy> getPossibleTreatments() {
  	return this.possibleTreatment;
  }
  
  /**
   * Get all the recognizingAuthority property values for this MedicalSignOrSymptom object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this MedicalSignOrSymptom object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this MedicalSignOrSymptom object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this MedicalSignOrSymptom object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this MedicalSignOrSymptom object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the cause property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param cause The value to set.
   */
  public void setCause(MedicalCause cause) {
  	this.cause.clear();
  	this.cause.add(cause);
  }
  
  /**
   * Set the code property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the possibleTreatment property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param possibleTreatment The value to set.
   */
  public void setPossibleTreatment(MedicalTherapy possibleTreatment) {
  	this.possibleTreatment.clear();
  	this.possibleTreatment.add(possibleTreatment);
  }
  
  /**
   * Set the recognizingAuthority property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the cause property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param causes The list of values to set.
   */
  public void setCauses(List<MedicalCause> causes) {
  	this.cause = causes;
  }
  
  /**
   * Set the code property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the possibleTreatment property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param possibleTreatments The list of values to set.
   */
  public void setPossibleTreatments(List<MedicalTherapy> possibleTreatments) {
  	this.possibleTreatment = possibleTreatments;
  }
  
  /**
   * Set the recognizingAuthority property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a cause property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param cause The value to add.
   */
  public void addCause(MedicalCause cause) {
  	this.cause.add(cause);
  }
  
  /**
   * Adds a code property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a possibleTreatment property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param possibleTreatment The value to add.
   */
  public void addPossibleTreatment(MedicalTherapy possibleTreatment) {
  	this.possibleTreatment.add(possibleTreatment);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}