package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.MedicalCode;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalStudyStatus;
import org.schema.MedicineSystem;
import org.schema.Organization;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A medical study is an umbrella type covering all kinds of research studies relating to human medicine or health, including observational studies and interventional trials and registries, randomized, controlled or not. When the specific type of study is known, use one of the extensions of this type, such as MedicalTrial or MedicalObservationalStudy. Also, note that this type should be used to mark up data that describes the study itself; to tag an article that publishes the results of a study, use MedicalScholarlyArticle. Note: use the code property of MedicalEntity to store study IDs, e.g. clinicaltrials.gov ID.
 */
public class MedicalStudyImpl extends SchemaObjectImpl implements MedicalStudy {


  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * Expected or actual outcomes of the study.
   */
  private List<String> outcome = new LinkedList<String>();
  
  /**
   * Any characteristics of the population used in the study, e.g. 'males under 65'.
   */
  private List<String> population = new LinkedList<String>();
  
  /**
   * Sponsor of the study.
   */
  private List<Organization> sponsor = new LinkedList<Organization>();
  
  /**
   * The status of the study (enumerated).
   */
  private List<MedicalStudyStatus> status = new LinkedList<MedicalStudyStatus>();
  
  /**
   * The location in which the study is taking/took place.
   */
  private List<AdministrativeArea> studyLocation = new LinkedList<AdministrativeArea>();
  
  /**
   * A subject of the study, i.e. one of the medical conditions, therapies, devices, drugs, etc. investigated by the study.
   */
  private List<MedicalEntity> studySubject = new LinkedList<MedicalEntity>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public MedicalStudyImpl() {
    super("http://schema.org/MedicalStudy");
    medicalEntity = new MedicalEntityImpl();
  }
  /**
   * Get a single additionalType property value for this MedicalStudy object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this MedicalStudy object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single code property value for this MedicalStudy object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this MedicalStudy object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this MedicalStudy object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this MedicalStudy object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this MedicalStudy object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this MedicalStudy object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single outcome property value for this MedicalStudy object.
   *
   * @return The first outcome property value.
   */
  public String getOutcome() {
  	return this.outcome.isEmpty() ? null : this.outcome.get(0);
  }
  
  /**
   * Get a single population property value for this MedicalStudy object.
   *
   * @return The first population property value.
   */
  public String getPopulation() {
  	return this.population.isEmpty() ? null : this.population.get(0);
  }
  
  /**
   * Get a single recognizingAuthority property value for this MedicalStudy object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this MedicalStudy object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this MedicalStudy object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single sponsor property value for this MedicalStudy object.
   *
   * @return The first sponsor property value.
   */
  public Organization getSponsor() {
  	return this.sponsor.isEmpty() ? null : this.sponsor.get(0);
  }
  
  /**
   * Get a single status property value for this MedicalStudy object.
   *
   * @return The first status property value.
   */
  public MedicalStudyStatus getStatus() {
  	return this.status.isEmpty() ? null : this.status.get(0);
  }
  
  /**
   * Get a single study property value for this MedicalStudy object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single studyLocation property value for this MedicalStudy object.
   *
   * @return The first studyLocation property value.
   */
  public AdministrativeArea getStudyLocation() {
  	return this.studyLocation.isEmpty() ? null : this.studyLocation.get(0);
  }
  
  /**
   * Get a single studySubject property value for this MedicalStudy object.
   *
   * @return The first studySubject property value.
   */
  public MedicalEntity getStudySubject() {
  	return this.studySubject.isEmpty() ? null : this.studySubject.get(0);
  }
  
  /**
   * Get a single url property value for this MedicalStudy object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this MedicalStudy object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this MedicalStudy object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the code property values for this MedicalStudy object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this MedicalStudy object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this MedicalStudy object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this MedicalStudy object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this MedicalStudy object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this MedicalStudy object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the outcome property values for this MedicalStudy object.
   *
   * @return A list of outcome property values.
   */
  public List<String> getOutcomes() {
  	return this.outcome;
  }
  
  /**
   * Get all the population property values for this MedicalStudy object.
   *
   * @return A list of population property values.
   */
  public List<String> getPopulations() {
  	return this.population;
  }
  
  /**
   * Get all the recognizingAuthority property values for this MedicalStudy object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this MedicalStudy object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this MedicalStudy object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the sponsor property values for this MedicalStudy object.
   *
   * @return A list of sponsor property values.
   */
  public List<Organization> getSponsors() {
  	return this.sponsor;
  }
  
  /**
   * Get all the status property values for this MedicalStudy object.
   *
   * @return A list of status property values.
   */
  public List<MedicalStudyStatus> getStatuses() {
  	return this.status;
  }
  
  /**
   * Get all the study property values for this MedicalStudy object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the studyLocation property values for this MedicalStudy object.
   *
   * @return A list of studyLocation property values.
   */
  public List<AdministrativeArea> getStudyLocations() {
  	return this.studyLocation;
  }
  
  /**
   * Get all the studySubject property values for this MedicalStudy object.
   *
   * @return A list of studySubject property values.
   */
  public List<MedicalEntity> getStudySubjects() {
  	return this.studySubject;
  }
  
  /**
   * Get all the url property values for this MedicalStudy object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the code property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the outcome property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param outcome The value to set.
   */
  public void setOutcome(String outcome) {
  	this.outcome.clear();
  	this.outcome.add(outcome);
  }
  
  /**
   * Set the population property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param population The value to set.
   */
  public void setPopulation(String population) {
  	this.population.clear();
  	this.population.add(population);
  }
  
  /**
   * Set the recognizingAuthority property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the sponsor property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param sponsor The value to set.
   */
  public void setSponsor(Organization sponsor) {
  	this.sponsor.clear();
  	this.sponsor.add(sponsor);
  }
  
  /**
   * Set the status property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param status The value to set.
   */
  public void setStatus(MedicalStudyStatus status) {
  	this.status.clear();
  	this.status.add(status);
  }
  
  /**
   * Set the study property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the studyLocation property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param studyLocation The value to set.
   */
  public void setStudyLocation(AdministrativeArea studyLocation) {
  	this.studyLocation.clear();
  	this.studyLocation.add(studyLocation);
  }
  
  /**
   * Set the studySubject property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param studySubject The value to set.
   */
  public void setStudySubject(MedicalEntity studySubject) {
  	this.studySubject.clear();
  	this.studySubject.add(studySubject);
  }
  
  /**
   * Set the url property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the code property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the outcome property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param outcomes The list of values to set.
   */
  public void setOutcomes(List<String> outcomes) {
  	this.outcome = outcomes;
  }
  
  /**
   * Set the population property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param populations The list of values to set.
   */
  public void setPopulations(List<String> populations) {
  	this.population = populations;
  }
  
  /**
   * Set the recognizingAuthority property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the sponsor property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param sponsors The list of values to set.
   */
  public void setSponsors(List<Organization> sponsors) {
  	this.sponsor = sponsors;
  }
  
  /**
   * Set the status property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param statuses The list of values to set.
   */
  public void setStatuses(List<MedicalStudyStatus> statuses) {
  	this.status = statuses;
  }
  
  /**
   * Set the study property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the studyLocation property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param studyLocations The list of values to set.
   */
  public void setStudyLocations(List<AdministrativeArea> studyLocations) {
  	this.studyLocation = studyLocations;
  }
  
  /**
   * Set the studySubject property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param studySubjects The list of values to set.
   */
  public void setStudySubjects(List<MedicalEntity> studySubjects) {
  	this.studySubject = studySubjects;
  }
  
  /**
   * Set the url property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a code property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a outcome property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param outcome The value to add.
   */
  public void addOutcome(String outcome) {
  	this.outcome.add(outcome);
  }
  
  /**
   * Adds a population property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param population The value to add.
   */
  public void addPopulation(String population) {
  	this.population.add(population);
  }
  
  /**
   * Adds a recognizingAuthority property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a sponsor property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param sponsor The value to add.
   */
  public void addSponsor(Organization sponsor) {
  	this.sponsor.add(sponsor);
  }
  
  /**
   * Adds a status property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param status The value to add.
   */
  public void addStatus(MedicalStudyStatus status) {
  	this.status.add(status);
  }
  
  /**
   * Adds a study property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a studyLocation property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param studyLocation The value to add.
   */
  public void addStudyLocation(AdministrativeArea studyLocation) {
  	this.studyLocation.add(studyLocation);
  }
  
  /**
   * Adds a studySubject property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param studySubject The value to add.
   */
  public void addStudySubject(MedicalEntity studySubject) {
  	this.studySubject.add(studySubject);
  }
  
  /**
   * Adds a url property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}