package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Energy;
import org.schema.Mass;
import org.schema.NutritionInformation;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Nutritional information about the recipe.
 */
public class NutritionInformationImpl extends SchemaObjectImpl implements NutritionInformation {


  private ThingImpl thing;

  /**
   * The number of calories
   */
  private List<Energy> calories = new LinkedList<Energy>();
  
  /**
   * The number of grams of carbohydrates.
   */
  private List<Mass> carbohydrateContent = new LinkedList<Mass>();
  
  /**
   * The number of milligrams of cholesterol.
   */
  private List<Mass> cholesterolContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of fat.
   */
  private List<Mass> fatContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of fiber.
   */
  private List<Mass> fiberContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of protein.
   */
  private List<Mass> proteinContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of saturated fat.
   */
  private List<Mass> saturatedFatContent = new LinkedList<Mass>();
  
  /**
   * The serving size, in terms of the number of volume or mass
   */
  private List<String> servingSize = new LinkedList<String>();
  
  /**
   * The number of milligrams of sodium.
   */
  private List<Mass> sodiumContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of sugar.
   */
  private List<Mass> sugarContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of trans fat.
   */
  private List<Mass> transFatContent = new LinkedList<Mass>();
  
  /**
   * The number of grams of unsaturated fat.
   */
  private List<Mass> unsaturatedFatContent = new LinkedList<Mass>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public NutritionInformationImpl() {
    super("http://schema.org/NutritionInformation");
  }
  /**
   * Get a single additionalType property value for this NutritionInformation object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this NutritionInformation object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single calories property value for this NutritionInformation object.
   *
   * @return The first calories property value.
   */
  public Energy getCalories() {
  	return this.calories.isEmpty() ? null : this.calories.get(0);
  }
  
  /**
   * Get a single carbohydrateContent property value for this NutritionInformation object.
   *
   * @return The first carbohydrateContent property value.
   */
  public Mass getCarbohydrateContent() {
  	return this.carbohydrateContent.isEmpty() ? null : this.carbohydrateContent.get(0);
  }
  
  /**
   * Get a single cholesterolContent property value for this NutritionInformation object.
   *
   * @return The first cholesterolContent property value.
   */
  public Mass getCholesterolContent() {
  	return this.cholesterolContent.isEmpty() ? null : this.cholesterolContent.get(0);
  }
  
  /**
   * Get a single description property value for this NutritionInformation object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single fatContent property value for this NutritionInformation object.
   *
   * @return The first fatContent property value.
   */
  public Mass getFatContent() {
  	return this.fatContent.isEmpty() ? null : this.fatContent.get(0);
  }
  
  /**
   * Get a single fiberContent property value for this NutritionInformation object.
   *
   * @return The first fiberContent property value.
   */
  public Mass getFiberContent() {
  	return this.fiberContent.isEmpty() ? null : this.fiberContent.get(0);
  }
  
  /**
   * Get a single image property value for this NutritionInformation object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this NutritionInformation object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single proteinContent property value for this NutritionInformation object.
   *
   * @return The first proteinContent property value.
   */
  public Mass getProteinContent() {
  	return this.proteinContent.isEmpty() ? null : this.proteinContent.get(0);
  }
  
  /**
   * Get a single sameAs property value for this NutritionInformation object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single saturatedFatContent property value for this NutritionInformation object.
   *
   * @return The first saturatedFatContent property value.
   */
  public Mass getSaturatedFatContent() {
  	return this.saturatedFatContent.isEmpty() ? null : this.saturatedFatContent.get(0);
  }
  
  /**
   * Get a single servingSize property value for this NutritionInformation object.
   *
   * @return The first servingSize property value.
   */
  public String getServingSize() {
  	return this.servingSize.isEmpty() ? null : this.servingSize.get(0);
  }
  
  /**
   * Get a single sodiumContent property value for this NutritionInformation object.
   *
   * @return The first sodiumContent property value.
   */
  public Mass getSodiumContent() {
  	return this.sodiumContent.isEmpty() ? null : this.sodiumContent.get(0);
  }
  
  /**
   * Get a single sugarContent property value for this NutritionInformation object.
   *
   * @return The first sugarContent property value.
   */
  public Mass getSugarContent() {
  	return this.sugarContent.isEmpty() ? null : this.sugarContent.get(0);
  }
  
  /**
   * Get a single transFatContent property value for this NutritionInformation object.
   *
   * @return The first transFatContent property value.
   */
  public Mass getTransFatContent() {
  	return this.transFatContent.isEmpty() ? null : this.transFatContent.get(0);
  }
  
  /**
   * Get a single unsaturatedFatContent property value for this NutritionInformation object.
   *
   * @return The first unsaturatedFatContent property value.
   */
  public Mass getUnsaturatedFatContent() {
  	return this.unsaturatedFatContent.isEmpty() ? null : this.unsaturatedFatContent.get(0);
  }
  
  /**
   * Get a single url property value for this NutritionInformation object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this NutritionInformation object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this NutritionInformation object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the calories property values for this NutritionInformation object.
   *
   * @return A list of calories property values.
   */
  public List<Energy> getCaloriess() {
  	return this.calories;
  }
  
  /**
   * Get all the carbohydrateContent property values for this NutritionInformation object.
   *
   * @return A list of carbohydrateContent property values.
   */
  public List<Mass> getCarbohydrateContents() {
  	return this.carbohydrateContent;
  }
  
  /**
   * Get all the cholesterolContent property values for this NutritionInformation object.
   *
   * @return A list of cholesterolContent property values.
   */
  public List<Mass> getCholesterolContents() {
  	return this.cholesterolContent;
  }
  
  /**
   * Get all the description property values for this NutritionInformation object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the fatContent property values for this NutritionInformation object.
   *
   * @return A list of fatContent property values.
   */
  public List<Mass> getFatContents() {
  	return this.fatContent;
  }
  
  /**
   * Get all the fiberContent property values for this NutritionInformation object.
   *
   * @return A list of fiberContent property values.
   */
  public List<Mass> getFiberContents() {
  	return this.fiberContent;
  }
  
  /**
   * Get all the image property values for this NutritionInformation object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this NutritionInformation object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the proteinContent property values for this NutritionInformation object.
   *
   * @return A list of proteinContent property values.
   */
  public List<Mass> getProteinContents() {
  	return this.proteinContent;
  }
  
  /**
   * Get all the sameAs property values for this NutritionInformation object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the saturatedFatContent property values for this NutritionInformation object.
   *
   * @return A list of saturatedFatContent property values.
   */
  public List<Mass> getSaturatedFatContents() {
  	return this.saturatedFatContent;
  }
  
  /**
   * Get all the servingSize property values for this NutritionInformation object.
   *
   * @return A list of servingSize property values.
   */
  public List<String> getServingSizes() {
  	return this.servingSize;
  }
  
  /**
   * Get all the sodiumContent property values for this NutritionInformation object.
   *
   * @return A list of sodiumContent property values.
   */
  public List<Mass> getSodiumContents() {
  	return this.sodiumContent;
  }
  
  /**
   * Get all the sugarContent property values for this NutritionInformation object.
   *
   * @return A list of sugarContent property values.
   */
  public List<Mass> getSugarContents() {
  	return this.sugarContent;
  }
  
  /**
   * Get all the transFatContent property values for this NutritionInformation object.
   *
   * @return A list of transFatContent property values.
   */
  public List<Mass> getTransFatContents() {
  	return this.transFatContent;
  }
  
  /**
   * Get all the unsaturatedFatContent property values for this NutritionInformation object.
   *
   * @return A list of unsaturatedFatContent property values.
   */
  public List<Mass> getUnsaturatedFatContents() {
  	return this.unsaturatedFatContent;
  }
  
  /**
   * Get all the url property values for this NutritionInformation object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the calories property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param calories The value to set.
   */
  public void setCalories(Energy calories) {
  	this.calories.clear();
  	this.calories.add(calories);
  }
  
  /**
   * Set the carbohydrateContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param carbohydrateContent The value to set.
   */
  public void setCarbohydrateContent(Mass carbohydrateContent) {
  	this.carbohydrateContent.clear();
  	this.carbohydrateContent.add(carbohydrateContent);
  }
  
  /**
   * Set the cholesterolContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param cholesterolContent The value to set.
   */
  public void setCholesterolContent(Mass cholesterolContent) {
  	this.cholesterolContent.clear();
  	this.cholesterolContent.add(cholesterolContent);
  }
  
  /**
   * Set the description property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the fatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param fatContent The value to set.
   */
  public void setFatContent(Mass fatContent) {
  	this.fatContent.clear();
  	this.fatContent.add(fatContent);
  }
  
  /**
   * Set the fiberContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param fiberContent The value to set.
   */
  public void setFiberContent(Mass fiberContent) {
  	this.fiberContent.clear();
  	this.fiberContent.add(fiberContent);
  }
  
  /**
   * Set the image property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the proteinContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param proteinContent The value to set.
   */
  public void setProteinContent(Mass proteinContent) {
  	this.proteinContent.clear();
  	this.proteinContent.add(proteinContent);
  }
  
  /**
   * Set the sameAs property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the saturatedFatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param saturatedFatContent The value to set.
   */
  public void setSaturatedFatContent(Mass saturatedFatContent) {
  	this.saturatedFatContent.clear();
  	this.saturatedFatContent.add(saturatedFatContent);
  }
  
  /**
   * Set the servingSize property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param servingSize The value to set.
   */
  public void setServingSize(String servingSize) {
  	this.servingSize.clear();
  	this.servingSize.add(servingSize);
  }
  
  /**
   * Set the sodiumContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param sodiumContent The value to set.
   */
  public void setSodiumContent(Mass sodiumContent) {
  	this.sodiumContent.clear();
  	this.sodiumContent.add(sodiumContent);
  }
  
  /**
   * Set the sugarContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param sugarContent The value to set.
   */
  public void setSugarContent(Mass sugarContent) {
  	this.sugarContent.clear();
  	this.sugarContent.add(sugarContent);
  }
  
  /**
   * Set the transFatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param transFatContent The value to set.
   */
  public void setTransFatContent(Mass transFatContent) {
  	this.transFatContent.clear();
  	this.transFatContent.add(transFatContent);
  }
  
  /**
   * Set the unsaturatedFatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param unsaturatedFatContent The value to set.
   */
  public void setUnsaturatedFatContent(Mass unsaturatedFatContent) {
  	this.unsaturatedFatContent.clear();
  	this.unsaturatedFatContent.add(unsaturatedFatContent);
  }
  
  /**
   * Set the url property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the calories property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param caloriess The list of values to set.
   */
  public void setCaloriess(List<Energy> caloriess) {
  	this.calories = caloriess;
  }
  
  /**
   * Set the carbohydrateContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param carbohydrateContents The list of values to set.
   */
  public void setCarbohydrateContents(List<Mass> carbohydrateContents) {
  	this.carbohydrateContent = carbohydrateContents;
  }
  
  /**
   * Set the cholesterolContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param cholesterolContents The list of values to set.
   */
  public void setCholesterolContents(List<Mass> cholesterolContents) {
  	this.cholesterolContent = cholesterolContents;
  }
  
  /**
   * Set the description property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the fatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param fatContents The list of values to set.
   */
  public void setFatContents(List<Mass> fatContents) {
  	this.fatContent = fatContents;
  }
  
  /**
   * Set the fiberContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param fiberContents The list of values to set.
   */
  public void setFiberContents(List<Mass> fiberContents) {
  	this.fiberContent = fiberContents;
  }
  
  /**
   * Set the image property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the proteinContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param proteinContents The list of values to set.
   */
  public void setProteinContents(List<Mass> proteinContents) {
  	this.proteinContent = proteinContents;
  }
  
  /**
   * Set the sameAs property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the saturatedFatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param saturatedFatContents The list of values to set.
   */
  public void setSaturatedFatContents(List<Mass> saturatedFatContents) {
  	this.saturatedFatContent = saturatedFatContents;
  }
  
  /**
   * Set the servingSize property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param servingSizes The list of values to set.
   */
  public void setServingSizes(List<String> servingSizes) {
  	this.servingSize = servingSizes;
  }
  
  /**
   * Set the sodiumContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param sodiumContents The list of values to set.
   */
  public void setSodiumContents(List<Mass> sodiumContents) {
  	this.sodiumContent = sodiumContents;
  }
  
  /**
   * Set the sugarContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param sugarContents The list of values to set.
   */
  public void setSugarContents(List<Mass> sugarContents) {
  	this.sugarContent = sugarContents;
  }
  
  /**
   * Set the transFatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param transFatContents The list of values to set.
   */
  public void setTransFatContents(List<Mass> transFatContents) {
  	this.transFatContent = transFatContents;
  }
  
  /**
   * Set the unsaturatedFatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param unsaturatedFatContents The list of values to set.
   */
  public void setUnsaturatedFatContents(List<Mass> unsaturatedFatContents) {
  	this.unsaturatedFatContent = unsaturatedFatContents;
  }
  
  /**
   * Set the url property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a calories property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param calories The value to add.
   */
  public void addCalories(Energy calories) {
  	this.calories.add(calories);
  }
  
  /**
   * Adds a carbohydrateContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param carbohydrateContent The value to add.
   */
  public void addCarbohydrateContent(Mass carbohydrateContent) {
  	this.carbohydrateContent.add(carbohydrateContent);
  }
  
  /**
   * Adds a cholesterolContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param cholesterolContent The value to add.
   */
  public void addCholesterolContent(Mass cholesterolContent) {
  	this.cholesterolContent.add(cholesterolContent);
  }
  
  /**
   * Adds a description property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a fatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param fatContent The value to add.
   */
  public void addFatContent(Mass fatContent) {
  	this.fatContent.add(fatContent);
  }
  
  /**
   * Adds a fiberContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param fiberContent The value to add.
   */
  public void addFiberContent(Mass fiberContent) {
  	this.fiberContent.add(fiberContent);
  }
  
  /**
   * Adds a image property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a proteinContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param proteinContent The value to add.
   */
  public void addProteinContent(Mass proteinContent) {
  	this.proteinContent.add(proteinContent);
  }
  
  /**
   * Adds a sameAs property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a saturatedFatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param saturatedFatContent The value to add.
   */
  public void addSaturatedFatContent(Mass saturatedFatContent) {
  	this.saturatedFatContent.add(saturatedFatContent);
  }
  
  /**
   * Adds a servingSize property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param servingSize The value to add.
   */
  public void addServingSize(String servingSize) {
  	this.servingSize.add(servingSize);
  }
  
  /**
   * Adds a sodiumContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param sodiumContent The value to add.
   */
  public void addSodiumContent(Mass sodiumContent) {
  	this.sodiumContent.add(sodiumContent);
  }
  
  /**
   * Adds a sugarContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param sugarContent The value to add.
   */
  public void addSugarContent(Mass sugarContent) {
  	this.sugarContent.add(sugarContent);
  }
  
  /**
   * Adds a transFatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param transFatContent The value to add.
   */
  public void addTransFatContent(Mass transFatContent) {
  	this.transFatContent.add(transFatContent);
  }
  
  /**
   * Adds a unsaturatedFatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param unsaturatedFatContent The value to add.
   */
  public void addUnsaturatedFatContent(Mass unsaturatedFatContent) {
  	this.unsaturatedFatContent.add(unsaturatedFatContent);
  }
  
  /**
   * Adds a url property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}