package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.DayOfWeek;
import org.schema.OpeningHoursSpecification;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A structured value providing information about the opening hours of a place or a certain service inside a place.
 */
public class OpeningHoursSpecificationImpl extends SchemaObjectImpl implements OpeningHoursSpecification {


  private ThingImpl thing;

  /**
   * The closing hour of the place or service on the given day(s) of the week.
   */
  private List<Date> closes = new LinkedList<Date>();
  
  /**
   * The day of the week for which these opening hours are valid.
   */
  private List<DayOfWeek> dayOfWeek = new LinkedList<DayOfWeek>();
  
  /**
   * The opening hour of the place or service on the given day(s) of the week.
   */
  private List<Date> opens = new LinkedList<Date>();
  
  /**
   * The date when the item becomes valid.
   */
  private List<Date> validFrom = new LinkedList<Date>();
  
  /**
   * The end of the validity of offer, price specification, or opening hours data.
   */
  private List<Date> validThrough = new LinkedList<Date>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public OpeningHoursSpecificationImpl() {
    super("http://schema.org/OpeningHoursSpecification");
  }
  /**
   * Get a single additionalType property value for this OpeningHoursSpecification object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this OpeningHoursSpecification object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single closes property value for this OpeningHoursSpecification object.
   *
   * @return The first closes property value.
   */
  public Date getCloses() {
  	return this.closes.isEmpty() ? null : this.closes.get(0);
  }
  
  /**
   * Get a single dayOfWeek property value for this OpeningHoursSpecification object.
   *
   * @return The first dayOfWeek property value.
   */
  public DayOfWeek getDayOfWeek() {
  	return this.dayOfWeek.isEmpty() ? null : this.dayOfWeek.get(0);
  }
  
  /**
   * Get a single description property value for this OpeningHoursSpecification object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this OpeningHoursSpecification object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this OpeningHoursSpecification object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single opens property value for this OpeningHoursSpecification object.
   *
   * @return The first opens property value.
   */
  public Date getOpens() {
  	return this.opens.isEmpty() ? null : this.opens.get(0);
  }
  
  /**
   * Get a single sameAs property value for this OpeningHoursSpecification object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this OpeningHoursSpecification object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single validFrom property value for this OpeningHoursSpecification object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom() {
  	return this.validFrom.isEmpty() ? null : this.validFrom.get(0);
  }
  
  /**
   * Get a single validThrough property value for this OpeningHoursSpecification object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough() {
  	return this.validThrough.isEmpty() ? null : this.validThrough.get(0);
  }
  
  /**
   * Get all the additionalType property values for this OpeningHoursSpecification object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this OpeningHoursSpecification object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the closes property values for this OpeningHoursSpecification object.
   *
   * @return A list of closes property values.
   */
  public List<Date> getClosess() {
  	return this.closes;
  }
  
  /**
   * Get all the dayOfWeek property values for this OpeningHoursSpecification object.
   *
   * @return A list of dayOfWeek property values.
   */
  public List<DayOfWeek> getDayOfWeeks() {
  	return this.dayOfWeek;
  }
  
  /**
   * Get all the description property values for this OpeningHoursSpecification object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this OpeningHoursSpecification object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this OpeningHoursSpecification object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the opens property values for this OpeningHoursSpecification object.
   *
   * @return A list of opens property values.
   */
  public List<Date> getOpenss() {
  	return this.opens;
  }
  
  /**
   * Get all the sameAs property values for this OpeningHoursSpecification object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this OpeningHoursSpecification object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the validFrom property values for this OpeningHoursSpecification object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms() {
  	return this.validFrom;
  }
  
  /**
   * Get all the validThrough property values for this OpeningHoursSpecification object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs() {
  	return this.validThrough;
  }
  
  /**
   * Set the additionalType property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the closes property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param closes The value to set.
   */
  public void setCloses(Date closes) {
  	this.closes.clear();
  	this.closes.add(closes);
  }
  
  /**
   * Set the dayOfWeek property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param dayOfWeek The value to set.
   */
  public void setDayOfWeek(DayOfWeek dayOfWeek) {
  	this.dayOfWeek.clear();
  	this.dayOfWeek.add(dayOfWeek);
  }
  
  /**
   * Set the description property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the opens property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param opens The value to set.
   */
  public void setOpens(Date opens) {
  	this.opens.clear();
  	this.opens.add(opens);
  }
  
  /**
   * Set the sameAs property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the validFrom property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom) {
  	this.validFrom.clear();
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Set the validThrough property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough) {
  	this.validThrough.clear();
  	this.validThrough.add(validThrough);
  }
  
  /**
   * Set the additionalType property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the closes property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param closess The list of values to set.
   */
  public void setClosess(List<Date> closess) {
  	this.closes = closess;
  }
  
  /**
   * Set the dayOfWeek property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param dayOfWeeks The list of values to set.
   */
  public void setDayOfWeeks(List<DayOfWeek> dayOfWeeks) {
  	this.dayOfWeek = dayOfWeeks;
  }
  
  /**
   * Set the description property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the opens property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param openss The list of values to set.
   */
  public void setOpenss(List<Date> openss) {
  	this.opens = openss;
  }
  
  /**
   * Set the sameAs property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the validFrom property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms) {
  	this.validFrom = validFroms;
  }
  
  /**
   * Set the validThrough property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs) {
  	this.validThrough = validThroughs;
  }
  
  /**
   * Adds a additionalType property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a closes property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param closes The value to add.
   */
  public void addCloses(Date closes) {
  	this.closes.add(closes);
  }
  
  /**
   * Adds a dayOfWeek property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param dayOfWeek The value to add.
   */
  public void addDayOfWeek(DayOfWeek dayOfWeek) {
  	this.dayOfWeek.add(dayOfWeek);
  }
  
  /**
   * Adds a description property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a opens property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param opens The value to add.
   */
  public void addOpens(Date opens) {
  	this.opens.add(opens);
  }
  
  /**
   * Adds a sameAs property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a validFrom property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom) {
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Adds a validThrough property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough) {
  	this.validThrough.add(validThrough);
  }
  
}