package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Offer;
import org.schema.Order;
import org.schema.OrderStatus;
import org.schema.PaymentMethod;
import org.schema.PostalAddress;
import org.schema.Product;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An order is a confirmation of a transaction (a receipt), which can contain multiple line items, each represented by an Offer that has been accepted by the customer.
 */
public class OrderImpl extends SchemaObjectImpl implements Order {


  private ThingImpl thing;

  /**
   * The offer(s) -- e.g., product, quantity and price combinations -- included in the order.
   */
  private List<Offer> acceptedOffer = new LinkedList<Offer>();
  
  /**
   * The billing address for the order.
   */
  private List<PostalAddress> billingAddress = new LinkedList<PostalAddress>();
  
  /**
   * A number that confirms the given order.
   */
  private List<String> confirmationNumber = new LinkedList<String>();
  
  /**
   * Party placing the order.
   */
  private List<Thing> customer = new LinkedList<Thing>();
  
  /**
   * Any discount applied (to an Order).
   */
  private List<Thing> discount = new LinkedList<Thing>();
  
  /**
   * Code used to redeem a discount.
   */
  private List<String> discountCode = new LinkedList<String>();
  
  /**
   * The currency (in 3-letter ISO 4217 format) of the discount.
   */
  private List<String> discountCurrency = new LinkedList<String>();
  
  /**
   * Was the offer accepted as a gift for someone other than the buyer.
   */
  private List<Boolean> isGift = new LinkedList<Boolean>();
  
  /**
   * The party taking the order (e.g. Amazon.com is a merchant for many sellers).
   */
  private List<Thing> merchant = new LinkedList<Thing>();
  
  /**
   * Date order was placed.
   */
  private List<Date> orderDate = new LinkedList<Date>();
  
  /**
   * The identifier of the transaction.
   */
  private List<String> orderNumber = new LinkedList<String>();
  
  /**
   * The current status of the order.
   */
  private List<OrderStatus> orderStatus = new LinkedList<OrderStatus>();
  
  /**
   * The item ordered.
   */
  private List<Product> orderedItem = new LinkedList<Product>();
  
  /**
   * The date that payment is due.
   */
  private List<Date> paymentDue = new LinkedList<Date>();
  
  /**
   * The name of the credit card or other method of payment for the order.
   */
  private List<PaymentMethod> paymentMethod = new LinkedList<PaymentMethod>();
  
  /**
   * An identifier for the method of payment used (e.g. the last 4 digits of the credit card).
   */
  private List<String> paymentMethodId = new LinkedList<String>();
  
  /**
   * The URL for sending a payment.
   */
  private List<URL> paymentUrl = new LinkedList<URL>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public OrderImpl() {
    super("http://schema.org/Order");
  }
  /**
   * Get a single acceptedOffer property value for this Order object.
   *
   * @return The first acceptedOffer property value.
   */
  public Offer getAcceptedOffer() {
  	return this.acceptedOffer.isEmpty() ? null : this.acceptedOffer.get(0);
  }
  
  /**
   * Get a single additionalType property value for this Order object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Order object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single billingAddress property value for this Order object.
   *
   * @return The first billingAddress property value.
   */
  public PostalAddress getBillingAddress() {
  	return this.billingAddress.isEmpty() ? null : this.billingAddress.get(0);
  }
  
  /**
   * Get a single confirmationNumber property value for this Order object.
   *
   * @return The first confirmationNumber property value.
   */
  public String getConfirmationNumber() {
  	return this.confirmationNumber.isEmpty() ? null : this.confirmationNumber.get(0);
  }
  
  /**
   * Get a single customer property value for this Order object.
   *
   * @return The first customer property value.
   */
  public Thing getCustomer() {
  	return this.customer.isEmpty() ? null : this.customer.get(0);
  }
  
  /**
   * Get a single description property value for this Order object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single discount property value for this Order object.
   *
   * @return The first discount property value.
   */
  public Thing getDiscount() {
  	return this.discount.isEmpty() ? null : this.discount.get(0);
  }
  
  /**
   * Get a single discountCode property value for this Order object.
   *
   * @return The first discountCode property value.
   */
  public String getDiscountCode() {
  	return this.discountCode.isEmpty() ? null : this.discountCode.get(0);
  }
  
  /**
   * Get a single discountCurrency property value for this Order object.
   *
   * @return The first discountCurrency property value.
   */
  public String getDiscountCurrency() {
  	return this.discountCurrency.isEmpty() ? null : this.discountCurrency.get(0);
  }
  
  /**
   * Get a single image property value for this Order object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single isGift property value for this Order object.
   *
   * @return The first isGift property value.
   */
  public Boolean getIsGift() {
  	return this.isGift.isEmpty() ? null : this.isGift.get(0);
  }
  
  /**
   * Get a single merchant property value for this Order object.
   *
   * @return The first merchant property value.
   */
  public Thing getMerchant() {
  	return this.merchant.isEmpty() ? null : this.merchant.get(0);
  }
  
  /**
   * Get a single name property value for this Order object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single orderDate property value for this Order object.
   *
   * @return The first orderDate property value.
   */
  public Date getOrderDate() {
  	return this.orderDate.isEmpty() ? null : this.orderDate.get(0);
  }
  
  /**
   * Get a single orderNumber property value for this Order object.
   *
   * @return The first orderNumber property value.
   */
  public String getOrderNumber() {
  	return this.orderNumber.isEmpty() ? null : this.orderNumber.get(0);
  }
  
  /**
   * Get a single orderStatus property value for this Order object.
   *
   * @return The first orderStatus property value.
   */
  public OrderStatus getOrderStatus() {
  	return this.orderStatus.isEmpty() ? null : this.orderStatus.get(0);
  }
  
  /**
   * Get a single orderedItem property value for this Order object.
   *
   * @return The first orderedItem property value.
   */
  public Product getOrderedItem() {
  	return this.orderedItem.isEmpty() ? null : this.orderedItem.get(0);
  }
  
  /**
   * Get a single paymentDue property value for this Order object.
   *
   * @return The first paymentDue property value.
   */
  public Date getPaymentDue() {
  	return this.paymentDue.isEmpty() ? null : this.paymentDue.get(0);
  }
  
  /**
   * Get a single paymentMethod property value for this Order object.
   *
   * @return The first paymentMethod property value.
   */
  public PaymentMethod getPaymentMethod() {
  	return this.paymentMethod.isEmpty() ? null : this.paymentMethod.get(0);
  }
  
  /**
   * Get a single paymentMethodId property value for this Order object.
   *
   * @return The first paymentMethodId property value.
   */
  public String getPaymentMethodId() {
  	return this.paymentMethodId.isEmpty() ? null : this.paymentMethodId.get(0);
  }
  
  /**
   * Get a single paymentUrl property value for this Order object.
   *
   * @return The first paymentUrl property value.
   */
  public URL getPaymentUrl() {
  	return this.paymentUrl.isEmpty() ? null : this.paymentUrl.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Order object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this Order object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the acceptedOffer property values for this Order object.
   *
   * @return A list of acceptedOffer property values.
   */
  public List<Offer> getAcceptedOffers() {
  	return this.acceptedOffer;
  }
  
  /**
   * Get all the additionalType property values for this Order object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Order object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the billingAddress property values for this Order object.
   *
   * @return A list of billingAddress property values.
   */
  public List<PostalAddress> getBillingAddresses() {
  	return this.billingAddress;
  }
  
  /**
   * Get all the confirmationNumber property values for this Order object.
   *
   * @return A list of confirmationNumber property values.
   */
  public List<String> getConfirmationNumbers() {
  	return this.confirmationNumber;
  }
  
  /**
   * Get all the customer property values for this Order object.
   *
   * @return A list of customer property values.
   */
  public List<Thing> getCustomers() {
  	return this.customer;
  }
  
  /**
   * Get all the description property values for this Order object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the discount property values for this Order object.
   *
   * @return A list of discount property values.
   */
  public List<Thing> getDiscounts() {
  	return this.discount;
  }
  
  /**
   * Get all the discountCode property values for this Order object.
   *
   * @return A list of discountCode property values.
   */
  public List<String> getDiscountCodes() {
  	return this.discountCode;
  }
  
  /**
   * Get all the discountCurrency property values for this Order object.
   *
   * @return A list of discountCurrency property values.
   */
  public List<String> getDiscountCurrencies() {
  	return this.discountCurrency;
  }
  
  /**
   * Get all the image property values for this Order object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the isGift property values for this Order object.
   *
   * @return A list of isGift property values.
   */
  public List<Boolean> getIsGifts() {
  	return this.isGift;
  }
  
  /**
   * Get all the merchant property values for this Order object.
   *
   * @return A list of merchant property values.
   */
  public List<Thing> getMerchants() {
  	return this.merchant;
  }
  
  /**
   * Get all the name property values for this Order object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the orderDate property values for this Order object.
   *
   * @return A list of orderDate property values.
   */
  public List<Date> getOrderDates() {
  	return this.orderDate;
  }
  
  /**
   * Get all the orderNumber property values for this Order object.
   *
   * @return A list of orderNumber property values.
   */
  public List<String> getOrderNumbers() {
  	return this.orderNumber;
  }
  
  /**
   * Get all the orderStatus property values for this Order object.
   *
   * @return A list of orderStatus property values.
   */
  public List<OrderStatus> getOrderStatuses() {
  	return this.orderStatus;
  }
  
  /**
   * Get all the orderedItem property values for this Order object.
   *
   * @return A list of orderedItem property values.
   */
  public List<Product> getOrderedItems() {
  	return this.orderedItem;
  }
  
  /**
   * Get all the paymentDue property values for this Order object.
   *
   * @return A list of paymentDue property values.
   */
  public List<Date> getPaymentDues() {
  	return this.paymentDue;
  }
  
  /**
   * Get all the paymentMethod property values for this Order object.
   *
   * @return A list of paymentMethod property values.
   */
  public List<PaymentMethod> getPaymentMethods() {
  	return this.paymentMethod;
  }
  
  /**
   * Get all the paymentMethodId property values for this Order object.
   *
   * @return A list of paymentMethodId property values.
   */
  public List<String> getPaymentMethodIds() {
  	return this.paymentMethodId;
  }
  
  /**
   * Get all the paymentUrl property values for this Order object.
   *
   * @return A list of paymentUrl property values.
   */
  public List<URL> getPaymentUrls() {
  	return this.paymentUrl;
  }
  
  /**
   * Get all the sameAs property values for this Order object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this Order object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the acceptedOffer property value for this Order object; overwriting any existing values.
   *
   * @param acceptedOffer The value to set.
   */
  public void setAcceptedOffer(Offer acceptedOffer) {
  	this.acceptedOffer.clear();
  	this.acceptedOffer.add(acceptedOffer);
  }
  
  /**
   * Set the additionalType property value for this Order object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Order object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the billingAddress property value for this Order object; overwriting any existing values.
   *
   * @param billingAddress The value to set.
   */
  public void setBillingAddress(PostalAddress billingAddress) {
  	this.billingAddress.clear();
  	this.billingAddress.add(billingAddress);
  }
  
  /**
   * Set the confirmationNumber property value for this Order object; overwriting any existing values.
   *
   * @param confirmationNumber The value to set.
   */
  public void setConfirmationNumber(String confirmationNumber) {
  	this.confirmationNumber.clear();
  	this.confirmationNumber.add(confirmationNumber);
  }
  
  /**
   * Set the customer property value for this Order object; overwriting any existing values.
   *
   * @param customer The value to set.
   */
  public void setCustomer(Thing customer) {
  	this.customer.clear();
  	this.customer.add(customer);
  }
  
  /**
   * Set the description property value for this Order object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the discount property value for this Order object; overwriting any existing values.
   *
   * @param discount The value to set.
   */
  public void setDiscount(Thing discount) {
  	this.discount.clear();
  	this.discount.add(discount);
  }
  
  /**
   * Set the discountCode property value for this Order object; overwriting any existing values.
   *
   * @param discountCode The value to set.
   */
  public void setDiscountCode(String discountCode) {
  	this.discountCode.clear();
  	this.discountCode.add(discountCode);
  }
  
  /**
   * Set the discountCurrency property value for this Order object; overwriting any existing values.
   *
   * @param discountCurrency The value to set.
   */
  public void setDiscountCurrency(String discountCurrency) {
  	this.discountCurrency.clear();
  	this.discountCurrency.add(discountCurrency);
  }
  
  /**
   * Set the image property value for this Order object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the isGift property value for this Order object; overwriting any existing values.
   *
   * @param isGift The value to set.
   */
  public void setIsGift(Boolean isGift) {
  	this.isGift.clear();
  	this.isGift.add(isGift);
  }
  
  /**
   * Set the merchant property value for this Order object; overwriting any existing values.
   *
   * @param merchant The value to set.
   */
  public void setMerchant(Thing merchant) {
  	this.merchant.clear();
  	this.merchant.add(merchant);
  }
  
  /**
   * Set the name property value for this Order object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the orderDate property value for this Order object; overwriting any existing values.
   *
   * @param orderDate The value to set.
   */
  public void setOrderDate(Date orderDate) {
  	this.orderDate.clear();
  	this.orderDate.add(orderDate);
  }
  
  /**
   * Set the orderNumber property value for this Order object; overwriting any existing values.
   *
   * @param orderNumber The value to set.
   */
  public void setOrderNumber(String orderNumber) {
  	this.orderNumber.clear();
  	this.orderNumber.add(orderNumber);
  }
  
  /**
   * Set the orderStatus property value for this Order object; overwriting any existing values.
   *
   * @param orderStatus The value to set.
   */
  public void setOrderStatus(OrderStatus orderStatus) {
  	this.orderStatus.clear();
  	this.orderStatus.add(orderStatus);
  }
  
  /**
   * Set the orderedItem property value for this Order object; overwriting any existing values.
   *
   * @param orderedItem The value to set.
   */
  public void setOrderedItem(Product orderedItem) {
  	this.orderedItem.clear();
  	this.orderedItem.add(orderedItem);
  }
  
  /**
   * Set the paymentDue property value for this Order object; overwriting any existing values.
   *
   * @param paymentDue The value to set.
   */
  public void setPaymentDue(Date paymentDue) {
  	this.paymentDue.clear();
  	this.paymentDue.add(paymentDue);
  }
  
  /**
   * Set the paymentMethod property value for this Order object; overwriting any existing values.
   *
   * @param paymentMethod The value to set.
   */
  public void setPaymentMethod(PaymentMethod paymentMethod) {
  	this.paymentMethod.clear();
  	this.paymentMethod.add(paymentMethod);
  }
  
  /**
   * Set the paymentMethodId property value for this Order object; overwriting any existing values.
   *
   * @param paymentMethodId The value to set.
   */
  public void setPaymentMethodId(String paymentMethodId) {
  	this.paymentMethodId.clear();
  	this.paymentMethodId.add(paymentMethodId);
  }
  
  /**
   * Set the paymentUrl property value for this Order object; overwriting any existing values.
   *
   * @param paymentUrl The value to set.
   */
  public void setPaymentUrl(URL paymentUrl) {
  	this.paymentUrl.clear();
  	this.paymentUrl.add(paymentUrl);
  }
  
  /**
   * Set the sameAs property value for this Order object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this Order object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the acceptedOffer property values for this Order object; overwriting any existing values.
   *
   * @param acceptedOffers The list of values to set.
   */
  public void setAcceptedOffers(List<Offer> acceptedOffers) {
  	this.acceptedOffer = acceptedOffers;
  }
  
  /**
   * Set the additionalType property values for this Order object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Order object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the billingAddress property values for this Order object; overwriting any existing values.
   *
   * @param billingAddresses The list of values to set.
   */
  public void setBillingAddresses(List<PostalAddress> billingAddresses) {
  	this.billingAddress = billingAddresses;
  }
  
  /**
   * Set the confirmationNumber property values for this Order object; overwriting any existing values.
   *
   * @param confirmationNumbers The list of values to set.
   */
  public void setConfirmationNumbers(List<String> confirmationNumbers) {
  	this.confirmationNumber = confirmationNumbers;
  }
  
  /**
   * Set the customer property values for this Order object; overwriting any existing values.
   *
   * @param customers The list of values to set.
   */
  public void setCustomers(List<Thing> customers) {
  	this.customer = customers;
  }
  
  /**
   * Set the description property values for this Order object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the discount property values for this Order object; overwriting any existing values.
   *
   * @param discounts The list of values to set.
   */
  public void setDiscounts(List<Thing> discounts) {
  	this.discount = discounts;
  }
  
  /**
   * Set the discountCode property values for this Order object; overwriting any existing values.
   *
   * @param discountCodes The list of values to set.
   */
  public void setDiscountCodes(List<String> discountCodes) {
  	this.discountCode = discountCodes;
  }
  
  /**
   * Set the discountCurrency property values for this Order object; overwriting any existing values.
   *
   * @param discountCurrencies The list of values to set.
   */
  public void setDiscountCurrencies(List<String> discountCurrencies) {
  	this.discountCurrency = discountCurrencies;
  }
  
  /**
   * Set the image property values for this Order object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the isGift property values for this Order object; overwriting any existing values.
   *
   * @param isGifts The list of values to set.
   */
  public void setIsGifts(List<Boolean> isGifts) {
  	this.isGift = isGifts;
  }
  
  /**
   * Set the merchant property values for this Order object; overwriting any existing values.
   *
   * @param merchants The list of values to set.
   */
  public void setMerchants(List<Thing> merchants) {
  	this.merchant = merchants;
  }
  
  /**
   * Set the name property values for this Order object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the orderDate property values for this Order object; overwriting any existing values.
   *
   * @param orderDates The list of values to set.
   */
  public void setOrderDates(List<Date> orderDates) {
  	this.orderDate = orderDates;
  }
  
  /**
   * Set the orderNumber property values for this Order object; overwriting any existing values.
   *
   * @param orderNumbers The list of values to set.
   */
  public void setOrderNumbers(List<String> orderNumbers) {
  	this.orderNumber = orderNumbers;
  }
  
  /**
   * Set the orderStatus property values for this Order object; overwriting any existing values.
   *
   * @param orderStatuses The list of values to set.
   */
  public void setOrderStatuses(List<OrderStatus> orderStatuses) {
  	this.orderStatus = orderStatuses;
  }
  
  /**
   * Set the orderedItem property values for this Order object; overwriting any existing values.
   *
   * @param orderedItems The list of values to set.
   */
  public void setOrderedItems(List<Product> orderedItems) {
  	this.orderedItem = orderedItems;
  }
  
  /**
   * Set the paymentDue property values for this Order object; overwriting any existing values.
   *
   * @param paymentDues The list of values to set.
   */
  public void setPaymentDues(List<Date> paymentDues) {
  	this.paymentDue = paymentDues;
  }
  
  /**
   * Set the paymentMethod property values for this Order object; overwriting any existing values.
   *
   * @param paymentMethods The list of values to set.
   */
  public void setPaymentMethods(List<PaymentMethod> paymentMethods) {
  	this.paymentMethod = paymentMethods;
  }
  
  /**
   * Set the paymentMethodId property values for this Order object; overwriting any existing values.
   *
   * @param paymentMethodIds The list of values to set.
   */
  public void setPaymentMethodIds(List<String> paymentMethodIds) {
  	this.paymentMethodId = paymentMethodIds;
  }
  
  /**
   * Set the paymentUrl property values for this Order object; overwriting any existing values.
   *
   * @param paymentUrls The list of values to set.
   */
  public void setPaymentUrls(List<URL> paymentUrls) {
  	this.paymentUrl = paymentUrls;
  }
  
  /**
   * Set the sameAs property values for this Order object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this Order object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a acceptedOffer property value for this Order object; appending it to the list of existing values.
   *
   * @param acceptedOffer The value to add.
   */
  public void addAcceptedOffer(Offer acceptedOffer) {
  	this.acceptedOffer.add(acceptedOffer);
  }
  
  /**
   * Adds a additionalType property value for this Order object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Order object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a billingAddress property value for this Order object; appending it to the list of existing values.
   *
   * @param billingAddress The value to add.
   */
  public void addBillingAddress(PostalAddress billingAddress) {
  	this.billingAddress.add(billingAddress);
  }
  
  /**
   * Adds a confirmationNumber property value for this Order object; appending it to the list of existing values.
   *
   * @param confirmationNumber The value to add.
   */
  public void addConfirmationNumber(String confirmationNumber) {
  	this.confirmationNumber.add(confirmationNumber);
  }
  
  /**
   * Adds a customer property value for this Order object; appending it to the list of existing values.
   *
   * @param customer The value to add.
   */
  public void addCustomer(Thing customer) {
  	this.customer.add(customer);
  }
  
  /**
   * Adds a description property value for this Order object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a discount property value for this Order object; appending it to the list of existing values.
   *
   * @param discount The value to add.
   */
  public void addDiscount(Thing discount) {
  	this.discount.add(discount);
  }
  
  /**
   * Adds a discountCode property value for this Order object; appending it to the list of existing values.
   *
   * @param discountCode The value to add.
   */
  public void addDiscountCode(String discountCode) {
  	this.discountCode.add(discountCode);
  }
  
  /**
   * Adds a discountCurrency property value for this Order object; appending it to the list of existing values.
   *
   * @param discountCurrency The value to add.
   */
  public void addDiscountCurrency(String discountCurrency) {
  	this.discountCurrency.add(discountCurrency);
  }
  
  /**
   * Adds a image property value for this Order object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a isGift property value for this Order object; appending it to the list of existing values.
   *
   * @param isGift The value to add.
   */
  public void addIsGift(Boolean isGift) {
  	this.isGift.add(isGift);
  }
  
  /**
   * Adds a merchant property value for this Order object; appending it to the list of existing values.
   *
   * @param merchant The value to add.
   */
  public void addMerchant(Thing merchant) {
  	this.merchant.add(merchant);
  }
  
  /**
   * Adds a name property value for this Order object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a orderDate property value for this Order object; appending it to the list of existing values.
   *
   * @param orderDate The value to add.
   */
  public void addOrderDate(Date orderDate) {
  	this.orderDate.add(orderDate);
  }
  
  /**
   * Adds a orderNumber property value for this Order object; appending it to the list of existing values.
   *
   * @param orderNumber The value to add.
   */
  public void addOrderNumber(String orderNumber) {
  	this.orderNumber.add(orderNumber);
  }
  
  /**
   * Adds a orderStatus property value for this Order object; appending it to the list of existing values.
   *
   * @param orderStatus The value to add.
   */
  public void addOrderStatus(OrderStatus orderStatus) {
  	this.orderStatus.add(orderStatus);
  }
  
  /**
   * Adds a orderedItem property value for this Order object; appending it to the list of existing values.
   *
   * @param orderedItem The value to add.
   */
  public void addOrderedItem(Product orderedItem) {
  	this.orderedItem.add(orderedItem);
  }
  
  /**
   * Adds a paymentDue property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentDue The value to add.
   */
  public void addPaymentDue(Date paymentDue) {
  	this.paymentDue.add(paymentDue);
  }
  
  /**
   * Adds a paymentMethod property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentMethod The value to add.
   */
  public void addPaymentMethod(PaymentMethod paymentMethod) {
  	this.paymentMethod.add(paymentMethod);
  }
  
  /**
   * Adds a paymentMethodId property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentMethodId The value to add.
   */
  public void addPaymentMethodId(String paymentMethodId) {
  	this.paymentMethodId.add(paymentMethodId);
  }
  
  /**
   * Adds a paymentUrl property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentUrl The value to add.
   */
  public void addPaymentUrl(URL paymentUrl) {
  	this.paymentUrl.add(paymentUrl);
  }
  
  /**
   * Adds a sameAs property value for this Order object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this Order object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}