package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.ContactPoint;
import org.schema.Demand;
import org.schema.Event;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Review;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * An organization such as a school, NGO, corporation, club, etc.
 */
public class OrganizationImpl extends SchemaObjectImpl implements Organization {


  private ThingImpl thing;

  /**
   * Physical address of the item.
   */
  private List<PostalAddress> address = new LinkedList<PostalAddress>();
  
  /**
   * The overall rating, based on a collection of reviews or ratings, of the item.
   */
  private List<AggregateRating> aggregateRating = new LinkedList<AggregateRating>();
  
  /**
   * The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
   */
  private List<Thing> brand = new LinkedList<Thing>();
  
  /**
   * A contact point for a person or organization.
   */
  private List<ContactPoint> contactPoint = new LinkedList<ContactPoint>();
  
  /**
   * A relationship between an organization and a department of that organization, also described as an organization (allowing different urls, logos, opening hours). For example: a store with a pharmacy, or a bakery with a cafe.
   */
  private List<Organization> department = new LinkedList<Organization>();
  
  /**
   * The Dun & Bradstreet DUNS number for identifying an organization or business person.
   */
  private List<String> duns = new LinkedList<String>();
  
  /**
   * Email address.
   */
  private List<String> email = new LinkedList<String>();
  
  /**
   * Someone working for this organization.
   */
  private List<Person> employee = new LinkedList<Person>();
  
  /**
   * Upcoming or past event associated with this place or organization.
   */
  private List<Event> event = new LinkedList<Event>();
  
  /**
   * The fax number.
   */
  private List<String> faxNumber = new LinkedList<String>();
  
  /**
   * A person who founded this organization.
   */
  private List<Person> founder = new LinkedList<Person>();
  
  /**
   * The date that this organization was founded.
   */
  private List<Date> foundingDate = new LinkedList<Date>();
  
  /**
   * The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.
   */
  private List<String> globalLocationNumber = new LinkedList<String>();
  
  /**
   * Points-of-Sales operated by the organization or person.
   */
  private List<Place> hasPOS = new LinkedList<Place>();
  
  /**
   * A count of a specific user interactions with this item&#x2014;for example, <code>20 UserLikes</code>, <code>5 UserComments</code>, or <code>300 UserDownloads</code>. The user interaction type should be one of the sub types of <a href='UserInteraction'>UserInteraction</a>.
   */
  private List<String> interactionCount = new LinkedList<String>();
  
  /**
   * The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.
   */
  private List<String> isicV4 = new LinkedList<String>();
  
  /**
   * The official name of the organization, e.g. the registered company name.
   */
  private List<String> legalName = new LinkedList<String>();
  
  /**
   * The location of the event, organization or action.
   */
  private List<Thing> location = new LinkedList<Thing>();
  
  /**
   * A logo associated with an organization.
   */
  private List<Thing> logo = new LinkedList<Thing>();
  
  /**
   * A pointer to products or services offered by the organization or person.
   */
  private List<Offer> makesOffer = new LinkedList<Offer>();
  
  /**
   * The individual with the membership.
   */
  private List<Thing> member = new LinkedList<Thing>();
  
  /**
   * The North American Industry Classification System (NAICS) code for a particular organization or business person.
   */
  private List<String> naics = new LinkedList<String>();
  
  /**
   * Products owned by the organization or person.
   */
  private List<Thing> owns = new LinkedList<Thing>();
  
  /**
   * A review of the item.
   */
  private List<Review> review = new LinkedList<Review>();
  
  /**
   * A pointer to products or services sought by the organization or person (demand).
   */
  private List<Demand> seeks = new LinkedList<Demand>();
  
  /**
   * A relationship between two organizations where the first includes the second, e.g., as a subsidiary. See also: the more specific 'department' property.
   */
  private List<Organization> subOrganization = new LinkedList<Organization>();
  
  /**
   * The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US or the CIF/NIF in Spain.
   */
  private List<String> taxID = new LinkedList<String>();
  
  /**
   * The telephone number.
   */
  private List<String> telephone = new LinkedList<String>();
  
  /**
   * The Value-added Tax ID of the organisation or person.
   */
  private List<String> vatID = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public OrganizationImpl() {
    super("http://schema.org/Organization");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this Organization object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single address property value for this Organization object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress() {
  	return this.address.isEmpty() ? null : this.address.get(0);
  }
  
  /**
   * Get a single aggregateRating property value for this Organization object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
  	return this.aggregateRating.isEmpty() ? null : this.aggregateRating.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Organization object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single brand property value for this Organization object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand() {
  	return this.brand.isEmpty() ? null : this.brand.get(0);
  }
  
  /**
   * Get a single contactPoint property value for this Organization object.
   *
   * @return The first contactPoint property value.
   */
  public ContactPoint getContactPoint() {
  	return this.contactPoint.isEmpty() ? null : this.contactPoint.get(0);
  }
  
  /**
   * Get a single department property value for this Organization object.
   *
   * @return The first department property value.
   */
  public Organization getDepartment() {
  	return this.department.isEmpty() ? null : this.department.get(0);
  }
  
  /**
   * Get a single description property value for this Organization object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single duns property value for this Organization object.
   *
   * @return The first duns property value.
   */
  public String getDuns() {
  	return this.duns.isEmpty() ? null : this.duns.get(0);
  }
  
  /**
   * Get a single email property value for this Organization object.
   *
   * @return The first email property value.
   */
  public String getEmail() {
  	return this.email.isEmpty() ? null : this.email.get(0);
  }
  
  /**
   * Get a single employee property value for this Organization object.
   *
   * @return The first employee property value.
   */
  public Person getEmployee() {
  	return this.employee.isEmpty() ? null : this.employee.get(0);
  }
  
  /**
   * Get a single event property value for this Organization object.
   *
   * @return The first event property value.
   */
  public Event getEvent() {
  	return this.event.isEmpty() ? null : this.event.get(0);
  }
  
  /**
   * Get a single faxNumber property value for this Organization object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
  	return this.faxNumber.isEmpty() ? null : this.faxNumber.get(0);
  }
  
  /**
   * Get a single founder property value for this Organization object.
   *
   * @return The first founder property value.
   */
  public Person getFounder() {
  	return this.founder.isEmpty() ? null : this.founder.get(0);
  }
  
  /**
   * Get a single foundingDate property value for this Organization object.
   *
   * @return The first foundingDate property value.
   */
  public Date getFoundingDate() {
  	return this.foundingDate.isEmpty() ? null : this.foundingDate.get(0);
  }
  
  /**
   * Get a single globalLocationNumber property value for this Organization object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber() {
  	return this.globalLocationNumber.isEmpty() ? null : this.globalLocationNumber.get(0);
  }
  
  /**
   * Get a single hasPOS property value for this Organization object.
   *
   * @return The first hasPOS property value.
   */
  public Place getHasPOS() {
  	return this.hasPOS.isEmpty() ? null : this.hasPOS.get(0);
  }
  
  /**
   * Get a single image property value for this Organization object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single interactionCount property value for this Organization object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
  	return this.interactionCount.isEmpty() ? null : this.interactionCount.get(0);
  }
  
  /**
   * Get a single isicV4 property value for this Organization object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4() {
  	return this.isicV4.isEmpty() ? null : this.isicV4.get(0);
  }
  
  /**
   * Get a single legalName property value for this Organization object.
   *
   * @return The first legalName property value.
   */
  public String getLegalName() {
  	return this.legalName.isEmpty() ? null : this.legalName.get(0);
  }
  
  /**
   * Get a single location property value for this Organization object.
   *
   * @return The first location property value.
   */
  public Thing getLocation() {
  	return this.location.isEmpty() ? null : this.location.get(0);
  }
  
  /**
   * Get a single logo property value for this Organization object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo() {
  	return this.logo.isEmpty() ? null : this.logo.get(0);
  }
  
  /**
   * Get a single makesOffer property value for this Organization object.
   *
   * @return The first makesOffer property value.
   */
  public Offer getMakesOffer() {
  	return this.makesOffer.isEmpty() ? null : this.makesOffer.get(0);
  }
  
  /**
   * Get a single member property value for this Organization object.
   *
   * @return The first member property value.
   */
  public Thing getMember() {
  	return this.member.isEmpty() ? null : this.member.get(0);
  }
  
  /**
   * Get a single naics property value for this Organization object.
   *
   * @return The first naics property value.
   */
  public String getNaics() {
  	return this.naics.isEmpty() ? null : this.naics.get(0);
  }
  
  /**
   * Get a single name property value for this Organization object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single owns property value for this Organization object.
   *
   * @return The first owns property value.
   */
  public Thing getOwns() {
  	return this.owns.isEmpty() ? null : this.owns.get(0);
  }
  
  /**
   * Get a single review property value for this Organization object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
  	return this.review.isEmpty() ? null : this.review.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Organization object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seeks property value for this Organization object.
   *
   * @return The first seeks property value.
   */
  public Demand getSeeks() {
  	return this.seeks.isEmpty() ? null : this.seeks.get(0);
  }
  
  /**
   * Get a single subOrganization property value for this Organization object.
   *
   * @return The first subOrganization property value.
   */
  public Organization getSubOrganization() {
  	return this.subOrganization.isEmpty() ? null : this.subOrganization.get(0);
  }
  
  /**
   * Get a single taxID property value for this Organization object.
   *
   * @return The first taxID property value.
   */
  public String getTaxID() {
  	return this.taxID.isEmpty() ? null : this.taxID.get(0);
  }
  
  /**
   * Get a single telephone property value for this Organization object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
  	return this.telephone.isEmpty() ? null : this.telephone.get(0);
  }
  
  /**
   * Get a single url property value for this Organization object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single vatID property value for this Organization object.
   *
   * @return The first vatID property value.
   */
  public String getVatID() {
  	return this.vatID.isEmpty() ? null : this.vatID.get(0);
  }
  
  /**
   * Get all the additionalType property values for this Organization object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the address property values for this Organization object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses() {
  	return this.address;
  }
  
  /**
   * Get all the aggregateRating property values for this Organization object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
  	return this.aggregateRating;
  }
  
  /**
   * Get all the alternateName property values for this Organization object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the brand property values for this Organization object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands() {
  	return this.brand;
  }
  
  /**
   * Get all the contactPoint property values for this Organization object.
   *
   * @return A list of contactPoint property values.
   */
  public List<ContactPoint> getContactPoints() {
  	return this.contactPoint;
  }
  
  /**
   * Get all the department property values for this Organization object.
   *
   * @return A list of department property values.
   */
  public List<Organization> getDepartments() {
  	return this.department;
  }
  
  /**
   * Get all the description property values for this Organization object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the duns property values for this Organization object.
   *
   * @return A list of duns property values.
   */
  public List<String> getDunss() {
  	return this.duns;
  }
  
  /**
   * Get all the email property values for this Organization object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails() {
  	return this.email;
  }
  
  /**
   * Get all the employee property values for this Organization object.
   *
   * @return A list of employee property values.
   */
  public List<Person> getEmployees() {
  	return this.employee;
  }
  
  /**
   * Get all the event property values for this Organization object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents() {
  	return this.event;
  }
  
  /**
   * Get all the faxNumber property values for this Organization object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
  	return this.faxNumber;
  }
  
  /**
   * Get all the founder property values for this Organization object.
   *
   * @return A list of founder property values.
   */
  public List<Person> getFounders() {
  	return this.founder;
  }
  
  /**
   * Get all the foundingDate property values for this Organization object.
   *
   * @return A list of foundingDate property values.
   */
  public List<Date> getFoundingDates() {
  	return this.foundingDate;
  }
  
  /**
   * Get all the globalLocationNumber property values for this Organization object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers() {
  	return this.globalLocationNumber;
  }
  
  /**
   * Get all the hasPOS property values for this Organization object.
   *
   * @return A list of hasPOS property values.
   */
  public List<Place> getHasPOSs() {
  	return this.hasPOS;
  }
  
  /**
   * Get all the image property values for this Organization object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the interactionCount property values for this Organization object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
  	return this.interactionCount;
  }
  
  /**
   * Get all the isicV4 property values for this Organization object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s() {
  	return this.isicV4;
  }
  
  /**
   * Get all the legalName property values for this Organization object.
   *
   * @return A list of legalName property values.
   */
  public List<String> getLegalNames() {
  	return this.legalName;
  }
  
  /**
   * Get all the location property values for this Organization object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations() {
  	return this.location;
  }
  
  /**
   * Get all the logo property values for this Organization object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes() {
  	return this.logo;
  }
  
  /**
   * Get all the makesOffer property values for this Organization object.
   *
   * @return A list of makesOffer property values.
   */
  public List<Offer> getMakesOffers() {
  	return this.makesOffer;
  }
  
  /**
   * Get all the member property values for this Organization object.
   *
   * @return A list of member property values.
   */
  public List<Thing> getMembers() {
  	return this.member;
  }
  
  /**
   * Get all the naics property values for this Organization object.
   *
   * @return A list of naics property values.
   */
  public List<String> getNaicss() {
  	return this.naics;
  }
  
  /**
   * Get all the name property values for this Organization object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the owns property values for this Organization object.
   *
   * @return A list of owns property values.
   */
  public List<Thing> getOwnss() {
  	return this.owns;
  }
  
  /**
   * Get all the review property values for this Organization object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
  	return this.review;
  }
  
  /**
   * Get all the sameAs property values for this Organization object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seeks property values for this Organization object.
   *
   * @return A list of seeks property values.
   */
  public List<Demand> getSeekss() {
  	return this.seeks;
  }
  
  /**
   * Get all the subOrganization property values for this Organization object.
   *
   * @return A list of subOrganization property values.
   */
  public List<Organization> getSubOrganizations() {
  	return this.subOrganization;
  }
  
  /**
   * Get all the taxID property values for this Organization object.
   *
   * @return A list of taxID property values.
   */
  public List<String> getTaxIDs() {
  	return this.taxID;
  }
  
  /**
   * Get all the telephone property values for this Organization object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
  	return this.telephone;
  }
  
  /**
   * Get all the url property values for this Organization object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the vatID property values for this Organization object.
   *
   * @return A list of vatID property values.
   */
  public List<String> getVatIDs() {
  	return this.vatID;
  }
  
  /**
   * Set the additionalType property value for this Organization object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the address property value for this Organization object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address) {
  	this.address.clear();
  	this.address.add(address);
  }
  
  /**
   * Set the aggregateRating property value for this Organization object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.clear();
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this Organization object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the brand property value for this Organization object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand) {
  	this.brand.clear();
  	this.brand.add(brand);
  }
  
  /**
   * Set the contactPoint property value for this Organization object; overwriting any existing values.
   *
   * @param contactPoint The value to set.
   */
  public void setContactPoint(ContactPoint contactPoint) {
  	this.contactPoint.clear();
  	this.contactPoint.add(contactPoint);
  }
  
  /**
   * Set the department property value for this Organization object; overwriting any existing values.
   *
   * @param department The value to set.
   */
  public void setDepartment(Organization department) {
  	this.department.clear();
  	this.department.add(department);
  }
  
  /**
   * Set the description property value for this Organization object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the duns property value for this Organization object; overwriting any existing values.
   *
   * @param duns The value to set.
   */
  public void setDuns(String duns) {
  	this.duns.clear();
  	this.duns.add(duns);
  }
  
  /**
   * Set the email property value for this Organization object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email) {
  	this.email.clear();
  	this.email.add(email);
  }
  
  /**
   * Set the employee property value for this Organization object; overwriting any existing values.
   *
   * @param employee The value to set.
   */
  public void setEmployee(Person employee) {
  	this.employee.clear();
  	this.employee.add(employee);
  }
  
  /**
   * Set the event property value for this Organization object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event) {
  	this.event.clear();
  	this.event.add(event);
  }
  
  /**
   * Set the faxNumber property value for this Organization object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
  	this.faxNumber.clear();
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Set the founder property value for this Organization object; overwriting any existing values.
   *
   * @param founder The value to set.
   */
  public void setFounder(Person founder) {
  	this.founder.clear();
  	this.founder.add(founder);
  }
  
  /**
   * Set the foundingDate property value for this Organization object; overwriting any existing values.
   *
   * @param foundingDate The value to set.
   */
  public void setFoundingDate(Date foundingDate) {
  	this.foundingDate.clear();
  	this.foundingDate.add(foundingDate);
  }
  
  /**
   * Set the globalLocationNumber property value for this Organization object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber) {
  	this.globalLocationNumber.clear();
  	this.globalLocationNumber.add(globalLocationNumber);
  }
  
  /**
   * Set the hasPOS property value for this Organization object; overwriting any existing values.
   *
   * @param hasPOS The value to set.
   */
  public void setHasPOS(Place hasPOS) {
  	this.hasPOS.clear();
  	this.hasPOS.add(hasPOS);
  }
  
  /**
   * Set the image property value for this Organization object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the interactionCount property value for this Organization object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
  	this.interactionCount.clear();
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Set the isicV4 property value for this Organization object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4) {
  	this.isicV4.clear();
  	this.isicV4.add(isicV4);
  }
  
  /**
   * Set the legalName property value for this Organization object; overwriting any existing values.
   *
   * @param legalName The value to set.
   */
  public void setLegalName(String legalName) {
  	this.legalName.clear();
  	this.legalName.add(legalName);
  }
  
  /**
   * Set the location property value for this Organization object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location) {
  	this.location.clear();
  	this.location.add(location);
  }
  
  /**
   * Set the logo property value for this Organization object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo) {
  	this.logo.clear();
  	this.logo.add(logo);
  }
  
  /**
   * Set the makesOffer property value for this Organization object; overwriting any existing values.
   *
   * @param makesOffer The value to set.
   */
  public void setMakesOffer(Offer makesOffer) {
  	this.makesOffer.clear();
  	this.makesOffer.add(makesOffer);
  }
  
  /**
   * Set the member property value for this Organization object; overwriting any existing values.
   *
   * @param member The value to set.
   */
  public void setMember(Thing member) {
  	this.member.clear();
  	this.member.add(member);
  }
  
  /**
   * Set the naics property value for this Organization object; overwriting any existing values.
   *
   * @param naics The value to set.
   */
  public void setNaics(String naics) {
  	this.naics.clear();
  	this.naics.add(naics);
  }
  
  /**
   * Set the name property value for this Organization object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the owns property value for this Organization object; overwriting any existing values.
   *
   * @param owns The value to set.
   */
  public void setOwns(Thing owns) {
  	this.owns.clear();
  	this.owns.add(owns);
  }
  
  /**
   * Set the review property value for this Organization object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
  	this.review.clear();
  	this.review.add(review);
  }
  
  /**
   * Set the sameAs property value for this Organization object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seeks property value for this Organization object; overwriting any existing values.
   *
   * @param seeks The value to set.
   */
  public void setSeeks(Demand seeks) {
  	this.seeks.clear();
  	this.seeks.add(seeks);
  }
  
  /**
   * Set the subOrganization property value for this Organization object; overwriting any existing values.
   *
   * @param subOrganization The value to set.
   */
  public void setSubOrganization(Organization subOrganization) {
  	this.subOrganization.clear();
  	this.subOrganization.add(subOrganization);
  }
  
  /**
   * Set the taxID property value for this Organization object; overwriting any existing values.
   *
   * @param taxID The value to set.
   */
  public void setTaxID(String taxID) {
  	this.taxID.clear();
  	this.taxID.add(taxID);
  }
  
  /**
   * Set the telephone property value for this Organization object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
  	this.telephone.clear();
  	this.telephone.add(telephone);
  }
  
  /**
   * Set the url property value for this Organization object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the vatID property value for this Organization object; overwriting any existing values.
   *
   * @param vatID The value to set.
   */
  public void setVatID(String vatID) {
  	this.vatID.clear();
  	this.vatID.add(vatID);
  }
  
  /**
   * Set the additionalType property values for this Organization object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the address property values for this Organization object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses) {
  	this.address = addresses;
  }
  
  /**
   * Set the aggregateRating property values for this Organization object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
  	this.aggregateRating = aggregateRatings;
  }
  
  /**
   * Set the alternateName property values for this Organization object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the brand property values for this Organization object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands) {
  	this.brand = brands;
  }
  
  /**
   * Set the contactPoint property values for this Organization object; overwriting any existing values.
   *
   * @param contactPoints The list of values to set.
   */
  public void setContactPoints(List<ContactPoint> contactPoints) {
  	this.contactPoint = contactPoints;
  }
  
  /**
   * Set the department property values for this Organization object; overwriting any existing values.
   *
   * @param departments The list of values to set.
   */
  public void setDepartments(List<Organization> departments) {
  	this.department = departments;
  }
  
  /**
   * Set the description property values for this Organization object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the duns property values for this Organization object; overwriting any existing values.
   *
   * @param dunss The list of values to set.
   */
  public void setDunss(List<String> dunss) {
  	this.duns = dunss;
  }
  
  /**
   * Set the email property values for this Organization object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails) {
  	this.email = emails;
  }
  
  /**
   * Set the employee property values for this Organization object; overwriting any existing values.
   *
   * @param employees The list of values to set.
   */
  public void setEmployees(List<Person> employees) {
  	this.employee = employees;
  }
  
  /**
   * Set the event property values for this Organization object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events) {
  	this.event = events;
  }
  
  /**
   * Set the faxNumber property values for this Organization object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
  	this.faxNumber = faxNumbers;
  }
  
  /**
   * Set the founder property values for this Organization object; overwriting any existing values.
   *
   * @param founders The list of values to set.
   */
  public void setFounders(List<Person> founders) {
  	this.founder = founders;
  }
  
  /**
   * Set the foundingDate property values for this Organization object; overwriting any existing values.
   *
   * @param foundingDates The list of values to set.
   */
  public void setFoundingDates(List<Date> foundingDates) {
  	this.foundingDate = foundingDates;
  }
  
  /**
   * Set the globalLocationNumber property values for this Organization object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers) {
  	this.globalLocationNumber = globalLocationNumbers;
  }
  
  /**
   * Set the hasPOS property values for this Organization object; overwriting any existing values.
   *
   * @param hasPOSs The list of values to set.
   */
  public void setHasPOSs(List<Place> hasPOSs) {
  	this.hasPOS = hasPOSs;
  }
  
  /**
   * Set the image property values for this Organization object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the interactionCount property values for this Organization object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
  	this.interactionCount = interactionCounts;
  }
  
  /**
   * Set the isicV4 property values for this Organization object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s) {
  	this.isicV4 = isicV4s;
  }
  
  /**
   * Set the legalName property values for this Organization object; overwriting any existing values.
   *
   * @param legalNames The list of values to set.
   */
  public void setLegalNames(List<String> legalNames) {
  	this.legalName = legalNames;
  }
  
  /**
   * Set the location property values for this Organization object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations) {
  	this.location = locations;
  }
  
  /**
   * Set the logo property values for this Organization object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes) {
  	this.logo = logoes;
  }
  
  /**
   * Set the makesOffer property values for this Organization object; overwriting any existing values.
   *
   * @param makesOffers The list of values to set.
   */
  public void setMakesOffers(List<Offer> makesOffers) {
  	this.makesOffer = makesOffers;
  }
  
  /**
   * Set the member property values for this Organization object; overwriting any existing values.
   *
   * @param members The list of values to set.
   */
  public void setMembers(List<Thing> members) {
  	this.member = members;
  }
  
  /**
   * Set the naics property values for this Organization object; overwriting any existing values.
   *
   * @param naicss The list of values to set.
   */
  public void setNaicss(List<String> naicss) {
  	this.naics = naicss;
  }
  
  /**
   * Set the name property values for this Organization object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the owns property values for this Organization object; overwriting any existing values.
   *
   * @param ownss The list of values to set.
   */
  public void setOwnss(List<Thing> ownss) {
  	this.owns = ownss;
  }
  
  /**
   * Set the review property values for this Organization object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
  	this.review = reviews;
  }
  
  /**
   * Set the sameAs property values for this Organization object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seeks property values for this Organization object; overwriting any existing values.
   *
   * @param seekss The list of values to set.
   */
  public void setSeekss(List<Demand> seekss) {
  	this.seeks = seekss;
  }
  
  /**
   * Set the subOrganization property values for this Organization object; overwriting any existing values.
   *
   * @param subOrganizations The list of values to set.
   */
  public void setSubOrganizations(List<Organization> subOrganizations) {
  	this.subOrganization = subOrganizations;
  }
  
  /**
   * Set the taxID property values for this Organization object; overwriting any existing values.
   *
   * @param taxIDs The list of values to set.
   */
  public void setTaxIDs(List<String> taxIDs) {
  	this.taxID = taxIDs;
  }
  
  /**
   * Set the telephone property values for this Organization object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
  	this.telephone = telephones;
  }
  
  /**
   * Set the url property values for this Organization object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the vatID property values for this Organization object; overwriting any existing values.
   *
   * @param vatIDs The list of values to set.
   */
  public void setVatIDs(List<String> vatIDs) {
  	this.vatID = vatIDs;
  }
  
  /**
   * Adds a additionalType property value for this Organization object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a address property value for this Organization object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address) {
  	this.address.add(address);
  }
  
  /**
   * Adds a aggregateRating property value for this Organization object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this Organization object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a brand property value for this Organization object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand) {
  	this.brand.add(brand);
  }
  
  /**
   * Adds a contactPoint property value for this Organization object; appending it to the list of existing values.
   *
   * @param contactPoint The value to add.
   */
  public void addContactPoint(ContactPoint contactPoint) {
  	this.contactPoint.add(contactPoint);
  }
  
  /**
   * Adds a department property value for this Organization object; appending it to the list of existing values.
   *
   * @param department The value to add.
   */
  public void addDepartment(Organization department) {
  	this.department.add(department);
  }
  
  /**
   * Adds a description property value for this Organization object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a duns property value for this Organization object; appending it to the list of existing values.
   *
   * @param duns The value to add.
   */
  public void addDuns(String duns) {
  	this.duns.add(duns);
  }
  
  /**
   * Adds a email property value for this Organization object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email) {
  	this.email.add(email);
  }
  
  /**
   * Adds a employee property value for this Organization object; appending it to the list of existing values.
   *
   * @param employee The value to add.
   */
  public void addEmployee(Person employee) {
  	this.employee.add(employee);
  }
  
  /**
   * Adds a event property value for this Organization object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event) {
  	this.event.add(event);
  }
  
  /**
   * Adds a faxNumber property value for this Organization object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Adds a founder property value for this Organization object; appending it to the list of existing values.
   *
   * @param founder The value to add.
   */
  public void addFounder(Person founder) {
  	this.founder.add(founder);
  }
  
  /**
   * Adds a foundingDate property value for this Organization object; appending it to the list of existing values.
   *
   * @param foundingDate The value to add.
   */
  public void addFoundingDate(Date foundingDate) {
  	this.foundingDate.add(foundingDate);
  }
  
  /**
   * Adds a globalLocationNumber property value for this Organization object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber) {
  	this.globalLocationNumber.add(globalLocationNumber);
  }
  
  /**
   * Adds a hasPOS property value for this Organization object; appending it to the list of existing values.
   *
   * @param hasPOS The value to add.
   */
  public void addHasPOS(Place hasPOS) {
  	this.hasPOS.add(hasPOS);
  }
  
  /**
   * Adds a image property value for this Organization object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a interactionCount property value for this Organization object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Adds a isicV4 property value for this Organization object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4) {
  	this.isicV4.add(isicV4);
  }
  
  /**
   * Adds a legalName property value for this Organization object; appending it to the list of existing values.
   *
   * @param legalName The value to add.
   */
  public void addLegalName(String legalName) {
  	this.legalName.add(legalName);
  }
  
  /**
   * Adds a location property value for this Organization object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location) {
  	this.location.add(location);
  }
  
  /**
   * Adds a logo property value for this Organization object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo) {
  	this.logo.add(logo);
  }
  
  /**
   * Adds a makesOffer property value for this Organization object; appending it to the list of existing values.
   *
   * @param makesOffer The value to add.
   */
  public void addMakesOffer(Offer makesOffer) {
  	this.makesOffer.add(makesOffer);
  }
  
  /**
   * Adds a member property value for this Organization object; appending it to the list of existing values.
   *
   * @param member The value to add.
   */
  public void addMember(Thing member) {
  	this.member.add(member);
  }
  
  /**
   * Adds a naics property value for this Organization object; appending it to the list of existing values.
   *
   * @param naics The value to add.
   */
  public void addNaics(String naics) {
  	this.naics.add(naics);
  }
  
  /**
   * Adds a name property value for this Organization object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a owns property value for this Organization object; appending it to the list of existing values.
   *
   * @param owns The value to add.
   */
  public void addOwns(Thing owns) {
  	this.owns.add(owns);
  }
  
  /**
   * Adds a review property value for this Organization object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
  	this.review.add(review);
  }
  
  /**
   * Adds a sameAs property value for this Organization object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seeks property value for this Organization object; appending it to the list of existing values.
   *
   * @param seeks The value to add.
   */
  public void addSeeks(Demand seeks) {
  	this.seeks.add(seeks);
  }
  
  /**
   * Adds a subOrganization property value for this Organization object; appending it to the list of existing values.
   *
   * @param subOrganization The value to add.
   */
  public void addSubOrganization(Organization subOrganization) {
  	this.subOrganization.add(subOrganization);
  }
  
  /**
   * Adds a taxID property value for this Organization object; appending it to the list of existing values.
   *
   * @param taxID The value to add.
   */
  public void addTaxID(String taxID) {
  	this.taxID.add(taxID);
  }
  
  /**
   * Adds a telephone property value for this Organization object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
  	this.telephone.add(telephone);
  }
  
  /**
   * Adds a url property value for this Organization object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a vatID property value for this Organization object; appending it to the list of existing values.
   *
   * @param vatID The value to add.
   */
  public void addVatID(String vatID) {
  	this.vatID.add(vatID);
  }
  
}