package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.OwnershipInfo;
import org.schema.Product;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A structured value providing information about when a certain organization or person owned a certain product.
 */
public class OwnershipInfoImpl extends SchemaObjectImpl implements OwnershipInfo {


  private ThingImpl thing;

  /**
   * The organization or person from which the product was acquired.
   */
  private List<Thing> acquiredFrom = new LinkedList<Thing>();
  
  /**
   * The date and time of obtaining the product.
   */
  private List<Date> ownedFrom = new LinkedList<Date>();
  
  /**
   * The date and time of giving up ownership on the product.
   */
  private List<Date> ownedThrough = new LinkedList<Date>();
  
  /**
   * The product that this structured value is referring to.
   */
  private List<Product> typeOfGood = new LinkedList<Product>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public OwnershipInfoImpl() {
    super("http://schema.org/OwnershipInfo");
  }
  /**
   * Get a single acquiredFrom property value for this OwnershipInfo object.
   *
   * @return The first acquiredFrom property value.
   */
  public Thing getAcquiredFrom() {
  	return this.acquiredFrom.isEmpty() ? null : this.acquiredFrom.get(0);
  }
  
  /**
   * Get a single additionalType property value for this OwnershipInfo object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this OwnershipInfo object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this OwnershipInfo object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this OwnershipInfo object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this OwnershipInfo object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single ownedFrom property value for this OwnershipInfo object.
   *
   * @return The first ownedFrom property value.
   */
  public Date getOwnedFrom() {
  	return this.ownedFrom.isEmpty() ? null : this.ownedFrom.get(0);
  }
  
  /**
   * Get a single ownedThrough property value for this OwnershipInfo object.
   *
   * @return The first ownedThrough property value.
   */
  public Date getOwnedThrough() {
  	return this.ownedThrough.isEmpty() ? null : this.ownedThrough.get(0);
  }
  
  /**
   * Get a single sameAs property value for this OwnershipInfo object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single typeOfGood property value for this OwnershipInfo object.
   *
   * @return The first typeOfGood property value.
   */
  public Product getTypeOfGood() {
  	return this.typeOfGood.isEmpty() ? null : this.typeOfGood.get(0);
  }
  
  /**
   * Get a single url property value for this OwnershipInfo object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the acquiredFrom property values for this OwnershipInfo object.
   *
   * @return A list of acquiredFrom property values.
   */
  public List<Thing> getAcquiredFroms() {
  	return this.acquiredFrom;
  }
  
  /**
   * Get all the additionalType property values for this OwnershipInfo object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this OwnershipInfo object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this OwnershipInfo object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this OwnershipInfo object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this OwnershipInfo object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the ownedFrom property values for this OwnershipInfo object.
   *
   * @return A list of ownedFrom property values.
   */
  public List<Date> getOwnedFroms() {
  	return this.ownedFrom;
  }
  
  /**
   * Get all the ownedThrough property values for this OwnershipInfo object.
   *
   * @return A list of ownedThrough property values.
   */
  public List<Date> getOwnedThroughs() {
  	return this.ownedThrough;
  }
  
  /**
   * Get all the sameAs property values for this OwnershipInfo object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the typeOfGood property values for this OwnershipInfo object.
   *
   * @return A list of typeOfGood property values.
   */
  public List<Product> getTypeOfGoods() {
  	return this.typeOfGood;
  }
  
  /**
   * Get all the url property values for this OwnershipInfo object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the acquiredFrom property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param acquiredFrom The value to set.
   */
  public void setAcquiredFrom(Thing acquiredFrom) {
  	this.acquiredFrom.clear();
  	this.acquiredFrom.add(acquiredFrom);
  }
  
  /**
   * Set the additionalType property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the ownedFrom property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedFrom The value to set.
   */
  public void setOwnedFrom(Date ownedFrom) {
  	this.ownedFrom.clear();
  	this.ownedFrom.add(ownedFrom);
  }
  
  /**
   * Set the ownedThrough property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedThrough The value to set.
   */
  public void setOwnedThrough(Date ownedThrough) {
  	this.ownedThrough.clear();
  	this.ownedThrough.add(ownedThrough);
  }
  
  /**
   * Set the sameAs property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the typeOfGood property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param typeOfGood The value to set.
   */
  public void setTypeOfGood(Product typeOfGood) {
  	this.typeOfGood.clear();
  	this.typeOfGood.add(typeOfGood);
  }
  
  /**
   * Set the url property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the acquiredFrom property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param acquiredFroms The list of values to set.
   */
  public void setAcquiredFroms(List<Thing> acquiredFroms) {
  	this.acquiredFrom = acquiredFroms;
  }
  
  /**
   * Set the additionalType property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the ownedFrom property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedFroms The list of values to set.
   */
  public void setOwnedFroms(List<Date> ownedFroms) {
  	this.ownedFrom = ownedFroms;
  }
  
  /**
   * Set the ownedThrough property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedThroughs The list of values to set.
   */
  public void setOwnedThroughs(List<Date> ownedThroughs) {
  	this.ownedThrough = ownedThroughs;
  }
  
  /**
   * Set the sameAs property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the typeOfGood property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param typeOfGoods The list of values to set.
   */
  public void setTypeOfGoods(List<Product> typeOfGoods) {
  	this.typeOfGood = typeOfGoods;
  }
  
  /**
   * Set the url property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a acquiredFrom property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param acquiredFrom The value to add.
   */
  public void addAcquiredFrom(Thing acquiredFrom) {
  	this.acquiredFrom.add(acquiredFrom);
  }
  
  /**
   * Adds a additionalType property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a ownedFrom property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param ownedFrom The value to add.
   */
  public void addOwnedFrom(Date ownedFrom) {
  	this.ownedFrom.add(ownedFrom);
  }
  
  /**
   * Adds a ownedThrough property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param ownedThrough The value to add.
   */
  public void addOwnedThrough(Date ownedThrough) {
  	this.ownedThrough.add(ownedThrough);
  }
  
  /**
   * Adds a sameAs property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a typeOfGood property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param typeOfGood The value to add.
   */
  public void addTypeOfGood(Product typeOfGood) {
  	this.typeOfGood.add(typeOfGood);
  }
  
  /**
   * Adds a url property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}