package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.DeliveryEvent;
import org.schema.DeliveryMethod;
import org.schema.Order;
import org.schema.ParcelDelivery;
import org.schema.PostalAddress;
import org.schema.Product;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The delivery of a parcel either via the postal service or a commercial service.
 */
public class ParcelDeliveryImpl extends SchemaObjectImpl implements ParcelDelivery {


  private ThingImpl thing;

  /**
   * The airline designated as the carrier for the flight.
   */
  private List<Thing> carrier = new LinkedList<Thing>();
  
  /**
   * Destination address.
   */
  private List<PostalAddress> deliveryAddress = new LinkedList<PostalAddress>();
  
  /**
   * New entry added as the package passes through each leg of its journey (from shipment to final delivery).
   */
  private List<DeliveryEvent> deliveryStatus = new LinkedList<DeliveryEvent>();
  
  /**
   * The earliest date the package may arrive.
   */
  private List<Date> expectedArrivalFrom = new LinkedList<Date>();
  
  /**
   * The latest date the package may arrive.
   */
  private List<Date> expectedArrivalUntil = new LinkedList<Date>();
  
  /**
   * Method used for delivery or shipping.
   */
  private List<DeliveryMethod> hasDeliveryMethod = new LinkedList<DeliveryMethod>();
  
  /**
   * Item(s) being shipped.
   */
  private List<Product> itemShipped = new LinkedList<Product>();
  
  /**
   * Shipper's address.
   */
  private List<PostalAddress> originAddress = new LinkedList<PostalAddress>();
  
  /**
   * The overall order the items in this delivery were included in.
   */
  private List<Order> partOfOrder = new LinkedList<Order>();
  
  /**
   * Shipper tracking number.
   */
  private List<String> trackingNumber = new LinkedList<String>();
  
  /**
   * Tracking url for the parcel delivery.
   */
  private List<URL> trackingUrl = new LinkedList<URL>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ParcelDeliveryImpl() {
    super("http://schema.org/ParcelDelivery");
  }
  /**
   * Get a single additionalType property value for this ParcelDelivery object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this ParcelDelivery object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single carrier property value for this ParcelDelivery object.
   *
   * @return The first carrier property value.
   */
  public Thing getCarrier() {
  	return this.carrier.isEmpty() ? null : this.carrier.get(0);
  }
  
  /**
   * Get a single deliveryAddress property value for this ParcelDelivery object.
   *
   * @return The first deliveryAddress property value.
   */
  public PostalAddress getDeliveryAddress() {
  	return this.deliveryAddress.isEmpty() ? null : this.deliveryAddress.get(0);
  }
  
  /**
   * Get a single deliveryStatus property value for this ParcelDelivery object.
   *
   * @return The first deliveryStatus property value.
   */
  public DeliveryEvent getDeliveryStatus() {
  	return this.deliveryStatus.isEmpty() ? null : this.deliveryStatus.get(0);
  }
  
  /**
   * Get a single description property value for this ParcelDelivery object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single expectedArrivalFrom property value for this ParcelDelivery object.
   *
   * @return The first expectedArrivalFrom property value.
   */
  public Date getExpectedArrivalFrom() {
  	return this.expectedArrivalFrom.isEmpty() ? null : this.expectedArrivalFrom.get(0);
  }
  
  /**
   * Get a single expectedArrivalUntil property value for this ParcelDelivery object.
   *
   * @return The first expectedArrivalUntil property value.
   */
  public Date getExpectedArrivalUntil() {
  	return this.expectedArrivalUntil.isEmpty() ? null : this.expectedArrivalUntil.get(0);
  }
  
  /**
   * Get a single hasDeliveryMethod property value for this ParcelDelivery object.
   *
   * @return The first hasDeliveryMethod property value.
   */
  public DeliveryMethod getHasDeliveryMethod() {
  	return this.hasDeliveryMethod.isEmpty() ? null : this.hasDeliveryMethod.get(0);
  }
  
  /**
   * Get a single image property value for this ParcelDelivery object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single itemShipped property value for this ParcelDelivery object.
   *
   * @return The first itemShipped property value.
   */
  public Product getItemShipped() {
  	return this.itemShipped.isEmpty() ? null : this.itemShipped.get(0);
  }
  
  /**
   * Get a single name property value for this ParcelDelivery object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single originAddress property value for this ParcelDelivery object.
   *
   * @return The first originAddress property value.
   */
  public PostalAddress getOriginAddress() {
  	return this.originAddress.isEmpty() ? null : this.originAddress.get(0);
  }
  
  /**
   * Get a single partOfOrder property value for this ParcelDelivery object.
   *
   * @return The first partOfOrder property value.
   */
  public Order getPartOfOrder() {
  	return this.partOfOrder.isEmpty() ? null : this.partOfOrder.get(0);
  }
  
  /**
   * Get a single sameAs property value for this ParcelDelivery object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single trackingNumber property value for this ParcelDelivery object.
   *
   * @return The first trackingNumber property value.
   */
  public String getTrackingNumber() {
  	return this.trackingNumber.isEmpty() ? null : this.trackingNumber.get(0);
  }
  
  /**
   * Get a single trackingUrl property value for this ParcelDelivery object.
   *
   * @return The first trackingUrl property value.
   */
  public URL getTrackingUrl() {
  	return this.trackingUrl.isEmpty() ? null : this.trackingUrl.get(0);
  }
  
  /**
   * Get a single url property value for this ParcelDelivery object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this ParcelDelivery object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this ParcelDelivery object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the carrier property values for this ParcelDelivery object.
   *
   * @return A list of carrier property values.
   */
  public List<Thing> getCarriers() {
  	return this.carrier;
  }
  
  /**
   * Get all the deliveryAddress property values for this ParcelDelivery object.
   *
   * @return A list of deliveryAddress property values.
   */
  public List<PostalAddress> getDeliveryAddresses() {
  	return this.deliveryAddress;
  }
  
  /**
   * Get all the deliveryStatus property values for this ParcelDelivery object.
   *
   * @return A list of deliveryStatus property values.
   */
  public List<DeliveryEvent> getDeliveryStatuses() {
  	return this.deliveryStatus;
  }
  
  /**
   * Get all the description property values for this ParcelDelivery object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the expectedArrivalFrom property values for this ParcelDelivery object.
   *
   * @return A list of expectedArrivalFrom property values.
   */
  public List<Date> getExpectedArrivalFroms() {
  	return this.expectedArrivalFrom;
  }
  
  /**
   * Get all the expectedArrivalUntil property values for this ParcelDelivery object.
   *
   * @return A list of expectedArrivalUntil property values.
   */
  public List<Date> getExpectedArrivalUntils() {
  	return this.expectedArrivalUntil;
  }
  
  /**
   * Get all the hasDeliveryMethod property values for this ParcelDelivery object.
   *
   * @return A list of hasDeliveryMethod property values.
   */
  public List<DeliveryMethod> getHasDeliveryMethods() {
  	return this.hasDeliveryMethod;
  }
  
  /**
   * Get all the image property values for this ParcelDelivery object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the itemShipped property values for this ParcelDelivery object.
   *
   * @return A list of itemShipped property values.
   */
  public List<Product> getItemShippeds() {
  	return this.itemShipped;
  }
  
  /**
   * Get all the name property values for this ParcelDelivery object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the originAddress property values for this ParcelDelivery object.
   *
   * @return A list of originAddress property values.
   */
  public List<PostalAddress> getOriginAddresses() {
  	return this.originAddress;
  }
  
  /**
   * Get all the partOfOrder property values for this ParcelDelivery object.
   *
   * @return A list of partOfOrder property values.
   */
  public List<Order> getPartOfOrders() {
  	return this.partOfOrder;
  }
  
  /**
   * Get all the sameAs property values for this ParcelDelivery object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the trackingNumber property values for this ParcelDelivery object.
   *
   * @return A list of trackingNumber property values.
   */
  public List<String> getTrackingNumbers() {
  	return this.trackingNumber;
  }
  
  /**
   * Get all the trackingUrl property values for this ParcelDelivery object.
   *
   * @return A list of trackingUrl property values.
   */
  public List<URL> getTrackingUrls() {
  	return this.trackingUrl;
  }
  
  /**
   * Get all the url property values for this ParcelDelivery object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the carrier property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param carrier The value to set.
   */
  public void setCarrier(Thing carrier) {
  	this.carrier.clear();
  	this.carrier.add(carrier);
  }
  
  /**
   * Set the deliveryAddress property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryAddress The value to set.
   */
  public void setDeliveryAddress(PostalAddress deliveryAddress) {
  	this.deliveryAddress.clear();
  	this.deliveryAddress.add(deliveryAddress);
  }
  
  /**
   * Set the deliveryStatus property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryStatus The value to set.
   */
  public void setDeliveryStatus(DeliveryEvent deliveryStatus) {
  	this.deliveryStatus.clear();
  	this.deliveryStatus.add(deliveryStatus);
  }
  
  /**
   * Set the description property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the expectedArrivalFrom property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalFrom The value to set.
   */
  public void setExpectedArrivalFrom(Date expectedArrivalFrom) {
  	this.expectedArrivalFrom.clear();
  	this.expectedArrivalFrom.add(expectedArrivalFrom);
  }
  
  /**
   * Set the expectedArrivalUntil property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalUntil The value to set.
   */
  public void setExpectedArrivalUntil(Date expectedArrivalUntil) {
  	this.expectedArrivalUntil.clear();
  	this.expectedArrivalUntil.add(expectedArrivalUntil);
  }
  
  /**
   * Set the hasDeliveryMethod property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param hasDeliveryMethod The value to set.
   */
  public void setHasDeliveryMethod(DeliveryMethod hasDeliveryMethod) {
  	this.hasDeliveryMethod.clear();
  	this.hasDeliveryMethod.add(hasDeliveryMethod);
  }
  
  /**
   * Set the image property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the itemShipped property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param itemShipped The value to set.
   */
  public void setItemShipped(Product itemShipped) {
  	this.itemShipped.clear();
  	this.itemShipped.add(itemShipped);
  }
  
  /**
   * Set the name property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the originAddress property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param originAddress The value to set.
   */
  public void setOriginAddress(PostalAddress originAddress) {
  	this.originAddress.clear();
  	this.originAddress.add(originAddress);
  }
  
  /**
   * Set the partOfOrder property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param partOfOrder The value to set.
   */
  public void setPartOfOrder(Order partOfOrder) {
  	this.partOfOrder.clear();
  	this.partOfOrder.add(partOfOrder);
  }
  
  /**
   * Set the sameAs property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the trackingNumber property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingNumber The value to set.
   */
  public void setTrackingNumber(String trackingNumber) {
  	this.trackingNumber.clear();
  	this.trackingNumber.add(trackingNumber);
  }
  
  /**
   * Set the trackingUrl property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingUrl The value to set.
   */
  public void setTrackingUrl(URL trackingUrl) {
  	this.trackingUrl.clear();
  	this.trackingUrl.add(trackingUrl);
  }
  
  /**
   * Set the url property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the carrier property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param carriers The list of values to set.
   */
  public void setCarriers(List<Thing> carriers) {
  	this.carrier = carriers;
  }
  
  /**
   * Set the deliveryAddress property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryAddresses The list of values to set.
   */
  public void setDeliveryAddresses(List<PostalAddress> deliveryAddresses) {
  	this.deliveryAddress = deliveryAddresses;
  }
  
  /**
   * Set the deliveryStatus property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryStatuses The list of values to set.
   */
  public void setDeliveryStatuses(List<DeliveryEvent> deliveryStatuses) {
  	this.deliveryStatus = deliveryStatuses;
  }
  
  /**
   * Set the description property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the expectedArrivalFrom property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalFroms The list of values to set.
   */
  public void setExpectedArrivalFroms(List<Date> expectedArrivalFroms) {
  	this.expectedArrivalFrom = expectedArrivalFroms;
  }
  
  /**
   * Set the expectedArrivalUntil property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalUntils The list of values to set.
   */
  public void setExpectedArrivalUntils(List<Date> expectedArrivalUntils) {
  	this.expectedArrivalUntil = expectedArrivalUntils;
  }
  
  /**
   * Set the hasDeliveryMethod property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param hasDeliveryMethods The list of values to set.
   */
  public void setHasDeliveryMethods(List<DeliveryMethod> hasDeliveryMethods) {
  	this.hasDeliveryMethod = hasDeliveryMethods;
  }
  
  /**
   * Set the image property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the itemShipped property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param itemShippeds The list of values to set.
   */
  public void setItemShippeds(List<Product> itemShippeds) {
  	this.itemShipped = itemShippeds;
  }
  
  /**
   * Set the name property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the originAddress property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param originAddresses The list of values to set.
   */
  public void setOriginAddresses(List<PostalAddress> originAddresses) {
  	this.originAddress = originAddresses;
  }
  
  /**
   * Set the partOfOrder property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param partOfOrders The list of values to set.
   */
  public void setPartOfOrders(List<Order> partOfOrders) {
  	this.partOfOrder = partOfOrders;
  }
  
  /**
   * Set the sameAs property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the trackingNumber property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingNumbers The list of values to set.
   */
  public void setTrackingNumbers(List<String> trackingNumbers) {
  	this.trackingNumber = trackingNumbers;
  }
  
  /**
   * Set the trackingUrl property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingUrls The list of values to set.
   */
  public void setTrackingUrls(List<URL> trackingUrls) {
  	this.trackingUrl = trackingUrls;
  }
  
  /**
   * Set the url property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a carrier property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param carrier The value to add.
   */
  public void addCarrier(Thing carrier) {
  	this.carrier.add(carrier);
  }
  
  /**
   * Adds a deliveryAddress property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param deliveryAddress The value to add.
   */
  public void addDeliveryAddress(PostalAddress deliveryAddress) {
  	this.deliveryAddress.add(deliveryAddress);
  }
  
  /**
   * Adds a deliveryStatus property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param deliveryStatus The value to add.
   */
  public void addDeliveryStatus(DeliveryEvent deliveryStatus) {
  	this.deliveryStatus.add(deliveryStatus);
  }
  
  /**
   * Adds a description property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a expectedArrivalFrom property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param expectedArrivalFrom The value to add.
   */
  public void addExpectedArrivalFrom(Date expectedArrivalFrom) {
  	this.expectedArrivalFrom.add(expectedArrivalFrom);
  }
  
  /**
   * Adds a expectedArrivalUntil property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param expectedArrivalUntil The value to add.
   */
  public void addExpectedArrivalUntil(Date expectedArrivalUntil) {
  	this.expectedArrivalUntil.add(expectedArrivalUntil);
  }
  
  /**
   * Adds a hasDeliveryMethod property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param hasDeliveryMethod The value to add.
   */
  public void addHasDeliveryMethod(DeliveryMethod hasDeliveryMethod) {
  	this.hasDeliveryMethod.add(hasDeliveryMethod);
  }
  
  /**
   * Adds a image property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a itemShipped property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param itemShipped The value to add.
   */
  public void addItemShipped(Product itemShipped) {
  	this.itemShipped.add(itemShipped);
  }
  
  /**
   * Adds a name property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a originAddress property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param originAddress The value to add.
   */
  public void addOriginAddress(PostalAddress originAddress) {
  	this.originAddress.add(originAddress);
  }
  
  /**
   * Adds a partOfOrder property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param partOfOrder The value to add.
   */
  public void addPartOfOrder(Order partOfOrder) {
  	this.partOfOrder.add(partOfOrder);
  }
  
  /**
   * Adds a sameAs property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a trackingNumber property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param trackingNumber The value to add.
   */
  public void addTrackingNumber(String trackingNumber) {
  	this.trackingNumber.add(trackingNumber);
  }
  
  /**
   * Adds a trackingUrl property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param trackingUrl The value to add.
   */
  public void addTrackingUrl(URL trackingUrl) {
  	this.trackingUrl.add(trackingUrl);
  }
  
  /**
   * Adds a url property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}