package com.google.developers.schemas.impl;

import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.MedicalCondition;
import org.schema.Number;
import org.schema.ParentAudience;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A set of characteristics describing parents, who can be interested in viewing some content
 */
public class ParentAudienceImpl extends SchemaObjectImpl implements ParentAudience {


  private AudienceImpl audience;
  private PeopleAudienceImpl peopleAudience;
  private ThingImpl thing;

  /**
   * Maximal age of the child
   */
  private List<Number> childMaxAge = new LinkedList<Number>();
  
  /**
   * Minimal age of the child
   */
  private List<Number> childMinAge = new LinkedList<Number>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ParentAudienceImpl() {
    super("http://schema.org/ParentAudience");
    peopleAudience = new PeopleAudienceImpl();
  }
  /**
   * Get a single additionalType property value for this ParentAudience object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this ParentAudience object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single audienceType property value for this ParentAudience object.
   *
   * @return The first audienceType property value.
   */
  public String getAudienceType() {
    return audience.getAudienceType();
  }
  
  /**
   * Get a single childMaxAge property value for this ParentAudience object.
   *
   * @return The first childMaxAge property value.
   */
  public Number getChildMaxAge() {
  	return this.childMaxAge.isEmpty() ? null : this.childMaxAge.get(0);
  }
  
  /**
   * Get a single childMinAge property value for this ParentAudience object.
   *
   * @return The first childMinAge property value.
   */
  public Number getChildMinAge() {
  	return this.childMinAge.isEmpty() ? null : this.childMinAge.get(0);
  }
  
  /**
   * Get a single description property value for this ParentAudience object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single geographicArea property value for this ParentAudience object.
   *
   * @return The first geographicArea property value.
   */
  public AdministrativeArea getGeographicArea() {
    return audience.getGeographicArea();
  }
  
  /**
   * Get a single healthCondition property value for this ParentAudience object.
   *
   * @return The first healthCondition property value.
   */
  public MedicalCondition getHealthCondition() {
    return peopleAudience.getHealthCondition();
  }
  
  /**
   * Get a single image property value for this ParentAudience object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this ParentAudience object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single requiredGender property value for this ParentAudience object.
   *
   * @return The first requiredGender property value.
   */
  public String getRequiredGender() {
    return peopleAudience.getRequiredGender();
  }
  
  /**
   * Get a single requiredMaxAge property value for this ParentAudience object.
   *
   * @return The first requiredMaxAge property value.
   */
  public Long getRequiredMaxAge() {
    return peopleAudience.getRequiredMaxAge();
  }
  
  /**
   * Get a single requiredMinAge property value for this ParentAudience object.
   *
   * @return The first requiredMinAge property value.
   */
  public Long getRequiredMinAge() {
    return peopleAudience.getRequiredMinAge();
  }
  
  /**
   * Get a single sameAs property value for this ParentAudience object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single suggestedGender property value for this ParentAudience object.
   *
   * @return The first suggestedGender property value.
   */
  public String getSuggestedGender() {
    return peopleAudience.getSuggestedGender();
  }
  
  /**
   * Get a single suggestedMaxAge property value for this ParentAudience object.
   *
   * @return The first suggestedMaxAge property value.
   */
  public Number getSuggestedMaxAge() {
    return peopleAudience.getSuggestedMaxAge();
  }
  
  /**
   * Get a single suggestedMinAge property value for this ParentAudience object.
   *
   * @return The first suggestedMinAge property value.
   */
  public Number getSuggestedMinAge() {
    return peopleAudience.getSuggestedMinAge();
  }
  
  /**
   * Get a single url property value for this ParentAudience object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this ParentAudience object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this ParentAudience object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the audienceType property values for this ParentAudience object.
   *
   * @return A list of audienceType property values.
   */
  public List<String> getAudienceTypes() {
    return audience.getAudienceTypes();
  }
  
  /**
   * Get all the childMaxAge property values for this ParentAudience object.
   *
   * @return A list of childMaxAge property values.
   */
  public List<Number> getChildMaxAges() {
  	return this.childMaxAge;
  }
  
  /**
   * Get all the childMinAge property values for this ParentAudience object.
   *
   * @return A list of childMinAge property values.
   */
  public List<Number> getChildMinAges() {
  	return this.childMinAge;
  }
  
  /**
   * Get all the description property values for this ParentAudience object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the geographicArea property values for this ParentAudience object.
   *
   * @return A list of geographicArea property values.
   */
  public List<AdministrativeArea> getGeographicAreas() {
    return audience.getGeographicAreas();
  }
  
  /**
   * Get all the healthCondition property values for this ParentAudience object.
   *
   * @return A list of healthCondition property values.
   */
  public List<MedicalCondition> getHealthConditions() {
    return peopleAudience.getHealthConditions();
  }
  
  /**
   * Get all the image property values for this ParentAudience object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this ParentAudience object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the requiredGender property values for this ParentAudience object.
   *
   * @return A list of requiredGender property values.
   */
  public List<String> getRequiredGenders() {
    return peopleAudience.getRequiredGenders();
  }
  
  /**
   * Get all the requiredMaxAge property values for this ParentAudience object.
   *
   * @return A list of requiredMaxAge property values.
   */
  public List<Long> getRequiredMaxAges() {
    return peopleAudience.getRequiredMaxAges();
  }
  
  /**
   * Get all the requiredMinAge property values for this ParentAudience object.
   *
   * @return A list of requiredMinAge property values.
   */
  public List<Long> getRequiredMinAges() {
    return peopleAudience.getRequiredMinAges();
  }
  
  /**
   * Get all the sameAs property values for this ParentAudience object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the suggestedGender property values for this ParentAudience object.
   *
   * @return A list of suggestedGender property values.
   */
  public List<String> getSuggestedGenders() {
    return peopleAudience.getSuggestedGenders();
  }
  
  /**
   * Get all the suggestedMaxAge property values for this ParentAudience object.
   *
   * @return A list of suggestedMaxAge property values.
   */
  public List<Number> getSuggestedMaxAges() {
    return peopleAudience.getSuggestedMaxAges();
  }
  
  /**
   * Get all the suggestedMinAge property values for this ParentAudience object.
   *
   * @return A list of suggestedMinAge property values.
   */
  public List<Number> getSuggestedMinAges() {
    return peopleAudience.getSuggestedMinAges();
  }
  
  /**
   * Get all the url property values for this ParentAudience object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this ParentAudience object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this ParentAudience object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the audienceType property value for this ParentAudience object; overwriting any existing values.
   *
   * @param audienceType The value to set.
   */
  public void setAudienceType(String audienceType) {
    audience.setAudienceType(audienceType);
  }
  
  /**
   * Set the childMaxAge property value for this ParentAudience object; overwriting any existing values.
   *
   * @param childMaxAge The value to set.
   */
  public void setChildMaxAge(Number childMaxAge) {
  	this.childMaxAge.clear();
  	this.childMaxAge.add(childMaxAge);
  }
  
  /**
   * Set the childMinAge property value for this ParentAudience object; overwriting any existing values.
   *
   * @param childMinAge The value to set.
   */
  public void setChildMinAge(Number childMinAge) {
  	this.childMinAge.clear();
  	this.childMinAge.add(childMinAge);
  }
  
  /**
   * Set the description property value for this ParentAudience object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the geographicArea property value for this ParentAudience object; overwriting any existing values.
   *
   * @param geographicArea The value to set.
   */
  public void setGeographicArea(AdministrativeArea geographicArea) {
    audience.setGeographicArea(geographicArea);
  }
  
  /**
   * Set the healthCondition property value for this ParentAudience object; overwriting any existing values.
   *
   * @param healthCondition The value to set.
   */
  public void setHealthCondition(MedicalCondition healthCondition) {
    peopleAudience.setHealthCondition(healthCondition);
  }
  
  /**
   * Set the image property value for this ParentAudience object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this ParentAudience object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the requiredGender property value for this ParentAudience object; overwriting any existing values.
   *
   * @param requiredGender The value to set.
   */
  public void setRequiredGender(String requiredGender) {
    peopleAudience.setRequiredGender(requiredGender);
  }
  
  /**
   * Set the requiredMaxAge property value for this ParentAudience object; overwriting any existing values.
   *
   * @param requiredMaxAge The value to set.
   */
  public void setRequiredMaxAge(Long requiredMaxAge) {
    peopleAudience.setRequiredMaxAge(requiredMaxAge);
  }
  
  /**
   * Set the requiredMinAge property value for this ParentAudience object; overwriting any existing values.
   *
   * @param requiredMinAge The value to set.
   */
  public void setRequiredMinAge(Long requiredMinAge) {
    peopleAudience.setRequiredMinAge(requiredMinAge);
  }
  
  /**
   * Set the sameAs property value for this ParentAudience object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the suggestedGender property value for this ParentAudience object; overwriting any existing values.
   *
   * @param suggestedGender The value to set.
   */
  public void setSuggestedGender(String suggestedGender) {
    peopleAudience.setSuggestedGender(suggestedGender);
  }
  
  /**
   * Set the suggestedMaxAge property value for this ParentAudience object; overwriting any existing values.
   *
   * @param suggestedMaxAge The value to set.
   */
  public void setSuggestedMaxAge(Number suggestedMaxAge) {
    peopleAudience.setSuggestedMaxAge(suggestedMaxAge);
  }
  
  /**
   * Set the suggestedMinAge property value for this ParentAudience object; overwriting any existing values.
   *
   * @param suggestedMinAge The value to set.
   */
  public void setSuggestedMinAge(Number suggestedMinAge) {
    peopleAudience.setSuggestedMinAge(suggestedMinAge);
  }
  
  /**
   * Set the url property value for this ParentAudience object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this ParentAudience object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this ParentAudience object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the audienceType property values for this ParentAudience object; overwriting any existing values.
   *
   * @param audienceTypes The list of values to set.
   */
  public void setAudienceTypes(List<String> audienceTypes) {
    audience.setAudienceTypes(audienceTypes);
  }
  
  /**
   * Set the childMaxAge property values for this ParentAudience object; overwriting any existing values.
   *
   * @param childMaxAges The list of values to set.
   */
  public void setChildMaxAges(List<Number> childMaxAges) {
  	this.childMaxAge = childMaxAges;
  }
  
  /**
   * Set the childMinAge property values for this ParentAudience object; overwriting any existing values.
   *
   * @param childMinAges The list of values to set.
   */
  public void setChildMinAges(List<Number> childMinAges) {
  	this.childMinAge = childMinAges;
  }
  
  /**
   * Set the description property values for this ParentAudience object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the geographicArea property values for this ParentAudience object; overwriting any existing values.
   *
   * @param geographicAreas The list of values to set.
   */
  public void setGeographicAreas(List<AdministrativeArea> geographicAreas) {
    audience.setGeographicAreas(geographicAreas);
  }
  
  /**
   * Set the healthCondition property values for this ParentAudience object; overwriting any existing values.
   *
   * @param healthConditions The list of values to set.
   */
  public void setHealthConditions(List<MedicalCondition> healthConditions) {
    peopleAudience.setHealthConditions(healthConditions);
  }
  
  /**
   * Set the image property values for this ParentAudience object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this ParentAudience object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the requiredGender property values for this ParentAudience object; overwriting any existing values.
   *
   * @param requiredGenders The list of values to set.
   */
  public void setRequiredGenders(List<String> requiredGenders) {
    peopleAudience.setRequiredGenders(requiredGenders);
  }
  
  /**
   * Set the requiredMaxAge property values for this ParentAudience object; overwriting any existing values.
   *
   * @param requiredMaxAges The list of values to set.
   */
  public void setRequiredMaxAges(List<Long> requiredMaxAges) {
    peopleAudience.setRequiredMaxAges(requiredMaxAges);
  }
  
  /**
   * Set the requiredMinAge property values for this ParentAudience object; overwriting any existing values.
   *
   * @param requiredMinAges The list of values to set.
   */
  public void setRequiredMinAges(List<Long> requiredMinAges) {
    peopleAudience.setRequiredMinAges(requiredMinAges);
  }
  
  /**
   * Set the sameAs property values for this ParentAudience object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the suggestedGender property values for this ParentAudience object; overwriting any existing values.
   *
   * @param suggestedGenders The list of values to set.
   */
  public void setSuggestedGenders(List<String> suggestedGenders) {
    peopleAudience.setSuggestedGenders(suggestedGenders);
  }
  
  /**
   * Set the suggestedMaxAge property values for this ParentAudience object; overwriting any existing values.
   *
   * @param suggestedMaxAges The list of values to set.
   */
  public void setSuggestedMaxAges(List<Number> suggestedMaxAges) {
    peopleAudience.setSuggestedMaxAges(suggestedMaxAges);
  }
  
  /**
   * Set the suggestedMinAge property values for this ParentAudience object; overwriting any existing values.
   *
   * @param suggestedMinAges The list of values to set.
   */
  public void setSuggestedMinAges(List<Number> suggestedMinAges) {
    peopleAudience.setSuggestedMinAges(suggestedMinAges);
  }
  
  /**
   * Set the url property values for this ParentAudience object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a audienceType property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param audienceType The value to add.
   */
  public void addAudienceType(String audienceType) {
    audience.addAudienceType(audienceType);
  }
  
  /**
   * Adds a childMaxAge property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param childMaxAge The value to add.
   */
  public void addChildMaxAge(Number childMaxAge) {
  	this.childMaxAge.add(childMaxAge);
  }
  
  /**
   * Adds a childMinAge property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param childMinAge The value to add.
   */
  public void addChildMinAge(Number childMinAge) {
  	this.childMinAge.add(childMinAge);
  }
  
  /**
   * Adds a description property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a geographicArea property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param geographicArea The value to add.
   */
  public void addGeographicArea(AdministrativeArea geographicArea) {
    audience.addGeographicArea(geographicArea);
  }
  
  /**
   * Adds a healthCondition property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param healthCondition The value to add.
   */
  public void addHealthCondition(MedicalCondition healthCondition) {
    peopleAudience.addHealthCondition(healthCondition);
  }
  
  /**
   * Adds a image property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a requiredGender property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param requiredGender The value to add.
   */
  public void addRequiredGender(String requiredGender) {
    peopleAudience.addRequiredGender(requiredGender);
  }
  
  /**
   * Adds a requiredMaxAge property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param requiredMaxAge The value to add.
   */
  public void addRequiredMaxAge(Long requiredMaxAge) {
    peopleAudience.addRequiredMaxAge(requiredMaxAge);
  }
  
  /**
   * Adds a requiredMinAge property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param requiredMinAge The value to add.
   */
  public void addRequiredMinAge(Long requiredMinAge) {
    peopleAudience.addRequiredMinAge(requiredMinAge);
  }
  
  /**
   * Adds a sameAs property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a suggestedGender property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param suggestedGender The value to add.
   */
  public void addSuggestedGender(String suggestedGender) {
    peopleAudience.addSuggestedGender(suggestedGender);
  }
  
  /**
   * Adds a suggestedMaxAge property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param suggestedMaxAge The value to add.
   */
  public void addSuggestedMaxAge(Number suggestedMaxAge) {
    peopleAudience.addSuggestedMaxAge(suggestedMaxAge);
  }
  
  /**
   * Adds a suggestedMinAge property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param suggestedMinAge The value to add.
   */
  public void addSuggestedMinAge(Number suggestedMinAge) {
    peopleAudience.addSuggestedMinAge(suggestedMinAge);
  }
  
  /**
   * Adds a url property value for this ParentAudience object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}