package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Drug;
import org.schema.MedicalCode;
import org.schema.MedicalCondition;
import org.schema.MedicalDevice;
import org.schema.MedicalGuideline;
import org.schema.MedicalSign;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.PathologyTest;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A medical test performed by a laboratory that typically involves examination of a tissue sample by a pathologist.
 */
public class PathologyTestImpl extends SchemaObjectImpl implements PathologyTest {


  private MedicalEntityImpl medicalEntity;
  private MedicalTestImpl medicalTest;
  private ThingImpl thing;

  /**
   * The type of tissue sample required for the test.
   */
  private List<String> tissueSample = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PathologyTestImpl() {
    super("http://schema.org/PathologyTest");
    medicalTest = new MedicalTestImpl();
  }
  /**
   * Get a single additionalType property value for this PathologyTest object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single affectedBy property value for this PathologyTest object.
   *
   * @return The first affectedBy property value.
   */
  public Drug getAffectedBy() {
    return medicalTest.getAffectedBy();
  }
  
  /**
   * Get a single alternateName property value for this PathologyTest object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single code property value for this PathologyTest object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single description property value for this PathologyTest object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single guideline property value for this PathologyTest object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this PathologyTest object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this PathologyTest object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this PathologyTest object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single normalRange property value for this PathologyTest object.
   *
   * @return The first normalRange property value.
   */
  public String getNormalRange() {
    return medicalTest.getNormalRange();
  }
  
  /**
   * Get a single recognizingAuthority property value for this PathologyTest object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this PathologyTest object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this PathologyTest object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single signDetected property value for this PathologyTest object.
   *
   * @return The first signDetected property value.
   */
  public MedicalSign getSignDetected() {
    return medicalTest.getSignDetected();
  }
  
  /**
   * Get a single study property value for this PathologyTest object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single tissueSample property value for this PathologyTest object.
   *
   * @return The first tissueSample property value.
   */
  public String getTissueSample() {
  	return this.tissueSample.isEmpty() ? null : this.tissueSample.get(0);
  }
  
  /**
   * Get a single url property value for this PathologyTest object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single usedToDiagnose property value for this PathologyTest object.
   *
   * @return The first usedToDiagnose property value.
   */
  public MedicalCondition getUsedToDiagnose() {
    return medicalTest.getUsedToDiagnose();
  }
  
  /**
   * Get a single usesDevice property value for this PathologyTest object.
   *
   * @return The first usesDevice property value.
   */
  public MedicalDevice getUsesDevice() {
    return medicalTest.getUsesDevice();
  }
  
  /**
   * Get all the additionalType property values for this PathologyTest object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the affectedBy property values for this PathologyTest object.
   *
   * @return A list of affectedBy property values.
   */
  public List<Drug> getAffectedBies() {
    return medicalTest.getAffectedBies();
  }
  
  /**
   * Get all the alternateName property values for this PathologyTest object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the code property values for this PathologyTest object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the description property values for this PathologyTest object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the guideline property values for this PathologyTest object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this PathologyTest object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this PathologyTest object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this PathologyTest object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the normalRange property values for this PathologyTest object.
   *
   * @return A list of normalRange property values.
   */
  public List<String> getNormalRanges() {
    return medicalTest.getNormalRanges();
  }
  
  /**
   * Get all the recognizingAuthority property values for this PathologyTest object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this PathologyTest object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this PathologyTest object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the signDetected property values for this PathologyTest object.
   *
   * @return A list of signDetected property values.
   */
  public List<MedicalSign> getSignDetecteds() {
    return medicalTest.getSignDetecteds();
  }
  
  /**
   * Get all the study property values for this PathologyTest object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the tissueSample property values for this PathologyTest object.
   *
   * @return A list of tissueSample property values.
   */
  public List<String> getTissueSamples() {
  	return this.tissueSample;
  }
  
  /**
   * Get all the url property values for this PathologyTest object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the usedToDiagnose property values for this PathologyTest object.
   *
   * @return A list of usedToDiagnose property values.
   */
  public List<MedicalCondition> getUsedToDiagnoses() {
    return medicalTest.getUsedToDiagnoses();
  }
  
  /**
   * Get all the usesDevice property values for this PathologyTest object.
   *
   * @return A list of usesDevice property values.
   */
  public List<MedicalDevice> getUsesDevices() {
    return medicalTest.getUsesDevices();
  }
  
  /**
   * Set the additionalType property value for this PathologyTest object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the affectedBy property value for this PathologyTest object; overwriting any existing values.
   *
   * @param affectedBy The value to set.
   */
  public void setAffectedBy(Drug affectedBy) {
    medicalTest.setAffectedBy(affectedBy);
  }
  
  /**
   * Set the alternateName property value for this PathologyTest object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the code property value for this PathologyTest object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the description property value for this PathologyTest object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the guideline property value for this PathologyTest object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this PathologyTest object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this PathologyTest object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this PathologyTest object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the normalRange property value for this PathologyTest object; overwriting any existing values.
   *
   * @param normalRange The value to set.
   */
  public void setNormalRange(String normalRange) {
    medicalTest.setNormalRange(normalRange);
  }
  
  /**
   * Set the recognizingAuthority property value for this PathologyTest object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this PathologyTest object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this PathologyTest object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the signDetected property value for this PathologyTest object; overwriting any existing values.
   *
   * @param signDetected The value to set.
   */
  public void setSignDetected(MedicalSign signDetected) {
    medicalTest.setSignDetected(signDetected);
  }
  
  /**
   * Set the study property value for this PathologyTest object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the tissueSample property value for this PathologyTest object; overwriting any existing values.
   *
   * @param tissueSample The value to set.
   */
  public void setTissueSample(String tissueSample) {
  	this.tissueSample.clear();
  	this.tissueSample.add(tissueSample);
  }
  
  /**
   * Set the url property value for this PathologyTest object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the usedToDiagnose property value for this PathologyTest object; overwriting any existing values.
   *
   * @param usedToDiagnose The value to set.
   */
  public void setUsedToDiagnose(MedicalCondition usedToDiagnose) {
    medicalTest.setUsedToDiagnose(usedToDiagnose);
  }
  
  /**
   * Set the usesDevice property value for this PathologyTest object; overwriting any existing values.
   *
   * @param usesDevice The value to set.
   */
  public void setUsesDevice(MedicalDevice usesDevice) {
    medicalTest.setUsesDevice(usesDevice);
  }
  
  /**
   * Set the additionalType property values for this PathologyTest object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the affectedBy property values for this PathologyTest object; overwriting any existing values.
   *
   * @param affectedBies The list of values to set.
   */
  public void setAffectedBies(List<Drug> affectedBies) {
    medicalTest.setAffectedBies(affectedBies);
  }
  
  /**
   * Set the alternateName property values for this PathologyTest object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the code property values for this PathologyTest object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the description property values for this PathologyTest object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the guideline property values for this PathologyTest object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this PathologyTest object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this PathologyTest object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this PathologyTest object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the normalRange property values for this PathologyTest object; overwriting any existing values.
   *
   * @param normalRanges The list of values to set.
   */
  public void setNormalRanges(List<String> normalRanges) {
    medicalTest.setNormalRanges(normalRanges);
  }
  
  /**
   * Set the recognizingAuthority property values for this PathologyTest object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this PathologyTest object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this PathologyTest object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the signDetected property values for this PathologyTest object; overwriting any existing values.
   *
   * @param signDetecteds The list of values to set.
   */
  public void setSignDetecteds(List<MedicalSign> signDetecteds) {
    medicalTest.setSignDetecteds(signDetecteds);
  }
  
  /**
   * Set the study property values for this PathologyTest object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the tissueSample property values for this PathologyTest object; overwriting any existing values.
   *
   * @param tissueSamples The list of values to set.
   */
  public void setTissueSamples(List<String> tissueSamples) {
  	this.tissueSample = tissueSamples;
  }
  
  /**
   * Set the url property values for this PathologyTest object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the usedToDiagnose property values for this PathologyTest object; overwriting any existing values.
   *
   * @param usedToDiagnoses The list of values to set.
   */
  public void setUsedToDiagnoses(List<MedicalCondition> usedToDiagnoses) {
    medicalTest.setUsedToDiagnoses(usedToDiagnoses);
  }
  
  /**
   * Set the usesDevice property values for this PathologyTest object; overwriting any existing values.
   *
   * @param usesDevices The list of values to set.
   */
  public void setUsesDevices(List<MedicalDevice> usesDevices) {
    medicalTest.setUsesDevices(usesDevices);
  }
  
  /**
   * Adds a additionalType property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a affectedBy property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param affectedBy The value to add.
   */
  public void addAffectedBy(Drug affectedBy) {
    medicalTest.addAffectedBy(affectedBy);
  }
  
  /**
   * Adds a alternateName property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a code property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a description property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a guideline property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a normalRange property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param normalRange The value to add.
   */
  public void addNormalRange(String normalRange) {
    medicalTest.addNormalRange(normalRange);
  }
  
  /**
   * Adds a recognizingAuthority property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a signDetected property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param signDetected The value to add.
   */
  public void addSignDetected(MedicalSign signDetected) {
    medicalTest.addSignDetected(signDetected);
  }
  
  /**
   * Adds a study property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a tissueSample property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param tissueSample The value to add.
   */
  public void addTissueSample(String tissueSample) {
  	this.tissueSample.add(tissueSample);
  }
  
  /**
   * Adds a url property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a usedToDiagnose property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param usedToDiagnose The value to add.
   */
  public void addUsedToDiagnose(MedicalCondition usedToDiagnose) {
    medicalTest.addUsedToDiagnose(usedToDiagnose);
  }
  
  /**
   * Adds a usesDevice property value for this PathologyTest object; appending it to the list of existing values.
   *
   * @param usesDevice The value to add.
   */
  public void addUsesDevice(MedicalDevice usesDevice) {
    medicalTest.addUsesDevice(usesDevice);
  }
  
}