package com.google.developers.schemas.impl;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.DeliveryMethod;
import org.schema.Number;
import org.schema.PaymentChargeSpecification;
import org.schema.PaymentMethod;
import org.schema.PriceSpecification;
import org.schema.QuantitativeValue;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The costs of settling the payment using a particular payment method.
 */
public class PaymentChargeSpecificationImpl extends SchemaObjectImpl implements PaymentChargeSpecification {


  private PriceSpecificationImpl priceSpecification;
  private ThingImpl thing;

  /**
   * The delivery method(s) to which the delivery charge or payment charge specification applies.
   */
  private List<DeliveryMethod> appliesToDeliveryMethod = new LinkedList<DeliveryMethod>();
  
  /**
   * The payment method(s) to which the payment charge specification applies.
   */
  private List<PaymentMethod> appliesToPaymentMethod = new LinkedList<PaymentMethod>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PaymentChargeSpecificationImpl() {
    super("http://schema.org/PaymentChargeSpecification");
    priceSpecification = new PriceSpecificationImpl();
  }
  /**
   * Get a single additionalType property value for this PaymentChargeSpecification object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this PaymentChargeSpecification object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single appliesToDeliveryMethod property value for this PaymentChargeSpecification object.
   *
   * @return The first appliesToDeliveryMethod property value.
   */
  public DeliveryMethod getAppliesToDeliveryMethod() {
  	return this.appliesToDeliveryMethod.isEmpty() ? null : this.appliesToDeliveryMethod.get(0);
  }
  
  /**
   * Get a single appliesToPaymentMethod property value for this PaymentChargeSpecification object.
   *
   * @return The first appliesToPaymentMethod property value.
   */
  public PaymentMethod getAppliesToPaymentMethod() {
  	return this.appliesToPaymentMethod.isEmpty() ? null : this.appliesToPaymentMethod.get(0);
  }
  
  /**
   * Get a single description property value for this PaymentChargeSpecification object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single eligibleQuantity property value for this PaymentChargeSpecification object.
   *
   * @return The first eligibleQuantity property value.
   */
  public QuantitativeValue getEligibleQuantity() {
    return priceSpecification.getEligibleQuantity();
  }
  
  /**
   * Get a single eligibleTransactionVolume property value for this PaymentChargeSpecification object.
   *
   * @return The first eligibleTransactionVolume property value.
   */
  public PriceSpecification getEligibleTransactionVolume() {
    return priceSpecification.getEligibleTransactionVolume();
  }
  
  /**
   * Get a single image property value for this PaymentChargeSpecification object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single maxPrice property value for this PaymentChargeSpecification object.
   *
   * @return The first maxPrice property value.
   */
  public Number getMaxPrice() {
    return priceSpecification.getMaxPrice();
  }
  
  /**
   * Get a single minPrice property value for this PaymentChargeSpecification object.
   *
   * @return The first minPrice property value.
   */
  public Number getMinPrice() {
    return priceSpecification.getMinPrice();
  }
  
  /**
   * Get a single name property value for this PaymentChargeSpecification object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single price property value for this PaymentChargeSpecification object.
   *
   * @return The first price property value.
   */
  public Thing getPrice() {
    return priceSpecification.getPrice();
  }
  
  /**
   * Get a single priceCurrency property value for this PaymentChargeSpecification object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency() {
    return priceSpecification.getPriceCurrency();
  }
  
  /**
   * Get a single sameAs property value for this PaymentChargeSpecification object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this PaymentChargeSpecification object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single validFrom property value for this PaymentChargeSpecification object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom() {
    return priceSpecification.getValidFrom();
  }
  
  /**
   * Get a single validThrough property value for this PaymentChargeSpecification object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough() {
    return priceSpecification.getValidThrough();
  }
  
  /**
   * Get a single valueAddedTaxIncluded property value for this PaymentChargeSpecification object.
   *
   * @return The first valueAddedTaxIncluded property value.
   */
  public Boolean getValueAddedTaxIncluded() {
    return priceSpecification.getValueAddedTaxIncluded();
  }
  
  /**
   * Get all the additionalType property values for this PaymentChargeSpecification object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this PaymentChargeSpecification object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the appliesToDeliveryMethod property values for this PaymentChargeSpecification object.
   *
   * @return A list of appliesToDeliveryMethod property values.
   */
  public List<DeliveryMethod> getAppliesToDeliveryMethods() {
  	return this.appliesToDeliveryMethod;
  }
  
  /**
   * Get all the appliesToPaymentMethod property values for this PaymentChargeSpecification object.
   *
   * @return A list of appliesToPaymentMethod property values.
   */
  public List<PaymentMethod> getAppliesToPaymentMethods() {
  	return this.appliesToPaymentMethod;
  }
  
  /**
   * Get all the description property values for this PaymentChargeSpecification object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the eligibleQuantity property values for this PaymentChargeSpecification object.
   *
   * @return A list of eligibleQuantity property values.
   */
  public List<QuantitativeValue> getEligibleQuantities() {
    return priceSpecification.getEligibleQuantities();
  }
  
  /**
   * Get all the eligibleTransactionVolume property values for this PaymentChargeSpecification object.
   *
   * @return A list of eligibleTransactionVolume property values.
   */
  public List<PriceSpecification> getEligibleTransactionVolumes() {
    return priceSpecification.getEligibleTransactionVolumes();
  }
  
  /**
   * Get all the image property values for this PaymentChargeSpecification object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the maxPrice property values for this PaymentChargeSpecification object.
   *
   * @return A list of maxPrice property values.
   */
  public List<Number> getMaxPrices() {
    return priceSpecification.getMaxPrices();
  }
  
  /**
   * Get all the minPrice property values for this PaymentChargeSpecification object.
   *
   * @return A list of minPrice property values.
   */
  public List<Number> getMinPrices() {
    return priceSpecification.getMinPrices();
  }
  
  /**
   * Get all the name property values for this PaymentChargeSpecification object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the price property values for this PaymentChargeSpecification object.
   *
   * @return A list of price property values.
   */
  public List<Thing> getPrices() {
    return priceSpecification.getPrices();
  }
  
  /**
   * Get all the priceCurrency property values for this PaymentChargeSpecification object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies() {
    return priceSpecification.getPriceCurrencies();
  }
  
  /**
   * Get all the sameAs property values for this PaymentChargeSpecification object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this PaymentChargeSpecification object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the validFrom property values for this PaymentChargeSpecification object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms() {
    return priceSpecification.getValidFroms();
  }
  
  /**
   * Get all the validThrough property values for this PaymentChargeSpecification object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs() {
    return priceSpecification.getValidThroughs();
  }
  
  /**
   * Get all the valueAddedTaxIncluded property values for this PaymentChargeSpecification object.
   *
   * @return A list of valueAddedTaxIncluded property values.
   */
  public List<Boolean> getValueAddedTaxIncludeds() {
    return priceSpecification.getValueAddedTaxIncludeds();
  }
  
  /**
   * Set the additionalType property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the appliesToDeliveryMethod property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param appliesToDeliveryMethod The value to set.
   */
  public void setAppliesToDeliveryMethod(DeliveryMethod appliesToDeliveryMethod) {
  	this.appliesToDeliveryMethod.clear();
  	this.appliesToDeliveryMethod.add(appliesToDeliveryMethod);
  }
  
  /**
   * Set the appliesToPaymentMethod property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param appliesToPaymentMethod The value to set.
   */
  public void setAppliesToPaymentMethod(PaymentMethod appliesToPaymentMethod) {
  	this.appliesToPaymentMethod.clear();
  	this.appliesToPaymentMethod.add(appliesToPaymentMethod);
  }
  
  /**
   * Set the description property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the eligibleQuantity property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param eligibleQuantity The value to set.
   */
  public void setEligibleQuantity(QuantitativeValue eligibleQuantity) {
    priceSpecification.setEligibleQuantity(eligibleQuantity);
  }
  
  /**
   * Set the eligibleTransactionVolume property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param eligibleTransactionVolume The value to set.
   */
  public void setEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
    priceSpecification.setEligibleTransactionVolume(eligibleTransactionVolume);
  }
  
  /**
   * Set the image property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the maxPrice property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param maxPrice The value to set.
   */
  public void setMaxPrice(Number maxPrice) {
    priceSpecification.setMaxPrice(maxPrice);
  }
  
  /**
   * Set the minPrice property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param minPrice The value to set.
   */
  public void setMinPrice(Number minPrice) {
    priceSpecification.setMinPrice(minPrice);
  }
  
  /**
   * Set the name property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the price property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param price The value to set.
   */
  public void setPrice(Thing price) {
    priceSpecification.setPrice(price);
  }
  
  /**
   * Set the priceCurrency property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency) {
    priceSpecification.setPriceCurrency(priceCurrency);
  }
  
  /**
   * Set the sameAs property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the validFrom property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom) {
    priceSpecification.setValidFrom(validFrom);
  }
  
  /**
   * Set the validThrough property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough) {
    priceSpecification.setValidThrough(validThrough);
  }
  
  /**
   * Set the valueAddedTaxIncluded property value for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param valueAddedTaxIncluded The value to set.
   */
  public void setValueAddedTaxIncluded(Boolean valueAddedTaxIncluded) {
    priceSpecification.setValueAddedTaxIncluded(valueAddedTaxIncluded);
  }
  
  /**
   * Set the additionalType property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the appliesToDeliveryMethod property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param appliesToDeliveryMethods The list of values to set.
   */
  public void setAppliesToDeliveryMethods(List<DeliveryMethod> appliesToDeliveryMethods) {
  	this.appliesToDeliveryMethod = appliesToDeliveryMethods;
  }
  
  /**
   * Set the appliesToPaymentMethod property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param appliesToPaymentMethods The list of values to set.
   */
  public void setAppliesToPaymentMethods(List<PaymentMethod> appliesToPaymentMethods) {
  	this.appliesToPaymentMethod = appliesToPaymentMethods;
  }
  
  /**
   * Set the description property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the eligibleQuantity property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param eligibleQuantities The list of values to set.
   */
  public void setEligibleQuantities(List<QuantitativeValue> eligibleQuantities) {
    priceSpecification.setEligibleQuantities(eligibleQuantities);
  }
  
  /**
   * Set the eligibleTransactionVolume property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param eligibleTransactionVolumes The list of values to set.
   */
  public void setEligibleTransactionVolumes(List<PriceSpecification> eligibleTransactionVolumes) {
    priceSpecification.setEligibleTransactionVolumes(eligibleTransactionVolumes);
  }
  
  /**
   * Set the image property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the maxPrice property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param maxPrices The list of values to set.
   */
  public void setMaxPrices(List<Number> maxPrices) {
    priceSpecification.setMaxPrices(maxPrices);
  }
  
  /**
   * Set the minPrice property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param minPrices The list of values to set.
   */
  public void setMinPrices(List<Number> minPrices) {
    priceSpecification.setMinPrices(minPrices);
  }
  
  /**
   * Set the name property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the price property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param prices The list of values to set.
   */
  public void setPrices(List<Thing> prices) {
    priceSpecification.setPrices(prices);
  }
  
  /**
   * Set the priceCurrency property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies) {
    priceSpecification.setPriceCurrencies(priceCurrencies);
  }
  
  /**
   * Set the sameAs property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the validFrom property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms) {
    priceSpecification.setValidFroms(validFroms);
  }
  
  /**
   * Set the validThrough property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs) {
    priceSpecification.setValidThroughs(validThroughs);
  }
  
  /**
   * Set the valueAddedTaxIncluded property values for this PaymentChargeSpecification object; overwriting any existing values.
   *
   * @param valueAddedTaxIncludeds The list of values to set.
   */
  public void setValueAddedTaxIncludeds(List<Boolean> valueAddedTaxIncludeds) {
    priceSpecification.setValueAddedTaxIncludeds(valueAddedTaxIncludeds);
  }
  
  /**
   * Adds a additionalType property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a appliesToDeliveryMethod property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param appliesToDeliveryMethod The value to add.
   */
  public void addAppliesToDeliveryMethod(DeliveryMethod appliesToDeliveryMethod) {
  	this.appliesToDeliveryMethod.add(appliesToDeliveryMethod);
  }
  
  /**
   * Adds a appliesToPaymentMethod property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param appliesToPaymentMethod The value to add.
   */
  public void addAppliesToPaymentMethod(PaymentMethod appliesToPaymentMethod) {
  	this.appliesToPaymentMethod.add(appliesToPaymentMethod);
  }
  
  /**
   * Adds a description property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a eligibleQuantity property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param eligibleQuantity The value to add.
   */
  public void addEligibleQuantity(QuantitativeValue eligibleQuantity) {
    priceSpecification.addEligibleQuantity(eligibleQuantity);
  }
  
  /**
   * Adds a eligibleTransactionVolume property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param eligibleTransactionVolume The value to add.
   */
  public void addEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume) {
    priceSpecification.addEligibleTransactionVolume(eligibleTransactionVolume);
  }
  
  /**
   * Adds a image property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a maxPrice property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param maxPrice The value to add.
   */
  public void addMaxPrice(Number maxPrice) {
    priceSpecification.addMaxPrice(maxPrice);
  }
  
  /**
   * Adds a minPrice property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param minPrice The value to add.
   */
  public void addMinPrice(Number minPrice) {
    priceSpecification.addMinPrice(minPrice);
  }
  
  /**
   * Adds a name property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a price property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param price The value to add.
   */
  public void addPrice(Thing price) {
    priceSpecification.addPrice(price);
  }
  
  /**
   * Adds a priceCurrency property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency) {
    priceSpecification.addPriceCurrency(priceCurrency);
  }
  
  /**
   * Adds a sameAs property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a validFrom property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom) {
    priceSpecification.addValidFrom(validFrom);
  }
  
  /**
   * Adds a validThrough property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough) {
    priceSpecification.addValidThrough(validThrough);
  }
  
  /**
   * Adds a valueAddedTaxIncluded property value for this PaymentChargeSpecification object; appending it to the list of existing values.
   *
   * @param valueAddedTaxIncluded The value to add.
   */
  public void addValueAddedTaxIncluded(Boolean valueAddedTaxIncluded) {
    priceSpecification.addValueAddedTaxIncluded(valueAddedTaxIncluded);
  }
  
}