package com.google.developers.schemas.impl;

import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.MedicalCondition;
import org.schema.Number;
import org.schema.PeopleAudience;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A set of characteristics belonging to people, e.g. who compose an item's target audience.
 */
public class PeopleAudienceImpl extends SchemaObjectImpl implements PeopleAudience {


  private AudienceImpl audience;
  private ThingImpl thing;

  /**
   * Expectations for health conditions of target audience
   */
  private List<MedicalCondition> healthCondition = new LinkedList<MedicalCondition>();
  
  /**
   * Audiences defined by a person's gender.
   */
  private List<String> requiredGender = new LinkedList<String>();
  
  /**
   * Audiences defined by a person's maximum age.
   */
  private List<Long> requiredMaxAge = new LinkedList<Long>();
  
  /**
   * Audiences defined by a person's minimum age.
   */
  private List<Long> requiredMinAge = new LinkedList<Long>();
  
  /**
   * The gender of the person or audience.
   */
  private List<String> suggestedGender = new LinkedList<String>();
  
  /**
   * Maximal age recommended for viewing content
   */
  private List<Number> suggestedMaxAge = new LinkedList<Number>();
  
  /**
   * Minimal age recommended for viewing content
   */
  private List<Number> suggestedMinAge = new LinkedList<Number>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PeopleAudienceImpl() {
    super("http://schema.org/PeopleAudience");
    audience = new AudienceImpl();
  }
  /**
   * Get a single additionalType property value for this PeopleAudience object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this PeopleAudience object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single audienceType property value for this PeopleAudience object.
   *
   * @return The first audienceType property value.
   */
  public String getAudienceType() {
    return audience.getAudienceType();
  }
  
  /**
   * Get a single description property value for this PeopleAudience object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single geographicArea property value for this PeopleAudience object.
   *
   * @return The first geographicArea property value.
   */
  public AdministrativeArea getGeographicArea() {
    return audience.getGeographicArea();
  }
  
  /**
   * Get a single healthCondition property value for this PeopleAudience object.
   *
   * @return The first healthCondition property value.
   */
  public MedicalCondition getHealthCondition() {
  	return this.healthCondition.isEmpty() ? null : this.healthCondition.get(0);
  }
  
  /**
   * Get a single image property value for this PeopleAudience object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this PeopleAudience object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single requiredGender property value for this PeopleAudience object.
   *
   * @return The first requiredGender property value.
   */
  public String getRequiredGender() {
  	return this.requiredGender.isEmpty() ? null : this.requiredGender.get(0);
  }
  
  /**
   * Get a single requiredMaxAge property value for this PeopleAudience object.
   *
   * @return The first requiredMaxAge property value.
   */
  public Long getRequiredMaxAge() {
  	return this.requiredMaxAge.isEmpty() ? null : this.requiredMaxAge.get(0);
  }
  
  /**
   * Get a single requiredMinAge property value for this PeopleAudience object.
   *
   * @return The first requiredMinAge property value.
   */
  public Long getRequiredMinAge() {
  	return this.requiredMinAge.isEmpty() ? null : this.requiredMinAge.get(0);
  }
  
  /**
   * Get a single sameAs property value for this PeopleAudience object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single suggestedGender property value for this PeopleAudience object.
   *
   * @return The first suggestedGender property value.
   */
  public String getSuggestedGender() {
  	return this.suggestedGender.isEmpty() ? null : this.suggestedGender.get(0);
  }
  
  /**
   * Get a single suggestedMaxAge property value for this PeopleAudience object.
   *
   * @return The first suggestedMaxAge property value.
   */
  public Number getSuggestedMaxAge() {
  	return this.suggestedMaxAge.isEmpty() ? null : this.suggestedMaxAge.get(0);
  }
  
  /**
   * Get a single suggestedMinAge property value for this PeopleAudience object.
   *
   * @return The first suggestedMinAge property value.
   */
  public Number getSuggestedMinAge() {
  	return this.suggestedMinAge.isEmpty() ? null : this.suggestedMinAge.get(0);
  }
  
  /**
   * Get a single url property value for this PeopleAudience object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this PeopleAudience object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this PeopleAudience object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the audienceType property values for this PeopleAudience object.
   *
   * @return A list of audienceType property values.
   */
  public List<String> getAudienceTypes() {
    return audience.getAudienceTypes();
  }
  
  /**
   * Get all the description property values for this PeopleAudience object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the geographicArea property values for this PeopleAudience object.
   *
   * @return A list of geographicArea property values.
   */
  public List<AdministrativeArea> getGeographicAreas() {
    return audience.getGeographicAreas();
  }
  
  /**
   * Get all the healthCondition property values for this PeopleAudience object.
   *
   * @return A list of healthCondition property values.
   */
  public List<MedicalCondition> getHealthConditions() {
  	return this.healthCondition;
  }
  
  /**
   * Get all the image property values for this PeopleAudience object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this PeopleAudience object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the requiredGender property values for this PeopleAudience object.
   *
   * @return A list of requiredGender property values.
   */
  public List<String> getRequiredGenders() {
  	return this.requiredGender;
  }
  
  /**
   * Get all the requiredMaxAge property values for this PeopleAudience object.
   *
   * @return A list of requiredMaxAge property values.
   */
  public List<Long> getRequiredMaxAges() {
  	return this.requiredMaxAge;
  }
  
  /**
   * Get all the requiredMinAge property values for this PeopleAudience object.
   *
   * @return A list of requiredMinAge property values.
   */
  public List<Long> getRequiredMinAges() {
  	return this.requiredMinAge;
  }
  
  /**
   * Get all the sameAs property values for this PeopleAudience object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the suggestedGender property values for this PeopleAudience object.
   *
   * @return A list of suggestedGender property values.
   */
  public List<String> getSuggestedGenders() {
  	return this.suggestedGender;
  }
  
  /**
   * Get all the suggestedMaxAge property values for this PeopleAudience object.
   *
   * @return A list of suggestedMaxAge property values.
   */
  public List<Number> getSuggestedMaxAges() {
  	return this.suggestedMaxAge;
  }
  
  /**
   * Get all the suggestedMinAge property values for this PeopleAudience object.
   *
   * @return A list of suggestedMinAge property values.
   */
  public List<Number> getSuggestedMinAges() {
  	return this.suggestedMinAge;
  }
  
  /**
   * Get all the url property values for this PeopleAudience object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the audienceType property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param audienceType The value to set.
   */
  public void setAudienceType(String audienceType) {
    audience.setAudienceType(audienceType);
  }
  
  /**
   * Set the description property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the geographicArea property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param geographicArea The value to set.
   */
  public void setGeographicArea(AdministrativeArea geographicArea) {
    audience.setGeographicArea(geographicArea);
  }
  
  /**
   * Set the healthCondition property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param healthCondition The value to set.
   */
  public void setHealthCondition(MedicalCondition healthCondition) {
  	this.healthCondition.clear();
  	this.healthCondition.add(healthCondition);
  }
  
  /**
   * Set the image property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the requiredGender property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredGender The value to set.
   */
  public void setRequiredGender(String requiredGender) {
  	this.requiredGender.clear();
  	this.requiredGender.add(requiredGender);
  }
  
  /**
   * Set the requiredMaxAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMaxAge The value to set.
   */
  public void setRequiredMaxAge(Long requiredMaxAge) {
  	this.requiredMaxAge.clear();
  	this.requiredMaxAge.add(requiredMaxAge);
  }
  
  /**
   * Set the requiredMinAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMinAge The value to set.
   */
  public void setRequiredMinAge(Long requiredMinAge) {
  	this.requiredMinAge.clear();
  	this.requiredMinAge.add(requiredMinAge);
  }
  
  /**
   * Set the sameAs property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the suggestedGender property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedGender The value to set.
   */
  public void setSuggestedGender(String suggestedGender) {
  	this.suggestedGender.clear();
  	this.suggestedGender.add(suggestedGender);
  }
  
  /**
   * Set the suggestedMaxAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMaxAge The value to set.
   */
  public void setSuggestedMaxAge(Number suggestedMaxAge) {
  	this.suggestedMaxAge.clear();
  	this.suggestedMaxAge.add(suggestedMaxAge);
  }
  
  /**
   * Set the suggestedMinAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMinAge The value to set.
   */
  public void setSuggestedMinAge(Number suggestedMinAge) {
  	this.suggestedMinAge.clear();
  	this.suggestedMinAge.add(suggestedMinAge);
  }
  
  /**
   * Set the url property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the audienceType property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param audienceTypes The list of values to set.
   */
  public void setAudienceTypes(List<String> audienceTypes) {
    audience.setAudienceTypes(audienceTypes);
  }
  
  /**
   * Set the description property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the geographicArea property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param geographicAreas The list of values to set.
   */
  public void setGeographicAreas(List<AdministrativeArea> geographicAreas) {
    audience.setGeographicAreas(geographicAreas);
  }
  
  /**
   * Set the healthCondition property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param healthConditions The list of values to set.
   */
  public void setHealthConditions(List<MedicalCondition> healthConditions) {
  	this.healthCondition = healthConditions;
  }
  
  /**
   * Set the image property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the requiredGender property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredGenders The list of values to set.
   */
  public void setRequiredGenders(List<String> requiredGenders) {
  	this.requiredGender = requiredGenders;
  }
  
  /**
   * Set the requiredMaxAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMaxAges The list of values to set.
   */
  public void setRequiredMaxAges(List<Long> requiredMaxAges) {
  	this.requiredMaxAge = requiredMaxAges;
  }
  
  /**
   * Set the requiredMinAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMinAges The list of values to set.
   */
  public void setRequiredMinAges(List<Long> requiredMinAges) {
  	this.requiredMinAge = requiredMinAges;
  }
  
  /**
   * Set the sameAs property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the suggestedGender property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedGenders The list of values to set.
   */
  public void setSuggestedGenders(List<String> suggestedGenders) {
  	this.suggestedGender = suggestedGenders;
  }
  
  /**
   * Set the suggestedMaxAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMaxAges The list of values to set.
   */
  public void setSuggestedMaxAges(List<Number> suggestedMaxAges) {
  	this.suggestedMaxAge = suggestedMaxAges;
  }
  
  /**
   * Set the suggestedMinAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMinAges The list of values to set.
   */
  public void setSuggestedMinAges(List<Number> suggestedMinAges) {
  	this.suggestedMinAge = suggestedMinAges;
  }
  
  /**
   * Set the url property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a audienceType property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param audienceType The value to add.
   */
  public void addAudienceType(String audienceType) {
    audience.addAudienceType(audienceType);
  }
  
  /**
   * Adds a description property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a geographicArea property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param geographicArea The value to add.
   */
  public void addGeographicArea(AdministrativeArea geographicArea) {
    audience.addGeographicArea(geographicArea);
  }
  
  /**
   * Adds a healthCondition property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param healthCondition The value to add.
   */
  public void addHealthCondition(MedicalCondition healthCondition) {
  	this.healthCondition.add(healthCondition);
  }
  
  /**
   * Adds a image property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a requiredGender property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param requiredGender The value to add.
   */
  public void addRequiredGender(String requiredGender) {
  	this.requiredGender.add(requiredGender);
  }
  
  /**
   * Adds a requiredMaxAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param requiredMaxAge The value to add.
   */
  public void addRequiredMaxAge(Long requiredMaxAge) {
  	this.requiredMaxAge.add(requiredMaxAge);
  }
  
  /**
   * Adds a requiredMinAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param requiredMinAge The value to add.
   */
  public void addRequiredMinAge(Long requiredMinAge) {
  	this.requiredMinAge.add(requiredMinAge);
  }
  
  /**
   * Adds a sameAs property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a suggestedGender property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param suggestedGender The value to add.
   */
  public void addSuggestedGender(String suggestedGender) {
  	this.suggestedGender.add(suggestedGender);
  }
  
  /**
   * Adds a suggestedMaxAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param suggestedMaxAge The value to add.
   */
  public void addSuggestedMaxAge(Number suggestedMaxAge) {
  	this.suggestedMaxAge.add(suggestedMaxAge);
  }
  
  /**
   * Adds a suggestedMinAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param suggestedMinAge The value to add.
   */
  public void addSuggestedMinAge(Number suggestedMinAge) {
  	this.suggestedMinAge.add(suggestedMinAge);
  }
  
  /**
   * Adds a url property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}