package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.Audience;
import org.schema.Duration;
import org.schema.Organization;
import org.schema.Permit;
import org.schema.Service;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A permit issued by an organization, e.g. a parking pass.
 */
public class PermitImpl extends SchemaObjectImpl implements Permit {


  private ThingImpl thing;

  /**
   * The organization issuing the ticket or permit.
   */
  private List<Organization> issuedBy = new LinkedList<Organization>();
  
  /**
   * The service through with the permit was granted.
   */
  private List<Service> issuedThrough = new LinkedList<Service>();
  
  /**
   * The target audience for this permit.
   */
  private List<Audience> permitAudience = new LinkedList<Audience>();
  
  /**
   * The time validity of the permit.
   */
  private List<Duration> validFor = new LinkedList<Duration>();
  
  /**
   * The date when the item becomes valid.
   */
  private List<Date> validFrom = new LinkedList<Date>();
  
  /**
   * The geographic area where the permit is valid.
   */
  private List<AdministrativeArea> validIn = new LinkedList<AdministrativeArea>();
  
  /**
   * The date when the item is no longer valid.
   */
  private List<Date> validUntil = new LinkedList<Date>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PermitImpl() {
    super("http://schema.org/Permit");
  }
  /**
   * Get a single additionalType property value for this Permit object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Permit object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this Permit object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this Permit object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single issuedBy property value for this Permit object.
   *
   * @return The first issuedBy property value.
   */
  public Organization getIssuedBy() {
  	return this.issuedBy.isEmpty() ? null : this.issuedBy.get(0);
  }
  
  /**
   * Get a single issuedThrough property value for this Permit object.
   *
   * @return The first issuedThrough property value.
   */
  public Service getIssuedThrough() {
  	return this.issuedThrough.isEmpty() ? null : this.issuedThrough.get(0);
  }
  
  /**
   * Get a single name property value for this Permit object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single permitAudience property value for this Permit object.
   *
   * @return The first permitAudience property value.
   */
  public Audience getPermitAudience() {
  	return this.permitAudience.isEmpty() ? null : this.permitAudience.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Permit object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this Permit object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single validFor property value for this Permit object.
   *
   * @return The first validFor property value.
   */
  public Duration getValidFor() {
  	return this.validFor.isEmpty() ? null : this.validFor.get(0);
  }
  
  /**
   * Get a single validFrom property value for this Permit object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom() {
  	return this.validFrom.isEmpty() ? null : this.validFrom.get(0);
  }
  
  /**
   * Get a single validIn property value for this Permit object.
   *
   * @return The first validIn property value.
   */
  public AdministrativeArea getValidIn() {
  	return this.validIn.isEmpty() ? null : this.validIn.get(0);
  }
  
  /**
   * Get a single validUntil property value for this Permit object.
   *
   * @return The first validUntil property value.
   */
  public Date getValidUntil() {
  	return this.validUntil.isEmpty() ? null : this.validUntil.get(0);
  }
  
  /**
   * Get all the additionalType property values for this Permit object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Permit object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this Permit object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this Permit object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the issuedBy property values for this Permit object.
   *
   * @return A list of issuedBy property values.
   */
  public List<Organization> getIssuedBies() {
  	return this.issuedBy;
  }
  
  /**
   * Get all the issuedThrough property values for this Permit object.
   *
   * @return A list of issuedThrough property values.
   */
  public List<Service> getIssuedThroughs() {
  	return this.issuedThrough;
  }
  
  /**
   * Get all the name property values for this Permit object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the permitAudience property values for this Permit object.
   *
   * @return A list of permitAudience property values.
   */
  public List<Audience> getPermitAudiences() {
  	return this.permitAudience;
  }
  
  /**
   * Get all the sameAs property values for this Permit object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this Permit object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the validFor property values for this Permit object.
   *
   * @return A list of validFor property values.
   */
  public List<Duration> getValidFors() {
  	return this.validFor;
  }
  
  /**
   * Get all the validFrom property values for this Permit object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms() {
  	return this.validFrom;
  }
  
  /**
   * Get all the validIn property values for this Permit object.
   *
   * @return A list of validIn property values.
   */
  public List<AdministrativeArea> getValidsIn() {
  	return this.validIn;
  }
  
  /**
   * Get all the validUntil property values for this Permit object.
   *
   * @return A list of validUntil property values.
   */
  public List<Date> getValidUntils() {
  	return this.validUntil;
  }
  
  /**
   * Set the additionalType property value for this Permit object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Permit object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this Permit object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this Permit object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the issuedBy property value for this Permit object; overwriting any existing values.
   *
   * @param issuedBy The value to set.
   */
  public void setIssuedBy(Organization issuedBy) {
  	this.issuedBy.clear();
  	this.issuedBy.add(issuedBy);
  }
  
  /**
   * Set the issuedThrough property value for this Permit object; overwriting any existing values.
   *
   * @param issuedThrough The value to set.
   */
  public void setIssuedThrough(Service issuedThrough) {
  	this.issuedThrough.clear();
  	this.issuedThrough.add(issuedThrough);
  }
  
  /**
   * Set the name property value for this Permit object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the permitAudience property value for this Permit object; overwriting any existing values.
   *
   * @param permitAudience The value to set.
   */
  public void setPermitAudience(Audience permitAudience) {
  	this.permitAudience.clear();
  	this.permitAudience.add(permitAudience);
  }
  
  /**
   * Set the sameAs property value for this Permit object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this Permit object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the validFor property value for this Permit object; overwriting any existing values.
   *
   * @param validFor The value to set.
   */
  public void setValidFor(Duration validFor) {
  	this.validFor.clear();
  	this.validFor.add(validFor);
  }
  
  /**
   * Set the validFrom property value for this Permit object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom) {
  	this.validFrom.clear();
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Set the validIn property value for this Permit object; overwriting any existing values.
   *
   * @param validIn The value to set.
   */
  public void setValidIn(AdministrativeArea validIn) {
  	this.validIn.clear();
  	this.validIn.add(validIn);
  }
  
  /**
   * Set the validUntil property value for this Permit object; overwriting any existing values.
   *
   * @param validUntil The value to set.
   */
  public void setValidUntil(Date validUntil) {
  	this.validUntil.clear();
  	this.validUntil.add(validUntil);
  }
  
  /**
   * Set the additionalType property values for this Permit object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Permit object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this Permit object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this Permit object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the issuedBy property values for this Permit object; overwriting any existing values.
   *
   * @param issuedBies The list of values to set.
   */
  public void setIssuedBies(List<Organization> issuedBies) {
  	this.issuedBy = issuedBies;
  }
  
  /**
   * Set the issuedThrough property values for this Permit object; overwriting any existing values.
   *
   * @param issuedThroughs The list of values to set.
   */
  public void setIssuedThroughs(List<Service> issuedThroughs) {
  	this.issuedThrough = issuedThroughs;
  }
  
  /**
   * Set the name property values for this Permit object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the permitAudience property values for this Permit object; overwriting any existing values.
   *
   * @param permitAudiences The list of values to set.
   */
  public void setPermitAudiences(List<Audience> permitAudiences) {
  	this.permitAudience = permitAudiences;
  }
  
  /**
   * Set the sameAs property values for this Permit object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this Permit object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the validFor property values for this Permit object; overwriting any existing values.
   *
   * @param validFors The list of values to set.
   */
  public void setValidFors(List<Duration> validFors) {
  	this.validFor = validFors;
  }
  
  /**
   * Set the validFrom property values for this Permit object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms) {
  	this.validFrom = validFroms;
  }
  
  /**
   * Set the validIn property values for this Permit object; overwriting any existing values.
   *
   * @param validsIn The list of values to set.
   */
  public void setValidsIn(List<AdministrativeArea> validsIn) {
  	this.validIn = validsIn;
  }
  
  /**
   * Set the validUntil property values for this Permit object; overwriting any existing values.
   *
   * @param validUntils The list of values to set.
   */
  public void setValidUntils(List<Date> validUntils) {
  	this.validUntil = validUntils;
  }
  
  /**
   * Adds a additionalType property value for this Permit object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Permit object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this Permit object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this Permit object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a issuedBy property value for this Permit object; appending it to the list of existing values.
   *
   * @param issuedBy The value to add.
   */
  public void addIssuedBy(Organization issuedBy) {
  	this.issuedBy.add(issuedBy);
  }
  
  /**
   * Adds a issuedThrough property value for this Permit object; appending it to the list of existing values.
   *
   * @param issuedThrough The value to add.
   */
  public void addIssuedThrough(Service issuedThrough) {
  	this.issuedThrough.add(issuedThrough);
  }
  
  /**
   * Adds a name property value for this Permit object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a permitAudience property value for this Permit object; appending it to the list of existing values.
   *
   * @param permitAudience The value to add.
   */
  public void addPermitAudience(Audience permitAudience) {
  	this.permitAudience.add(permitAudience);
  }
  
  /**
   * Adds a sameAs property value for this Permit object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this Permit object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a validFor property value for this Permit object; appending it to the list of existing values.
   *
   * @param validFor The value to add.
   */
  public void addValidFor(Duration validFor) {
  	this.validFor.add(validFor);
  }
  
  /**
   * Adds a validFrom property value for this Permit object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom) {
  	this.validFrom.add(validFrom);
  }
  
  /**
   * Adds a validIn property value for this Permit object; appending it to the list of existing values.
   *
   * @param validIn The value to add.
   */
  public void addValidIn(AdministrativeArea validIn) {
  	this.validIn.add(validIn);
  }
  
  /**
   * Adds a validUntil property value for this Permit object; appending it to the list of existing values.
   *
   * @param validUntil The value to add.
   */
  public void addValidUntil(Date validUntil) {
  	this.validUntil.add(validUntil);
  }
  
}