package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.ContactPoint;
import org.schema.Country;
import org.schema.Demand;
import org.schema.EducationalOrganization;
import org.schema.Event;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A person (alive, dead, undead, or fictional).
 */
public class PersonImpl extends SchemaObjectImpl implements Person {


  private ThingImpl thing;

  /**
   * An additional name for a Person, can be used for a middle name.
   */
  private List<String> additionalName = new LinkedList<String>();
  
  /**
   * Physical address of the item.
   */
  private List<PostalAddress> address = new LinkedList<PostalAddress>();
  
  /**
   * An organization that this person is affiliated with. For example, a school/university, a club, or a team.
   */
  private List<Organization> affiliation = new LinkedList<Organization>();
  
  /**
   * An educational organizations that the person is an alumni of.
   */
  private List<EducationalOrganization> alumniOf = new LinkedList<EducationalOrganization>();
  
  /**
   * An award won by this person or for this creative work.
   */
  private List<String> award = new LinkedList<String>();
  
  /**
   * Date of birth.
   */
  private List<Date> birthDate = new LinkedList<Date>();
  
  /**
   * The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
   */
  private List<Thing> brand = new LinkedList<Thing>();
  
  /**
   * A child of the person.
   */
  private List<Person> children = new LinkedList<Person>();
  
  /**
   * A colleague of the person.
   */
  private List<Person> colleague = new LinkedList<Person>();
  
  /**
   * A contact point for a person or organization.
   */
  private List<ContactPoint> contactPoint = new LinkedList<ContactPoint>();
  
  /**
   * Date of death.
   */
  private List<Date> deathDate = new LinkedList<Date>();
  
  /**
   * The Dun & Bradstreet DUNS number for identifying an organization or business person.
   */
  private List<String> duns = new LinkedList<String>();
  
  /**
   * Email address.
   */
  private List<String> email = new LinkedList<String>();
  
  /**
   * Family name. In the U.S., the last name of an Person. This can be used along with givenName instead of the Name property.
   */
  private List<String> familyName = new LinkedList<String>();
  
  /**
   * The fax number.
   */
  private List<String> faxNumber = new LinkedList<String>();
  
  /**
   * The most generic uni-directional social relation.
   */
  private List<Person> follows = new LinkedList<Person>();
  
  /**
   * Gender of the person.
   */
  private List<String> gender = new LinkedList<String>();
  
  /**
   * Given name. In the U.S., the first name of a Person. This can be used along with familyName instead of the Name property.
   */
  private List<String> givenName = new LinkedList<String>();
  
  /**
   * The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.
   */
  private List<String> globalLocationNumber = new LinkedList<String>();
  
  /**
   * Points-of-Sales operated by the organization or person.
   */
  private List<Place> hasPOS = new LinkedList<Place>();
  
  /**
   * A contact location for a person's residence.
   */
  private List<Thing> homeLocation = new LinkedList<Thing>();
  
  /**
   * An honorific prefix preceding a Person's name such as Dr/Mrs/Mr.
   */
  private List<String> honorificPrefix = new LinkedList<String>();
  
  /**
   * An honorific suffix preceding a Person's name such as M.D. /PhD/MSCSW.
   */
  private List<String> honorificSuffix = new LinkedList<String>();
  
  /**
   * A count of a specific user interactions with this item&#x2014;for example, <code>20 UserLikes</code>, <code>5 UserComments</code>, or <code>300 UserDownloads</code>. The user interaction type should be one of the sub types of <a href='UserInteraction'>UserInteraction</a>.
   */
  private List<String> interactionCount = new LinkedList<String>();
  
  /**
   * The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.
   */
  private List<String> isicV4 = new LinkedList<String>();
  
  /**
   * The job title of the person (for example, Financial Manager).
   */
  private List<String> jobTitle = new LinkedList<String>();
  
  /**
   * The most generic bi-directional social/work relation.
   */
  private List<Person> knows = new LinkedList<Person>();
  
  /**
   * A pointer to products or services offered by the organization or person.
   */
  private List<Offer> makesOffer = new LinkedList<Offer>();
  
  /**
   * An organization to which the person belongs.
   */
  private List<Organization> memberOf = new LinkedList<Organization>();
  
  /**
   * The North American Industry Classification System (NAICS) code for a particular organization or business person.
   */
  private List<String> naics = new LinkedList<String>();
  
  /**
   * Nationality of the person.
   */
  private List<Country> nationality = new LinkedList<Country>();
  
  /**
   * Products owned by the organization or person.
   */
  private List<Thing> owns = new LinkedList<Thing>();
  
  /**
   * A parent of this person.
   */
  private List<Person> parent = new LinkedList<Person>();
  
  /**
   * Event that this person is a performer or participant in.
   */
  private List<Event> performerIn = new LinkedList<Event>();
  
  /**
   * The most generic familial relation.
   */
  private List<Person> relatedTo = new LinkedList<Person>();
  
  /**
   * A pointer to products or services sought by the organization or person (demand).
   */
  private List<Demand> seeks = new LinkedList<Demand>();
  
  /**
   * A sibling of the person.
   */
  private List<Person> sibling = new LinkedList<Person>();
  
  /**
   * The person's spouse.
   */
  private List<Person> spouse = new LinkedList<Person>();
  
  /**
   * The Tax / Fiscal ID of the organization or person, e.g. the TIN in the US or the CIF/NIF in Spain.
   */
  private List<String> taxID = new LinkedList<String>();
  
  /**
   * The telephone number.
   */
  private List<String> telephone = new LinkedList<String>();
  
  /**
   * The Value-added Tax ID of the organisation or person.
   */
  private List<String> vatID = new LinkedList<String>();
  
  /**
   * A contact location for a person's place of work.
   */
  private List<Thing> workLocation = new LinkedList<Thing>();
  
  /**
   * Organizations that the person works for.
   */
  private List<Organization> worksFor = new LinkedList<Organization>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PersonImpl() {
    super("http://schema.org/Person");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalName property value for this Person object.
   *
   * @return The first additionalName property value.
   */
  public String getAdditionalName() {
  	return this.additionalName.isEmpty() ? null : this.additionalName.get(0);
  }
  
  /**
   * Get a single additionalType property value for this Person object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single address property value for this Person object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress() {
  	return this.address.isEmpty() ? null : this.address.get(0);
  }
  
  /**
   * Get a single affiliation property value for this Person object.
   *
   * @return The first affiliation property value.
   */
  public Organization getAffiliation() {
  	return this.affiliation.isEmpty() ? null : this.affiliation.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Person object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single alumniOf property value for this Person object.
   *
   * @return The first alumniOf property value.
   */
  public EducationalOrganization getAlumniOf() {
  	return this.alumniOf.isEmpty() ? null : this.alumniOf.get(0);
  }
  
  /**
   * Get a single award property value for this Person object.
   *
   * @return The first award property value.
   */
  public String getAward() {
  	return this.award.isEmpty() ? null : this.award.get(0);
  }
  
  /**
   * Get a single birthDate property value for this Person object.
   *
   * @return The first birthDate property value.
   */
  public Date getBirthDate() {
  	return this.birthDate.isEmpty() ? null : this.birthDate.get(0);
  }
  
  /**
   * Get a single brand property value for this Person object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand() {
  	return this.brand.isEmpty() ? null : this.brand.get(0);
  }
  
  /**
   * Get a single children property value for this Person object.
   *
   * @return The first children property value.
   */
  public Person getChildren() {
  	return this.children.isEmpty() ? null : this.children.get(0);
  }
  
  /**
   * Get a single colleague property value for this Person object.
   *
   * @return The first colleague property value.
   */
  public Person getColleague() {
  	return this.colleague.isEmpty() ? null : this.colleague.get(0);
  }
  
  /**
   * Get a single contactPoint property value for this Person object.
   *
   * @return The first contactPoint property value.
   */
  public ContactPoint getContactPoint() {
  	return this.contactPoint.isEmpty() ? null : this.contactPoint.get(0);
  }
  
  /**
   * Get a single deathDate property value for this Person object.
   *
   * @return The first deathDate property value.
   */
  public Date getDeathDate() {
  	return this.deathDate.isEmpty() ? null : this.deathDate.get(0);
  }
  
  /**
   * Get a single description property value for this Person object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single duns property value for this Person object.
   *
   * @return The first duns property value.
   */
  public String getDuns() {
  	return this.duns.isEmpty() ? null : this.duns.get(0);
  }
  
  /**
   * Get a single email property value for this Person object.
   *
   * @return The first email property value.
   */
  public String getEmail() {
  	return this.email.isEmpty() ? null : this.email.get(0);
  }
  
  /**
   * Get a single familyName property value for this Person object.
   *
   * @return The first familyName property value.
   */
  public String getFamilyName() {
  	return this.familyName.isEmpty() ? null : this.familyName.get(0);
  }
  
  /**
   * Get a single faxNumber property value for this Person object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
  	return this.faxNumber.isEmpty() ? null : this.faxNumber.get(0);
  }
  
  /**
   * Get a single follows property value for this Person object.
   *
   * @return The first follows property value.
   */
  public Person getFollows() {
  	return this.follows.isEmpty() ? null : this.follows.get(0);
  }
  
  /**
   * Get a single gender property value for this Person object.
   *
   * @return The first gender property value.
   */
  public String getGender() {
  	return this.gender.isEmpty() ? null : this.gender.get(0);
  }
  
  /**
   * Get a single givenName property value for this Person object.
   *
   * @return The first givenName property value.
   */
  public String getGivenName() {
  	return this.givenName.isEmpty() ? null : this.givenName.get(0);
  }
  
  /**
   * Get a single globalLocationNumber property value for this Person object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber() {
  	return this.globalLocationNumber.isEmpty() ? null : this.globalLocationNumber.get(0);
  }
  
  /**
   * Get a single hasPOS property value for this Person object.
   *
   * @return The first hasPOS property value.
   */
  public Place getHasPOS() {
  	return this.hasPOS.isEmpty() ? null : this.hasPOS.get(0);
  }
  
  /**
   * Get a single homeLocation property value for this Person object.
   *
   * @return The first homeLocation property value.
   */
  public Thing getHomeLocation() {
  	return this.homeLocation.isEmpty() ? null : this.homeLocation.get(0);
  }
  
  /**
   * Get a single honorificPrefix property value for this Person object.
   *
   * @return The first honorificPrefix property value.
   */
  public String getHonorificPrefix() {
  	return this.honorificPrefix.isEmpty() ? null : this.honorificPrefix.get(0);
  }
  
  /**
   * Get a single honorificSuffix property value for this Person object.
   *
   * @return The first honorificSuffix property value.
   */
  public String getHonorificSuffix() {
  	return this.honorificSuffix.isEmpty() ? null : this.honorificSuffix.get(0);
  }
  
  /**
   * Get a single image property value for this Person object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single interactionCount property value for this Person object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
  	return this.interactionCount.isEmpty() ? null : this.interactionCount.get(0);
  }
  
  /**
   * Get a single isicV4 property value for this Person object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4() {
  	return this.isicV4.isEmpty() ? null : this.isicV4.get(0);
  }
  
  /**
   * Get a single jobTitle property value for this Person object.
   *
   * @return The first jobTitle property value.
   */
  public String getJobTitle() {
  	return this.jobTitle.isEmpty() ? null : this.jobTitle.get(0);
  }
  
  /**
   * Get a single knows property value for this Person object.
   *
   * @return The first knows property value.
   */
  public Person getKnows() {
  	return this.knows.isEmpty() ? null : this.knows.get(0);
  }
  
  /**
   * Get a single makesOffer property value for this Person object.
   *
   * @return The first makesOffer property value.
   */
  public Offer getMakesOffer() {
  	return this.makesOffer.isEmpty() ? null : this.makesOffer.get(0);
  }
  
  /**
   * Get a single memberOf property value for this Person object.
   *
   * @return The first memberOf property value.
   */
  public Organization getMemberOf() {
  	return this.memberOf.isEmpty() ? null : this.memberOf.get(0);
  }
  
  /**
   * Get a single naics property value for this Person object.
   *
   * @return The first naics property value.
   */
  public String getNaics() {
  	return this.naics.isEmpty() ? null : this.naics.get(0);
  }
  
  /**
   * Get a single name property value for this Person object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single nationality property value for this Person object.
   *
   * @return The first nationality property value.
   */
  public Country getNationality() {
  	return this.nationality.isEmpty() ? null : this.nationality.get(0);
  }
  
  /**
   * Get a single owns property value for this Person object.
   *
   * @return The first owns property value.
   */
  public Thing getOwns() {
  	return this.owns.isEmpty() ? null : this.owns.get(0);
  }
  
  /**
   * Get a single parent property value for this Person object.
   *
   * @return The first parent property value.
   */
  public Person getParent() {
  	return this.parent.isEmpty() ? null : this.parent.get(0);
  }
  
  /**
   * Get a single performerIn property value for this Person object.
   *
   * @return The first performerIn property value.
   */
  public Event getPerformerIn() {
  	return this.performerIn.isEmpty() ? null : this.performerIn.get(0);
  }
  
  /**
   * Get a single relatedTo property value for this Person object.
   *
   * @return The first relatedTo property value.
   */
  public Person getRelatedTo() {
  	return this.relatedTo.isEmpty() ? null : this.relatedTo.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Person object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seeks property value for this Person object.
   *
   * @return The first seeks property value.
   */
  public Demand getSeeks() {
  	return this.seeks.isEmpty() ? null : this.seeks.get(0);
  }
  
  /**
   * Get a single sibling property value for this Person object.
   *
   * @return The first sibling property value.
   */
  public Person getSibling() {
  	return this.sibling.isEmpty() ? null : this.sibling.get(0);
  }
  
  /**
   * Get a single spouse property value for this Person object.
   *
   * @return The first spouse property value.
   */
  public Person getSpouse() {
  	return this.spouse.isEmpty() ? null : this.spouse.get(0);
  }
  
  /**
   * Get a single taxID property value for this Person object.
   *
   * @return The first taxID property value.
   */
  public String getTaxID() {
  	return this.taxID.isEmpty() ? null : this.taxID.get(0);
  }
  
  /**
   * Get a single telephone property value for this Person object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
  	return this.telephone.isEmpty() ? null : this.telephone.get(0);
  }
  
  /**
   * Get a single url property value for this Person object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single vatID property value for this Person object.
   *
   * @return The first vatID property value.
   */
  public String getVatID() {
  	return this.vatID.isEmpty() ? null : this.vatID.get(0);
  }
  
  /**
   * Get a single workLocation property value for this Person object.
   *
   * @return The first workLocation property value.
   */
  public Thing getWorkLocation() {
  	return this.workLocation.isEmpty() ? null : this.workLocation.get(0);
  }
  
  /**
   * Get a single worksFor property value for this Person object.
   *
   * @return The first worksFor property value.
   */
  public Organization getWorksFor() {
  	return this.worksFor.isEmpty() ? null : this.worksFor.get(0);
  }
  
  /**
   * Get all the additionalName property values for this Person object.
   *
   * @return A list of additionalName property values.
   */
  public List<String> getAdditionalNames() {
  	return this.additionalName;
  }
  
  /**
   * Get all the additionalType property values for this Person object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the address property values for this Person object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses() {
  	return this.address;
  }
  
  /**
   * Get all the affiliation property values for this Person object.
   *
   * @return A list of affiliation property values.
   */
  public List<Organization> getAffiliations() {
  	return this.affiliation;
  }
  
  /**
   * Get all the alternateName property values for this Person object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the alumniOf property values for this Person object.
   *
   * @return A list of alumniOf property values.
   */
  public List<EducationalOrganization> getAlumnisOf() {
  	return this.alumniOf;
  }
  
  /**
   * Get all the award property values for this Person object.
   *
   * @return A list of award property values.
   */
  public List<String> getAwards() {
  	return this.award;
  }
  
  /**
   * Get all the birthDate property values for this Person object.
   *
   * @return A list of birthDate property values.
   */
  public List<Date> getBirthDates() {
  	return this.birthDate;
  }
  
  /**
   * Get all the brand property values for this Person object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands() {
  	return this.brand;
  }
  
  /**
   * Get all the children property values for this Person object.
   *
   * @return A list of children property values.
   */
  public List<Person> getChildrens() {
  	return this.children;
  }
  
  /**
   * Get all the colleague property values for this Person object.
   *
   * @return A list of colleague property values.
   */
  public List<Person> getColleagues() {
  	return this.colleague;
  }
  
  /**
   * Get all the contactPoint property values for this Person object.
   *
   * @return A list of contactPoint property values.
   */
  public List<ContactPoint> getContactPoints() {
  	return this.contactPoint;
  }
  
  /**
   * Get all the deathDate property values for this Person object.
   *
   * @return A list of deathDate property values.
   */
  public List<Date> getDeathDates() {
  	return this.deathDate;
  }
  
  /**
   * Get all the description property values for this Person object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the duns property values for this Person object.
   *
   * @return A list of duns property values.
   */
  public List<String> getDunss() {
  	return this.duns;
  }
  
  /**
   * Get all the email property values for this Person object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails() {
  	return this.email;
  }
  
  /**
   * Get all the familyName property values for this Person object.
   *
   * @return A list of familyName property values.
   */
  public List<String> getFamilyNames() {
  	return this.familyName;
  }
  
  /**
   * Get all the faxNumber property values for this Person object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
  	return this.faxNumber;
  }
  
  /**
   * Get all the follows property values for this Person object.
   *
   * @return A list of follows property values.
   */
  public List<Person> getFollowss() {
  	return this.follows;
  }
  
  /**
   * Get all the gender property values for this Person object.
   *
   * @return A list of gender property values.
   */
  public List<String> getGenders() {
  	return this.gender;
  }
  
  /**
   * Get all the givenName property values for this Person object.
   *
   * @return A list of givenName property values.
   */
  public List<String> getGivenNames() {
  	return this.givenName;
  }
  
  /**
   * Get all the globalLocationNumber property values for this Person object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers() {
  	return this.globalLocationNumber;
  }
  
  /**
   * Get all the hasPOS property values for this Person object.
   *
   * @return A list of hasPOS property values.
   */
  public List<Place> getHasPOSs() {
  	return this.hasPOS;
  }
  
  /**
   * Get all the homeLocation property values for this Person object.
   *
   * @return A list of homeLocation property values.
   */
  public List<Thing> getHomeLocations() {
  	return this.homeLocation;
  }
  
  /**
   * Get all the honorificPrefix property values for this Person object.
   *
   * @return A list of honorificPrefix property values.
   */
  public List<String> getHonorificPrefixes() {
  	return this.honorificPrefix;
  }
  
  /**
   * Get all the honorificSuffix property values for this Person object.
   *
   * @return A list of honorificSuffix property values.
   */
  public List<String> getHonorificSuffixes() {
  	return this.honorificSuffix;
  }
  
  /**
   * Get all the image property values for this Person object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the interactionCount property values for this Person object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
  	return this.interactionCount;
  }
  
  /**
   * Get all the isicV4 property values for this Person object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s() {
  	return this.isicV4;
  }
  
  /**
   * Get all the jobTitle property values for this Person object.
   *
   * @return A list of jobTitle property values.
   */
  public List<String> getJobTitles() {
  	return this.jobTitle;
  }
  
  /**
   * Get all the knows property values for this Person object.
   *
   * @return A list of knows property values.
   */
  public List<Person> getKnowss() {
  	return this.knows;
  }
  
  /**
   * Get all the makesOffer property values for this Person object.
   *
   * @return A list of makesOffer property values.
   */
  public List<Offer> getMakesOffers() {
  	return this.makesOffer;
  }
  
  /**
   * Get all the memberOf property values for this Person object.
   *
   * @return A list of memberOf property values.
   */
  public List<Organization> getMembersOf() {
  	return this.memberOf;
  }
  
  /**
   * Get all the naics property values for this Person object.
   *
   * @return A list of naics property values.
   */
  public List<String> getNaicss() {
  	return this.naics;
  }
  
  /**
   * Get all the name property values for this Person object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the nationality property values for this Person object.
   *
   * @return A list of nationality property values.
   */
  public List<Country> getNationalities() {
  	return this.nationality;
  }
  
  /**
   * Get all the owns property values for this Person object.
   *
   * @return A list of owns property values.
   */
  public List<Thing> getOwnss() {
  	return this.owns;
  }
  
  /**
   * Get all the parent property values for this Person object.
   *
   * @return A list of parent property values.
   */
  public List<Person> getParents() {
  	return this.parent;
  }
  
  /**
   * Get all the performerIn property values for this Person object.
   *
   * @return A list of performerIn property values.
   */
  public List<Event> getPerformersIn() {
  	return this.performerIn;
  }
  
  /**
   * Get all the relatedTo property values for this Person object.
   *
   * @return A list of relatedTo property values.
   */
  public List<Person> getRelatedToes() {
  	return this.relatedTo;
  }
  
  /**
   * Get all the sameAs property values for this Person object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seeks property values for this Person object.
   *
   * @return A list of seeks property values.
   */
  public List<Demand> getSeekss() {
  	return this.seeks;
  }
  
  /**
   * Get all the sibling property values for this Person object.
   *
   * @return A list of sibling property values.
   */
  public List<Person> getSiblings() {
  	return this.sibling;
  }
  
  /**
   * Get all the spouse property values for this Person object.
   *
   * @return A list of spouse property values.
   */
  public List<Person> getSpouses() {
  	return this.spouse;
  }
  
  /**
   * Get all the taxID property values for this Person object.
   *
   * @return A list of taxID property values.
   */
  public List<String> getTaxIDs() {
  	return this.taxID;
  }
  
  /**
   * Get all the telephone property values for this Person object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
  	return this.telephone;
  }
  
  /**
   * Get all the url property values for this Person object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the vatID property values for this Person object.
   *
   * @return A list of vatID property values.
   */
  public List<String> getVatIDs() {
  	return this.vatID;
  }
  
  /**
   * Get all the workLocation property values for this Person object.
   *
   * @return A list of workLocation property values.
   */
  public List<Thing> getWorkLocations() {
  	return this.workLocation;
  }
  
  /**
   * Get all the worksFor property values for this Person object.
   *
   * @return A list of worksFor property values.
   */
  public List<Organization> getWorksFors() {
  	return this.worksFor;
  }
  
  /**
   * Set the additionalName property value for this Person object; overwriting any existing values.
   *
   * @param additionalName The value to set.
   */
  public void setAdditionalName(String additionalName) {
  	this.additionalName.clear();
  	this.additionalName.add(additionalName);
  }
  
  /**
   * Set the additionalType property value for this Person object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the address property value for this Person object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address) {
  	this.address.clear();
  	this.address.add(address);
  }
  
  /**
   * Set the affiliation property value for this Person object; overwriting any existing values.
   *
   * @param affiliation The value to set.
   */
  public void setAffiliation(Organization affiliation) {
  	this.affiliation.clear();
  	this.affiliation.add(affiliation);
  }
  
  /**
   * Set the alternateName property value for this Person object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the alumniOf property value for this Person object; overwriting any existing values.
   *
   * @param alumniOf The value to set.
   */
  public void setAlumniOf(EducationalOrganization alumniOf) {
  	this.alumniOf.clear();
  	this.alumniOf.add(alumniOf);
  }
  
  /**
   * Set the award property value for this Person object; overwriting any existing values.
   *
   * @param award The value to set.
   */
  public void setAward(String award) {
  	this.award.clear();
  	this.award.add(award);
  }
  
  /**
   * Set the birthDate property value for this Person object; overwriting any existing values.
   *
   * @param birthDate The value to set.
   */
  public void setBirthDate(Date birthDate) {
  	this.birthDate.clear();
  	this.birthDate.add(birthDate);
  }
  
  /**
   * Set the brand property value for this Person object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand) {
  	this.brand.clear();
  	this.brand.add(brand);
  }
  
  /**
   * Set the children property value for this Person object; overwriting any existing values.
   *
   * @param children The value to set.
   */
  public void setChildren(Person children) {
  	this.children.clear();
  	this.children.add(children);
  }
  
  /**
   * Set the colleague property value for this Person object; overwriting any existing values.
   *
   * @param colleague The value to set.
   */
  public void setColleague(Person colleague) {
  	this.colleague.clear();
  	this.colleague.add(colleague);
  }
  
  /**
   * Set the contactPoint property value for this Person object; overwriting any existing values.
   *
   * @param contactPoint The value to set.
   */
  public void setContactPoint(ContactPoint contactPoint) {
  	this.contactPoint.clear();
  	this.contactPoint.add(contactPoint);
  }
  
  /**
   * Set the deathDate property value for this Person object; overwriting any existing values.
   *
   * @param deathDate The value to set.
   */
  public void setDeathDate(Date deathDate) {
  	this.deathDate.clear();
  	this.deathDate.add(deathDate);
  }
  
  /**
   * Set the description property value for this Person object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the duns property value for this Person object; overwriting any existing values.
   *
   * @param duns The value to set.
   */
  public void setDuns(String duns) {
  	this.duns.clear();
  	this.duns.add(duns);
  }
  
  /**
   * Set the email property value for this Person object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email) {
  	this.email.clear();
  	this.email.add(email);
  }
  
  /**
   * Set the familyName property value for this Person object; overwriting any existing values.
   *
   * @param familyName The value to set.
   */
  public void setFamilyName(String familyName) {
  	this.familyName.clear();
  	this.familyName.add(familyName);
  }
  
  /**
   * Set the faxNumber property value for this Person object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
  	this.faxNumber.clear();
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Set the follows property value for this Person object; overwriting any existing values.
   *
   * @param follows The value to set.
   */
  public void setFollows(Person follows) {
  	this.follows.clear();
  	this.follows.add(follows);
  }
  
  /**
   * Set the gender property value for this Person object; overwriting any existing values.
   *
   * @param gender The value to set.
   */
  public void setGender(String gender) {
  	this.gender.clear();
  	this.gender.add(gender);
  }
  
  /**
   * Set the givenName property value for this Person object; overwriting any existing values.
   *
   * @param givenName The value to set.
   */
  public void setGivenName(String givenName) {
  	this.givenName.clear();
  	this.givenName.add(givenName);
  }
  
  /**
   * Set the globalLocationNumber property value for this Person object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber) {
  	this.globalLocationNumber.clear();
  	this.globalLocationNumber.add(globalLocationNumber);
  }
  
  /**
   * Set the hasPOS property value for this Person object; overwriting any existing values.
   *
   * @param hasPOS The value to set.
   */
  public void setHasPOS(Place hasPOS) {
  	this.hasPOS.clear();
  	this.hasPOS.add(hasPOS);
  }
  
  /**
   * Set the homeLocation property value for this Person object; overwriting any existing values.
   *
   * @param homeLocation The value to set.
   */
  public void setHomeLocation(Thing homeLocation) {
  	this.homeLocation.clear();
  	this.homeLocation.add(homeLocation);
  }
  
  /**
   * Set the honorificPrefix property value for this Person object; overwriting any existing values.
   *
   * @param honorificPrefix The value to set.
   */
  public void setHonorificPrefix(String honorificPrefix) {
  	this.honorificPrefix.clear();
  	this.honorificPrefix.add(honorificPrefix);
  }
  
  /**
   * Set the honorificSuffix property value for this Person object; overwriting any existing values.
   *
   * @param honorificSuffix The value to set.
   */
  public void setHonorificSuffix(String honorificSuffix) {
  	this.honorificSuffix.clear();
  	this.honorificSuffix.add(honorificSuffix);
  }
  
  /**
   * Set the image property value for this Person object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the interactionCount property value for this Person object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
  	this.interactionCount.clear();
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Set the isicV4 property value for this Person object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4) {
  	this.isicV4.clear();
  	this.isicV4.add(isicV4);
  }
  
  /**
   * Set the jobTitle property value for this Person object; overwriting any existing values.
   *
   * @param jobTitle The value to set.
   */
  public void setJobTitle(String jobTitle) {
  	this.jobTitle.clear();
  	this.jobTitle.add(jobTitle);
  }
  
  /**
   * Set the knows property value for this Person object; overwriting any existing values.
   *
   * @param knows The value to set.
   */
  public void setKnows(Person knows) {
  	this.knows.clear();
  	this.knows.add(knows);
  }
  
  /**
   * Set the makesOffer property value for this Person object; overwriting any existing values.
   *
   * @param makesOffer The value to set.
   */
  public void setMakesOffer(Offer makesOffer) {
  	this.makesOffer.clear();
  	this.makesOffer.add(makesOffer);
  }
  
  /**
   * Set the memberOf property value for this Person object; overwriting any existing values.
   *
   * @param memberOf The value to set.
   */
  public void setMemberOf(Organization memberOf) {
  	this.memberOf.clear();
  	this.memberOf.add(memberOf);
  }
  
  /**
   * Set the naics property value for this Person object; overwriting any existing values.
   *
   * @param naics The value to set.
   */
  public void setNaics(String naics) {
  	this.naics.clear();
  	this.naics.add(naics);
  }
  
  /**
   * Set the name property value for this Person object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the nationality property value for this Person object; overwriting any existing values.
   *
   * @param nationality The value to set.
   */
  public void setNationality(Country nationality) {
  	this.nationality.clear();
  	this.nationality.add(nationality);
  }
  
  /**
   * Set the owns property value for this Person object; overwriting any existing values.
   *
   * @param owns The value to set.
   */
  public void setOwns(Thing owns) {
  	this.owns.clear();
  	this.owns.add(owns);
  }
  
  /**
   * Set the parent property value for this Person object; overwriting any existing values.
   *
   * @param parent The value to set.
   */
  public void setParent(Person parent) {
  	this.parent.clear();
  	this.parent.add(parent);
  }
  
  /**
   * Set the performerIn property value for this Person object; overwriting any existing values.
   *
   * @param performerIn The value to set.
   */
  public void setPerformerIn(Event performerIn) {
  	this.performerIn.clear();
  	this.performerIn.add(performerIn);
  }
  
  /**
   * Set the relatedTo property value for this Person object; overwriting any existing values.
   *
   * @param relatedTo The value to set.
   */
  public void setRelatedTo(Person relatedTo) {
  	this.relatedTo.clear();
  	this.relatedTo.add(relatedTo);
  }
  
  /**
   * Set the sameAs property value for this Person object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seeks property value for this Person object; overwriting any existing values.
   *
   * @param seeks The value to set.
   */
  public void setSeeks(Demand seeks) {
  	this.seeks.clear();
  	this.seeks.add(seeks);
  }
  
  /**
   * Set the sibling property value for this Person object; overwriting any existing values.
   *
   * @param sibling The value to set.
   */
  public void setSibling(Person sibling) {
  	this.sibling.clear();
  	this.sibling.add(sibling);
  }
  
  /**
   * Set the spouse property value for this Person object; overwriting any existing values.
   *
   * @param spouse The value to set.
   */
  public void setSpouse(Person spouse) {
  	this.spouse.clear();
  	this.spouse.add(spouse);
  }
  
  /**
   * Set the taxID property value for this Person object; overwriting any existing values.
   *
   * @param taxID The value to set.
   */
  public void setTaxID(String taxID) {
  	this.taxID.clear();
  	this.taxID.add(taxID);
  }
  
  /**
   * Set the telephone property value for this Person object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
  	this.telephone.clear();
  	this.telephone.add(telephone);
  }
  
  /**
   * Set the url property value for this Person object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the vatID property value for this Person object; overwriting any existing values.
   *
   * @param vatID The value to set.
   */
  public void setVatID(String vatID) {
  	this.vatID.clear();
  	this.vatID.add(vatID);
  }
  
  /**
   * Set the workLocation property value for this Person object; overwriting any existing values.
   *
   * @param workLocation The value to set.
   */
  public void setWorkLocation(Thing workLocation) {
  	this.workLocation.clear();
  	this.workLocation.add(workLocation);
  }
  
  /**
   * Set the worksFor property value for this Person object; overwriting any existing values.
   *
   * @param worksFor The value to set.
   */
  public void setWorksFor(Organization worksFor) {
  	this.worksFor.clear();
  	this.worksFor.add(worksFor);
  }
  
  /**
   * Set the additionalName property values for this Person object; overwriting any existing values.
   *
   * @param additionalNames The list of values to set.
   */
  public void setAdditionalNames(List<String> additionalNames) {
  	this.additionalName = additionalNames;
  }
  
  /**
   * Set the additionalType property values for this Person object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the address property values for this Person object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses) {
  	this.address = addresses;
  }
  
  /**
   * Set the affiliation property values for this Person object; overwriting any existing values.
   *
   * @param affiliations The list of values to set.
   */
  public void setAffiliations(List<Organization> affiliations) {
  	this.affiliation = affiliations;
  }
  
  /**
   * Set the alternateName property values for this Person object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the alumniOf property values for this Person object; overwriting any existing values.
   *
   * @param alumnisOf The list of values to set.
   */
  public void setAlumnisOf(List<EducationalOrganization> alumnisOf) {
  	this.alumniOf = alumnisOf;
  }
  
  /**
   * Set the award property values for this Person object; overwriting any existing values.
   *
   * @param awards The list of values to set.
   */
  public void setAwards(List<String> awards) {
  	this.award = awards;
  }
  
  /**
   * Set the birthDate property values for this Person object; overwriting any existing values.
   *
   * @param birthDates The list of values to set.
   */
  public void setBirthDates(List<Date> birthDates) {
  	this.birthDate = birthDates;
  }
  
  /**
   * Set the brand property values for this Person object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands) {
  	this.brand = brands;
  }
  
  /**
   * Set the children property values for this Person object; overwriting any existing values.
   *
   * @param childrens The list of values to set.
   */
  public void setChildrens(List<Person> childrens) {
  	this.children = childrens;
  }
  
  /**
   * Set the colleague property values for this Person object; overwriting any existing values.
   *
   * @param colleagues The list of values to set.
   */
  public void setColleagues(List<Person> colleagues) {
  	this.colleague = colleagues;
  }
  
  /**
   * Set the contactPoint property values for this Person object; overwriting any existing values.
   *
   * @param contactPoints The list of values to set.
   */
  public void setContactPoints(List<ContactPoint> contactPoints) {
  	this.contactPoint = contactPoints;
  }
  
  /**
   * Set the deathDate property values for this Person object; overwriting any existing values.
   *
   * @param deathDates The list of values to set.
   */
  public void setDeathDates(List<Date> deathDates) {
  	this.deathDate = deathDates;
  }
  
  /**
   * Set the description property values for this Person object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the duns property values for this Person object; overwriting any existing values.
   *
   * @param dunss The list of values to set.
   */
  public void setDunss(List<String> dunss) {
  	this.duns = dunss;
  }
  
  /**
   * Set the email property values for this Person object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails) {
  	this.email = emails;
  }
  
  /**
   * Set the familyName property values for this Person object; overwriting any existing values.
   *
   * @param familyNames The list of values to set.
   */
  public void setFamilyNames(List<String> familyNames) {
  	this.familyName = familyNames;
  }
  
  /**
   * Set the faxNumber property values for this Person object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
  	this.faxNumber = faxNumbers;
  }
  
  /**
   * Set the follows property values for this Person object; overwriting any existing values.
   *
   * @param followss The list of values to set.
   */
  public void setFollowss(List<Person> followss) {
  	this.follows = followss;
  }
  
  /**
   * Set the gender property values for this Person object; overwriting any existing values.
   *
   * @param genders The list of values to set.
   */
  public void setGenders(List<String> genders) {
  	this.gender = genders;
  }
  
  /**
   * Set the givenName property values for this Person object; overwriting any existing values.
   *
   * @param givenNames The list of values to set.
   */
  public void setGivenNames(List<String> givenNames) {
  	this.givenName = givenNames;
  }
  
  /**
   * Set the globalLocationNumber property values for this Person object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers) {
  	this.globalLocationNumber = globalLocationNumbers;
  }
  
  /**
   * Set the hasPOS property values for this Person object; overwriting any existing values.
   *
   * @param hasPOSs The list of values to set.
   */
  public void setHasPOSs(List<Place> hasPOSs) {
  	this.hasPOS = hasPOSs;
  }
  
  /**
   * Set the homeLocation property values for this Person object; overwriting any existing values.
   *
   * @param homeLocations The list of values to set.
   */
  public void setHomeLocations(List<Thing> homeLocations) {
  	this.homeLocation = homeLocations;
  }
  
  /**
   * Set the honorificPrefix property values for this Person object; overwriting any existing values.
   *
   * @param honorificPrefixes The list of values to set.
   */
  public void setHonorificPrefixes(List<String> honorificPrefixes) {
  	this.honorificPrefix = honorificPrefixes;
  }
  
  /**
   * Set the honorificSuffix property values for this Person object; overwriting any existing values.
   *
   * @param honorificSuffixes The list of values to set.
   */
  public void setHonorificSuffixes(List<String> honorificSuffixes) {
  	this.honorificSuffix = honorificSuffixes;
  }
  
  /**
   * Set the image property values for this Person object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the interactionCount property values for this Person object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
  	this.interactionCount = interactionCounts;
  }
  
  /**
   * Set the isicV4 property values for this Person object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s) {
  	this.isicV4 = isicV4s;
  }
  
  /**
   * Set the jobTitle property values for this Person object; overwriting any existing values.
   *
   * @param jobTitles The list of values to set.
   */
  public void setJobTitles(List<String> jobTitles) {
  	this.jobTitle = jobTitles;
  }
  
  /**
   * Set the knows property values for this Person object; overwriting any existing values.
   *
   * @param knowss The list of values to set.
   */
  public void setKnowss(List<Person> knowss) {
  	this.knows = knowss;
  }
  
  /**
   * Set the makesOffer property values for this Person object; overwriting any existing values.
   *
   * @param makesOffers The list of values to set.
   */
  public void setMakesOffers(List<Offer> makesOffers) {
  	this.makesOffer = makesOffers;
  }
  
  /**
   * Set the memberOf property values for this Person object; overwriting any existing values.
   *
   * @param membersOf The list of values to set.
   */
  public void setMembersOf(List<Organization> membersOf) {
  	this.memberOf = membersOf;
  }
  
  /**
   * Set the naics property values for this Person object; overwriting any existing values.
   *
   * @param naicss The list of values to set.
   */
  public void setNaicss(List<String> naicss) {
  	this.naics = naicss;
  }
  
  /**
   * Set the name property values for this Person object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the nationality property values for this Person object; overwriting any existing values.
   *
   * @param nationalities The list of values to set.
   */
  public void setNationalities(List<Country> nationalities) {
  	this.nationality = nationalities;
  }
  
  /**
   * Set the owns property values for this Person object; overwriting any existing values.
   *
   * @param ownss The list of values to set.
   */
  public void setOwnss(List<Thing> ownss) {
  	this.owns = ownss;
  }
  
  /**
   * Set the parent property values for this Person object; overwriting any existing values.
   *
   * @param parents The list of values to set.
   */
  public void setParents(List<Person> parents) {
  	this.parent = parents;
  }
  
  /**
   * Set the performerIn property values for this Person object; overwriting any existing values.
   *
   * @param performersIn The list of values to set.
   */
  public void setPerformersIn(List<Event> performersIn) {
  	this.performerIn = performersIn;
  }
  
  /**
   * Set the relatedTo property values for this Person object; overwriting any existing values.
   *
   * @param relatedToes The list of values to set.
   */
  public void setRelatedToes(List<Person> relatedToes) {
  	this.relatedTo = relatedToes;
  }
  
  /**
   * Set the sameAs property values for this Person object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seeks property values for this Person object; overwriting any existing values.
   *
   * @param seekss The list of values to set.
   */
  public void setSeekss(List<Demand> seekss) {
  	this.seeks = seekss;
  }
  
  /**
   * Set the sibling property values for this Person object; overwriting any existing values.
   *
   * @param siblings The list of values to set.
   */
  public void setSiblings(List<Person> siblings) {
  	this.sibling = siblings;
  }
  
  /**
   * Set the spouse property values for this Person object; overwriting any existing values.
   *
   * @param spouses The list of values to set.
   */
  public void setSpouses(List<Person> spouses) {
  	this.spouse = spouses;
  }
  
  /**
   * Set the taxID property values for this Person object; overwriting any existing values.
   *
   * @param taxIDs The list of values to set.
   */
  public void setTaxIDs(List<String> taxIDs) {
  	this.taxID = taxIDs;
  }
  
  /**
   * Set the telephone property values for this Person object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
  	this.telephone = telephones;
  }
  
  /**
   * Set the url property values for this Person object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the vatID property values for this Person object; overwriting any existing values.
   *
   * @param vatIDs The list of values to set.
   */
  public void setVatIDs(List<String> vatIDs) {
  	this.vatID = vatIDs;
  }
  
  /**
   * Set the workLocation property values for this Person object; overwriting any existing values.
   *
   * @param workLocations The list of values to set.
   */
  public void setWorkLocations(List<Thing> workLocations) {
  	this.workLocation = workLocations;
  }
  
  /**
   * Set the worksFor property values for this Person object; overwriting any existing values.
   *
   * @param worksFors The list of values to set.
   */
  public void setWorksFors(List<Organization> worksFors) {
  	this.worksFor = worksFors;
  }
  
  /**
   * Adds a additionalName property value for this Person object; appending it to the list of existing values.
   *
   * @param additionalName The value to add.
   */
  public void addAdditionalName(String additionalName) {
  	this.additionalName.add(additionalName);
  }
  
  /**
   * Adds a additionalType property value for this Person object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a address property value for this Person object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address) {
  	this.address.add(address);
  }
  
  /**
   * Adds a affiliation property value for this Person object; appending it to the list of existing values.
   *
   * @param affiliation The value to add.
   */
  public void addAffiliation(Organization affiliation) {
  	this.affiliation.add(affiliation);
  }
  
  /**
   * Adds a alternateName property value for this Person object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a alumniOf property value for this Person object; appending it to the list of existing values.
   *
   * @param alumniOf The value to add.
   */
  public void addAlumniOf(EducationalOrganization alumniOf) {
  	this.alumniOf.add(alumniOf);
  }
  
  /**
   * Adds a award property value for this Person object; appending it to the list of existing values.
   *
   * @param award The value to add.
   */
  public void addAward(String award) {
  	this.award.add(award);
  }
  
  /**
   * Adds a birthDate property value for this Person object; appending it to the list of existing values.
   *
   * @param birthDate The value to add.
   */
  public void addBirthDate(Date birthDate) {
  	this.birthDate.add(birthDate);
  }
  
  /**
   * Adds a brand property value for this Person object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand) {
  	this.brand.add(brand);
  }
  
  /**
   * Adds a children property value for this Person object; appending it to the list of existing values.
   *
   * @param children The value to add.
   */
  public void addChildren(Person children) {
  	this.children.add(children);
  }
  
  /**
   * Adds a colleague property value for this Person object; appending it to the list of existing values.
   *
   * @param colleague The value to add.
   */
  public void addColleague(Person colleague) {
  	this.colleague.add(colleague);
  }
  
  /**
   * Adds a contactPoint property value for this Person object; appending it to the list of existing values.
   *
   * @param contactPoint The value to add.
   */
  public void addContactPoint(ContactPoint contactPoint) {
  	this.contactPoint.add(contactPoint);
  }
  
  /**
   * Adds a deathDate property value for this Person object; appending it to the list of existing values.
   *
   * @param deathDate The value to add.
   */
  public void addDeathDate(Date deathDate) {
  	this.deathDate.add(deathDate);
  }
  
  /**
   * Adds a description property value for this Person object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a duns property value for this Person object; appending it to the list of existing values.
   *
   * @param duns The value to add.
   */
  public void addDuns(String duns) {
  	this.duns.add(duns);
  }
  
  /**
   * Adds a email property value for this Person object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email) {
  	this.email.add(email);
  }
  
  /**
   * Adds a familyName property value for this Person object; appending it to the list of existing values.
   *
   * @param familyName The value to add.
   */
  public void addFamilyName(String familyName) {
  	this.familyName.add(familyName);
  }
  
  /**
   * Adds a faxNumber property value for this Person object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Adds a follows property value for this Person object; appending it to the list of existing values.
   *
   * @param follows The value to add.
   */
  public void addFollows(Person follows) {
  	this.follows.add(follows);
  }
  
  /**
   * Adds a gender property value for this Person object; appending it to the list of existing values.
   *
   * @param gender The value to add.
   */
  public void addGender(String gender) {
  	this.gender.add(gender);
  }
  
  /**
   * Adds a givenName property value for this Person object; appending it to the list of existing values.
   *
   * @param givenName The value to add.
   */
  public void addGivenName(String givenName) {
  	this.givenName.add(givenName);
  }
  
  /**
   * Adds a globalLocationNumber property value for this Person object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber) {
  	this.globalLocationNumber.add(globalLocationNumber);
  }
  
  /**
   * Adds a hasPOS property value for this Person object; appending it to the list of existing values.
   *
   * @param hasPOS The value to add.
   */
  public void addHasPOS(Place hasPOS) {
  	this.hasPOS.add(hasPOS);
  }
  
  /**
   * Adds a homeLocation property value for this Person object; appending it to the list of existing values.
   *
   * @param homeLocation The value to add.
   */
  public void addHomeLocation(Thing homeLocation) {
  	this.homeLocation.add(homeLocation);
  }
  
  /**
   * Adds a honorificPrefix property value for this Person object; appending it to the list of existing values.
   *
   * @param honorificPrefix The value to add.
   */
  public void addHonorificPrefix(String honorificPrefix) {
  	this.honorificPrefix.add(honorificPrefix);
  }
  
  /**
   * Adds a honorificSuffix property value for this Person object; appending it to the list of existing values.
   *
   * @param honorificSuffix The value to add.
   */
  public void addHonorificSuffix(String honorificSuffix) {
  	this.honorificSuffix.add(honorificSuffix);
  }
  
  /**
   * Adds a image property value for this Person object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a interactionCount property value for this Person object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Adds a isicV4 property value for this Person object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4) {
  	this.isicV4.add(isicV4);
  }
  
  /**
   * Adds a jobTitle property value for this Person object; appending it to the list of existing values.
   *
   * @param jobTitle The value to add.
   */
  public void addJobTitle(String jobTitle) {
  	this.jobTitle.add(jobTitle);
  }
  
  /**
   * Adds a knows property value for this Person object; appending it to the list of existing values.
   *
   * @param knows The value to add.
   */
  public void addKnows(Person knows) {
  	this.knows.add(knows);
  }
  
  /**
   * Adds a makesOffer property value for this Person object; appending it to the list of existing values.
   *
   * @param makesOffer The value to add.
   */
  public void addMakesOffer(Offer makesOffer) {
  	this.makesOffer.add(makesOffer);
  }
  
  /**
   * Adds a memberOf property value for this Person object; appending it to the list of existing values.
   *
   * @param memberOf The value to add.
   */
  public void addMemberOf(Organization memberOf) {
  	this.memberOf.add(memberOf);
  }
  
  /**
   * Adds a naics property value for this Person object; appending it to the list of existing values.
   *
   * @param naics The value to add.
   */
  public void addNaics(String naics) {
  	this.naics.add(naics);
  }
  
  /**
   * Adds a name property value for this Person object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a nationality property value for this Person object; appending it to the list of existing values.
   *
   * @param nationality The value to add.
   */
  public void addNationality(Country nationality) {
  	this.nationality.add(nationality);
  }
  
  /**
   * Adds a owns property value for this Person object; appending it to the list of existing values.
   *
   * @param owns The value to add.
   */
  public void addOwns(Thing owns) {
  	this.owns.add(owns);
  }
  
  /**
   * Adds a parent property value for this Person object; appending it to the list of existing values.
   *
   * @param parent The value to add.
   */
  public void addParent(Person parent) {
  	this.parent.add(parent);
  }
  
  /**
   * Adds a performerIn property value for this Person object; appending it to the list of existing values.
   *
   * @param performerIn The value to add.
   */
  public void addPerformerIn(Event performerIn) {
  	this.performerIn.add(performerIn);
  }
  
  /**
   * Adds a relatedTo property value for this Person object; appending it to the list of existing values.
   *
   * @param relatedTo The value to add.
   */
  public void addRelatedTo(Person relatedTo) {
  	this.relatedTo.add(relatedTo);
  }
  
  /**
   * Adds a sameAs property value for this Person object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seeks property value for this Person object; appending it to the list of existing values.
   *
   * @param seeks The value to add.
   */
  public void addSeeks(Demand seeks) {
  	this.seeks.add(seeks);
  }
  
  /**
   * Adds a sibling property value for this Person object; appending it to the list of existing values.
   *
   * @param sibling The value to add.
   */
  public void addSibling(Person sibling) {
  	this.sibling.add(sibling);
  }
  
  /**
   * Adds a spouse property value for this Person object; appending it to the list of existing values.
   *
   * @param spouse The value to add.
   */
  public void addSpouse(Person spouse) {
  	this.spouse.add(spouse);
  }
  
  /**
   * Adds a taxID property value for this Person object; appending it to the list of existing values.
   *
   * @param taxID The value to add.
   */
  public void addTaxID(String taxID) {
  	this.taxID.add(taxID);
  }
  
  /**
   * Adds a telephone property value for this Person object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
  	this.telephone.add(telephone);
  }
  
  /**
   * Adds a url property value for this Person object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a vatID property value for this Person object; appending it to the list of existing values.
   *
   * @param vatID The value to add.
   */
  public void addVatID(String vatID) {
  	this.vatID.add(vatID);
  }
  
  /**
   * Adds a workLocation property value for this Person object; appending it to the list of existing values.
   *
   * @param workLocation The value to add.
   */
  public void addWorkLocation(Thing workLocation) {
  	this.workLocation.add(workLocation);
  }
  
  /**
   * Adds a worksFor property value for this Person object; appending it to the list of existing values.
   *
   * @param worksFor The value to add.
   */
  public void addWorksFor(Organization worksFor) {
  	this.worksFor.add(worksFor);
  }
  
}