package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.Event;
import org.schema.OpeningHoursSpecification;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Review;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Entities that have a somewhat fixed, physical extension.
 */
public class PlaceImpl extends SchemaObjectImpl implements Place {


  private ThingImpl thing;

  /**
   * Physical address of the item.
   */
  private List<PostalAddress> address = new LinkedList<PostalAddress>();
  
  /**
   * The overall rating, based on a collection of reviews or ratings, of the item.
   */
  private List<AggregateRating> aggregateRating = new LinkedList<AggregateRating>();
  
  /**
   * The basic containment relation between places.
   */
  private List<Place> containedIn = new LinkedList<Place>();
  
  /**
   * Upcoming or past event associated with this place or organization.
   */
  private List<Event> event = new LinkedList<Event>();
  
  /**
   * The fax number.
   */
  private List<String> faxNumber = new LinkedList<String>();
  
  /**
   * The geo coordinates of the place.
   */
  private List<Thing> geo = new LinkedList<Thing>();
  
  /**
   * The Global Location Number (GLN, sometimes also referred to as International Location Number or ILN) of the respective organization, person, or place. The GLN is a 13-digit number used to identify parties and physical locations.
   */
  private List<String> globalLocationNumber = new LinkedList<String>();
  
  /**
   * A count of a specific user interactions with this item&#x2014;for example, <code>20 UserLikes</code>, <code>5 UserComments</code>, or <code>300 UserDownloads</code>. The user interaction type should be one of the sub types of <a href='UserInteraction'>UserInteraction</a>.
   */
  private List<String> interactionCount = new LinkedList<String>();
  
  /**
   * The International Standard of Industrial Classification of All Economic Activities (ISIC), Revision 4 code for a particular organization, business person, or place.
   */
  private List<String> isicV4 = new LinkedList<String>();
  
  /**
   * A logo associated with an organization.
   */
  private List<Thing> logo = new LinkedList<Thing>();
  
  /**
   * A URL to a map of the place.
   */
  private List<URL> map = new LinkedList<URL>();
  
  /**
   * The opening hours of a certain place.
   */
  private List<OpeningHoursSpecification> openingHoursSpecification = new LinkedList<OpeningHoursSpecification>();
  
  /**
   * A photograph of this place.
   */
  private List<Thing> photo = new LinkedList<Thing>();
  
  /**
   * A review of the item.
   */
  private List<Review> review = new LinkedList<Review>();
  
  /**
   * The telephone number.
   */
  private List<String> telephone = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PlaceImpl() {
    super("http://schema.org/Place");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this Place object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single address property value for this Place object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress() {
  	return this.address.isEmpty() ? null : this.address.get(0);
  }
  
  /**
   * Get a single aggregateRating property value for this Place object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
  	return this.aggregateRating.isEmpty() ? null : this.aggregateRating.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Place object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single containedIn property value for this Place object.
   *
   * @return The first containedIn property value.
   */
  public Place getContainedIn() {
  	return this.containedIn.isEmpty() ? null : this.containedIn.get(0);
  }
  
  /**
   * Get a single description property value for this Place object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single event property value for this Place object.
   *
   * @return The first event property value.
   */
  public Event getEvent() {
  	return this.event.isEmpty() ? null : this.event.get(0);
  }
  
  /**
   * Get a single faxNumber property value for this Place object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
  	return this.faxNumber.isEmpty() ? null : this.faxNumber.get(0);
  }
  
  /**
   * Get a single geo property value for this Place object.
   *
   * @return The first geo property value.
   */
  public Thing getGeo() {
  	return this.geo.isEmpty() ? null : this.geo.get(0);
  }
  
  /**
   * Get a single globalLocationNumber property value for this Place object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber() {
  	return this.globalLocationNumber.isEmpty() ? null : this.globalLocationNumber.get(0);
  }
  
  /**
   * Get a single image property value for this Place object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single interactionCount property value for this Place object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount() {
  	return this.interactionCount.isEmpty() ? null : this.interactionCount.get(0);
  }
  
  /**
   * Get a single isicV4 property value for this Place object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4() {
  	return this.isicV4.isEmpty() ? null : this.isicV4.get(0);
  }
  
  /**
   * Get a single logo property value for this Place object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo() {
  	return this.logo.isEmpty() ? null : this.logo.get(0);
  }
  
  /**
   * Get a single map property value for this Place object.
   *
   * @return The first map property value.
   */
  public URL getMap() {
  	return this.map.isEmpty() ? null : this.map.get(0);
  }
  
  /**
   * Get a single name property value for this Place object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single openingHoursSpecification property value for this Place object.
   *
   * @return The first openingHoursSpecification property value.
   */
  public OpeningHoursSpecification getOpeningHoursSpecification() {
  	return this.openingHoursSpecification.isEmpty() ? null : this.openingHoursSpecification.get(0);
  }
  
  /**
   * Get a single photo property value for this Place object.
   *
   * @return The first photo property value.
   */
  public Thing getPhoto() {
  	return this.photo.isEmpty() ? null : this.photo.get(0);
  }
  
  /**
   * Get a single review property value for this Place object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
  	return this.review.isEmpty() ? null : this.review.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Place object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single telephone property value for this Place object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
  	return this.telephone.isEmpty() ? null : this.telephone.get(0);
  }
  
  /**
   * Get a single url property value for this Place object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Place object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the address property values for this Place object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses() {
  	return this.address;
  }
  
  /**
   * Get all the aggregateRating property values for this Place object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
  	return this.aggregateRating;
  }
  
  /**
   * Get all the alternateName property values for this Place object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the containedIn property values for this Place object.
   *
   * @return A list of containedIn property values.
   */
  public List<Place> getContainedsIn() {
  	return this.containedIn;
  }
  
  /**
   * Get all the description property values for this Place object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the event property values for this Place object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents() {
  	return this.event;
  }
  
  /**
   * Get all the faxNumber property values for this Place object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
  	return this.faxNumber;
  }
  
  /**
   * Get all the geo property values for this Place object.
   *
   * @return A list of geo property values.
   */
  public List<Thing> getGeos() {
  	return this.geo;
  }
  
  /**
   * Get all the globalLocationNumber property values for this Place object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers() {
  	return this.globalLocationNumber;
  }
  
  /**
   * Get all the image property values for this Place object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the interactionCount property values for this Place object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts() {
  	return this.interactionCount;
  }
  
  /**
   * Get all the isicV4 property values for this Place object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s() {
  	return this.isicV4;
  }
  
  /**
   * Get all the logo property values for this Place object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes() {
  	return this.logo;
  }
  
  /**
   * Get all the map property values for this Place object.
   *
   * @return A list of map property values.
   */
  public List<URL> getMaps() {
  	return this.map;
  }
  
  /**
   * Get all the name property values for this Place object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the openingHoursSpecification property values for this Place object.
   *
   * @return A list of openingHoursSpecification property values.
   */
  public List<OpeningHoursSpecification> getOpeningHoursSpecifications() {
  	return this.openingHoursSpecification;
  }
  
  /**
   * Get all the photo property values for this Place object.
   *
   * @return A list of photo property values.
   */
  public List<Thing> getPhotos() {
  	return this.photo;
  }
  
  /**
   * Get all the review property values for this Place object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
  	return this.review;
  }
  
  /**
   * Get all the sameAs property values for this Place object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the telephone property values for this Place object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
  	return this.telephone;
  }
  
  /**
   * Get all the url property values for this Place object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Place object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the address property value for this Place object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address) {
  	this.address.clear();
  	this.address.add(address);
  }
  
  /**
   * Set the aggregateRating property value for this Place object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.clear();
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this Place object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the containedIn property value for this Place object; overwriting any existing values.
   *
   * @param containedIn The value to set.
   */
  public void setContainedIn(Place containedIn) {
  	this.containedIn.clear();
  	this.containedIn.add(containedIn);
  }
  
  /**
   * Set the description property value for this Place object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the event property value for this Place object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event) {
  	this.event.clear();
  	this.event.add(event);
  }
  
  /**
   * Set the faxNumber property value for this Place object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
  	this.faxNumber.clear();
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Set the geo property value for this Place object; overwriting any existing values.
   *
   * @param geo The value to set.
   */
  public void setGeo(Thing geo) {
  	this.geo.clear();
  	this.geo.add(geo);
  }
  
  /**
   * Set the globalLocationNumber property value for this Place object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber) {
  	this.globalLocationNumber.clear();
  	this.globalLocationNumber.add(globalLocationNumber);
  }
  
  /**
   * Set the image property value for this Place object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the interactionCount property value for this Place object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount) {
  	this.interactionCount.clear();
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Set the isicV4 property value for this Place object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4) {
  	this.isicV4.clear();
  	this.isicV4.add(isicV4);
  }
  
  /**
   * Set the logo property value for this Place object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo) {
  	this.logo.clear();
  	this.logo.add(logo);
  }
  
  /**
   * Set the map property value for this Place object; overwriting any existing values.
   *
   * @param map The value to set.
   */
  public void setMap(URL map) {
  	this.map.clear();
  	this.map.add(map);
  }
  
  /**
   * Set the name property value for this Place object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the openingHoursSpecification property value for this Place object; overwriting any existing values.
   *
   * @param openingHoursSpecification The value to set.
   */
  public void setOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification) {
  	this.openingHoursSpecification.clear();
  	this.openingHoursSpecification.add(openingHoursSpecification);
  }
  
  /**
   * Set the photo property value for this Place object; overwriting any existing values.
   *
   * @param photo The value to set.
   */
  public void setPhoto(Thing photo) {
  	this.photo.clear();
  	this.photo.add(photo);
  }
  
  /**
   * Set the review property value for this Place object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
  	this.review.clear();
  	this.review.add(review);
  }
  
  /**
   * Set the sameAs property value for this Place object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the telephone property value for this Place object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
  	this.telephone.clear();
  	this.telephone.add(telephone);
  }
  
  /**
   * Set the url property value for this Place object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Place object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the address property values for this Place object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses) {
  	this.address = addresses;
  }
  
  /**
   * Set the aggregateRating property values for this Place object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
  	this.aggregateRating = aggregateRatings;
  }
  
  /**
   * Set the alternateName property values for this Place object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the containedIn property values for this Place object; overwriting any existing values.
   *
   * @param containedsIn The list of values to set.
   */
  public void setContainedsIn(List<Place> containedsIn) {
  	this.containedIn = containedsIn;
  }
  
  /**
   * Set the description property values for this Place object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the event property values for this Place object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events) {
  	this.event = events;
  }
  
  /**
   * Set the faxNumber property values for this Place object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
  	this.faxNumber = faxNumbers;
  }
  
  /**
   * Set the geo property values for this Place object; overwriting any existing values.
   *
   * @param geos The list of values to set.
   */
  public void setGeos(List<Thing> geos) {
  	this.geo = geos;
  }
  
  /**
   * Set the globalLocationNumber property values for this Place object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers) {
  	this.globalLocationNumber = globalLocationNumbers;
  }
  
  /**
   * Set the image property values for this Place object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the interactionCount property values for this Place object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts) {
  	this.interactionCount = interactionCounts;
  }
  
  /**
   * Set the isicV4 property values for this Place object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s) {
  	this.isicV4 = isicV4s;
  }
  
  /**
   * Set the logo property values for this Place object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes) {
  	this.logo = logoes;
  }
  
  /**
   * Set the map property values for this Place object; overwriting any existing values.
   *
   * @param maps The list of values to set.
   */
  public void setMaps(List<URL> maps) {
  	this.map = maps;
  }
  
  /**
   * Set the name property values for this Place object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the openingHoursSpecification property values for this Place object; overwriting any existing values.
   *
   * @param openingHoursSpecifications The list of values to set.
   */
  public void setOpeningHoursSpecifications(List<OpeningHoursSpecification> openingHoursSpecifications) {
  	this.openingHoursSpecification = openingHoursSpecifications;
  }
  
  /**
   * Set the photo property values for this Place object; overwriting any existing values.
   *
   * @param photos The list of values to set.
   */
  public void setPhotos(List<Thing> photos) {
  	this.photo = photos;
  }
  
  /**
   * Set the review property values for this Place object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
  	this.review = reviews;
  }
  
  /**
   * Set the sameAs property values for this Place object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the telephone property values for this Place object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
  	this.telephone = telephones;
  }
  
  /**
   * Set the url property values for this Place object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Place object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a address property value for this Place object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address) {
  	this.address.add(address);
  }
  
  /**
   * Adds a aggregateRating property value for this Place object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this Place object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a containedIn property value for this Place object; appending it to the list of existing values.
   *
   * @param containedIn The value to add.
   */
  public void addContainedIn(Place containedIn) {
  	this.containedIn.add(containedIn);
  }
  
  /**
   * Adds a description property value for this Place object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a event property value for this Place object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event) {
  	this.event.add(event);
  }
  
  /**
   * Adds a faxNumber property value for this Place object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
  	this.faxNumber.add(faxNumber);
  }
  
  /**
   * Adds a geo property value for this Place object; appending it to the list of existing values.
   *
   * @param geo The value to add.
   */
  public void addGeo(Thing geo) {
  	this.geo.add(geo);
  }
  
  /**
   * Adds a globalLocationNumber property value for this Place object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber) {
  	this.globalLocationNumber.add(globalLocationNumber);
  }
  
  /**
   * Adds a image property value for this Place object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a interactionCount property value for this Place object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount) {
  	this.interactionCount.add(interactionCount);
  }
  
  /**
   * Adds a isicV4 property value for this Place object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4) {
  	this.isicV4.add(isicV4);
  }
  
  /**
   * Adds a logo property value for this Place object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo) {
  	this.logo.add(logo);
  }
  
  /**
   * Adds a map property value for this Place object; appending it to the list of existing values.
   *
   * @param map The value to add.
   */
  public void addMap(URL map) {
  	this.map.add(map);
  }
  
  /**
   * Adds a name property value for this Place object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a openingHoursSpecification property value for this Place object; appending it to the list of existing values.
   *
   * @param openingHoursSpecification The value to add.
   */
  public void addOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification) {
  	this.openingHoursSpecification.add(openingHoursSpecification);
  }
  
  /**
   * Adds a photo property value for this Place object; appending it to the list of existing values.
   *
   * @param photo The value to add.
   */
  public void addPhoto(Thing photo) {
  	this.photo.add(photo);
  }
  
  /**
   * Adds a review property value for this Place object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
  	this.review.add(review);
  }
  
  /**
   * Adds a sameAs property value for this Place object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a telephone property value for this Place object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
  	this.telephone.add(telephone);
  }
  
  /**
   * Adds a url property value for this Place object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}