package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.ContactPointOption;
import org.schema.Country;
import org.schema.Language;
import org.schema.OpeningHoursSpecification;
import org.schema.PostalAddress;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The mailing address.
 */
public class PostalAddressImpl extends SchemaObjectImpl implements PostalAddress {


  private ContactPointImpl contactPoint;
  private ThingImpl thing;

  /**
   * The country. For example, USA. You can also provide the two-letter <a href='http://en.wikipedia.org/wiki/ISO_3166-1'>ISO 3166-1 alpha-2 country code</a>.
   */
  private List<Country> addressCountry = new LinkedList<Country>();
  
  /**
   * The locality. For example, Mountain View.
   */
  private List<String> addressLocality = new LinkedList<String>();
  
  /**
   * The region. For example, CA.
   */
  private List<String> addressRegion = new LinkedList<String>();
  
  /**
   * The post offce box number for PO box addresses.
   */
  private List<String> postOfficeBoxNumber = new LinkedList<String>();
  
  /**
   * The postal code. For example, 94043.
   */
  private List<String> postalCode = new LinkedList<String>();
  
  /**
   * The street address. For example, 1600 Amphitheatre Pkwy.
   */
  private List<String> streetAddress = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PostalAddressImpl() {
    super("http://schema.org/PostalAddress");
    contactPoint = new ContactPointImpl();
  }
  /**
   * Get a single additionalType property value for this PostalAddress object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single addressCountry property value for this PostalAddress object.
   *
   * @return The first addressCountry property value.
   */
  public Country getAddressCountry() {
  	return this.addressCountry.isEmpty() ? null : this.addressCountry.get(0);
  }
  
  /**
   * Get a single addressLocality property value for this PostalAddress object.
   *
   * @return The first addressLocality property value.
   */
  public String getAddressLocality() {
  	return this.addressLocality.isEmpty() ? null : this.addressLocality.get(0);
  }
  
  /**
   * Get a single addressRegion property value for this PostalAddress object.
   *
   * @return The first addressRegion property value.
   */
  public String getAddressRegion() {
  	return this.addressRegion.isEmpty() ? null : this.addressRegion.get(0);
  }
  
  /**
   * Get a single alternateName property value for this PostalAddress object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single areaServed property value for this PostalAddress object.
   *
   * @return The first areaServed property value.
   */
  public AdministrativeArea getAreaServed() {
    return contactPoint.getAreaServed();
  }
  
  /**
   * Get a single availableLanguage property value for this PostalAddress object.
   *
   * @return The first availableLanguage property value.
   */
  public Language getAvailableLanguage() {
    return contactPoint.getAvailableLanguage();
  }
  
  /**
   * Get a single contactOption property value for this PostalAddress object.
   *
   * @return The first contactOption property value.
   */
  public ContactPointOption getContactOption() {
    return contactPoint.getContactOption();
  }
  
  /**
   * Get a single contactType property value for this PostalAddress object.
   *
   * @return The first contactType property value.
   */
  public String getContactType() {
    return contactPoint.getContactType();
  }
  
  /**
   * Get a single description property value for this PostalAddress object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single email property value for this PostalAddress object.
   *
   * @return The first email property value.
   */
  public String getEmail() {
    return contactPoint.getEmail();
  }
  
  /**
   * Get a single faxNumber property value for this PostalAddress object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber() {
    return contactPoint.getFaxNumber();
  }
  
  /**
   * Get a single hoursAvailable property value for this PostalAddress object.
   *
   * @return The first hoursAvailable property value.
   */
  public OpeningHoursSpecification getHoursAvailable() {
    return contactPoint.getHoursAvailable();
  }
  
  /**
   * Get a single image property value for this PostalAddress object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this PostalAddress object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single postOfficeBoxNumber property value for this PostalAddress object.
   *
   * @return The first postOfficeBoxNumber property value.
   */
  public String getPostOfficeBoxNumber() {
  	return this.postOfficeBoxNumber.isEmpty() ? null : this.postOfficeBoxNumber.get(0);
  }
  
  /**
   * Get a single postalCode property value for this PostalAddress object.
   *
   * @return The first postalCode property value.
   */
  public String getPostalCode() {
  	return this.postalCode.isEmpty() ? null : this.postalCode.get(0);
  }
  
  /**
   * Get a single productSupported property value for this PostalAddress object.
   *
   * @return The first productSupported property value.
   */
  public Thing getProductSupported() {
    return contactPoint.getProductSupported();
  }
  
  /**
   * Get a single sameAs property value for this PostalAddress object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single streetAddress property value for this PostalAddress object.
   *
   * @return The first streetAddress property value.
   */
  public String getStreetAddress() {
  	return this.streetAddress.isEmpty() ? null : this.streetAddress.get(0);
  }
  
  /**
   * Get a single telephone property value for this PostalAddress object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone() {
    return contactPoint.getTelephone();
  }
  
  /**
   * Get a single url property value for this PostalAddress object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this PostalAddress object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the addressCountry property values for this PostalAddress object.
   *
   * @return A list of addressCountry property values.
   */
  public List<Country> getAddressCountries() {
  	return this.addressCountry;
  }
  
  /**
   * Get all the addressLocality property values for this PostalAddress object.
   *
   * @return A list of addressLocality property values.
   */
  public List<String> getAddressLocalities() {
  	return this.addressLocality;
  }
  
  /**
   * Get all the addressRegion property values for this PostalAddress object.
   *
   * @return A list of addressRegion property values.
   */
  public List<String> getAddressRegions() {
  	return this.addressRegion;
  }
  
  /**
   * Get all the alternateName property values for this PostalAddress object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the areaServed property values for this PostalAddress object.
   *
   * @return A list of areaServed property values.
   */
  public List<AdministrativeArea> getAreaServeds() {
    return contactPoint.getAreaServeds();
  }
  
  /**
   * Get all the availableLanguage property values for this PostalAddress object.
   *
   * @return A list of availableLanguage property values.
   */
  public List<Language> getAvailableLanguages() {
    return contactPoint.getAvailableLanguages();
  }
  
  /**
   * Get all the contactOption property values for this PostalAddress object.
   *
   * @return A list of contactOption property values.
   */
  public List<ContactPointOption> getContactOptions() {
    return contactPoint.getContactOptions();
  }
  
  /**
   * Get all the contactType property values for this PostalAddress object.
   *
   * @return A list of contactType property values.
   */
  public List<String> getContactTypes() {
    return contactPoint.getContactTypes();
  }
  
  /**
   * Get all the description property values for this PostalAddress object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the email property values for this PostalAddress object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails() {
    return contactPoint.getEmails();
  }
  
  /**
   * Get all the faxNumber property values for this PostalAddress object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers() {
    return contactPoint.getFaxNumbers();
  }
  
  /**
   * Get all the hoursAvailable property values for this PostalAddress object.
   *
   * @return A list of hoursAvailable property values.
   */
  public List<OpeningHoursSpecification> getHoursAvailables() {
    return contactPoint.getHoursAvailables();
  }
  
  /**
   * Get all the image property values for this PostalAddress object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this PostalAddress object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the postOfficeBoxNumber property values for this PostalAddress object.
   *
   * @return A list of postOfficeBoxNumber property values.
   */
  public List<String> getPostOfficeBoxNumbers() {
  	return this.postOfficeBoxNumber;
  }
  
  /**
   * Get all the postalCode property values for this PostalAddress object.
   *
   * @return A list of postalCode property values.
   */
  public List<String> getPostalCodes() {
  	return this.postalCode;
  }
  
  /**
   * Get all the productSupported property values for this PostalAddress object.
   *
   * @return A list of productSupported property values.
   */
  public List<Thing> getProductSupporteds() {
    return contactPoint.getProductSupporteds();
  }
  
  /**
   * Get all the sameAs property values for this PostalAddress object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the streetAddress property values for this PostalAddress object.
   *
   * @return A list of streetAddress property values.
   */
  public List<String> getStreetAddresses() {
  	return this.streetAddress;
  }
  
  /**
   * Get all the telephone property values for this PostalAddress object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones() {
    return contactPoint.getTelephones();
  }
  
  /**
   * Get all the url property values for this PostalAddress object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this PostalAddress object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the addressCountry property value for this PostalAddress object; overwriting any existing values.
   *
   * @param addressCountry The value to set.
   */
  public void setAddressCountry(Country addressCountry) {
  	this.addressCountry.clear();
  	this.addressCountry.add(addressCountry);
  }
  
  /**
   * Set the addressLocality property value for this PostalAddress object; overwriting any existing values.
   *
   * @param addressLocality The value to set.
   */
  public void setAddressLocality(String addressLocality) {
  	this.addressLocality.clear();
  	this.addressLocality.add(addressLocality);
  }
  
  /**
   * Set the addressRegion property value for this PostalAddress object; overwriting any existing values.
   *
   * @param addressRegion The value to set.
   */
  public void setAddressRegion(String addressRegion) {
  	this.addressRegion.clear();
  	this.addressRegion.add(addressRegion);
  }
  
  /**
   * Set the alternateName property value for this PostalAddress object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the areaServed property value for this PostalAddress object; overwriting any existing values.
   *
   * @param areaServed The value to set.
   */
  public void setAreaServed(AdministrativeArea areaServed) {
    contactPoint.setAreaServed(areaServed);
  }
  
  /**
   * Set the availableLanguage property value for this PostalAddress object; overwriting any existing values.
   *
   * @param availableLanguage The value to set.
   */
  public void setAvailableLanguage(Language availableLanguage) {
    contactPoint.setAvailableLanguage(availableLanguage);
  }
  
  /**
   * Set the contactOption property value for this PostalAddress object; overwriting any existing values.
   *
   * @param contactOption The value to set.
   */
  public void setContactOption(ContactPointOption contactOption) {
    contactPoint.setContactOption(contactOption);
  }
  
  /**
   * Set the contactType property value for this PostalAddress object; overwriting any existing values.
   *
   * @param contactType The value to set.
   */
  public void setContactType(String contactType) {
    contactPoint.setContactType(contactType);
  }
  
  /**
   * Set the description property value for this PostalAddress object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the email property value for this PostalAddress object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email) {
    contactPoint.setEmail(email);
  }
  
  /**
   * Set the faxNumber property value for this PostalAddress object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber) {
    contactPoint.setFaxNumber(faxNumber);
  }
  
  /**
   * Set the hoursAvailable property value for this PostalAddress object; overwriting any existing values.
   *
   * @param hoursAvailable The value to set.
   */
  public void setHoursAvailable(OpeningHoursSpecification hoursAvailable) {
    contactPoint.setHoursAvailable(hoursAvailable);
  }
  
  /**
   * Set the image property value for this PostalAddress object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this PostalAddress object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the postOfficeBoxNumber property value for this PostalAddress object; overwriting any existing values.
   *
   * @param postOfficeBoxNumber The value to set.
   */
  public void setPostOfficeBoxNumber(String postOfficeBoxNumber) {
  	this.postOfficeBoxNumber.clear();
  	this.postOfficeBoxNumber.add(postOfficeBoxNumber);
  }
  
  /**
   * Set the postalCode property value for this PostalAddress object; overwriting any existing values.
   *
   * @param postalCode The value to set.
   */
  public void setPostalCode(String postalCode) {
  	this.postalCode.clear();
  	this.postalCode.add(postalCode);
  }
  
  /**
   * Set the productSupported property value for this PostalAddress object; overwriting any existing values.
   *
   * @param productSupported The value to set.
   */
  public void setProductSupported(Thing productSupported) {
    contactPoint.setProductSupported(productSupported);
  }
  
  /**
   * Set the sameAs property value for this PostalAddress object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the streetAddress property value for this PostalAddress object; overwriting any existing values.
   *
   * @param streetAddress The value to set.
   */
  public void setStreetAddress(String streetAddress) {
  	this.streetAddress.clear();
  	this.streetAddress.add(streetAddress);
  }
  
  /**
   * Set the telephone property value for this PostalAddress object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone) {
    contactPoint.setTelephone(telephone);
  }
  
  /**
   * Set the url property value for this PostalAddress object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this PostalAddress object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the addressCountry property values for this PostalAddress object; overwriting any existing values.
   *
   * @param addressCountries The list of values to set.
   */
  public void setAddressCountries(List<Country> addressCountries) {
  	this.addressCountry = addressCountries;
  }
  
  /**
   * Set the addressLocality property values for this PostalAddress object; overwriting any existing values.
   *
   * @param addressLocalities The list of values to set.
   */
  public void setAddressLocalities(List<String> addressLocalities) {
  	this.addressLocality = addressLocalities;
  }
  
  /**
   * Set the addressRegion property values for this PostalAddress object; overwriting any existing values.
   *
   * @param addressRegions The list of values to set.
   */
  public void setAddressRegions(List<String> addressRegions) {
  	this.addressRegion = addressRegions;
  }
  
  /**
   * Set the alternateName property values for this PostalAddress object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the areaServed property values for this PostalAddress object; overwriting any existing values.
   *
   * @param areaServeds The list of values to set.
   */
  public void setAreaServeds(List<AdministrativeArea> areaServeds) {
    contactPoint.setAreaServeds(areaServeds);
  }
  
  /**
   * Set the availableLanguage property values for this PostalAddress object; overwriting any existing values.
   *
   * @param availableLanguages The list of values to set.
   */
  public void setAvailableLanguages(List<Language> availableLanguages) {
    contactPoint.setAvailableLanguages(availableLanguages);
  }
  
  /**
   * Set the contactOption property values for this PostalAddress object; overwriting any existing values.
   *
   * @param contactOptions The list of values to set.
   */
  public void setContactOptions(List<ContactPointOption> contactOptions) {
    contactPoint.setContactOptions(contactOptions);
  }
  
  /**
   * Set the contactType property values for this PostalAddress object; overwriting any existing values.
   *
   * @param contactTypes The list of values to set.
   */
  public void setContactTypes(List<String> contactTypes) {
    contactPoint.setContactTypes(contactTypes);
  }
  
  /**
   * Set the description property values for this PostalAddress object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the email property values for this PostalAddress object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails) {
    contactPoint.setEmails(emails);
  }
  
  /**
   * Set the faxNumber property values for this PostalAddress object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers) {
    contactPoint.setFaxNumbers(faxNumbers);
  }
  
  /**
   * Set the hoursAvailable property values for this PostalAddress object; overwriting any existing values.
   *
   * @param hoursAvailables The list of values to set.
   */
  public void setHoursAvailables(List<OpeningHoursSpecification> hoursAvailables) {
    contactPoint.setHoursAvailables(hoursAvailables);
  }
  
  /**
   * Set the image property values for this PostalAddress object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this PostalAddress object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the postOfficeBoxNumber property values for this PostalAddress object; overwriting any existing values.
   *
   * @param postOfficeBoxNumbers The list of values to set.
   */
  public void setPostOfficeBoxNumbers(List<String> postOfficeBoxNumbers) {
  	this.postOfficeBoxNumber = postOfficeBoxNumbers;
  }
  
  /**
   * Set the postalCode property values for this PostalAddress object; overwriting any existing values.
   *
   * @param postalCodes The list of values to set.
   */
  public void setPostalCodes(List<String> postalCodes) {
  	this.postalCode = postalCodes;
  }
  
  /**
   * Set the productSupported property values for this PostalAddress object; overwriting any existing values.
   *
   * @param productSupporteds The list of values to set.
   */
  public void setProductSupporteds(List<Thing> productSupporteds) {
    contactPoint.setProductSupporteds(productSupporteds);
  }
  
  /**
   * Set the sameAs property values for this PostalAddress object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the streetAddress property values for this PostalAddress object; overwriting any existing values.
   *
   * @param streetAddresses The list of values to set.
   */
  public void setStreetAddresses(List<String> streetAddresses) {
  	this.streetAddress = streetAddresses;
  }
  
  /**
   * Set the telephone property values for this PostalAddress object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones) {
    contactPoint.setTelephones(telephones);
  }
  
  /**
   * Set the url property values for this PostalAddress object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a addressCountry property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param addressCountry The value to add.
   */
  public void addAddressCountry(Country addressCountry) {
  	this.addressCountry.add(addressCountry);
  }
  
  /**
   * Adds a addressLocality property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param addressLocality The value to add.
   */
  public void addAddressLocality(String addressLocality) {
  	this.addressLocality.add(addressLocality);
  }
  
  /**
   * Adds a addressRegion property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param addressRegion The value to add.
   */
  public void addAddressRegion(String addressRegion) {
  	this.addressRegion.add(addressRegion);
  }
  
  /**
   * Adds a alternateName property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a areaServed property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param areaServed The value to add.
   */
  public void addAreaServed(AdministrativeArea areaServed) {
    contactPoint.addAreaServed(areaServed);
  }
  
  /**
   * Adds a availableLanguage property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param availableLanguage The value to add.
   */
  public void addAvailableLanguage(Language availableLanguage) {
    contactPoint.addAvailableLanguage(availableLanguage);
  }
  
  /**
   * Adds a contactOption property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param contactOption The value to add.
   */
  public void addContactOption(ContactPointOption contactOption) {
    contactPoint.addContactOption(contactOption);
  }
  
  /**
   * Adds a contactType property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param contactType The value to add.
   */
  public void addContactType(String contactType) {
    contactPoint.addContactType(contactType);
  }
  
  /**
   * Adds a description property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a email property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email) {
    contactPoint.addEmail(email);
  }
  
  /**
   * Adds a faxNumber property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber) {
    contactPoint.addFaxNumber(faxNumber);
  }
  
  /**
   * Adds a hoursAvailable property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param hoursAvailable The value to add.
   */
  public void addHoursAvailable(OpeningHoursSpecification hoursAvailable) {
    contactPoint.addHoursAvailable(hoursAvailable);
  }
  
  /**
   * Adds a image property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a postOfficeBoxNumber property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param postOfficeBoxNumber The value to add.
   */
  public void addPostOfficeBoxNumber(String postOfficeBoxNumber) {
  	this.postOfficeBoxNumber.add(postOfficeBoxNumber);
  }
  
  /**
   * Adds a postalCode property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param postalCode The value to add.
   */
  public void addPostalCode(String postalCode) {
  	this.postalCode.add(postalCode);
  }
  
  /**
   * Adds a productSupported property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param productSupported The value to add.
   */
  public void addProductSupported(Thing productSupported) {
    contactPoint.addProductSupported(productSupported);
  }
  
  /**
   * Adds a sameAs property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a streetAddress property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param streetAddress The value to add.
   */
  public void addStreetAddress(String streetAddress) {
  	this.streetAddress.add(streetAddress);
  }
  
  /**
   * Adds a telephone property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone) {
    contactPoint.addTelephone(telephone);
  }
  
  /**
   * Adds a url property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}