package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.Audience;
import org.schema.Offer;
import org.schema.OfferItemCondition;
import org.schema.Organization;
import org.schema.Product;
import org.schema.QuantitativeValue;
import org.schema.Review;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A product is anything that is made available for sale???for example, a pair of shoes, a concert ticket, or a car. Commodity services, like haircuts, can also be represented using this type.
 */
public class ProductImpl extends SchemaObjectImpl implements Product {


  private ThingImpl thing;

  /**
   * The overall rating, based on a collection of reviews or ratings, of the item.
   */
  private List<AggregateRating> aggregateRating = new LinkedList<AggregateRating>();
  
  /**
   * The intended audience of the item, i.e. the group for whom the item was created.
   */
  private List<Audience> audience = new LinkedList<Audience>();
  
  /**
   * The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
   */
  private List<Thing> brand = new LinkedList<Thing>();
  
  /**
   * The color of the product.
   */
  private List<String> color = new LinkedList<String>();
  
  /**
   * The depth of the product.
   */
  private List<Thing> depth = new LinkedList<Thing>();
  
  /**
   * The GTIN-13 code of the product, or the product to which the offer refers. This is equivalent to 13-digit ISBN codes and EAN UCC-13. Former 12-digit UPC codes can be converted into a GTIN-13 code by simply adding a preceeding zero.
   */
  private List<String> gtin13 = new LinkedList<String>();
  
  /**
   * The GTIN-14 code of the product, or the product to which the offer refers.
   */
  private List<String> gtin14 = new LinkedList<String>();
  
  /**
   * The GTIN-8 code of the product, or the product to which the offer refers. This code is also known as EAN/UCC-8 or 8-digit EAN.
   */
  private List<String> gtin8 = new LinkedList<String>();
  
  /**
   * The height of the item.
   */
  private List<Thing> height = new LinkedList<Thing>();
  
  /**
   * A pointer to another product (or multiple products) for which this product is an accessory or spare part.
   */
  private List<Product> isAccessoryOrSparePartFor = new LinkedList<Product>();
  
  /**
   * A pointer to another product (or multiple products) for which this product is a consumable.
   */
  private List<Product> isConsumableFor = new LinkedList<Product>();
  
  /**
   * A pointer to another, somehow related product (or multiple products).
   */
  private List<Product> isRelatedTo = new LinkedList<Product>();
  
  /**
   * A pointer to another, functionally similar product (or multiple products).
   */
  private List<Product> isSimilarTo = new LinkedList<Product>();
  
  /**
   * A predefined value from OfferItemCondition or a textual description of the condition of the product or service, or the products or services included in the offer.
   */
  private List<OfferItemCondition> itemCondition = new LinkedList<OfferItemCondition>();
  
  /**
   * A logo associated with an organization.
   */
  private List<Thing> logo = new LinkedList<Thing>();
  
  /**
   * The manufacturer of the product.
   */
  private List<Organization> manufacturer = new LinkedList<Organization>();
  
  /**
   * The model of the product. Use with the URL of a ProductModel or a textual representation of the model identifier. The URL of the ProductModel can be from an external source. It is recommended to additionally provide strong product identifiers via the gtin8/gtin13/gtin14 and mpn properties.
   */
  private List<Thing> model = new LinkedList<Thing>();
  
  /**
   * The Manufacturer Part Number (MPN) of the product, or the product to which the offer refers.
   */
  private List<String> mpn = new LinkedList<String>();
  
  /**
   * An offer to transfer some rights to an item or to provide a service&#x2014;for example, an offer to sell tickets to an event, to rent the DVD of a movie, to stream a TV show over the internet, to repair a motorcycle, or to loan a book.
   */
  private List<Offer> offers = new LinkedList<Offer>();
  
  /**
   * The product identifier, such as ISBN. For example: <code>&lt;meta itemprop='productID' content='isbn:123-456-789'/&gt;</code>.
   */
  private List<String> productID = new LinkedList<String>();
  
  /**
   * The release date of a product or product model. This can be used to distinguish the exact variant of a product.
   */
  private List<Date> releaseDate = new LinkedList<Date>();
  
  /**
   * A review of the item.
   */
  private List<Review> review = new LinkedList<Review>();
  
  /**
   * The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
   */
  private List<String> sku = new LinkedList<String>();
  
  /**
   * The weight of the product.
   */
  private List<QuantitativeValue> weight = new LinkedList<QuantitativeValue>();
  
  /**
   * The width of the item.
   */
  private List<Thing> width = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ProductImpl() {
    super("http://schema.org/Product");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this Product object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single aggregateRating property value for this Product object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
  	return this.aggregateRating.isEmpty() ? null : this.aggregateRating.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Product object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single audience property value for this Product object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience() {
  	return this.audience.isEmpty() ? null : this.audience.get(0);
  }
  
  /**
   * Get a single brand property value for this Product object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand() {
  	return this.brand.isEmpty() ? null : this.brand.get(0);
  }
  
  /**
   * Get a single color property value for this Product object.
   *
   * @return The first color property value.
   */
  public String getColor() {
  	return this.color.isEmpty() ? null : this.color.get(0);
  }
  
  /**
   * Get a single depth property value for this Product object.
   *
   * @return The first depth property value.
   */
  public Thing getDepth() {
  	return this.depth.isEmpty() ? null : this.depth.get(0);
  }
  
  /**
   * Get a single description property value for this Product object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single gtin13 property value for this Product object.
   *
   * @return The first gtin13 property value.
   */
  public String getGtin13() {
  	return this.gtin13.isEmpty() ? null : this.gtin13.get(0);
  }
  
  /**
   * Get a single gtin14 property value for this Product object.
   *
   * @return The first gtin14 property value.
   */
  public String getGtin14() {
  	return this.gtin14.isEmpty() ? null : this.gtin14.get(0);
  }
  
  /**
   * Get a single gtin8 property value for this Product object.
   *
   * @return The first gtin8 property value.
   */
  public String getGtin8() {
  	return this.gtin8.isEmpty() ? null : this.gtin8.get(0);
  }
  
  /**
   * Get a single height property value for this Product object.
   *
   * @return The first height property value.
   */
  public Thing getHeight() {
  	return this.height.isEmpty() ? null : this.height.get(0);
  }
  
  /**
   * Get a single image property value for this Product object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single isAccessoryOrSparePartFor property value for this Product object.
   *
   * @return The first isAccessoryOrSparePartFor property value.
   */
  public Product getIsAccessoryOrSparePartFor() {
  	return this.isAccessoryOrSparePartFor.isEmpty() ? null : this.isAccessoryOrSparePartFor.get(0);
  }
  
  /**
   * Get a single isConsumableFor property value for this Product object.
   *
   * @return The first isConsumableFor property value.
   */
  public Product getIsConsumableFor() {
  	return this.isConsumableFor.isEmpty() ? null : this.isConsumableFor.get(0);
  }
  
  /**
   * Get a single isRelatedTo property value for this Product object.
   *
   * @return The first isRelatedTo property value.
   */
  public Product getIsRelatedTo() {
  	return this.isRelatedTo.isEmpty() ? null : this.isRelatedTo.get(0);
  }
  
  /**
   * Get a single isSimilarTo property value for this Product object.
   *
   * @return The first isSimilarTo property value.
   */
  public Product getIsSimilarTo() {
  	return this.isSimilarTo.isEmpty() ? null : this.isSimilarTo.get(0);
  }
  
  /**
   * Get a single itemCondition property value for this Product object.
   *
   * @return The first itemCondition property value.
   */
  public OfferItemCondition getItemCondition() {
  	return this.itemCondition.isEmpty() ? null : this.itemCondition.get(0);
  }
  
  /**
   * Get a single logo property value for this Product object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo() {
  	return this.logo.isEmpty() ? null : this.logo.get(0);
  }
  
  /**
   * Get a single manufacturer property value for this Product object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer() {
  	return this.manufacturer.isEmpty() ? null : this.manufacturer.get(0);
  }
  
  /**
   * Get a single model property value for this Product object.
   *
   * @return The first model property value.
   */
  public Thing getModel() {
  	return this.model.isEmpty() ? null : this.model.get(0);
  }
  
  /**
   * Get a single mpn property value for this Product object.
   *
   * @return The first mpn property value.
   */
  public String getMpn() {
  	return this.mpn.isEmpty() ? null : this.mpn.get(0);
  }
  
  /**
   * Get a single name property value for this Product object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offers property value for this Product object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers() {
  	return this.offers.isEmpty() ? null : this.offers.get(0);
  }
  
  /**
   * Get a single productID property value for this Product object.
   *
   * @return The first productID property value.
   */
  public String getProductID() {
  	return this.productID.isEmpty() ? null : this.productID.get(0);
  }
  
  /**
   * Get a single releaseDate property value for this Product object.
   *
   * @return The first releaseDate property value.
   */
  public Date getReleaseDate() {
  	return this.releaseDate.isEmpty() ? null : this.releaseDate.get(0);
  }
  
  /**
   * Get a single review property value for this Product object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
  	return this.review.isEmpty() ? null : this.review.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Product object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single sku property value for this Product object.
   *
   * @return The first sku property value.
   */
  public String getSku() {
  	return this.sku.isEmpty() ? null : this.sku.get(0);
  }
  
  /**
   * Get a single url property value for this Product object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single weight property value for this Product object.
   *
   * @return The first weight property value.
   */
  public QuantitativeValue getWeight() {
  	return this.weight.isEmpty() ? null : this.weight.get(0);
  }
  
  /**
   * Get a single width property value for this Product object.
   *
   * @return The first width property value.
   */
  public Thing getWidth() {
  	return this.width.isEmpty() ? null : this.width.get(0);
  }
  
  /**
   * Get all the additionalType property values for this Product object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the aggregateRating property values for this Product object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
  	return this.aggregateRating;
  }
  
  /**
   * Get all the alternateName property values for this Product object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the audience property values for this Product object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences() {
  	return this.audience;
  }
  
  /**
   * Get all the brand property values for this Product object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands() {
  	return this.brand;
  }
  
  /**
   * Get all the color property values for this Product object.
   *
   * @return A list of color property values.
   */
  public List<String> getColors() {
  	return this.color;
  }
  
  /**
   * Get all the depth property values for this Product object.
   *
   * @return A list of depth property values.
   */
  public List<Thing> getDepths() {
  	return this.depth;
  }
  
  /**
   * Get all the description property values for this Product object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the gtin13 property values for this Product object.
   *
   * @return A list of gtin13 property values.
   */
  public List<String> getGtin13s() {
  	return this.gtin13;
  }
  
  /**
   * Get all the gtin14 property values for this Product object.
   *
   * @return A list of gtin14 property values.
   */
  public List<String> getGtin14s() {
  	return this.gtin14;
  }
  
  /**
   * Get all the gtin8 property values for this Product object.
   *
   * @return A list of gtin8 property values.
   */
  public List<String> getGtin8s() {
  	return this.gtin8;
  }
  
  /**
   * Get all the height property values for this Product object.
   *
   * @return A list of height property values.
   */
  public List<Thing> getHeights() {
  	return this.height;
  }
  
  /**
   * Get all the image property values for this Product object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the isAccessoryOrSparePartFor property values for this Product object.
   *
   * @return A list of isAccessoryOrSparePartFor property values.
   */
  public List<Product> getIsAccessoryOrSparePartFors() {
  	return this.isAccessoryOrSparePartFor;
  }
  
  /**
   * Get all the isConsumableFor property values for this Product object.
   *
   * @return A list of isConsumableFor property values.
   */
  public List<Product> getIsConsumableFors() {
  	return this.isConsumableFor;
  }
  
  /**
   * Get all the isRelatedTo property values for this Product object.
   *
   * @return A list of isRelatedTo property values.
   */
  public List<Product> getIsRelatedToes() {
  	return this.isRelatedTo;
  }
  
  /**
   * Get all the isSimilarTo property values for this Product object.
   *
   * @return A list of isSimilarTo property values.
   */
  public List<Product> getIsSimilarToes() {
  	return this.isSimilarTo;
  }
  
  /**
   * Get all the itemCondition property values for this Product object.
   *
   * @return A list of itemCondition property values.
   */
  public List<OfferItemCondition> getItemConditions() {
  	return this.itemCondition;
  }
  
  /**
   * Get all the logo property values for this Product object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes() {
  	return this.logo;
  }
  
  /**
   * Get all the manufacturer property values for this Product object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers() {
  	return this.manufacturer;
  }
  
  /**
   * Get all the model property values for this Product object.
   *
   * @return A list of model property values.
   */
  public List<Thing> getModels() {
  	return this.model;
  }
  
  /**
   * Get all the mpn property values for this Product object.
   *
   * @return A list of mpn property values.
   */
  public List<String> getMpns() {
  	return this.mpn;
  }
  
  /**
   * Get all the name property values for this Product object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offers property values for this Product object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss() {
  	return this.offers;
  }
  
  /**
   * Get all the productID property values for this Product object.
   *
   * @return A list of productID property values.
   */
  public List<String> getProductIDs() {
  	return this.productID;
  }
  
  /**
   * Get all the releaseDate property values for this Product object.
   *
   * @return A list of releaseDate property values.
   */
  public List<Date> getReleaseDates() {
  	return this.releaseDate;
  }
  
  /**
   * Get all the review property values for this Product object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
  	return this.review;
  }
  
  /**
   * Get all the sameAs property values for this Product object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the sku property values for this Product object.
   *
   * @return A list of sku property values.
   */
  public List<String> getSkus() {
  	return this.sku;
  }
  
  /**
   * Get all the url property values for this Product object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the weight property values for this Product object.
   *
   * @return A list of weight property values.
   */
  public List<QuantitativeValue> getWeights() {
  	return this.weight;
  }
  
  /**
   * Get all the width property values for this Product object.
   *
   * @return A list of width property values.
   */
  public List<Thing> getWidths() {
  	return this.width;
  }
  
  /**
   * Set the additionalType property value for this Product object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the aggregateRating property value for this Product object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.clear();
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this Product object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the audience property value for this Product object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience) {
  	this.audience.clear();
  	this.audience.add(audience);
  }
  
  /**
   * Set the brand property value for this Product object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand) {
  	this.brand.clear();
  	this.brand.add(brand);
  }
  
  /**
   * Set the color property value for this Product object; overwriting any existing values.
   *
   * @param color The value to set.
   */
  public void setColor(String color) {
  	this.color.clear();
  	this.color.add(color);
  }
  
  /**
   * Set the depth property value for this Product object; overwriting any existing values.
   *
   * @param depth The value to set.
   */
  public void setDepth(Thing depth) {
  	this.depth.clear();
  	this.depth.add(depth);
  }
  
  /**
   * Set the description property value for this Product object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the gtin13 property value for this Product object; overwriting any existing values.
   *
   * @param gtin13 The value to set.
   */
  public void setGtin13(String gtin13) {
  	this.gtin13.clear();
  	this.gtin13.add(gtin13);
  }
  
  /**
   * Set the gtin14 property value for this Product object; overwriting any existing values.
   *
   * @param gtin14 The value to set.
   */
  public void setGtin14(String gtin14) {
  	this.gtin14.clear();
  	this.gtin14.add(gtin14);
  }
  
  /**
   * Set the gtin8 property value for this Product object; overwriting any existing values.
   *
   * @param gtin8 The value to set.
   */
  public void setGtin8(String gtin8) {
  	this.gtin8.clear();
  	this.gtin8.add(gtin8);
  }
  
  /**
   * Set the height property value for this Product object; overwriting any existing values.
   *
   * @param height The value to set.
   */
  public void setHeight(Thing height) {
  	this.height.clear();
  	this.height.add(height);
  }
  
  /**
   * Set the image property value for this Product object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the isAccessoryOrSparePartFor property value for this Product object; overwriting any existing values.
   *
   * @param isAccessoryOrSparePartFor The value to set.
   */
  public void setIsAccessoryOrSparePartFor(Product isAccessoryOrSparePartFor) {
  	this.isAccessoryOrSparePartFor.clear();
  	this.isAccessoryOrSparePartFor.add(isAccessoryOrSparePartFor);
  }
  
  /**
   * Set the isConsumableFor property value for this Product object; overwriting any existing values.
   *
   * @param isConsumableFor The value to set.
   */
  public void setIsConsumableFor(Product isConsumableFor) {
  	this.isConsumableFor.clear();
  	this.isConsumableFor.add(isConsumableFor);
  }
  
  /**
   * Set the isRelatedTo property value for this Product object; overwriting any existing values.
   *
   * @param isRelatedTo The value to set.
   */
  public void setIsRelatedTo(Product isRelatedTo) {
  	this.isRelatedTo.clear();
  	this.isRelatedTo.add(isRelatedTo);
  }
  
  /**
   * Set the isSimilarTo property value for this Product object; overwriting any existing values.
   *
   * @param isSimilarTo The value to set.
   */
  public void setIsSimilarTo(Product isSimilarTo) {
  	this.isSimilarTo.clear();
  	this.isSimilarTo.add(isSimilarTo);
  }
  
  /**
   * Set the itemCondition property value for this Product object; overwriting any existing values.
   *
   * @param itemCondition The value to set.
   */
  public void setItemCondition(OfferItemCondition itemCondition) {
  	this.itemCondition.clear();
  	this.itemCondition.add(itemCondition);
  }
  
  /**
   * Set the logo property value for this Product object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo) {
  	this.logo.clear();
  	this.logo.add(logo);
  }
  
  /**
   * Set the manufacturer property value for this Product object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer) {
  	this.manufacturer.clear();
  	this.manufacturer.add(manufacturer);
  }
  
  /**
   * Set the model property value for this Product object; overwriting any existing values.
   *
   * @param model The value to set.
   */
  public void setModel(Thing model) {
  	this.model.clear();
  	this.model.add(model);
  }
  
  /**
   * Set the mpn property value for this Product object; overwriting any existing values.
   *
   * @param mpn The value to set.
   */
  public void setMpn(String mpn) {
  	this.mpn.clear();
  	this.mpn.add(mpn);
  }
  
  /**
   * Set the name property value for this Product object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offers property value for this Product object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers) {
  	this.offers.clear();
  	this.offers.add(offers);
  }
  
  /**
   * Set the productID property value for this Product object; overwriting any existing values.
   *
   * @param productID The value to set.
   */
  public void setProductID(String productID) {
  	this.productID.clear();
  	this.productID.add(productID);
  }
  
  /**
   * Set the releaseDate property value for this Product object; overwriting any existing values.
   *
   * @param releaseDate The value to set.
   */
  public void setReleaseDate(Date releaseDate) {
  	this.releaseDate.clear();
  	this.releaseDate.add(releaseDate);
  }
  
  /**
   * Set the review property value for this Product object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
  	this.review.clear();
  	this.review.add(review);
  }
  
  /**
   * Set the sameAs property value for this Product object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the sku property value for this Product object; overwriting any existing values.
   *
   * @param sku The value to set.
   */
  public void setSku(String sku) {
  	this.sku.clear();
  	this.sku.add(sku);
  }
  
  /**
   * Set the url property value for this Product object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the weight property value for this Product object; overwriting any existing values.
   *
   * @param weight The value to set.
   */
  public void setWeight(QuantitativeValue weight) {
  	this.weight.clear();
  	this.weight.add(weight);
  }
  
  /**
   * Set the width property value for this Product object; overwriting any existing values.
   *
   * @param width The value to set.
   */
  public void setWidth(Thing width) {
  	this.width.clear();
  	this.width.add(width);
  }
  
  /**
   * Set the additionalType property values for this Product object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the aggregateRating property values for this Product object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
  	this.aggregateRating = aggregateRatings;
  }
  
  /**
   * Set the alternateName property values for this Product object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the audience property values for this Product object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences) {
  	this.audience = audiences;
  }
  
  /**
   * Set the brand property values for this Product object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands) {
  	this.brand = brands;
  }
  
  /**
   * Set the color property values for this Product object; overwriting any existing values.
   *
   * @param colors The list of values to set.
   */
  public void setColors(List<String> colors) {
  	this.color = colors;
  }
  
  /**
   * Set the depth property values for this Product object; overwriting any existing values.
   *
   * @param depths The list of values to set.
   */
  public void setDepths(List<Thing> depths) {
  	this.depth = depths;
  }
  
  /**
   * Set the description property values for this Product object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the gtin13 property values for this Product object; overwriting any existing values.
   *
   * @param gtin13s The list of values to set.
   */
  public void setGtin13s(List<String> gtin13s) {
  	this.gtin13 = gtin13s;
  }
  
  /**
   * Set the gtin14 property values for this Product object; overwriting any existing values.
   *
   * @param gtin14s The list of values to set.
   */
  public void setGtin14s(List<String> gtin14s) {
  	this.gtin14 = gtin14s;
  }
  
  /**
   * Set the gtin8 property values for this Product object; overwriting any existing values.
   *
   * @param gtin8s The list of values to set.
   */
  public void setGtin8s(List<String> gtin8s) {
  	this.gtin8 = gtin8s;
  }
  
  /**
   * Set the height property values for this Product object; overwriting any existing values.
   *
   * @param heights The list of values to set.
   */
  public void setHeights(List<Thing> heights) {
  	this.height = heights;
  }
  
  /**
   * Set the image property values for this Product object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the isAccessoryOrSparePartFor property values for this Product object; overwriting any existing values.
   *
   * @param isAccessoryOrSparePartFors The list of values to set.
   */
  public void setIsAccessoryOrSparePartFors(List<Product> isAccessoryOrSparePartFors) {
  	this.isAccessoryOrSparePartFor = isAccessoryOrSparePartFors;
  }
  
  /**
   * Set the isConsumableFor property values for this Product object; overwriting any existing values.
   *
   * @param isConsumableFors The list of values to set.
   */
  public void setIsConsumableFors(List<Product> isConsumableFors) {
  	this.isConsumableFor = isConsumableFors;
  }
  
  /**
   * Set the isRelatedTo property values for this Product object; overwriting any existing values.
   *
   * @param isRelatedToes The list of values to set.
   */
  public void setIsRelatedToes(List<Product> isRelatedToes) {
  	this.isRelatedTo = isRelatedToes;
  }
  
  /**
   * Set the isSimilarTo property values for this Product object; overwriting any existing values.
   *
   * @param isSimilarToes The list of values to set.
   */
  public void setIsSimilarToes(List<Product> isSimilarToes) {
  	this.isSimilarTo = isSimilarToes;
  }
  
  /**
   * Set the itemCondition property values for this Product object; overwriting any existing values.
   *
   * @param itemConditions The list of values to set.
   */
  public void setItemConditions(List<OfferItemCondition> itemConditions) {
  	this.itemCondition = itemConditions;
  }
  
  /**
   * Set the logo property values for this Product object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes) {
  	this.logo = logoes;
  }
  
  /**
   * Set the manufacturer property values for this Product object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers) {
  	this.manufacturer = manufacturers;
  }
  
  /**
   * Set the model property values for this Product object; overwriting any existing values.
   *
   * @param models The list of values to set.
   */
  public void setModels(List<Thing> models) {
  	this.model = models;
  }
  
  /**
   * Set the mpn property values for this Product object; overwriting any existing values.
   *
   * @param mpns The list of values to set.
   */
  public void setMpns(List<String> mpns) {
  	this.mpn = mpns;
  }
  
  /**
   * Set the name property values for this Product object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offers property values for this Product object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss) {
  	this.offers = offerss;
  }
  
  /**
   * Set the productID property values for this Product object; overwriting any existing values.
   *
   * @param productIDs The list of values to set.
   */
  public void setProductIDs(List<String> productIDs) {
  	this.productID = productIDs;
  }
  
  /**
   * Set the releaseDate property values for this Product object; overwriting any existing values.
   *
   * @param releaseDates The list of values to set.
   */
  public void setReleaseDates(List<Date> releaseDates) {
  	this.releaseDate = releaseDates;
  }
  
  /**
   * Set the review property values for this Product object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
  	this.review = reviews;
  }
  
  /**
   * Set the sameAs property values for this Product object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the sku property values for this Product object; overwriting any existing values.
   *
   * @param skus The list of values to set.
   */
  public void setSkus(List<String> skus) {
  	this.sku = skus;
  }
  
  /**
   * Set the url property values for this Product object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the weight property values for this Product object; overwriting any existing values.
   *
   * @param weights The list of values to set.
   */
  public void setWeights(List<QuantitativeValue> weights) {
  	this.weight = weights;
  }
  
  /**
   * Set the width property values for this Product object; overwriting any existing values.
   *
   * @param widths The list of values to set.
   */
  public void setWidths(List<Thing> widths) {
  	this.width = widths;
  }
  
  /**
   * Adds a additionalType property value for this Product object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a aggregateRating property value for this Product object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
  	this.aggregateRating.add(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this Product object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a audience property value for this Product object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience) {
  	this.audience.add(audience);
  }
  
  /**
   * Adds a brand property value for this Product object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand) {
  	this.brand.add(brand);
  }
  
  /**
   * Adds a color property value for this Product object; appending it to the list of existing values.
   *
   * @param color The value to add.
   */
  public void addColor(String color) {
  	this.color.add(color);
  }
  
  /**
   * Adds a depth property value for this Product object; appending it to the list of existing values.
   *
   * @param depth The value to add.
   */
  public void addDepth(Thing depth) {
  	this.depth.add(depth);
  }
  
  /**
   * Adds a description property value for this Product object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a gtin13 property value for this Product object; appending it to the list of existing values.
   *
   * @param gtin13 The value to add.
   */
  public void addGtin13(String gtin13) {
  	this.gtin13.add(gtin13);
  }
  
  /**
   * Adds a gtin14 property value for this Product object; appending it to the list of existing values.
   *
   * @param gtin14 The value to add.
   */
  public void addGtin14(String gtin14) {
  	this.gtin14.add(gtin14);
  }
  
  /**
   * Adds a gtin8 property value for this Product object; appending it to the list of existing values.
   *
   * @param gtin8 The value to add.
   */
  public void addGtin8(String gtin8) {
  	this.gtin8.add(gtin8);
  }
  
  /**
   * Adds a height property value for this Product object; appending it to the list of existing values.
   *
   * @param height The value to add.
   */
  public void addHeight(Thing height) {
  	this.height.add(height);
  }
  
  /**
   * Adds a image property value for this Product object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a isAccessoryOrSparePartFor property value for this Product object; appending it to the list of existing values.
   *
   * @param isAccessoryOrSparePartFor The value to add.
   */
  public void addIsAccessoryOrSparePartFor(Product isAccessoryOrSparePartFor) {
  	this.isAccessoryOrSparePartFor.add(isAccessoryOrSparePartFor);
  }
  
  /**
   * Adds a isConsumableFor property value for this Product object; appending it to the list of existing values.
   *
   * @param isConsumableFor The value to add.
   */
  public void addIsConsumableFor(Product isConsumableFor) {
  	this.isConsumableFor.add(isConsumableFor);
  }
  
  /**
   * Adds a isRelatedTo property value for this Product object; appending it to the list of existing values.
   *
   * @param isRelatedTo The value to add.
   */
  public void addIsRelatedTo(Product isRelatedTo) {
  	this.isRelatedTo.add(isRelatedTo);
  }
  
  /**
   * Adds a isSimilarTo property value for this Product object; appending it to the list of existing values.
   *
   * @param isSimilarTo The value to add.
   */
  public void addIsSimilarTo(Product isSimilarTo) {
  	this.isSimilarTo.add(isSimilarTo);
  }
  
  /**
   * Adds a itemCondition property value for this Product object; appending it to the list of existing values.
   *
   * @param itemCondition The value to add.
   */
  public void addItemCondition(OfferItemCondition itemCondition) {
  	this.itemCondition.add(itemCondition);
  }
  
  /**
   * Adds a logo property value for this Product object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo) {
  	this.logo.add(logo);
  }
  
  /**
   * Adds a manufacturer property value for this Product object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer) {
  	this.manufacturer.add(manufacturer);
  }
  
  /**
   * Adds a model property value for this Product object; appending it to the list of existing values.
   *
   * @param model The value to add.
   */
  public void addModel(Thing model) {
  	this.model.add(model);
  }
  
  /**
   * Adds a mpn property value for this Product object; appending it to the list of existing values.
   *
   * @param mpn The value to add.
   */
  public void addMpn(String mpn) {
  	this.mpn.add(mpn);
  }
  
  /**
   * Adds a name property value for this Product object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offers property value for this Product object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers) {
  	this.offers.add(offers);
  }
  
  /**
   * Adds a productID property value for this Product object; appending it to the list of existing values.
   *
   * @param productID The value to add.
   */
  public void addProductID(String productID) {
  	this.productID.add(productID);
  }
  
  /**
   * Adds a releaseDate property value for this Product object; appending it to the list of existing values.
   *
   * @param releaseDate The value to add.
   */
  public void addReleaseDate(Date releaseDate) {
  	this.releaseDate.add(releaseDate);
  }
  
  /**
   * Adds a review property value for this Product object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
  	this.review.add(review);
  }
  
  /**
   * Adds a sameAs property value for this Product object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a sku property value for this Product object; appending it to the list of existing values.
   *
   * @param sku The value to add.
   */
  public void addSku(String sku) {
  	this.sku.add(sku);
  }
  
  /**
   * Adds a url property value for this Product object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a weight property value for this Product object; appending it to the list of existing values.
   *
   * @param weight The value to add.
   */
  public void addWeight(QuantitativeValue weight) {
  	this.weight.add(weight);
  }
  
  /**
   * Adds a width property value for this Product object; appending it to the list of existing values.
   *
   * @param width The value to add.
   */
  public void addWidth(Thing width) {
  	this.width.add(width);
  }
  
}