package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.Audience;
import org.schema.Offer;
import org.schema.OfferItemCondition;
import org.schema.Organization;
import org.schema.Product;
import org.schema.ProductModel;
import org.schema.QuantitativeValue;
import org.schema.Review;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A datasheet or vendor specification of a product (in the sense of a prototypical description).
 */
public class ProductModelImpl extends SchemaObjectImpl implements ProductModel {


  private ProductImpl product;
  private ThingImpl thing;

  /**
   * A pointer to a base product from which this product is a variant. It is safe to infer that the variant inherits all product features from the base model, unless defined locally. This is not transitive.
   */
  private List<ProductModel> isVariantOf = new LinkedList<ProductModel>();
  
  /**
   * A pointer from a previous, often discontinued variant of the product to its newer variant.
   */
  private List<ProductModel> predecessorOf = new LinkedList<ProductModel>();
  
  /**
   * A pointer from a newer variant of a product  to its previous, often discontinued predecessor.
   */
  private List<ProductModel> successorOf = new LinkedList<ProductModel>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ProductModelImpl() {
    super("http://schema.org/ProductModel");
    product = new ProductImpl();
  }
  /**
   * Get a single additionalType property value for this ProductModel object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single aggregateRating property value for this ProductModel object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating() {
    return product.getAggregateRating();
  }
  
  /**
   * Get a single alternateName property value for this ProductModel object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single audience property value for this ProductModel object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience() {
    return product.getAudience();
  }
  
  /**
   * Get a single brand property value for this ProductModel object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand() {
    return product.getBrand();
  }
  
  /**
   * Get a single color property value for this ProductModel object.
   *
   * @return The first color property value.
   */
  public String getColor() {
    return product.getColor();
  }
  
  /**
   * Get a single depth property value for this ProductModel object.
   *
   * @return The first depth property value.
   */
  public Thing getDepth() {
    return product.getDepth();
  }
  
  /**
   * Get a single description property value for this ProductModel object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single gtin13 property value for this ProductModel object.
   *
   * @return The first gtin13 property value.
   */
  public String getGtin13() {
    return product.getGtin13();
  }
  
  /**
   * Get a single gtin14 property value for this ProductModel object.
   *
   * @return The first gtin14 property value.
   */
  public String getGtin14() {
    return product.getGtin14();
  }
  
  /**
   * Get a single gtin8 property value for this ProductModel object.
   *
   * @return The first gtin8 property value.
   */
  public String getGtin8() {
    return product.getGtin8();
  }
  
  /**
   * Get a single height property value for this ProductModel object.
   *
   * @return The first height property value.
   */
  public Thing getHeight() {
    return product.getHeight();
  }
  
  /**
   * Get a single image property value for this ProductModel object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single isAccessoryOrSparePartFor property value for this ProductModel object.
   *
   * @return The first isAccessoryOrSparePartFor property value.
   */
  public Product getIsAccessoryOrSparePartFor() {
    return product.getIsAccessoryOrSparePartFor();
  }
  
  /**
   * Get a single isConsumableFor property value for this ProductModel object.
   *
   * @return The first isConsumableFor property value.
   */
  public Product getIsConsumableFor() {
    return product.getIsConsumableFor();
  }
  
  /**
   * Get a single isRelatedTo property value for this ProductModel object.
   *
   * @return The first isRelatedTo property value.
   */
  public Product getIsRelatedTo() {
    return product.getIsRelatedTo();
  }
  
  /**
   * Get a single isSimilarTo property value for this ProductModel object.
   *
   * @return The first isSimilarTo property value.
   */
  public Product getIsSimilarTo() {
    return product.getIsSimilarTo();
  }
  
  /**
   * Get a single isVariantOf property value for this ProductModel object.
   *
   * @return The first isVariantOf property value.
   */
  public ProductModel getIsVariantOf() {
  	return this.isVariantOf.isEmpty() ? null : this.isVariantOf.get(0);
  }
  
  /**
   * Get a single itemCondition property value for this ProductModel object.
   *
   * @return The first itemCondition property value.
   */
  public OfferItemCondition getItemCondition() {
    return product.getItemCondition();
  }
  
  /**
   * Get a single logo property value for this ProductModel object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo() {
    return product.getLogo();
  }
  
  /**
   * Get a single manufacturer property value for this ProductModel object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer() {
    return product.getManufacturer();
  }
  
  /**
   * Get a single model property value for this ProductModel object.
   *
   * @return The first model property value.
   */
  public Thing getModel() {
    return product.getModel();
  }
  
  /**
   * Get a single mpn property value for this ProductModel object.
   *
   * @return The first mpn property value.
   */
  public String getMpn() {
    return product.getMpn();
  }
  
  /**
   * Get a single name property value for this ProductModel object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single offers property value for this ProductModel object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers() {
    return product.getOffers();
  }
  
  /**
   * Get a single predecessorOf property value for this ProductModel object.
   *
   * @return The first predecessorOf property value.
   */
  public ProductModel getPredecessorOf() {
  	return this.predecessorOf.isEmpty() ? null : this.predecessorOf.get(0);
  }
  
  /**
   * Get a single productID property value for this ProductModel object.
   *
   * @return The first productID property value.
   */
  public String getProductID() {
    return product.getProductID();
  }
  
  /**
   * Get a single releaseDate property value for this ProductModel object.
   *
   * @return The first releaseDate property value.
   */
  public Date getReleaseDate() {
    return product.getReleaseDate();
  }
  
  /**
   * Get a single review property value for this ProductModel object.
   *
   * @return The first review property value.
   */
  public Review getReview() {
    return product.getReview();
  }
  
  /**
   * Get a single sameAs property value for this ProductModel object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single sku property value for this ProductModel object.
   *
   * @return The first sku property value.
   */
  public String getSku() {
    return product.getSku();
  }
  
  /**
   * Get a single successorOf property value for this ProductModel object.
   *
   * @return The first successorOf property value.
   */
  public ProductModel getSuccessorOf() {
  	return this.successorOf.isEmpty() ? null : this.successorOf.get(0);
  }
  
  /**
   * Get a single url property value for this ProductModel object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single weight property value for this ProductModel object.
   *
   * @return The first weight property value.
   */
  public QuantitativeValue getWeight() {
    return product.getWeight();
  }
  
  /**
   * Get a single width property value for this ProductModel object.
   *
   * @return The first width property value.
   */
  public Thing getWidth() {
    return product.getWidth();
  }
  
  /**
   * Get all the additionalType property values for this ProductModel object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the aggregateRating property values for this ProductModel object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings() {
    return product.getAggregateRatings();
  }
  
  /**
   * Get all the alternateName property values for this ProductModel object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the audience property values for this ProductModel object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences() {
    return product.getAudiences();
  }
  
  /**
   * Get all the brand property values for this ProductModel object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands() {
    return product.getBrands();
  }
  
  /**
   * Get all the color property values for this ProductModel object.
   *
   * @return A list of color property values.
   */
  public List<String> getColors() {
    return product.getColors();
  }
  
  /**
   * Get all the depth property values for this ProductModel object.
   *
   * @return A list of depth property values.
   */
  public List<Thing> getDepths() {
    return product.getDepths();
  }
  
  /**
   * Get all the description property values for this ProductModel object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the gtin13 property values for this ProductModel object.
   *
   * @return A list of gtin13 property values.
   */
  public List<String> getGtin13s() {
    return product.getGtin13s();
  }
  
  /**
   * Get all the gtin14 property values for this ProductModel object.
   *
   * @return A list of gtin14 property values.
   */
  public List<String> getGtin14s() {
    return product.getGtin14s();
  }
  
  /**
   * Get all the gtin8 property values for this ProductModel object.
   *
   * @return A list of gtin8 property values.
   */
  public List<String> getGtin8s() {
    return product.getGtin8s();
  }
  
  /**
   * Get all the height property values for this ProductModel object.
   *
   * @return A list of height property values.
   */
  public List<Thing> getHeights() {
    return product.getHeights();
  }
  
  /**
   * Get all the image property values for this ProductModel object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the isAccessoryOrSparePartFor property values for this ProductModel object.
   *
   * @return A list of isAccessoryOrSparePartFor property values.
   */
  public List<Product> getIsAccessoryOrSparePartFors() {
    return product.getIsAccessoryOrSparePartFors();
  }
  
  /**
   * Get all the isConsumableFor property values for this ProductModel object.
   *
   * @return A list of isConsumableFor property values.
   */
  public List<Product> getIsConsumableFors() {
    return product.getIsConsumableFors();
  }
  
  /**
   * Get all the isRelatedTo property values for this ProductModel object.
   *
   * @return A list of isRelatedTo property values.
   */
  public List<Product> getIsRelatedToes() {
    return product.getIsRelatedToes();
  }
  
  /**
   * Get all the isSimilarTo property values for this ProductModel object.
   *
   * @return A list of isSimilarTo property values.
   */
  public List<Product> getIsSimilarToes() {
    return product.getIsSimilarToes();
  }
  
  /**
   * Get all the isVariantOf property values for this ProductModel object.
   *
   * @return A list of isVariantOf property values.
   */
  public List<ProductModel> getIsVariantsOf() {
  	return this.isVariantOf;
  }
  
  /**
   * Get all the itemCondition property values for this ProductModel object.
   *
   * @return A list of itemCondition property values.
   */
  public List<OfferItemCondition> getItemConditions() {
    return product.getItemConditions();
  }
  
  /**
   * Get all the logo property values for this ProductModel object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes() {
    return product.getLogoes();
  }
  
  /**
   * Get all the manufacturer property values for this ProductModel object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers() {
    return product.getManufacturers();
  }
  
  /**
   * Get all the model property values for this ProductModel object.
   *
   * @return A list of model property values.
   */
  public List<Thing> getModels() {
    return product.getModels();
  }
  
  /**
   * Get all the mpn property values for this ProductModel object.
   *
   * @return A list of mpn property values.
   */
  public List<String> getMpns() {
    return product.getMpns();
  }
  
  /**
   * Get all the name property values for this ProductModel object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the offers property values for this ProductModel object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss() {
    return product.getOfferss();
  }
  
  /**
   * Get all the predecessorOf property values for this ProductModel object.
   *
   * @return A list of predecessorOf property values.
   */
  public List<ProductModel> getPredecessorsOf() {
  	return this.predecessorOf;
  }
  
  /**
   * Get all the productID property values for this ProductModel object.
   *
   * @return A list of productID property values.
   */
  public List<String> getProductIDs() {
    return product.getProductIDs();
  }
  
  /**
   * Get all the releaseDate property values for this ProductModel object.
   *
   * @return A list of releaseDate property values.
   */
  public List<Date> getReleaseDates() {
    return product.getReleaseDates();
  }
  
  /**
   * Get all the review property values for this ProductModel object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews() {
    return product.getReviews();
  }
  
  /**
   * Get all the sameAs property values for this ProductModel object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the sku property values for this ProductModel object.
   *
   * @return A list of sku property values.
   */
  public List<String> getSkus() {
    return product.getSkus();
  }
  
  /**
   * Get all the successorOf property values for this ProductModel object.
   *
   * @return A list of successorOf property values.
   */
  public List<ProductModel> getSuccessorsOf() {
  	return this.successorOf;
  }
  
  /**
   * Get all the url property values for this ProductModel object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the weight property values for this ProductModel object.
   *
   * @return A list of weight property values.
   */
  public List<QuantitativeValue> getWeights() {
    return product.getWeights();
  }
  
  /**
   * Get all the width property values for this ProductModel object.
   *
   * @return A list of width property values.
   */
  public List<Thing> getWidths() {
    return product.getWidths();
  }
  
  /**
   * Set the additionalType property value for this ProductModel object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the aggregateRating property value for this ProductModel object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating) {
    product.setAggregateRating(aggregateRating);
  }
  
  /**
   * Set the alternateName property value for this ProductModel object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the audience property value for this ProductModel object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience) {
    product.setAudience(audience);
  }
  
  /**
   * Set the brand property value for this ProductModel object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand) {
    product.setBrand(brand);
  }
  
  /**
   * Set the color property value for this ProductModel object; overwriting any existing values.
   *
   * @param color The value to set.
   */
  public void setColor(String color) {
    product.setColor(color);
  }
  
  /**
   * Set the depth property value for this ProductModel object; overwriting any existing values.
   *
   * @param depth The value to set.
   */
  public void setDepth(Thing depth) {
    product.setDepth(depth);
  }
  
  /**
   * Set the description property value for this ProductModel object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the gtin13 property value for this ProductModel object; overwriting any existing values.
   *
   * @param gtin13 The value to set.
   */
  public void setGtin13(String gtin13) {
    product.setGtin13(gtin13);
  }
  
  /**
   * Set the gtin14 property value for this ProductModel object; overwriting any existing values.
   *
   * @param gtin14 The value to set.
   */
  public void setGtin14(String gtin14) {
    product.setGtin14(gtin14);
  }
  
  /**
   * Set the gtin8 property value for this ProductModel object; overwriting any existing values.
   *
   * @param gtin8 The value to set.
   */
  public void setGtin8(String gtin8) {
    product.setGtin8(gtin8);
  }
  
  /**
   * Set the height property value for this ProductModel object; overwriting any existing values.
   *
   * @param height The value to set.
   */
  public void setHeight(Thing height) {
    product.setHeight(height);
  }
  
  /**
   * Set the image property value for this ProductModel object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the isAccessoryOrSparePartFor property value for this ProductModel object; overwriting any existing values.
   *
   * @param isAccessoryOrSparePartFor The value to set.
   */
  public void setIsAccessoryOrSparePartFor(Product isAccessoryOrSparePartFor) {
    product.setIsAccessoryOrSparePartFor(isAccessoryOrSparePartFor);
  }
  
  /**
   * Set the isConsumableFor property value for this ProductModel object; overwriting any existing values.
   *
   * @param isConsumableFor The value to set.
   */
  public void setIsConsumableFor(Product isConsumableFor) {
    product.setIsConsumableFor(isConsumableFor);
  }
  
  /**
   * Set the isRelatedTo property value for this ProductModel object; overwriting any existing values.
   *
   * @param isRelatedTo The value to set.
   */
  public void setIsRelatedTo(Product isRelatedTo) {
    product.setIsRelatedTo(isRelatedTo);
  }
  
  /**
   * Set the isSimilarTo property value for this ProductModel object; overwriting any existing values.
   *
   * @param isSimilarTo The value to set.
   */
  public void setIsSimilarTo(Product isSimilarTo) {
    product.setIsSimilarTo(isSimilarTo);
  }
  
  /**
   * Set the isVariantOf property value for this ProductModel object; overwriting any existing values.
   *
   * @param isVariantOf The value to set.
   */
  public void setIsVariantOf(ProductModel isVariantOf) {
  	this.isVariantOf.clear();
  	this.isVariantOf.add(isVariantOf);
  }
  
  /**
   * Set the itemCondition property value for this ProductModel object; overwriting any existing values.
   *
   * @param itemCondition The value to set.
   */
  public void setItemCondition(OfferItemCondition itemCondition) {
    product.setItemCondition(itemCondition);
  }
  
  /**
   * Set the logo property value for this ProductModel object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo) {
    product.setLogo(logo);
  }
  
  /**
   * Set the manufacturer property value for this ProductModel object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer) {
    product.setManufacturer(manufacturer);
  }
  
  /**
   * Set the model property value for this ProductModel object; overwriting any existing values.
   *
   * @param model The value to set.
   */
  public void setModel(Thing model) {
    product.setModel(model);
  }
  
  /**
   * Set the mpn property value for this ProductModel object; overwriting any existing values.
   *
   * @param mpn The value to set.
   */
  public void setMpn(String mpn) {
    product.setMpn(mpn);
  }
  
  /**
   * Set the name property value for this ProductModel object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the offers property value for this ProductModel object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers) {
    product.setOffers(offers);
  }
  
  /**
   * Set the predecessorOf property value for this ProductModel object; overwriting any existing values.
   *
   * @param predecessorOf The value to set.
   */
  public void setPredecessorOf(ProductModel predecessorOf) {
  	this.predecessorOf.clear();
  	this.predecessorOf.add(predecessorOf);
  }
  
  /**
   * Set the productID property value for this ProductModel object; overwriting any existing values.
   *
   * @param productID The value to set.
   */
  public void setProductID(String productID) {
    product.setProductID(productID);
  }
  
  /**
   * Set the releaseDate property value for this ProductModel object; overwriting any existing values.
   *
   * @param releaseDate The value to set.
   */
  public void setReleaseDate(Date releaseDate) {
    product.setReleaseDate(releaseDate);
  }
  
  /**
   * Set the review property value for this ProductModel object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review) {
    product.setReview(review);
  }
  
  /**
   * Set the sameAs property value for this ProductModel object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the sku property value for this ProductModel object; overwriting any existing values.
   *
   * @param sku The value to set.
   */
  public void setSku(String sku) {
    product.setSku(sku);
  }
  
  /**
   * Set the successorOf property value for this ProductModel object; overwriting any existing values.
   *
   * @param successorOf The value to set.
   */
  public void setSuccessorOf(ProductModel successorOf) {
  	this.successorOf.clear();
  	this.successorOf.add(successorOf);
  }
  
  /**
   * Set the url property value for this ProductModel object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the weight property value for this ProductModel object; overwriting any existing values.
   *
   * @param weight The value to set.
   */
  public void setWeight(QuantitativeValue weight) {
    product.setWeight(weight);
  }
  
  /**
   * Set the width property value for this ProductModel object; overwriting any existing values.
   *
   * @param width The value to set.
   */
  public void setWidth(Thing width) {
    product.setWidth(width);
  }
  
  /**
   * Set the additionalType property values for this ProductModel object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the aggregateRating property values for this ProductModel object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings) {
    product.setAggregateRatings(aggregateRatings);
  }
  
  /**
   * Set the alternateName property values for this ProductModel object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the audience property values for this ProductModel object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences) {
    product.setAudiences(audiences);
  }
  
  /**
   * Set the brand property values for this ProductModel object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands) {
    product.setBrands(brands);
  }
  
  /**
   * Set the color property values for this ProductModel object; overwriting any existing values.
   *
   * @param colors The list of values to set.
   */
  public void setColors(List<String> colors) {
    product.setColors(colors);
  }
  
  /**
   * Set the depth property values for this ProductModel object; overwriting any existing values.
   *
   * @param depths The list of values to set.
   */
  public void setDepths(List<Thing> depths) {
    product.setDepths(depths);
  }
  
  /**
   * Set the description property values for this ProductModel object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the gtin13 property values for this ProductModel object; overwriting any existing values.
   *
   * @param gtin13s The list of values to set.
   */
  public void setGtin13s(List<String> gtin13s) {
    product.setGtin13s(gtin13s);
  }
  
  /**
   * Set the gtin14 property values for this ProductModel object; overwriting any existing values.
   *
   * @param gtin14s The list of values to set.
   */
  public void setGtin14s(List<String> gtin14s) {
    product.setGtin14s(gtin14s);
  }
  
  /**
   * Set the gtin8 property values for this ProductModel object; overwriting any existing values.
   *
   * @param gtin8s The list of values to set.
   */
  public void setGtin8s(List<String> gtin8s) {
    product.setGtin8s(gtin8s);
  }
  
  /**
   * Set the height property values for this ProductModel object; overwriting any existing values.
   *
   * @param heights The list of values to set.
   */
  public void setHeights(List<Thing> heights) {
    product.setHeights(heights);
  }
  
  /**
   * Set the image property values for this ProductModel object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the isAccessoryOrSparePartFor property values for this ProductModel object; overwriting any existing values.
   *
   * @param isAccessoryOrSparePartFors The list of values to set.
   */
  public void setIsAccessoryOrSparePartFors(List<Product> isAccessoryOrSparePartFors) {
    product.setIsAccessoryOrSparePartFors(isAccessoryOrSparePartFors);
  }
  
  /**
   * Set the isConsumableFor property values for this ProductModel object; overwriting any existing values.
   *
   * @param isConsumableFors The list of values to set.
   */
  public void setIsConsumableFors(List<Product> isConsumableFors) {
    product.setIsConsumableFors(isConsumableFors);
  }
  
  /**
   * Set the isRelatedTo property values for this ProductModel object; overwriting any existing values.
   *
   * @param isRelatedToes The list of values to set.
   */
  public void setIsRelatedToes(List<Product> isRelatedToes) {
    product.setIsRelatedToes(isRelatedToes);
  }
  
  /**
   * Set the isSimilarTo property values for this ProductModel object; overwriting any existing values.
   *
   * @param isSimilarToes The list of values to set.
   */
  public void setIsSimilarToes(List<Product> isSimilarToes) {
    product.setIsSimilarToes(isSimilarToes);
  }
  
  /**
   * Set the isVariantOf property values for this ProductModel object; overwriting any existing values.
   *
   * @param isVariantsOf The list of values to set.
   */
  public void setIsVariantsOf(List<ProductModel> isVariantsOf) {
  	this.isVariantOf = isVariantsOf;
  }
  
  /**
   * Set the itemCondition property values for this ProductModel object; overwriting any existing values.
   *
   * @param itemConditions The list of values to set.
   */
  public void setItemConditions(List<OfferItemCondition> itemConditions) {
    product.setItemConditions(itemConditions);
  }
  
  /**
   * Set the logo property values for this ProductModel object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes) {
    product.setLogoes(logoes);
  }
  
  /**
   * Set the manufacturer property values for this ProductModel object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers) {
    product.setManufacturers(manufacturers);
  }
  
  /**
   * Set the model property values for this ProductModel object; overwriting any existing values.
   *
   * @param models The list of values to set.
   */
  public void setModels(List<Thing> models) {
    product.setModels(models);
  }
  
  /**
   * Set the mpn property values for this ProductModel object; overwriting any existing values.
   *
   * @param mpns The list of values to set.
   */
  public void setMpns(List<String> mpns) {
    product.setMpns(mpns);
  }
  
  /**
   * Set the name property values for this ProductModel object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the offers property values for this ProductModel object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss) {
    product.setOfferss(offerss);
  }
  
  /**
   * Set the predecessorOf property values for this ProductModel object; overwriting any existing values.
   *
   * @param predecessorsOf The list of values to set.
   */
  public void setPredecessorsOf(List<ProductModel> predecessorsOf) {
  	this.predecessorOf = predecessorsOf;
  }
  
  /**
   * Set the productID property values for this ProductModel object; overwriting any existing values.
   *
   * @param productIDs The list of values to set.
   */
  public void setProductIDs(List<String> productIDs) {
    product.setProductIDs(productIDs);
  }
  
  /**
   * Set the releaseDate property values for this ProductModel object; overwriting any existing values.
   *
   * @param releaseDates The list of values to set.
   */
  public void setReleaseDates(List<Date> releaseDates) {
    product.setReleaseDates(releaseDates);
  }
  
  /**
   * Set the review property values for this ProductModel object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews) {
    product.setReviews(reviews);
  }
  
  /**
   * Set the sameAs property values for this ProductModel object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the sku property values for this ProductModel object; overwriting any existing values.
   *
   * @param skus The list of values to set.
   */
  public void setSkus(List<String> skus) {
    product.setSkus(skus);
  }
  
  /**
   * Set the successorOf property values for this ProductModel object; overwriting any existing values.
   *
   * @param successorsOf The list of values to set.
   */
  public void setSuccessorsOf(List<ProductModel> successorsOf) {
  	this.successorOf = successorsOf;
  }
  
  /**
   * Set the url property values for this ProductModel object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the weight property values for this ProductModel object; overwriting any existing values.
   *
   * @param weights The list of values to set.
   */
  public void setWeights(List<QuantitativeValue> weights) {
    product.setWeights(weights);
  }
  
  /**
   * Set the width property values for this ProductModel object; overwriting any existing values.
   *
   * @param widths The list of values to set.
   */
  public void setWidths(List<Thing> widths) {
    product.setWidths(widths);
  }
  
  /**
   * Adds a additionalType property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a aggregateRating property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating) {
    product.addAggregateRating(aggregateRating);
  }
  
  /**
   * Adds a alternateName property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a audience property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience) {
    product.addAudience(audience);
  }
  
  /**
   * Adds a brand property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand) {
    product.addBrand(brand);
  }
  
  /**
   * Adds a color property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param color The value to add.
   */
  public void addColor(String color) {
    product.addColor(color);
  }
  
  /**
   * Adds a depth property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param depth The value to add.
   */
  public void addDepth(Thing depth) {
    product.addDepth(depth);
  }
  
  /**
   * Adds a description property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a gtin13 property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param gtin13 The value to add.
   */
  public void addGtin13(String gtin13) {
    product.addGtin13(gtin13);
  }
  
  /**
   * Adds a gtin14 property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param gtin14 The value to add.
   */
  public void addGtin14(String gtin14) {
    product.addGtin14(gtin14);
  }
  
  /**
   * Adds a gtin8 property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param gtin8 The value to add.
   */
  public void addGtin8(String gtin8) {
    product.addGtin8(gtin8);
  }
  
  /**
   * Adds a height property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param height The value to add.
   */
  public void addHeight(Thing height) {
    product.addHeight(height);
  }
  
  /**
   * Adds a image property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a isAccessoryOrSparePartFor property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param isAccessoryOrSparePartFor The value to add.
   */
  public void addIsAccessoryOrSparePartFor(Product isAccessoryOrSparePartFor) {
    product.addIsAccessoryOrSparePartFor(isAccessoryOrSparePartFor);
  }
  
  /**
   * Adds a isConsumableFor property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param isConsumableFor The value to add.
   */
  public void addIsConsumableFor(Product isConsumableFor) {
    product.addIsConsumableFor(isConsumableFor);
  }
  
  /**
   * Adds a isRelatedTo property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param isRelatedTo The value to add.
   */
  public void addIsRelatedTo(Product isRelatedTo) {
    product.addIsRelatedTo(isRelatedTo);
  }
  
  /**
   * Adds a isSimilarTo property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param isSimilarTo The value to add.
   */
  public void addIsSimilarTo(Product isSimilarTo) {
    product.addIsSimilarTo(isSimilarTo);
  }
  
  /**
   * Adds a isVariantOf property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param isVariantOf The value to add.
   */
  public void addIsVariantOf(ProductModel isVariantOf) {
  	this.isVariantOf.add(isVariantOf);
  }
  
  /**
   * Adds a itemCondition property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param itemCondition The value to add.
   */
  public void addItemCondition(OfferItemCondition itemCondition) {
    product.addItemCondition(itemCondition);
  }
  
  /**
   * Adds a logo property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo) {
    product.addLogo(logo);
  }
  
  /**
   * Adds a manufacturer property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer) {
    product.addManufacturer(manufacturer);
  }
  
  /**
   * Adds a model property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param model The value to add.
   */
  public void addModel(Thing model) {
    product.addModel(model);
  }
  
  /**
   * Adds a mpn property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param mpn The value to add.
   */
  public void addMpn(String mpn) {
    product.addMpn(mpn);
  }
  
  /**
   * Adds a name property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a offers property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers) {
    product.addOffers(offers);
  }
  
  /**
   * Adds a predecessorOf property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param predecessorOf The value to add.
   */
  public void addPredecessorOf(ProductModel predecessorOf) {
  	this.predecessorOf.add(predecessorOf);
  }
  
  /**
   * Adds a productID property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param productID The value to add.
   */
  public void addProductID(String productID) {
    product.addProductID(productID);
  }
  
  /**
   * Adds a releaseDate property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param releaseDate The value to add.
   */
  public void addReleaseDate(Date releaseDate) {
    product.addReleaseDate(releaseDate);
  }
  
  /**
   * Adds a review property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review) {
    product.addReview(review);
  }
  
  /**
   * Adds a sameAs property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a sku property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param sku The value to add.
   */
  public void addSku(String sku) {
    product.addSku(sku);
  }
  
  /**
   * Adds a successorOf property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param successorOf The value to add.
   */
  public void addSuccessorOf(ProductModel successorOf) {
  	this.successorOf.add(successorOf);
  }
  
  /**
   * Adds a url property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a weight property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param weight The value to add.
   */
  public void addWeight(QuantitativeValue weight) {
    product.addWeight(weight);
  }
  
  /**
   * Adds a width property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param width The value to add.
   */
  public void addWidth(Thing width) {
    product.addWidth(width);
  }
  
}