package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Organization;
import org.schema.ProgramMembership;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Used to describe membership in a loyalty programs (e.g. "StarAliance"), traveler clubs (e.g. "AAA"), purchase clubs ("Safeway Club"), etc.
 */
public class ProgramMembershipImpl extends SchemaObjectImpl implements ProgramMembership {


  private ThingImpl thing;

  /**
   * The organization (airline, travelers' club, etc.) the membership is made with.
   */
  private List<Organization> hostingOrganization = new LinkedList<Organization>();
  
  /**
   * The individual with the membership.
   */
  private List<Thing> member = new LinkedList<Thing>();
  
  /**
   * A unique identifier for the membership.
   */
  private List<String> membershipNumber = new LinkedList<String>();
  
  /**
   * The program providing the membership.
   */
  private List<String> programName = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ProgramMembershipImpl() {
    super("http://schema.org/ProgramMembership");
  }
  /**
   * Get a single additionalType property value for this ProgramMembership object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this ProgramMembership object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this ProgramMembership object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single hostingOrganization property value for this ProgramMembership object.
   *
   * @return The first hostingOrganization property value.
   */
  public Organization getHostingOrganization() {
  	return this.hostingOrganization.isEmpty() ? null : this.hostingOrganization.get(0);
  }
  
  /**
   * Get a single image property value for this ProgramMembership object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single member property value for this ProgramMembership object.
   *
   * @return The first member property value.
   */
  public Thing getMember() {
  	return this.member.isEmpty() ? null : this.member.get(0);
  }
  
  /**
   * Get a single membershipNumber property value for this ProgramMembership object.
   *
   * @return The first membershipNumber property value.
   */
  public String getMembershipNumber() {
  	return this.membershipNumber.isEmpty() ? null : this.membershipNumber.get(0);
  }
  
  /**
   * Get a single name property value for this ProgramMembership object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single programName property value for this ProgramMembership object.
   *
   * @return The first programName property value.
   */
  public String getProgramName() {
  	return this.programName.isEmpty() ? null : this.programName.get(0);
  }
  
  /**
   * Get a single sameAs property value for this ProgramMembership object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this ProgramMembership object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this ProgramMembership object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this ProgramMembership object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this ProgramMembership object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the hostingOrganization property values for this ProgramMembership object.
   *
   * @return A list of hostingOrganization property values.
   */
  public List<Organization> getHostingOrganizations() {
  	return this.hostingOrganization;
  }
  
  /**
   * Get all the image property values for this ProgramMembership object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the member property values for this ProgramMembership object.
   *
   * @return A list of member property values.
   */
  public List<Thing> getMembers() {
  	return this.member;
  }
  
  /**
   * Get all the membershipNumber property values for this ProgramMembership object.
   *
   * @return A list of membershipNumber property values.
   */
  public List<String> getMembershipNumbers() {
  	return this.membershipNumber;
  }
  
  /**
   * Get all the name property values for this ProgramMembership object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the programName property values for this ProgramMembership object.
   *
   * @return A list of programName property values.
   */
  public List<String> getProgramNames() {
  	return this.programName;
  }
  
  /**
   * Get all the sameAs property values for this ProgramMembership object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this ProgramMembership object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the hostingOrganization property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param hostingOrganization The value to set.
   */
  public void setHostingOrganization(Organization hostingOrganization) {
  	this.hostingOrganization.clear();
  	this.hostingOrganization.add(hostingOrganization);
  }
  
  /**
   * Set the image property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the member property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param member The value to set.
   */
  public void setMember(Thing member) {
  	this.member.clear();
  	this.member.add(member);
  }
  
  /**
   * Set the membershipNumber property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param membershipNumber The value to set.
   */
  public void setMembershipNumber(String membershipNumber) {
  	this.membershipNumber.clear();
  	this.membershipNumber.add(membershipNumber);
  }
  
  /**
   * Set the name property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the programName property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param programName The value to set.
   */
  public void setProgramName(String programName) {
  	this.programName.clear();
  	this.programName.add(programName);
  }
  
  /**
   * Set the sameAs property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the hostingOrganization property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param hostingOrganizations The list of values to set.
   */
  public void setHostingOrganizations(List<Organization> hostingOrganizations) {
  	this.hostingOrganization = hostingOrganizations;
  }
  
  /**
   * Set the image property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the member property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param members The list of values to set.
   */
  public void setMembers(List<Thing> members) {
  	this.member = members;
  }
  
  /**
   * Set the membershipNumber property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param membershipNumbers The list of values to set.
   */
  public void setMembershipNumbers(List<String> membershipNumbers) {
  	this.membershipNumber = membershipNumbers;
  }
  
  /**
   * Set the name property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the programName property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param programNames The list of values to set.
   */
  public void setProgramNames(List<String> programNames) {
  	this.programName = programNames;
  }
  
  /**
   * Set the sameAs property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a hostingOrganization property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param hostingOrganization The value to add.
   */
  public void addHostingOrganization(Organization hostingOrganization) {
  	this.hostingOrganization.add(hostingOrganization);
  }
  
  /**
   * Adds a image property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a member property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param member The value to add.
   */
  public void addMember(Thing member) {
  	this.member.add(member);
  }
  
  /**
   * Adds a membershipNumber property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param membershipNumber The value to add.
   */
  public void addMembershipNumber(String membershipNumber) {
  	this.membershipNumber.add(membershipNumber);
  }
  
  /**
   * Adds a name property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a programName property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param programName The value to add.
   */
  public void addProgramName(String programName) {
  	this.programName.add(programName);
  }
  
  /**
   * Adds a sameAs property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}