package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Class;
import org.schema.Property;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property.
 */
public class PropertyImpl extends SchemaObjectImpl implements Property {


  private ThingImpl thing;

  /**
   * Relates a property to a class that is (one of) the type(s) the property is expected to be used on.
   */
  private List<Class> domainIncludes = new LinkedList<Class>();
  
  /**
   * Relates a property to a class that constitutes (one of) the expected type(s) for values of the property.
   */
  private List<Class> rangeIncludes = new LinkedList<Class>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public PropertyImpl() {
    super("http://schema.org/Property");
    thing = new ThingImpl();
  }
  /**
   * Get a single additionalType property value for this Property object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Property object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this Property object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single domainIncludes property value for this Property object.
   *
   * @return The first domainIncludes property value.
   */
  public Class getDomainIncludes() {
  	return this.domainIncludes.isEmpty() ? null : this.domainIncludes.get(0);
  }
  
  /**
   * Get a single image property value for this Property object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this Property object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single rangeIncludes property value for this Property object.
   *
   * @return The first rangeIncludes property value.
   */
  public Class getRangeIncludes() {
  	return this.rangeIncludes.isEmpty() ? null : this.rangeIncludes.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Property object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this Property object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Property object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Property object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this Property object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the domainIncludes property values for this Property object.
   *
   * @return A list of domainIncludes property values.
   */
  public List<Class> getDomainIncludess() {
  	return this.domainIncludes;
  }
  
  /**
   * Get all the image property values for this Property object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this Property object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the rangeIncludes property values for this Property object.
   *
   * @return A list of rangeIncludes property values.
   */
  public List<Class> getRangeIncludess() {
  	return this.rangeIncludes;
  }
  
  /**
   * Get all the sameAs property values for this Property object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this Property object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Property object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Property object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this Property object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the domainIncludes property value for this Property object; overwriting any existing values.
   *
   * @param domainIncludes The value to set.
   */
  public void setDomainIncludes(Class domainIncludes) {
  	this.domainIncludes.clear();
  	this.domainIncludes.add(domainIncludes);
  }
  
  /**
   * Set the image property value for this Property object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this Property object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the rangeIncludes property value for this Property object; overwriting any existing values.
   *
   * @param rangeIncludes The value to set.
   */
  public void setRangeIncludes(Class rangeIncludes) {
  	this.rangeIncludes.clear();
  	this.rangeIncludes.add(rangeIncludes);
  }
  
  /**
   * Set the sameAs property value for this Property object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this Property object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Property object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Property object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this Property object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the domainIncludes property values for this Property object; overwriting any existing values.
   *
   * @param domainIncludess The list of values to set.
   */
  public void setDomainIncludess(List<Class> domainIncludess) {
  	this.domainIncludes = domainIncludess;
  }
  
  /**
   * Set the image property values for this Property object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this Property object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the rangeIncludes property values for this Property object; overwriting any existing values.
   *
   * @param rangeIncludess The list of values to set.
   */
  public void setRangeIncludess(List<Class> rangeIncludess) {
  	this.rangeIncludes = rangeIncludess;
  }
  
  /**
   * Set the sameAs property values for this Property object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this Property object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Property object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Property object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this Property object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a domainIncludes property value for this Property object; appending it to the list of existing values.
   *
   * @param domainIncludes The value to add.
   */
  public void addDomainIncludes(Class domainIncludes) {
  	this.domainIncludes.add(domainIncludes);
  }
  
  /**
   * Adds a image property value for this Property object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this Property object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a rangeIncludes property value for this Property object; appending it to the list of existing values.
   *
   * @param rangeIncludes The value to add.
   */
  public void addRangeIncludes(Class rangeIncludes) {
  	this.rangeIncludes.add(rangeIncludes);
  }
  
  /**
   * Adds a sameAs property value for this Property object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this Property object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}