package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.QualitativeValue;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A predefined value for a product characteristic, e.g. the the power cord plug type "US" or the garment sizes "S", "M", "L", and "XL"
 */
public class QualitativeValueImpl extends SchemaObjectImpl implements QualitativeValue {


  private ThingImpl thing;

  /**
   * This ordering relation for qualitative values indicates that the subject is equal to the object.
   */
  private List<QualitativeValue> equal = new LinkedList<QualitativeValue>();
  
  /**
   * This ordering relation for qualitative values indicates that the subject is greater than the object.
   */
  private List<QualitativeValue> greater = new LinkedList<QualitativeValue>();
  
  /**
   * This ordering relation for qualitative values indicates that the subject is greater than or equal to the object.
   */
  private List<QualitativeValue> greaterOrEqual = new LinkedList<QualitativeValue>();
  
  /**
   * This ordering relation for qualitative values indicates that the subject is lesser than the object.
   */
  private List<QualitativeValue> lesser = new LinkedList<QualitativeValue>();
  
  /**
   * This ordering relation for qualitative values indicates that the subject is lesser than or equal to the object.
   */
  private List<QualitativeValue> lesserOrEqual = new LinkedList<QualitativeValue>();
  
  /**
   * This ordering relation for qualitative values indicates that the subject is not equal to the object.
   */
  private List<QualitativeValue> nonEqual = new LinkedList<QualitativeValue>();
  
  /**
   * A pointer to a secondary value that provides additional information on the original value, e.g. a reference temperature.
   */
  private List<Thing> valueReference = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public QualitativeValueImpl() {
    super("http://schema.org/QualitativeValue");
  }
  /**
   * Get a single additionalType property value for this QualitativeValue object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this QualitativeValue object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this QualitativeValue object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single equal property value for this QualitativeValue object.
   *
   * @return The first equal property value.
   */
  public QualitativeValue getEqual() {
  	return this.equal.isEmpty() ? null : this.equal.get(0);
  }
  
  /**
   * Get a single greater property value for this QualitativeValue object.
   *
   * @return The first greater property value.
   */
  public QualitativeValue getGreater() {
  	return this.greater.isEmpty() ? null : this.greater.get(0);
  }
  
  /**
   * Get a single greaterOrEqual property value for this QualitativeValue object.
   *
   * @return The first greaterOrEqual property value.
   */
  public QualitativeValue getGreaterOrEqual() {
  	return this.greaterOrEqual.isEmpty() ? null : this.greaterOrEqual.get(0);
  }
  
  /**
   * Get a single image property value for this QualitativeValue object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single lesser property value for this QualitativeValue object.
   *
   * @return The first lesser property value.
   */
  public QualitativeValue getLesser() {
  	return this.lesser.isEmpty() ? null : this.lesser.get(0);
  }
  
  /**
   * Get a single lesserOrEqual property value for this QualitativeValue object.
   *
   * @return The first lesserOrEqual property value.
   */
  public QualitativeValue getLesserOrEqual() {
  	return this.lesserOrEqual.isEmpty() ? null : this.lesserOrEqual.get(0);
  }
  
  /**
   * Get a single name property value for this QualitativeValue object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single nonEqual property value for this QualitativeValue object.
   *
   * @return The first nonEqual property value.
   */
  public QualitativeValue getNonEqual() {
  	return this.nonEqual.isEmpty() ? null : this.nonEqual.get(0);
  }
  
  /**
   * Get a single sameAs property value for this QualitativeValue object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this QualitativeValue object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single valueReference property value for this QualitativeValue object.
   *
   * @return The first valueReference property value.
   */
  public Thing getValueReference() {
  	return this.valueReference.isEmpty() ? null : this.valueReference.get(0);
  }
  
  /**
   * Get all the additionalType property values for this QualitativeValue object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this QualitativeValue object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this QualitativeValue object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the equal property values for this QualitativeValue object.
   *
   * @return A list of equal property values.
   */
  public List<QualitativeValue> getEquals() {
  	return this.equal;
  }
  
  /**
   * Get all the greater property values for this QualitativeValue object.
   *
   * @return A list of greater property values.
   */
  public List<QualitativeValue> getGreaters() {
  	return this.greater;
  }
  
  /**
   * Get all the greaterOrEqual property values for this QualitativeValue object.
   *
   * @return A list of greaterOrEqual property values.
   */
  public List<QualitativeValue> getGreaterOrEquals() {
  	return this.greaterOrEqual;
  }
  
  /**
   * Get all the image property values for this QualitativeValue object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the lesser property values for this QualitativeValue object.
   *
   * @return A list of lesser property values.
   */
  public List<QualitativeValue> getLessers() {
  	return this.lesser;
  }
  
  /**
   * Get all the lesserOrEqual property values for this QualitativeValue object.
   *
   * @return A list of lesserOrEqual property values.
   */
  public List<QualitativeValue> getLesserOrEquals() {
  	return this.lesserOrEqual;
  }
  
  /**
   * Get all the name property values for this QualitativeValue object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the nonEqual property values for this QualitativeValue object.
   *
   * @return A list of nonEqual property values.
   */
  public List<QualitativeValue> getNonEquals() {
  	return this.nonEqual;
  }
  
  /**
   * Get all the sameAs property values for this QualitativeValue object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this QualitativeValue object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the valueReference property values for this QualitativeValue object.
   *
   * @return A list of valueReference property values.
   */
  public List<Thing> getValueReferences() {
  	return this.valueReference;
  }
  
  /**
   * Set the additionalType property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the equal property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param equal The value to set.
   */
  public void setEqual(QualitativeValue equal) {
  	this.equal.clear();
  	this.equal.add(equal);
  }
  
  /**
   * Set the greater property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param greater The value to set.
   */
  public void setGreater(QualitativeValue greater) {
  	this.greater.clear();
  	this.greater.add(greater);
  }
  
  /**
   * Set the greaterOrEqual property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param greaterOrEqual The value to set.
   */
  public void setGreaterOrEqual(QualitativeValue greaterOrEqual) {
  	this.greaterOrEqual.clear();
  	this.greaterOrEqual.add(greaterOrEqual);
  }
  
  /**
   * Set the image property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the lesser property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param lesser The value to set.
   */
  public void setLesser(QualitativeValue lesser) {
  	this.lesser.clear();
  	this.lesser.add(lesser);
  }
  
  /**
   * Set the lesserOrEqual property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param lesserOrEqual The value to set.
   */
  public void setLesserOrEqual(QualitativeValue lesserOrEqual) {
  	this.lesserOrEqual.clear();
  	this.lesserOrEqual.add(lesserOrEqual);
  }
  
  /**
   * Set the name property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the nonEqual property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param nonEqual The value to set.
   */
  public void setNonEqual(QualitativeValue nonEqual) {
  	this.nonEqual.clear();
  	this.nonEqual.add(nonEqual);
  }
  
  /**
   * Set the sameAs property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the valueReference property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param valueReference The value to set.
   */
  public void setValueReference(Thing valueReference) {
  	this.valueReference.clear();
  	this.valueReference.add(valueReference);
  }
  
  /**
   * Set the additionalType property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the equal property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param equals The list of values to set.
   */
  public void setEquals(List<QualitativeValue> equals) {
  	this.equal = equals;
  }
  
  /**
   * Set the greater property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param greaters The list of values to set.
   */
  public void setGreaters(List<QualitativeValue> greaters) {
  	this.greater = greaters;
  }
  
  /**
   * Set the greaterOrEqual property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param greaterOrEquals The list of values to set.
   */
  public void setGreaterOrEquals(List<QualitativeValue> greaterOrEquals) {
  	this.greaterOrEqual = greaterOrEquals;
  }
  
  /**
   * Set the image property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the lesser property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param lessers The list of values to set.
   */
  public void setLessers(List<QualitativeValue> lessers) {
  	this.lesser = lessers;
  }
  
  /**
   * Set the lesserOrEqual property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param lesserOrEquals The list of values to set.
   */
  public void setLesserOrEquals(List<QualitativeValue> lesserOrEquals) {
  	this.lesserOrEqual = lesserOrEquals;
  }
  
  /**
   * Set the name property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the nonEqual property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param nonEquals The list of values to set.
   */
  public void setNonEquals(List<QualitativeValue> nonEquals) {
  	this.nonEqual = nonEquals;
  }
  
  /**
   * Set the sameAs property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the valueReference property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param valueReferences The list of values to set.
   */
  public void setValueReferences(List<Thing> valueReferences) {
  	this.valueReference = valueReferences;
  }
  
  /**
   * Adds a additionalType property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a equal property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param equal The value to add.
   */
  public void addEqual(QualitativeValue equal) {
  	this.equal.add(equal);
  }
  
  /**
   * Adds a greater property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param greater The value to add.
   */
  public void addGreater(QualitativeValue greater) {
  	this.greater.add(greater);
  }
  
  /**
   * Adds a greaterOrEqual property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param greaterOrEqual The value to add.
   */
  public void addGreaterOrEqual(QualitativeValue greaterOrEqual) {
  	this.greaterOrEqual.add(greaterOrEqual);
  }
  
  /**
   * Adds a image property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a lesser property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param lesser The value to add.
   */
  public void addLesser(QualitativeValue lesser) {
  	this.lesser.add(lesser);
  }
  
  /**
   * Adds a lesserOrEqual property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param lesserOrEqual The value to add.
   */
  public void addLesserOrEqual(QualitativeValue lesserOrEqual) {
  	this.lesserOrEqual.add(lesserOrEqual);
  }
  
  /**
   * Adds a name property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a nonEqual property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param nonEqual The value to add.
   */
  public void addNonEqual(QualitativeValue nonEqual) {
  	this.nonEqual.add(nonEqual);
  }
  
  /**
   * Adds a sameAs property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a valueReference property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param valueReference The value to add.
   */
  public void addValueReference(Thing valueReference) {
  	this.valueReference.add(valueReference);
  }
  
}