package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Number;
import org.schema.QuantitativeValue;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 *  A point value or interval for product characteristics and other purposes.
 */
public class QuantitativeValueImpl extends SchemaObjectImpl implements QuantitativeValue {


  private ThingImpl thing;

  /**
   * The upper of the product characteristic.
   */
  private List<Number> maxValue = new LinkedList<Number>();
  
  /**
   * The lower value of the product characteristic.
   */
  private List<Number> minValue = new LinkedList<Number>();
  
  /**
   * The unit of measurement given using the UN/CEFACT Common Code (3 characters).
   */
  private List<String> unitCode = new LinkedList<String>();
  
  /**
   * The value of the product characteristic.
   */
  private List<Number> value = new LinkedList<Number>();
  
  /**
   * A pointer to a secondary value that provides additional information on the original value, e.g. a reference temperature.
   */
  private List<Thing> valueReference = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public QuantitativeValueImpl() {
    super("http://schema.org/QuantitativeValue");
  }
  /**
   * Get a single additionalType property value for this QuantitativeValue object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this QuantitativeValue object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this QuantitativeValue object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this QuantitativeValue object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single maxValue property value for this QuantitativeValue object.
   *
   * @return The first maxValue property value.
   */
  public Number getMaxValue() {
  	return this.maxValue.isEmpty() ? null : this.maxValue.get(0);
  }
  
  /**
   * Get a single minValue property value for this QuantitativeValue object.
   *
   * @return The first minValue property value.
   */
  public Number getMinValue() {
  	return this.minValue.isEmpty() ? null : this.minValue.get(0);
  }
  
  /**
   * Get a single name property value for this QuantitativeValue object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single sameAs property value for this QuantitativeValue object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single unitCode property value for this QuantitativeValue object.
   *
   * @return The first unitCode property value.
   */
  public String getUnitCode() {
  	return this.unitCode.isEmpty() ? null : this.unitCode.get(0);
  }
  
  /**
   * Get a single url property value for this QuantitativeValue object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single value property value for this QuantitativeValue object.
   *
   * @return The first value property value.
   */
  public Number getValue() {
  	return this.value.isEmpty() ? null : this.value.get(0);
  }
  
  /**
   * Get a single valueReference property value for this QuantitativeValue object.
   *
   * @return The first valueReference property value.
   */
  public Thing getValueReference() {
  	return this.valueReference.isEmpty() ? null : this.valueReference.get(0);
  }
  
  /**
   * Get all the additionalType property values for this QuantitativeValue object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this QuantitativeValue object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this QuantitativeValue object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this QuantitativeValue object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the maxValue property values for this QuantitativeValue object.
   *
   * @return A list of maxValue property values.
   */
  public List<Number> getMaxValues() {
  	return this.maxValue;
  }
  
  /**
   * Get all the minValue property values for this QuantitativeValue object.
   *
   * @return A list of minValue property values.
   */
  public List<Number> getMinValues() {
  	return this.minValue;
  }
  
  /**
   * Get all the name property values for this QuantitativeValue object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the sameAs property values for this QuantitativeValue object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the unitCode property values for this QuantitativeValue object.
   *
   * @return A list of unitCode property values.
   */
  public List<String> getUnitCodes() {
  	return this.unitCode;
  }
  
  /**
   * Get all the url property values for this QuantitativeValue object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the value property values for this QuantitativeValue object.
   *
   * @return A list of value property values.
   */
  public List<Number> getValues() {
  	return this.value;
  }
  
  /**
   * Get all the valueReference property values for this QuantitativeValue object.
   *
   * @return A list of valueReference property values.
   */
  public List<Thing> getValueReferences() {
  	return this.valueReference;
  }
  
  /**
   * Set the additionalType property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the maxValue property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param maxValue The value to set.
   */
  public void setMaxValue(Number maxValue) {
  	this.maxValue.clear();
  	this.maxValue.add(maxValue);
  }
  
  /**
   * Set the minValue property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param minValue The value to set.
   */
  public void setMinValue(Number minValue) {
  	this.minValue.clear();
  	this.minValue.add(minValue);
  }
  
  /**
   * Set the name property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the sameAs property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the unitCode property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param unitCode The value to set.
   */
  public void setUnitCode(String unitCode) {
  	this.unitCode.clear();
  	this.unitCode.add(unitCode);
  }
  
  /**
   * Set the url property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the value property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param value The value to set.
   */
  public void setValue(Number value) {
  	this.value.clear();
  	this.value.add(value);
  }
  
  /**
   * Set the valueReference property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param valueReference The value to set.
   */
  public void setValueReference(Thing valueReference) {
  	this.valueReference.clear();
  	this.valueReference.add(valueReference);
  }
  
  /**
   * Set the additionalType property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the maxValue property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param maxValues The list of values to set.
   */
  public void setMaxValues(List<Number> maxValues) {
  	this.maxValue = maxValues;
  }
  
  /**
   * Set the minValue property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param minValues The list of values to set.
   */
  public void setMinValues(List<Number> minValues) {
  	this.minValue = minValues;
  }
  
  /**
   * Set the name property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the sameAs property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the unitCode property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param unitCodes The list of values to set.
   */
  public void setUnitCodes(List<String> unitCodes) {
  	this.unitCode = unitCodes;
  }
  
  /**
   * Set the url property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the value property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param values The list of values to set.
   */
  public void setValues(List<Number> values) {
  	this.value = values;
  }
  
  /**
   * Set the valueReference property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param valueReferences The list of values to set.
   */
  public void setValueReferences(List<Thing> valueReferences) {
  	this.valueReference = valueReferences;
  }
  
  /**
   * Adds a additionalType property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a maxValue property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param maxValue The value to add.
   */
  public void addMaxValue(Number maxValue) {
  	this.maxValue.add(maxValue);
  }
  
  /**
   * Adds a minValue property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param minValue The value to add.
   */
  public void addMinValue(Number minValue) {
  	this.minValue.add(minValue);
  }
  
  /**
   * Adds a name property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a sameAs property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a unitCode property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param unitCode The value to add.
   */
  public void addUnitCode(String unitCode) {
  	this.unitCode.add(unitCode);
  }
  
  /**
   * Adds a url property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a value property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param value The value to add.
   */
  public void addValue(Number value) {
  	this.value.add(value);
  }
  
  /**
   * Adds a valueReference property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param valueReference The value to add.
   */
  public void addValueReference(Thing valueReference) {
  	this.valueReference.add(valueReference);
  }
  
}