package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Rating;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The rating of the video.
 */
public class RatingImpl extends SchemaObjectImpl implements Rating {


  private ThingImpl thing;

  /**
   * The highest value allowed in this rating system. If bestRating is omitted, 5 is assumed.
   */
  private List<Thing> bestRating = new LinkedList<Thing>();
  
  /**
   * The rating for the content.
   */
  private List<String> ratingValue = new LinkedList<String>();
  
  /**
   * The lowest value allowed in this rating system. If worstRating is omitted, 1 is assumed.
   */
  private List<Thing> worstRating = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public RatingImpl() {
    super("http://schema.org/Rating");
  }
  /**
   * Get a single additionalType property value for this Rating object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Rating object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single bestRating property value for this Rating object.
   *
   * @return The first bestRating property value.
   */
  public Thing getBestRating() {
  	return this.bestRating.isEmpty() ? null : this.bestRating.get(0);
  }
  
  /**
   * Get a single description property value for this Rating object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this Rating object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this Rating object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single ratingValue property value for this Rating object.
   *
   * @return The first ratingValue property value.
   */
  public String getRatingValue() {
  	return this.ratingValue.isEmpty() ? null : this.ratingValue.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Rating object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this Rating object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single worstRating property value for this Rating object.
   *
   * @return The first worstRating property value.
   */
  public Thing getWorstRating() {
  	return this.worstRating.isEmpty() ? null : this.worstRating.get(0);
  }
  
  /**
   * Get all the additionalType property values for this Rating object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Rating object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the bestRating property values for this Rating object.
   *
   * @return A list of bestRating property values.
   */
  public List<Thing> getBestRatings() {
  	return this.bestRating;
  }
  
  /**
   * Get all the description property values for this Rating object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this Rating object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this Rating object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the ratingValue property values for this Rating object.
   *
   * @return A list of ratingValue property values.
   */
  public List<String> getRatingValues() {
  	return this.ratingValue;
  }
  
  /**
   * Get all the sameAs property values for this Rating object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this Rating object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the worstRating property values for this Rating object.
   *
   * @return A list of worstRating property values.
   */
  public List<Thing> getWorstRatings() {
  	return this.worstRating;
  }
  
  /**
   * Set the additionalType property value for this Rating object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Rating object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the bestRating property value for this Rating object; overwriting any existing values.
   *
   * @param bestRating The value to set.
   */
  public void setBestRating(Thing bestRating) {
  	this.bestRating.clear();
  	this.bestRating.add(bestRating);
  }
  
  /**
   * Set the description property value for this Rating object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this Rating object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this Rating object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the ratingValue property value for this Rating object; overwriting any existing values.
   *
   * @param ratingValue The value to set.
   */
  public void setRatingValue(String ratingValue) {
  	this.ratingValue.clear();
  	this.ratingValue.add(ratingValue);
  }
  
  /**
   * Set the sameAs property value for this Rating object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this Rating object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the worstRating property value for this Rating object; overwriting any existing values.
   *
   * @param worstRating The value to set.
   */
  public void setWorstRating(Thing worstRating) {
  	this.worstRating.clear();
  	this.worstRating.add(worstRating);
  }
  
  /**
   * Set the additionalType property values for this Rating object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Rating object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the bestRating property values for this Rating object; overwriting any existing values.
   *
   * @param bestRatings The list of values to set.
   */
  public void setBestRatings(List<Thing> bestRatings) {
  	this.bestRating = bestRatings;
  }
  
  /**
   * Set the description property values for this Rating object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this Rating object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this Rating object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the ratingValue property values for this Rating object; overwriting any existing values.
   *
   * @param ratingValues The list of values to set.
   */
  public void setRatingValues(List<String> ratingValues) {
  	this.ratingValue = ratingValues;
  }
  
  /**
   * Set the sameAs property values for this Rating object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this Rating object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the worstRating property values for this Rating object; overwriting any existing values.
   *
   * @param worstRatings The list of values to set.
   */
  public void setWorstRatings(List<Thing> worstRatings) {
  	this.worstRating = worstRatings;
  }
  
  /**
   * Adds a additionalType property value for this Rating object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Rating object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a bestRating property value for this Rating object; appending it to the list of existing values.
   *
   * @param bestRating The value to add.
   */
  public void addBestRating(Thing bestRating) {
  	this.bestRating.add(bestRating);
  }
  
  /**
   * Adds a description property value for this Rating object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this Rating object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this Rating object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a ratingValue property value for this Rating object; appending it to the list of existing values.
   *
   * @param ratingValue The value to add.
   */
  public void addRatingValue(String ratingValue) {
  	this.ratingValue.add(ratingValue);
  }
  
  /**
   * Adds a sameAs property value for this Rating object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this Rating object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a worstRating property value for this Rating object; appending it to the list of existing values.
   *
   * @param worstRating The value to add.
   */
  public void addWorstRating(Thing worstRating) {
  	this.worstRating.add(worstRating);
  }
  
}