package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.ProgramMembership;
import org.schema.Reservation;
import org.schema.ReservationStatusType;
import org.schema.Thing;
import org.schema.Ticket;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Describes a reservation for travel, dining or an event. Some reservations require tickets.Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, restaurant reservations, flights, or rental cars, use http://schema.org/Offer.
 */
public class ReservationImpl extends SchemaObjectImpl implements Reservation {


  private ThingImpl thing;

  /**
   * If the reservation was not booked directly through the provider, the third-party booking agent can be recorded through this property.
   */
  private List<Thing> bookingAgent = new LinkedList<Thing>();
  
  /**
   * The date and time the reservation was booked.
   */
  private List<Date> bookingTime = new LinkedList<Date>();
  
  /**
   * The date and time the reservation was modified.
   */
  private List<Date> modifiedTime = new LinkedList<Date>();
  
  /**
   * The currency (in 3-letter ISO 4217 format) of the price or a price component, when attached to PriceSpecification and its subtypes.
   */
  private List<String> priceCurrency = new LinkedList<String>();
  
  /**
   * Any membership in a frequent flyer, hotel loyalty program, etc. being applied to the reservation.
   */
  private List<ProgramMembership> programMembershipUsed = new LinkedList<ProgramMembership>();
  
  /**
   * The organization or agency that is providing the service.
   */
  private List<Thing> provider = new LinkedList<Thing>();
  
  /**
   * The thing -- flight, event, restaurant,etc. being reserved.
   */
  private List<Thing> reservationFor = new LinkedList<Thing>();
  
  /**
   * A unique identifier for the reservation.
   */
  private List<String> reservationId = new LinkedList<String>();
  
  /**
   * The current status of the reservation.
   */
  private List<ReservationStatusType> reservationStatus = new LinkedList<ReservationStatusType>();
  
  /**
   * A ticket associated with the reservation.
   */
  private List<Ticket> reservedTicket = new LinkedList<Ticket>();
  
  /**
   * The total price for the reservation or ticket, including applicable taxes, shipping, etc.
   */
  private List<Thing> totalPrice = new LinkedList<Thing>();
  
  /**
   * The person or organization the reservation or ticket is for.
   */
  private List<Thing> underName = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ReservationImpl() {
    super("http://schema.org/Reservation");
  }
  /**
   * Get a single additionalType property value for this Reservation object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Reservation object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single bookingAgent property value for this Reservation object.
   *
   * @return The first bookingAgent property value.
   */
  public Thing getBookingAgent() {
  	return this.bookingAgent.isEmpty() ? null : this.bookingAgent.get(0);
  }
  
  /**
   * Get a single bookingTime property value for this Reservation object.
   *
   * @return The first bookingTime property value.
   */
  public Date getBookingTime() {
  	return this.bookingTime.isEmpty() ? null : this.bookingTime.get(0);
  }
  
  /**
   * Get a single description property value for this Reservation object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this Reservation object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single modifiedTime property value for this Reservation object.
   *
   * @return The first modifiedTime property value.
   */
  public Date getModifiedTime() {
  	return this.modifiedTime.isEmpty() ? null : this.modifiedTime.get(0);
  }
  
  /**
   * Get a single name property value for this Reservation object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single priceCurrency property value for this Reservation object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency() {
  	return this.priceCurrency.isEmpty() ? null : this.priceCurrency.get(0);
  }
  
  /**
   * Get a single programMembershipUsed property value for this Reservation object.
   *
   * @return The first programMembershipUsed property value.
   */
  public ProgramMembership getProgramMembershipUsed() {
  	return this.programMembershipUsed.isEmpty() ? null : this.programMembershipUsed.get(0);
  }
  
  /**
   * Get a single provider property value for this Reservation object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
  	return this.provider.isEmpty() ? null : this.provider.get(0);
  }
  
  /**
   * Get a single reservationFor property value for this Reservation object.
   *
   * @return The first reservationFor property value.
   */
  public Thing getReservationFor() {
  	return this.reservationFor.isEmpty() ? null : this.reservationFor.get(0);
  }
  
  /**
   * Get a single reservationId property value for this Reservation object.
   *
   * @return The first reservationId property value.
   */
  public String getReservationId() {
  	return this.reservationId.isEmpty() ? null : this.reservationId.get(0);
  }
  
  /**
   * Get a single reservationStatus property value for this Reservation object.
   *
   * @return The first reservationStatus property value.
   */
  public ReservationStatusType getReservationStatus() {
  	return this.reservationStatus.isEmpty() ? null : this.reservationStatus.get(0);
  }
  
  /**
   * Get a single reservedTicket property value for this Reservation object.
   *
   * @return The first reservedTicket property value.
   */
  public Ticket getReservedTicket() {
  	return this.reservedTicket.isEmpty() ? null : this.reservedTicket.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Reservation object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single totalPrice property value for this Reservation object.
   *
   * @return The first totalPrice property value.
   */
  public Thing getTotalPrice() {
  	return this.totalPrice.isEmpty() ? null : this.totalPrice.get(0);
  }
  
  /**
   * Get a single underName property value for this Reservation object.
   *
   * @return The first underName property value.
   */
  public Thing getUnderName() {
  	return this.underName.isEmpty() ? null : this.underName.get(0);
  }
  
  /**
   * Get a single url property value for this Reservation object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Reservation object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Reservation object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the bookingAgent property values for this Reservation object.
   *
   * @return A list of bookingAgent property values.
   */
  public List<Thing> getBookingAgents() {
  	return this.bookingAgent;
  }
  
  /**
   * Get all the bookingTime property values for this Reservation object.
   *
   * @return A list of bookingTime property values.
   */
  public List<Date> getBookingTimes() {
  	return this.bookingTime;
  }
  
  /**
   * Get all the description property values for this Reservation object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this Reservation object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the modifiedTime property values for this Reservation object.
   *
   * @return A list of modifiedTime property values.
   */
  public List<Date> getModifiedTimes() {
  	return this.modifiedTime;
  }
  
  /**
   * Get all the name property values for this Reservation object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the priceCurrency property values for this Reservation object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies() {
  	return this.priceCurrency;
  }
  
  /**
   * Get all the programMembershipUsed property values for this Reservation object.
   *
   * @return A list of programMembershipUsed property values.
   */
  public List<ProgramMembership> getProgramMembershipUseds() {
  	return this.programMembershipUsed;
  }
  
  /**
   * Get all the provider property values for this Reservation object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
  	return this.provider;
  }
  
  /**
   * Get all the reservationFor property values for this Reservation object.
   *
   * @return A list of reservationFor property values.
   */
  public List<Thing> getReservationFors() {
  	return this.reservationFor;
  }
  
  /**
   * Get all the reservationId property values for this Reservation object.
   *
   * @return A list of reservationId property values.
   */
  public List<String> getReservationIds() {
  	return this.reservationId;
  }
  
  /**
   * Get all the reservationStatus property values for this Reservation object.
   *
   * @return A list of reservationStatus property values.
   */
  public List<ReservationStatusType> getReservationStatuses() {
  	return this.reservationStatus;
  }
  
  /**
   * Get all the reservedTicket property values for this Reservation object.
   *
   * @return A list of reservedTicket property values.
   */
  public List<Ticket> getReservedTickets() {
  	return this.reservedTicket;
  }
  
  /**
   * Get all the sameAs property values for this Reservation object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the totalPrice property values for this Reservation object.
   *
   * @return A list of totalPrice property values.
   */
  public List<Thing> getTotalPrices() {
  	return this.totalPrice;
  }
  
  /**
   * Get all the underName property values for this Reservation object.
   *
   * @return A list of underName property values.
   */
  public List<Thing> getUnderNames() {
  	return this.underName;
  }
  
  /**
   * Get all the url property values for this Reservation object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Reservation object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Reservation object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the bookingAgent property value for this Reservation object; overwriting any existing values.
   *
   * @param bookingAgent The value to set.
   */
  public void setBookingAgent(Thing bookingAgent) {
  	this.bookingAgent.clear();
  	this.bookingAgent.add(bookingAgent);
  }
  
  /**
   * Set the bookingTime property value for this Reservation object; overwriting any existing values.
   *
   * @param bookingTime The value to set.
   */
  public void setBookingTime(Date bookingTime) {
  	this.bookingTime.clear();
  	this.bookingTime.add(bookingTime);
  }
  
  /**
   * Set the description property value for this Reservation object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this Reservation object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the modifiedTime property value for this Reservation object; overwriting any existing values.
   *
   * @param modifiedTime The value to set.
   */
  public void setModifiedTime(Date modifiedTime) {
  	this.modifiedTime.clear();
  	this.modifiedTime.add(modifiedTime);
  }
  
  /**
   * Set the name property value for this Reservation object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the priceCurrency property value for this Reservation object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency) {
  	this.priceCurrency.clear();
  	this.priceCurrency.add(priceCurrency);
  }
  
  /**
   * Set the programMembershipUsed property value for this Reservation object; overwriting any existing values.
   *
   * @param programMembershipUsed The value to set.
   */
  public void setProgramMembershipUsed(ProgramMembership programMembershipUsed) {
  	this.programMembershipUsed.clear();
  	this.programMembershipUsed.add(programMembershipUsed);
  }
  
  /**
   * Set the provider property value for this Reservation object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
  	this.provider.clear();
  	this.provider.add(provider);
  }
  
  /**
   * Set the reservationFor property value for this Reservation object; overwriting any existing values.
   *
   * @param reservationFor The value to set.
   */
  public void setReservationFor(Thing reservationFor) {
  	this.reservationFor.clear();
  	this.reservationFor.add(reservationFor);
  }
  
  /**
   * Set the reservationId property value for this Reservation object; overwriting any existing values.
   *
   * @param reservationId The value to set.
   */
  public void setReservationId(String reservationId) {
  	this.reservationId.clear();
  	this.reservationId.add(reservationId);
  }
  
  /**
   * Set the reservationStatus property value for this Reservation object; overwriting any existing values.
   *
   * @param reservationStatus The value to set.
   */
  public void setReservationStatus(ReservationStatusType reservationStatus) {
  	this.reservationStatus.clear();
  	this.reservationStatus.add(reservationStatus);
  }
  
  /**
   * Set the reservedTicket property value for this Reservation object; overwriting any existing values.
   *
   * @param reservedTicket The value to set.
   */
  public void setReservedTicket(Ticket reservedTicket) {
  	this.reservedTicket.clear();
  	this.reservedTicket.add(reservedTicket);
  }
  
  /**
   * Set the sameAs property value for this Reservation object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the totalPrice property value for this Reservation object; overwriting any existing values.
   *
   * @param totalPrice The value to set.
   */
  public void setTotalPrice(Thing totalPrice) {
  	this.totalPrice.clear();
  	this.totalPrice.add(totalPrice);
  }
  
  /**
   * Set the underName property value for this Reservation object; overwriting any existing values.
   *
   * @param underName The value to set.
   */
  public void setUnderName(Thing underName) {
  	this.underName.clear();
  	this.underName.add(underName);
  }
  
  /**
   * Set the url property value for this Reservation object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Reservation object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Reservation object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the bookingAgent property values for this Reservation object; overwriting any existing values.
   *
   * @param bookingAgents The list of values to set.
   */
  public void setBookingAgents(List<Thing> bookingAgents) {
  	this.bookingAgent = bookingAgents;
  }
  
  /**
   * Set the bookingTime property values for this Reservation object; overwriting any existing values.
   *
   * @param bookingTimes The list of values to set.
   */
  public void setBookingTimes(List<Date> bookingTimes) {
  	this.bookingTime = bookingTimes;
  }
  
  /**
   * Set the description property values for this Reservation object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this Reservation object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the modifiedTime property values for this Reservation object; overwriting any existing values.
   *
   * @param modifiedTimes The list of values to set.
   */
  public void setModifiedTimes(List<Date> modifiedTimes) {
  	this.modifiedTime = modifiedTimes;
  }
  
  /**
   * Set the name property values for this Reservation object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the priceCurrency property values for this Reservation object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies) {
  	this.priceCurrency = priceCurrencies;
  }
  
  /**
   * Set the programMembershipUsed property values for this Reservation object; overwriting any existing values.
   *
   * @param programMembershipUseds The list of values to set.
   */
  public void setProgramMembershipUseds(List<ProgramMembership> programMembershipUseds) {
  	this.programMembershipUsed = programMembershipUseds;
  }
  
  /**
   * Set the provider property values for this Reservation object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
  	this.provider = providers;
  }
  
  /**
   * Set the reservationFor property values for this Reservation object; overwriting any existing values.
   *
   * @param reservationFors The list of values to set.
   */
  public void setReservationFors(List<Thing> reservationFors) {
  	this.reservationFor = reservationFors;
  }
  
  /**
   * Set the reservationId property values for this Reservation object; overwriting any existing values.
   *
   * @param reservationIds The list of values to set.
   */
  public void setReservationIds(List<String> reservationIds) {
  	this.reservationId = reservationIds;
  }
  
  /**
   * Set the reservationStatus property values for this Reservation object; overwriting any existing values.
   *
   * @param reservationStatuses The list of values to set.
   */
  public void setReservationStatuses(List<ReservationStatusType> reservationStatuses) {
  	this.reservationStatus = reservationStatuses;
  }
  
  /**
   * Set the reservedTicket property values for this Reservation object; overwriting any existing values.
   *
   * @param reservedTickets The list of values to set.
   */
  public void setReservedTickets(List<Ticket> reservedTickets) {
  	this.reservedTicket = reservedTickets;
  }
  
  /**
   * Set the sameAs property values for this Reservation object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the totalPrice property values for this Reservation object; overwriting any existing values.
   *
   * @param totalPrices The list of values to set.
   */
  public void setTotalPrices(List<Thing> totalPrices) {
  	this.totalPrice = totalPrices;
  }
  
  /**
   * Set the underName property values for this Reservation object; overwriting any existing values.
   *
   * @param underNames The list of values to set.
   */
  public void setUnderNames(List<Thing> underNames) {
  	this.underName = underNames;
  }
  
  /**
   * Set the url property values for this Reservation object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Reservation object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Reservation object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a bookingAgent property value for this Reservation object; appending it to the list of existing values.
   *
   * @param bookingAgent The value to add.
   */
  public void addBookingAgent(Thing bookingAgent) {
  	this.bookingAgent.add(bookingAgent);
  }
  
  /**
   * Adds a bookingTime property value for this Reservation object; appending it to the list of existing values.
   *
   * @param bookingTime The value to add.
   */
  public void addBookingTime(Date bookingTime) {
  	this.bookingTime.add(bookingTime);
  }
  
  /**
   * Adds a description property value for this Reservation object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this Reservation object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a modifiedTime property value for this Reservation object; appending it to the list of existing values.
   *
   * @param modifiedTime The value to add.
   */
  public void addModifiedTime(Date modifiedTime) {
  	this.modifiedTime.add(modifiedTime);
  }
  
  /**
   * Adds a name property value for this Reservation object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a priceCurrency property value for this Reservation object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency) {
  	this.priceCurrency.add(priceCurrency);
  }
  
  /**
   * Adds a programMembershipUsed property value for this Reservation object; appending it to the list of existing values.
   *
   * @param programMembershipUsed The value to add.
   */
  public void addProgramMembershipUsed(ProgramMembership programMembershipUsed) {
  	this.programMembershipUsed.add(programMembershipUsed);
  }
  
  /**
   * Adds a provider property value for this Reservation object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
  	this.provider.add(provider);
  }
  
  /**
   * Adds a reservationFor property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservationFor The value to add.
   */
  public void addReservationFor(Thing reservationFor) {
  	this.reservationFor.add(reservationFor);
  }
  
  /**
   * Adds a reservationId property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservationId The value to add.
   */
  public void addReservationId(String reservationId) {
  	this.reservationId.add(reservationId);
  }
  
  /**
   * Adds a reservationStatus property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservationStatus The value to add.
   */
  public void addReservationStatus(ReservationStatusType reservationStatus) {
  	this.reservationStatus.add(reservationStatus);
  }
  
  /**
   * Adds a reservedTicket property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservedTicket The value to add.
   */
  public void addReservedTicket(Ticket reservedTicket) {
  	this.reservedTicket.add(reservedTicket);
  }
  
  /**
   * Adds a sameAs property value for this Reservation object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a totalPrice property value for this Reservation object; appending it to the list of existing values.
   *
   * @param totalPrice The value to add.
   */
  public void addTotalPrice(Thing totalPrice) {
  	this.totalPrice.add(totalPrice);
  }
  
  /**
   * Adds a underName property value for this Reservation object; appending it to the list of existing values.
   *
   * @param underName The value to add.
   */
  public void addUnderName(Thing underName) {
  	this.underName.add(underName);
  }
  
  /**
   * Adds a url property value for this Reservation object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}