package com.google.developers.schemas.impl;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import java.lang.Boolean;
import org.schema.EventStatusType;
import org.schema.MedicalSpecialty;
import org.schema.OfferItemCondition;
import org.schema.MedicalTrialDesign;
import org.schema.InfectiousAgentClass;
import org.schema.MedicalStudyStatus;
import org.schema.ItemAvailability;
import org.schema.SchemaObject;
import org.schema.DrugPregnancyCategory;
import org.schema.BookFormatType;
import org.schema.OrderStatus;
import org.schema.MedicalEvidenceLevel;
import org.schema.MedicalObservationalStudyDesign;
import org.schema.PhysicalExam;
import org.schema.MedicalAudience;
import org.schema.ReservationStatusType;
import org.schema.DrugCostCategory;
import org.schema.MedicalImagingTechnique;
import org.schema.MedicalProcedureType;
import org.schema.DrugPrescriptionStatus;
import org.schema.ContactPointOption;
import org.schema.MedicineSystem;
import org.schema.MedicalDevicePurpose;
import org.schema.SchemaObjectFactory;
import org.schema.PhysicalActivityCategory;

public class SchemaObjectFactoryImpl implements SchemaObjectFactory {

	private static Map<String, Class> classesById = new HashMap<String, Class>();
	private static Map<String, Object> enumerationsById = new HashMap<String, Object>();
	
	static {
		classesById.put("http://schema.org/APIReference", APIReferenceImpl.class);
		classesById.put("http://schema.org/AboutPage", AboutPageImpl.class);
		classesById.put("http://schema.org/AcceptAction", AcceptActionImpl.class);
		classesById.put("http://schema.org/AccountingService", AccountingServiceImpl.class);
		classesById.put("http://schema.org/AchieveAction", AchieveActionImpl.class);
		classesById.put("http://schema.org/Action", ActionImpl.class);
		classesById.put("http://schema.org/AddAction", AddActionImpl.class);
		classesById.put("http://schema.org/AdministrativeArea", AdministrativeAreaImpl.class);
		classesById.put("http://schema.org/AdultEntertainment", AdultEntertainmentImpl.class);
		classesById.put("http://schema.org/AggregateOffer", AggregateOfferImpl.class);
		classesById.put("http://schema.org/AggregateRating", AggregateRatingImpl.class);
		classesById.put("http://schema.org/AgreeAction", AgreeActionImpl.class);
		classesById.put("http://schema.org/Airline", AirlineImpl.class);
		classesById.put("http://schema.org/Airport", AirportImpl.class);
		classesById.put("http://schema.org/AlignmentObject", AlignmentObjectImpl.class);
		classesById.put("http://schema.org/AllocateAction", AllocateActionImpl.class);
		classesById.put("http://schema.org/AmusementPark", AmusementParkImpl.class);
		classesById.put("http://schema.org/AnatomicalStructure", AnatomicalStructureImpl.class);
		classesById.put("http://schema.org/AnatomicalSystem", AnatomicalSystemImpl.class);
		classesById.put("http://schema.org/AnimalShelter", AnimalShelterImpl.class);
		classesById.put("http://schema.org/Answer", AnswerImpl.class);
		classesById.put("http://schema.org/ApartmentComplex", ApartmentComplexImpl.class);
		classesById.put("http://schema.org/AppendAction", AppendActionImpl.class);
		classesById.put("http://schema.org/ApplyAction", ApplyActionImpl.class);
		classesById.put("http://schema.org/ApprovedIndication", ApprovedIndicationImpl.class);
		classesById.put("http://schema.org/Aquarium", AquariumImpl.class);
		classesById.put("http://schema.org/ArriveAction", ArriveActionImpl.class);
		classesById.put("http://schema.org/ArtGallery", ArtGalleryImpl.class);
		classesById.put("http://schema.org/Artery", ArteryImpl.class);
		classesById.put("http://schema.org/Article", ArticleImpl.class);
		classesById.put("http://schema.org/AskAction", AskActionImpl.class);
		classesById.put("http://schema.org/AssessAction", AssessActionImpl.class);
		classesById.put("http://schema.org/AssignAction", AssignActionImpl.class);
		classesById.put("http://schema.org/Attorney", AttorneyImpl.class);
		classesById.put("http://schema.org/Audience", AudienceImpl.class);
		classesById.put("http://schema.org/AudioObject", AudioObjectImpl.class);
		classesById.put("http://schema.org/AuthorizeAction", AuthorizeActionImpl.class);
		classesById.put("http://schema.org/AutoBodyShop", AutoBodyShopImpl.class);
		classesById.put("http://schema.org/AutoDealer", AutoDealerImpl.class);
		classesById.put("http://schema.org/AutoPartsStore", AutoPartsStoreImpl.class);
		classesById.put("http://schema.org/AutoRental", AutoRentalImpl.class);
		classesById.put("http://schema.org/AutoRepair", AutoRepairImpl.class);
		classesById.put("http://schema.org/AutoWash", AutoWashImpl.class);
		classesById.put("http://schema.org/AutomatedTeller", AutomatedTellerImpl.class);
		classesById.put("http://schema.org/AutomotiveBusiness", AutomotiveBusinessImpl.class);
		classesById.put("http://schema.org/Bakery", BakeryImpl.class);
		classesById.put("http://schema.org/BankOrCreditUnion", BankOrCreditUnionImpl.class);
		classesById.put("http://schema.org/BarOrPub", BarOrPubImpl.class);
		classesById.put("http://schema.org/Beach", BeachImpl.class);
		classesById.put("http://schema.org/BeautySalon", BeautySalonImpl.class);
		classesById.put("http://schema.org/BedAndBreakfast", BedAndBreakfastImpl.class);
		classesById.put("http://schema.org/BefriendAction", BefriendActionImpl.class);
		classesById.put("http://schema.org/BikeStore", BikeStoreImpl.class);
		classesById.put("http://schema.org/Blog", BlogImpl.class);
		classesById.put("http://schema.org/BlogPosting", BlogPostingImpl.class);
		classesById.put("http://schema.org/BloodTest", BloodTestImpl.class);
		classesById.put("http://schema.org/BodyOfWater", BodyOfWaterImpl.class);
		classesById.put("http://schema.org/Bone", BoneImpl.class);
		classesById.put("http://schema.org/Book", BookImpl.class);
		enumerationsById.put("http://schema.org/EBook", BookFormatType.EBook);
		enumerationsById.put("http://schema.org/Hardcover", BookFormatType.Hardcover);
		enumerationsById.put("http://schema.org/Paperback", BookFormatType.Paperback);
		classesById.put("http://schema.org/BookStore", BookStoreImpl.class);
		classesById.put("http://schema.org/BookmarkAction", BookmarkActionImpl.class);
		classesById.put("http://schema.org/BorrowAction", BorrowActionImpl.class);
		classesById.put("http://schema.org/BowlingAlley", BowlingAlleyImpl.class);
		classesById.put("http://schema.org/BrainStructure", BrainStructureImpl.class);
		classesById.put("http://schema.org/Brand", BrandImpl.class);
		classesById.put("http://schema.org/Brewery", BreweryImpl.class);
		classesById.put("http://schema.org/BroadcastEvent", BroadcastEventImpl.class);
		classesById.put("http://schema.org/BroadcastService", BroadcastServiceImpl.class);
		classesById.put("http://schema.org/BuddhistTemple", BuddhistTempleImpl.class);
		classesById.put("http://schema.org/BusReservation", BusReservationImpl.class);
		classesById.put("http://schema.org/BusStation", BusStationImpl.class);
		classesById.put("http://schema.org/BusStop", BusStopImpl.class);
		classesById.put("http://schema.org/BusTrip", BusTripImpl.class);
		classesById.put("http://schema.org/BusinessAudience", BusinessAudienceImpl.class);
		classesById.put("http://schema.org/BusinessEntityType", BusinessEntityTypeImpl.class);
		classesById.put("http://schema.org/BusinessEvent", BusinessEventImpl.class);
		classesById.put("http://schema.org/BusinessFunction", BusinessFunctionImpl.class);
		classesById.put("http://schema.org/BuyAction", BuyActionImpl.class);
		classesById.put("http://schema.org/CafeOrCoffeeShop", CafeOrCoffeeShopImpl.class);
		classesById.put("http://schema.org/Campground", CampgroundImpl.class);
		classesById.put("http://schema.org/Canal", CanalImpl.class);
		classesById.put("http://schema.org/CancelAction", CancelActionImpl.class);
		classesById.put("http://schema.org/Car", CarImpl.class);
		classesById.put("http://schema.org/Casino", CasinoImpl.class);
		classesById.put("http://schema.org/CatholicChurch", CatholicChurchImpl.class);
		classesById.put("http://schema.org/Cemetery", CemeteryImpl.class);
		classesById.put("http://schema.org/CheckAction", CheckActionImpl.class);
		classesById.put("http://schema.org/CheckInAction", CheckInActionImpl.class);
		classesById.put("http://schema.org/CheckOutAction", CheckOutActionImpl.class);
		classesById.put("http://schema.org/CheckoutPage", CheckoutPageImpl.class);
		classesById.put("http://schema.org/ChildCare", ChildCareImpl.class);
		classesById.put("http://schema.org/ChildrensEvent", ChildrensEventImpl.class);
		classesById.put("http://schema.org/ChooseAction", ChooseActionImpl.class);
		classesById.put("http://schema.org/Church", ChurchImpl.class);
		classesById.put("http://schema.org/City", CityImpl.class);
		classesById.put("http://schema.org/CityHall", CityHallImpl.class);
		classesById.put("http://schema.org/CivicStructure", CivicStructureImpl.class);
		classesById.put("http://schema.org/Class", ClassImpl.class);
		classesById.put("http://schema.org/Clip", ClipImpl.class);
		classesById.put("http://schema.org/ClothingStore", ClothingStoreImpl.class);
		classesById.put("http://schema.org/Code", CodeImpl.class);
		classesById.put("http://schema.org/CollectionPage", CollectionPageImpl.class);
		classesById.put("http://schema.org/CollegeOrUniversity", CollegeOrUniversityImpl.class);
		classesById.put("http://schema.org/ComedyClub", ComedyClubImpl.class);
		classesById.put("http://schema.org/ComedyEvent", ComedyEventImpl.class);
		classesById.put("http://schema.org/Comment", CommentImpl.class);
		classesById.put("http://schema.org/CommentAction", CommentActionImpl.class);
		classesById.put("http://schema.org/CommunicateAction", CommunicateActionImpl.class);
		classesById.put("http://schema.org/ComputerStore", ComputerStoreImpl.class);
		classesById.put("http://schema.org/ConfirmAction", ConfirmActionImpl.class);
		classesById.put("http://schema.org/ConsumeAction", ConsumeActionImpl.class);
		classesById.put("http://schema.org/ContactPage", ContactPageImpl.class);
		classesById.put("http://schema.org/ContactPoint", ContactPointImpl.class);
		enumerationsById.put("http://schema.org/HearingImpairedSupported", ContactPointOption.HearingImpairedSupported);
		enumerationsById.put("http://schema.org/TollFree", ContactPointOption.TollFree);
		classesById.put("http://schema.org/Continent", ContinentImpl.class);
		classesById.put("http://schema.org/ConvenienceStore", ConvenienceStoreImpl.class);
		classesById.put("http://schema.org/CookAction", CookActionImpl.class);
		classesById.put("http://schema.org/Corporation", CorporationImpl.class);
		classesById.put("http://schema.org/Country", CountryImpl.class);
		classesById.put("http://schema.org/Courthouse", CourthouseImpl.class);
		classesById.put("http://schema.org/CreateAction", CreateActionImpl.class);
		classesById.put("http://schema.org/CreativeWork", CreativeWorkImpl.class);
		classesById.put("http://schema.org/CreditCard", CreditCardImpl.class);
		classesById.put("http://schema.org/Crematorium", CrematoriumImpl.class);
		classesById.put("http://schema.org/DDxElement", DDxElementImpl.class);
		classesById.put("http://schema.org/DanceEvent", DanceEventImpl.class);
		classesById.put("http://schema.org/DanceGroup", DanceGroupImpl.class);
		classesById.put("http://schema.org/DataCatalog", DataCatalogImpl.class);
		classesById.put("http://schema.org/DataDownload", DataDownloadImpl.class);
		classesById.put("http://schema.org/DataType", DataTypeImpl.class);
		classesById.put("http://schema.org/Dataset", DatasetImpl.class);
		classesById.put("http://schema.org/DayOfWeek", DayOfWeekImpl.class);
		classesById.put("http://schema.org/DaySpa", DaySpaImpl.class);
		classesById.put("http://schema.org/DefenceEstablishment", DefenceEstablishmentImpl.class);
		classesById.put("http://schema.org/DeleteAction", DeleteActionImpl.class);
		classesById.put("http://schema.org/DeliveryChargeSpecification", DeliveryChargeSpecificationImpl.class);
		classesById.put("http://schema.org/DeliveryEvent", DeliveryEventImpl.class);
		classesById.put("http://schema.org/DeliveryMethod", DeliveryMethodImpl.class);
		classesById.put("http://schema.org/Demand", DemandImpl.class);
		classesById.put("http://schema.org/Dentist", DentistImpl.class);
		classesById.put("http://schema.org/DepartAction", DepartActionImpl.class);
		classesById.put("http://schema.org/DepartmentStore", DepartmentStoreImpl.class);
		classesById.put("http://schema.org/DiagnosticLab", DiagnosticLabImpl.class);
		classesById.put("http://schema.org/DiagnosticProcedure", DiagnosticProcedureImpl.class);
		classesById.put("http://schema.org/Diet", DietImpl.class);
		classesById.put("http://schema.org/DietarySupplement", DietarySupplementImpl.class);
		classesById.put("http://schema.org/DisagreeAction", DisagreeActionImpl.class);
		classesById.put("http://schema.org/DiscoverAction", DiscoverActionImpl.class);
		classesById.put("http://schema.org/DislikeAction", DislikeActionImpl.class);
		classesById.put("http://schema.org/Distance", DistanceImpl.class);
		classesById.put("http://schema.org/DonateAction", DonateActionImpl.class);
		classesById.put("http://schema.org/DoseSchedule", DoseScheduleImpl.class);
		classesById.put("http://schema.org/DownloadAction", DownloadActionImpl.class);
		classesById.put("http://schema.org/DrawAction", DrawActionImpl.class);
		classesById.put("http://schema.org/DrinkAction", DrinkActionImpl.class);
		classesById.put("http://schema.org/Drug", DrugImpl.class);
		classesById.put("http://schema.org/DrugClass", DrugClassImpl.class);
		classesById.put("http://schema.org/DrugCost", DrugCostImpl.class);
		enumerationsById.put("http://schema.org/ReimbursementCap", DrugCostCategory.ReimbursementCap);
		enumerationsById.put("http://schema.org/Retail", DrugCostCategory.Retail);
		enumerationsById.put("http://schema.org/Wholesale", DrugCostCategory.Wholesale);
		classesById.put("http://schema.org/DrugLegalStatus", DrugLegalStatusImpl.class);
		enumerationsById.put("http://schema.org/FDAcategoryA", DrugPregnancyCategory.FDAcategoryA);
		enumerationsById.put("http://schema.org/FDAcategoryB", DrugPregnancyCategory.FDAcategoryB);
		enumerationsById.put("http://schema.org/FDAcategoryC", DrugPregnancyCategory.FDAcategoryC);
		enumerationsById.put("http://schema.org/FDAcategoryD", DrugPregnancyCategory.FDAcategoryD);
		enumerationsById.put("http://schema.org/FDAcategoryX", DrugPregnancyCategory.FDAcategoryX);
		enumerationsById.put("http://schema.org/FDAnotEvaluated", DrugPregnancyCategory.FDAnotEvaluated);
		enumerationsById.put("http://schema.org/OTC", DrugPrescriptionStatus.OTC);
		enumerationsById.put("http://schema.org/PrescriptionOnly", DrugPrescriptionStatus.PrescriptionOnly);
		classesById.put("http://schema.org/DrugStrength", DrugStrengthImpl.class);
		classesById.put("http://schema.org/DryCleaningOrLaundry", DryCleaningOrLaundryImpl.class);
		classesById.put("http://schema.org/Duration", DurationImpl.class);
		classesById.put("http://schema.org/EatAction", EatActionImpl.class);
		classesById.put("http://schema.org/EducationEvent", EducationEventImpl.class);
		classesById.put("http://schema.org/EducationalAudience", EducationalAudienceImpl.class);
		classesById.put("http://schema.org/EducationalOrganization", EducationalOrganizationImpl.class);
		classesById.put("http://schema.org/Electrician", ElectricianImpl.class);
		classesById.put("http://schema.org/ElectronicsStore", ElectronicsStoreImpl.class);
		classesById.put("http://schema.org/ElementarySchool", ElementarySchoolImpl.class);
		classesById.put("http://schema.org/EmailMessage", EmailMessageImpl.class);
		classesById.put("http://schema.org/Embassy", EmbassyImpl.class);
		classesById.put("http://schema.org/EmergencyService", EmergencyServiceImpl.class);
		classesById.put("http://schema.org/EmploymentAgency", EmploymentAgencyImpl.class);
		classesById.put("http://schema.org/EndorseAction", EndorseActionImpl.class);
		classesById.put("http://schema.org/Energy", EnergyImpl.class);
		classesById.put("http://schema.org/EntertainmentBusiness", EntertainmentBusinessImpl.class);
		classesById.put("http://schema.org/Enumeration", EnumerationImpl.class);
		classesById.put("http://schema.org/Episode", EpisodeImpl.class);
		classesById.put("http://schema.org/Event", EventImpl.class);
		classesById.put("http://schema.org/EventReservation", EventReservationImpl.class);
		enumerationsById.put("http://schema.org/EventCancelled", EventStatusType.EventCancelled);
		enumerationsById.put("http://schema.org/EventPostponed", EventStatusType.EventPostponed);
		enumerationsById.put("http://schema.org/EventRescheduled", EventStatusType.EventRescheduled);
		enumerationsById.put("http://schema.org/EventScheduled", EventStatusType.EventScheduled);
		classesById.put("http://schema.org/EventVenue", EventVenueImpl.class);
		classesById.put("http://schema.org/ExerciseAction", ExerciseActionImpl.class);
		classesById.put("http://schema.org/ExerciseGym", ExerciseGymImpl.class);
		classesById.put("http://schema.org/ExercisePlan", ExercisePlanImpl.class);
		classesById.put("http://schema.org/FastFoodRestaurant", FastFoodRestaurantImpl.class);
		classesById.put("http://schema.org/Festival", FestivalImpl.class);
		classesById.put("http://schema.org/FilmAction", FilmActionImpl.class);
		classesById.put("http://schema.org/FinancialService", FinancialServiceImpl.class);
		classesById.put("http://schema.org/FindAction", FindActionImpl.class);
		classesById.put("http://schema.org/FireStation", FireStationImpl.class);
		classesById.put("http://schema.org/Flight", FlightImpl.class);
		classesById.put("http://schema.org/FlightReservation", FlightReservationImpl.class);
		classesById.put("http://schema.org/Florist", FloristImpl.class);
		classesById.put("http://schema.org/FollowAction", FollowActionImpl.class);
		classesById.put("http://schema.org/FoodEstablishment", FoodEstablishmentImpl.class);
		classesById.put("http://schema.org/FoodEstablishmentReservation", FoodEstablishmentReservationImpl.class);
		classesById.put("http://schema.org/FoodEvent", FoodEventImpl.class);
		classesById.put("http://schema.org/FurnitureStore", FurnitureStoreImpl.class);
		classesById.put("http://schema.org/GardenStore", GardenStoreImpl.class);
		classesById.put("http://schema.org/GasStation", GasStationImpl.class);
		classesById.put("http://schema.org/GatedResidenceCommunity", GatedResidenceCommunityImpl.class);
		classesById.put("http://schema.org/GeneralContractor", GeneralContractorImpl.class);
		classesById.put("http://schema.org/GeoCoordinates", GeoCoordinatesImpl.class);
		classesById.put("http://schema.org/GeoShape", GeoShapeImpl.class);
		classesById.put("http://schema.org/GiveAction", GiveActionImpl.class);
		classesById.put("http://schema.org/GolfCourse", GolfCourseImpl.class);
		classesById.put("http://schema.org/GovernmentBuilding", GovernmentBuildingImpl.class);
		classesById.put("http://schema.org/GovernmentOffice", GovernmentOfficeImpl.class);
		classesById.put("http://schema.org/GovernmentOrganization", GovernmentOrganizationImpl.class);
		classesById.put("http://schema.org/GovernmentPermit", GovernmentPermitImpl.class);
		classesById.put("http://schema.org/GovernmentService", GovernmentServiceImpl.class);
		classesById.put("http://schema.org/GroceryStore", GroceryStoreImpl.class);
		classesById.put("http://schema.org/HVACBusiness", HVACBusinessImpl.class);
		classesById.put("http://schema.org/HairSalon", HairSalonImpl.class);
		classesById.put("http://schema.org/HardwareStore", HardwareStoreImpl.class);
		classesById.put("http://schema.org/HealthAndBeautyBusiness", HealthAndBeautyBusinessImpl.class);
		classesById.put("http://schema.org/HealthClub", HealthClubImpl.class);
		classesById.put("http://schema.org/HighSchool", HighSchoolImpl.class);
		classesById.put("http://schema.org/HinduTemple", HinduTempleImpl.class);
		classesById.put("http://schema.org/HobbyShop", HobbyShopImpl.class);
		classesById.put("http://schema.org/HomeAndConstructionBusiness", HomeAndConstructionBusinessImpl.class);
		classesById.put("http://schema.org/HomeGoodsStore", HomeGoodsStoreImpl.class);
		classesById.put("http://schema.org/Hospital", HospitalImpl.class);
		classesById.put("http://schema.org/Hostel", HostelImpl.class);
		classesById.put("http://schema.org/Hotel", HotelImpl.class);
		classesById.put("http://schema.org/HousePainter", HousePainterImpl.class);
		classesById.put("http://schema.org/IceCreamShop", IceCreamShopImpl.class);
		classesById.put("http://schema.org/IgnoreAction", IgnoreActionImpl.class);
		classesById.put("http://schema.org/ImageGallery", ImageGalleryImpl.class);
		classesById.put("http://schema.org/ImageObject", ImageObjectImpl.class);
		classesById.put("http://schema.org/ImagingTest", ImagingTestImpl.class);
		classesById.put("http://schema.org/IndividualProduct", IndividualProductImpl.class);
		enumerationsById.put("http://schema.org/Bacteria", InfectiousAgentClass.Bacteria);
		enumerationsById.put("http://schema.org/Fungus", InfectiousAgentClass.Fungus);
		enumerationsById.put("http://schema.org/MulticellularParasite", InfectiousAgentClass.MulticellularParasite);
		enumerationsById.put("http://schema.org/Prion", InfectiousAgentClass.Prion);
		enumerationsById.put("http://schema.org/Protozoa", InfectiousAgentClass.Protozoa);
		enumerationsById.put("http://schema.org/Virus", InfectiousAgentClass.Virus);
		classesById.put("http://schema.org/InfectiousDisease", InfectiousDiseaseImpl.class);
		classesById.put("http://schema.org/InformAction", InformActionImpl.class);
		classesById.put("http://schema.org/InsertAction", InsertActionImpl.class);
		classesById.put("http://schema.org/InstallAction", InstallActionImpl.class);
		classesById.put("http://schema.org/InsuranceAgency", InsuranceAgencyImpl.class);
		classesById.put("http://schema.org/Intangible", IntangibleImpl.class);
		classesById.put("http://schema.org/InteractAction", InteractActionImpl.class);
		classesById.put("http://schema.org/InternetCafe", InternetCafeImpl.class);
		classesById.put("http://schema.org/InviteAction", InviteActionImpl.class);
		enumerationsById.put("http://schema.org/Discontinued", ItemAvailability.Discontinued);
		enumerationsById.put("http://schema.org/InStock", ItemAvailability.InStock);
		enumerationsById.put("http://schema.org/InStoreOnly", ItemAvailability.InStoreOnly);
		enumerationsById.put("http://schema.org/LimitedAvailability", ItemAvailability.LimitedAvailability);
		enumerationsById.put("http://schema.org/OnlineOnly", ItemAvailability.OnlineOnly);
		enumerationsById.put("http://schema.org/OutOfStock", ItemAvailability.OutOfStock);
		enumerationsById.put("http://schema.org/PreOrder", ItemAvailability.PreOrder);
		enumerationsById.put("http://schema.org/SoldOut", ItemAvailability.SoldOut);
		classesById.put("http://schema.org/ItemList", ItemListImpl.class);
		classesById.put("http://schema.org/ItemPage", ItemPageImpl.class);
		classesById.put("http://schema.org/JewelryStore", JewelryStoreImpl.class);
		classesById.put("http://schema.org/JobPosting", JobPostingImpl.class);
		classesById.put("http://schema.org/JoinAction", JoinActionImpl.class);
		classesById.put("http://schema.org/Joint", JointImpl.class);
		classesById.put("http://schema.org/LakeBodyOfWater", LakeBodyOfWaterImpl.class);
		classesById.put("http://schema.org/Landform", LandformImpl.class);
		classesById.put("http://schema.org/LandmarksOrHistoricalBuildings", LandmarksOrHistoricalBuildingsImpl.class);
		classesById.put("http://schema.org/Language", LanguageImpl.class);
		classesById.put("http://schema.org/LeaveAction", LeaveActionImpl.class);
		classesById.put("http://schema.org/LegislativeBuilding", LegislativeBuildingImpl.class);
		classesById.put("http://schema.org/LendAction", LendActionImpl.class);
		classesById.put("http://schema.org/Library", LibraryImpl.class);
		classesById.put("http://schema.org/LifestyleModification", LifestyleModificationImpl.class);
		classesById.put("http://schema.org/Ligament", LigamentImpl.class);
		classesById.put("http://schema.org/LikeAction", LikeActionImpl.class);
		classesById.put("http://schema.org/LiquorStore", LiquorStoreImpl.class);
		classesById.put("http://schema.org/ListenAction", ListenActionImpl.class);
		classesById.put("http://schema.org/LiteraryEvent", LiteraryEventImpl.class);
		classesById.put("http://schema.org/LocalBusiness", LocalBusinessImpl.class);
		classesById.put("http://schema.org/LockerDelivery", LockerDeliveryImpl.class);
		classesById.put("http://schema.org/Locksmith", LocksmithImpl.class);
		classesById.put("http://schema.org/LodgingBusiness", LodgingBusinessImpl.class);
		classesById.put("http://schema.org/LodgingReservation", LodgingReservationImpl.class);
		classesById.put("http://schema.org/LoseAction", LoseActionImpl.class);
		classesById.put("http://schema.org/LymphaticVessel", LymphaticVesselImpl.class);
		classesById.put("http://schema.org/Map", MapImpl.class);
		classesById.put("http://schema.org/MarryAction", MarryActionImpl.class);
		classesById.put("http://schema.org/Mass", MassImpl.class);
		classesById.put("http://schema.org/MaximumDoseSchedule", MaximumDoseScheduleImpl.class);
		classesById.put("http://schema.org/MediaObject", MediaObjectImpl.class);
		enumerationsById.put("http://schema.org/Clinician", MedicalAudience.Clinician);
		enumerationsById.put("http://schema.org/MedicalResearcher", MedicalAudience.MedicalResearcher);
		enumerationsById.put("http://schema.org/Patient", MedicalAudience.Patient);
		classesById.put("http://schema.org/MedicalCause", MedicalCauseImpl.class);
		classesById.put("http://schema.org/MedicalClinic", MedicalClinicImpl.class);
		classesById.put("http://schema.org/MedicalCode", MedicalCodeImpl.class);
		classesById.put("http://schema.org/MedicalCondition", MedicalConditionImpl.class);
		classesById.put("http://schema.org/MedicalConditionStage", MedicalConditionStageImpl.class);
		classesById.put("http://schema.org/MedicalContraindication", MedicalContraindicationImpl.class);
		classesById.put("http://schema.org/MedicalDevice", MedicalDeviceImpl.class);
		enumerationsById.put("http://schema.org/Diagnostic", MedicalDevicePurpose.Diagnostic);
		enumerationsById.put("http://schema.org/Therapeutic", MedicalDevicePurpose.Therapeutic);
		classesById.put("http://schema.org/MedicalEntity", MedicalEntityImpl.class);
		classesById.put("http://schema.org/MedicalEnumeration", MedicalEnumerationImpl.class);
		enumerationsById.put("http://schema.org/EvidenceLevelA", MedicalEvidenceLevel.EvidenceLevelA);
		enumerationsById.put("http://schema.org/EvidenceLevelB", MedicalEvidenceLevel.EvidenceLevelB);
		enumerationsById.put("http://schema.org/EvidenceLevelC", MedicalEvidenceLevel.EvidenceLevelC);
		classesById.put("http://schema.org/MedicalGuideline", MedicalGuidelineImpl.class);
		classesById.put("http://schema.org/MedicalGuidelineContraindication", MedicalGuidelineContraindicationImpl.class);
		classesById.put("http://schema.org/MedicalGuidelineRecommendation", MedicalGuidelineRecommendationImpl.class);
		enumerationsById.put("http://schema.org/CT", MedicalImagingTechnique.CT);
		enumerationsById.put("http://schema.org/MRI", MedicalImagingTechnique.MRI);
		enumerationsById.put("http://schema.org/PET", MedicalImagingTechnique.PET);
		enumerationsById.put("http://schema.org/Ultrasound", MedicalImagingTechnique.Ultrasound);
		enumerationsById.put("http://schema.org/XRay", MedicalImagingTechnique.XRay);
		classesById.put("http://schema.org/MedicalIndication", MedicalIndicationImpl.class);
		classesById.put("http://schema.org/MedicalIntangible", MedicalIntangibleImpl.class);
		classesById.put("http://schema.org/MedicalObservationalStudy", MedicalObservationalStudyImpl.class);
		enumerationsById.put("http://schema.org/CaseSeries", MedicalObservationalStudyDesign.CaseSeries);
		enumerationsById.put("http://schema.org/CohortStudy", MedicalObservationalStudyDesign.CohortStudy);
		enumerationsById.put("http://schema.org/CrossSectional", MedicalObservationalStudyDesign.CrossSectional);
		enumerationsById.put("http://schema.org/Longitudinal", MedicalObservationalStudyDesign.Longitudinal);
		enumerationsById.put("http://schema.org/Observational", MedicalObservationalStudyDesign.Observational);
		enumerationsById.put("http://schema.org/Registry", MedicalObservationalStudyDesign.Registry);
		classesById.put("http://schema.org/MedicalOrganization", MedicalOrganizationImpl.class);
		classesById.put("http://schema.org/MedicalProcedure", MedicalProcedureImpl.class);
		enumerationsById.put("http://schema.org/NoninvasiveProcedure", MedicalProcedureType.NoninvasiveProcedure);
		enumerationsById.put("http://schema.org/PercutaneousProcedure", MedicalProcedureType.PercutaneousProcedure);
		enumerationsById.put("http://schema.org/SurgicalProcedure", MedicalProcedureType.SurgicalProcedure);
		classesById.put("http://schema.org/MedicalRiskCalculator", MedicalRiskCalculatorImpl.class);
		classesById.put("http://schema.org/MedicalRiskEstimator", MedicalRiskEstimatorImpl.class);
		classesById.put("http://schema.org/MedicalRiskFactor", MedicalRiskFactorImpl.class);
		classesById.put("http://schema.org/MedicalRiskScore", MedicalRiskScoreImpl.class);
		classesById.put("http://schema.org/MedicalScholarlyArticle", MedicalScholarlyArticleImpl.class);
		classesById.put("http://schema.org/MedicalSign", MedicalSignImpl.class);
		classesById.put("http://schema.org/MedicalSignOrSymptom", MedicalSignOrSymptomImpl.class);
		enumerationsById.put("http://schema.org/Anesthesia", MedicalSpecialty.Anesthesia);
		enumerationsById.put("http://schema.org/Cardiovascular", MedicalSpecialty.Cardiovascular);
		enumerationsById.put("http://schema.org/CommunityHealth", MedicalSpecialty.CommunityHealth);
		enumerationsById.put("http://schema.org/Dentistry", MedicalSpecialty.Dentistry);
		enumerationsById.put("http://schema.org/Dermatologic", MedicalSpecialty.Dermatologic);
		enumerationsById.put("http://schema.org/DietNutrition", MedicalSpecialty.DietNutrition);
		enumerationsById.put("http://schema.org/Emergency", MedicalSpecialty.Emergency);
		enumerationsById.put("http://schema.org/Endocrine", MedicalSpecialty.Endocrine);
		enumerationsById.put("http://schema.org/Gastroenterologic", MedicalSpecialty.Gastroenterologic);
		enumerationsById.put("http://schema.org/Genetic", MedicalSpecialty.Genetic);
		enumerationsById.put("http://schema.org/Geriatric", MedicalSpecialty.Geriatric);
		enumerationsById.put("http://schema.org/Gynecologic", MedicalSpecialty.Gynecologic);
		enumerationsById.put("http://schema.org/Hematologic", MedicalSpecialty.Hematologic);
		enumerationsById.put("http://schema.org/Infectious", MedicalSpecialty.Infectious);
		enumerationsById.put("http://schema.org/LaboratoryScience", MedicalSpecialty.LaboratoryScience);
		enumerationsById.put("http://schema.org/Midwifery", MedicalSpecialty.Midwifery);
		enumerationsById.put("http://schema.org/Musculoskeletal", MedicalSpecialty.Musculoskeletal);
		enumerationsById.put("http://schema.org/Neurologic", MedicalSpecialty.Neurologic);
		enumerationsById.put("http://schema.org/Nursing", MedicalSpecialty.Nursing);
		enumerationsById.put("http://schema.org/Obstetric", MedicalSpecialty.Obstetric);
		enumerationsById.put("http://schema.org/OccupationalTherapy", MedicalSpecialty.OccupationalTherapy);
		enumerationsById.put("http://schema.org/Oncologic", MedicalSpecialty.Oncologic);
		enumerationsById.put("http://schema.org/Optometic", MedicalSpecialty.Optometic);
		enumerationsById.put("http://schema.org/Otolaryngologic", MedicalSpecialty.Otolaryngologic);
		enumerationsById.put("http://schema.org/Pathology", MedicalSpecialty.Pathology);
		enumerationsById.put("http://schema.org/Pediatric", MedicalSpecialty.Pediatric);
		enumerationsById.put("http://schema.org/PharmacySpecialty", MedicalSpecialty.PharmacySpecialty);
		enumerationsById.put("http://schema.org/Physiotherapy", MedicalSpecialty.Physiotherapy);
		enumerationsById.put("http://schema.org/PlasticSurgery", MedicalSpecialty.PlasticSurgery);
		enumerationsById.put("http://schema.org/Podiatric", MedicalSpecialty.Podiatric);
		enumerationsById.put("http://schema.org/PrimaryCare", MedicalSpecialty.PrimaryCare);
		enumerationsById.put("http://schema.org/Psychiatric", MedicalSpecialty.Psychiatric);
		enumerationsById.put("http://schema.org/PublicHealth", MedicalSpecialty.PublicHealth);
		enumerationsById.put("http://schema.org/Pulmonary", MedicalSpecialty.Pulmonary);
		enumerationsById.put("http://schema.org/Radiograpy", MedicalSpecialty.Radiograpy);
		enumerationsById.put("http://schema.org/Renal", MedicalSpecialty.Renal);
		enumerationsById.put("http://schema.org/RespiratoryTherapy", MedicalSpecialty.RespiratoryTherapy);
		enumerationsById.put("http://schema.org/Rheumatologic", MedicalSpecialty.Rheumatologic);
		enumerationsById.put("http://schema.org/SpeechPathology", MedicalSpecialty.SpeechPathology);
		enumerationsById.put("http://schema.org/Surgical", MedicalSpecialty.Surgical);
		enumerationsById.put("http://schema.org/Toxicologic", MedicalSpecialty.Toxicologic);
		enumerationsById.put("http://schema.org/Urologic", MedicalSpecialty.Urologic);
		classesById.put("http://schema.org/MedicalStudy", MedicalStudyImpl.class);
		enumerationsById.put("http://schema.org/ActiveNotRecruiting", MedicalStudyStatus.ActiveNotRecruiting);
		enumerationsById.put("http://schema.org/Completed", MedicalStudyStatus.Completed);
		enumerationsById.put("http://schema.org/EnrollingByInvitation", MedicalStudyStatus.EnrollingByInvitation);
		enumerationsById.put("http://schema.org/NotYetRecruiting", MedicalStudyStatus.NotYetRecruiting);
		enumerationsById.put("http://schema.org/Recruiting", MedicalStudyStatus.Recruiting);
		enumerationsById.put("http://schema.org/ResultsAvailable", MedicalStudyStatus.ResultsAvailable);
		enumerationsById.put("http://schema.org/ResultsNotAvailable", MedicalStudyStatus.ResultsNotAvailable);
		enumerationsById.put("http://schema.org/Suspended", MedicalStudyStatus.Suspended);
		enumerationsById.put("http://schema.org/Terminated", MedicalStudyStatus.Terminated);
		enumerationsById.put("http://schema.org/Withdrawn", MedicalStudyStatus.Withdrawn);
		classesById.put("http://schema.org/MedicalSymptom", MedicalSymptomImpl.class);
		classesById.put("http://schema.org/MedicalTest", MedicalTestImpl.class);
		classesById.put("http://schema.org/MedicalTestPanel", MedicalTestPanelImpl.class);
		classesById.put("http://schema.org/MedicalTherapy", MedicalTherapyImpl.class);
		classesById.put("http://schema.org/MedicalTrial", MedicalTrialImpl.class);
		enumerationsById.put("http://schema.org/DoubleBlindedTrial", MedicalTrialDesign.DoubleBlindedTrial);
		enumerationsById.put("http://schema.org/InternationalTrial", MedicalTrialDesign.InternationalTrial);
		enumerationsById.put("http://schema.org/MultiCenterTrial", MedicalTrialDesign.MultiCenterTrial);
		enumerationsById.put("http://schema.org/OpenTrial", MedicalTrialDesign.OpenTrial);
		enumerationsById.put("http://schema.org/PlaceboControlledTrial", MedicalTrialDesign.PlaceboControlledTrial);
		enumerationsById.put("http://schema.org/RandomizedTrial", MedicalTrialDesign.RandomizedTrial);
		enumerationsById.put("http://schema.org/SingleBlindedTrial", MedicalTrialDesign.SingleBlindedTrial);
		enumerationsById.put("http://schema.org/SingleCenterTrial", MedicalTrialDesign.SingleCenterTrial);
		enumerationsById.put("http://schema.org/TripleBlindedTrial", MedicalTrialDesign.TripleBlindedTrial);
		classesById.put("http://schema.org/MedicalWebPage", MedicalWebPageImpl.class);
		enumerationsById.put("http://schema.org/Ayurvedic", MedicineSystem.Ayurvedic);
		enumerationsById.put("http://schema.org/Chiropractic", MedicineSystem.Chiropractic);
		enumerationsById.put("http://schema.org/Homeopathic", MedicineSystem.Homeopathic);
		enumerationsById.put("http://schema.org/Osteopathic", MedicineSystem.Osteopathic);
		enumerationsById.put("http://schema.org/TraditionalChinese", MedicineSystem.TraditionalChinese);
		enumerationsById.put("http://schema.org/WesternConventional", MedicineSystem.WesternConventional);
		classesById.put("http://schema.org/MensClothingStore", MensClothingStoreImpl.class);
		classesById.put("http://schema.org/MiddleSchool", MiddleSchoolImpl.class);
		classesById.put("http://schema.org/MobileApplication", MobileApplicationImpl.class);
		classesById.put("http://schema.org/MobilePhoneStore", MobilePhoneStoreImpl.class);
		classesById.put("http://schema.org/Mosque", MosqueImpl.class);
		classesById.put("http://schema.org/Motel", MotelImpl.class);
		classesById.put("http://schema.org/MotorcycleDealer", MotorcycleDealerImpl.class);
		classesById.put("http://schema.org/MotorcycleRepair", MotorcycleRepairImpl.class);
		classesById.put("http://schema.org/Mountain", MountainImpl.class);
		classesById.put("http://schema.org/MoveAction", MoveActionImpl.class);
		classesById.put("http://schema.org/Movie", MovieImpl.class);
		classesById.put("http://schema.org/MovieRentalStore", MovieRentalStoreImpl.class);
		classesById.put("http://schema.org/MovieTheater", MovieTheaterImpl.class);
		classesById.put("http://schema.org/MovingCompany", MovingCompanyImpl.class);
		classesById.put("http://schema.org/Muscle", MuscleImpl.class);
		classesById.put("http://schema.org/Museum", MuseumImpl.class);
		classesById.put("http://schema.org/MusicAlbum", MusicAlbumImpl.class);
		classesById.put("http://schema.org/MusicEvent", MusicEventImpl.class);
		classesById.put("http://schema.org/MusicGroup", MusicGroupImpl.class);
		classesById.put("http://schema.org/MusicPlaylist", MusicPlaylistImpl.class);
		classesById.put("http://schema.org/MusicRecording", MusicRecordingImpl.class);
		classesById.put("http://schema.org/MusicStore", MusicStoreImpl.class);
		classesById.put("http://schema.org/MusicVenue", MusicVenueImpl.class);
		classesById.put("http://schema.org/MusicVideoObject", MusicVideoObjectImpl.class);
		classesById.put("http://schema.org/NGO", NGOImpl.class);
		classesById.put("http://schema.org/NailSalon", NailSalonImpl.class);
		classesById.put("http://schema.org/Nerve", NerveImpl.class);
		classesById.put("http://schema.org/NewsArticle", NewsArticleImpl.class);
		classesById.put("http://schema.org/NightClub", NightClubImpl.class);
		classesById.put("http://schema.org/Notary", NotaryImpl.class);
		classesById.put("http://schema.org/Number", NumberImpl.class);
		classesById.put("http://schema.org/NutritionInformation", NutritionInformationImpl.class);
		classesById.put("http://schema.org/OceanBodyOfWater", OceanBodyOfWaterImpl.class);
		classesById.put("http://schema.org/Offer", OfferImpl.class);
		enumerationsById.put("http://schema.org/DamagedCondition", OfferItemCondition.DamagedCondition);
		enumerationsById.put("http://schema.org/NewCondition", OfferItemCondition.NewCondition);
		enumerationsById.put("http://schema.org/RefurbishedCondition", OfferItemCondition.RefurbishedCondition);
		enumerationsById.put("http://schema.org/UsedCondition", OfferItemCondition.UsedCondition);
		classesById.put("http://schema.org/OfficeEquipmentStore", OfficeEquipmentStoreImpl.class);
		classesById.put("http://schema.org/OnDemandEvent", OnDemandEventImpl.class);
		classesById.put("http://schema.org/OpeningHoursSpecification", OpeningHoursSpecificationImpl.class);
		classesById.put("http://schema.org/Optician", OpticianImpl.class);
		classesById.put("http://schema.org/Order", OrderImpl.class);
		classesById.put("http://schema.org/OrderAction", OrderActionImpl.class);
		enumerationsById.put("http://schema.org/OrderCancelled", OrderStatus.OrderCancelled);
		enumerationsById.put("http://schema.org/OrderDelivered", OrderStatus.OrderDelivered);
		enumerationsById.put("http://schema.org/OrderInTransit", OrderStatus.OrderInTransit);
		enumerationsById.put("http://schema.org/OrderPaymentDue", OrderStatus.OrderPaymentDue);
		enumerationsById.put("http://schema.org/OrderPickupAvailable", OrderStatus.OrderPickupAvailable);
		enumerationsById.put("http://schema.org/OrderProblem", OrderStatus.OrderProblem);
		enumerationsById.put("http://schema.org/OrderProcessing", OrderStatus.OrderProcessing);
		enumerationsById.put("http://schema.org/OrderReturned", OrderStatus.OrderReturned);
		classesById.put("http://schema.org/Organization", OrganizationImpl.class);
		classesById.put("http://schema.org/OrganizeAction", OrganizeActionImpl.class);
		classesById.put("http://schema.org/OutletStore", OutletStoreImpl.class);
		classesById.put("http://schema.org/OwnershipInfo", OwnershipInfoImpl.class);
		classesById.put("http://schema.org/PaintAction", PaintActionImpl.class);
		classesById.put("http://schema.org/Painting", PaintingImpl.class);
		classesById.put("http://schema.org/PalliativeProcedure", PalliativeProcedureImpl.class);
		classesById.put("http://schema.org/ParcelDelivery", ParcelDeliveryImpl.class);
		classesById.put("http://schema.org/ParcelService", ParcelServiceImpl.class);
		classesById.put("http://schema.org/ParentAudience", ParentAudienceImpl.class);
		classesById.put("http://schema.org/Park", ParkImpl.class);
		classesById.put("http://schema.org/ParkingFacility", ParkingFacilityImpl.class);
		classesById.put("http://schema.org/PathologyTest", PathologyTestImpl.class);
		classesById.put("http://schema.org/PawnShop", PawnShopImpl.class);
		classesById.put("http://schema.org/PayAction", PayActionImpl.class);
		classesById.put("http://schema.org/PaymentChargeSpecification", PaymentChargeSpecificationImpl.class);
		classesById.put("http://schema.org/PaymentMethod", PaymentMethodImpl.class);
		classesById.put("http://schema.org/PeopleAudience", PeopleAudienceImpl.class);
		classesById.put("http://schema.org/PerformAction", PerformActionImpl.class);
		classesById.put("http://schema.org/PerformingArtsTheater", PerformingArtsTheaterImpl.class);
		classesById.put("http://schema.org/PerformingGroup", PerformingGroupImpl.class);
		classesById.put("http://schema.org/Permit", PermitImpl.class);
		classesById.put("http://schema.org/Person", PersonImpl.class);
		classesById.put("http://schema.org/PetStore", PetStoreImpl.class);
		classesById.put("http://schema.org/Pharmacy", PharmacyImpl.class);
		classesById.put("http://schema.org/Photograph", PhotographImpl.class);
		classesById.put("http://schema.org/PhotographAction", PhotographActionImpl.class);
		classesById.put("http://schema.org/PhysicalActivity", PhysicalActivityImpl.class);
		enumerationsById.put("http://schema.org/AerobicActivity", PhysicalActivityCategory.AerobicActivity);
		enumerationsById.put("http://schema.org/AnaerobicActivity", PhysicalActivityCategory.AnaerobicActivity);
		enumerationsById.put("http://schema.org/Balance", PhysicalActivityCategory.Balance);
		enumerationsById.put("http://schema.org/Flexibility", PhysicalActivityCategory.Flexibility);
		enumerationsById.put("http://schema.org/LeisureTimeActivity", PhysicalActivityCategory.LeisureTimeActivity);
		enumerationsById.put("http://schema.org/OccupationalActivity", PhysicalActivityCategory.OccupationalActivity);
		enumerationsById.put("http://schema.org/StrengthTraining", PhysicalActivityCategory.StrengthTraining);
		enumerationsById.put("http://schema.org/Abdomen", PhysicalExam.Abdomen);
		enumerationsById.put("http://schema.org/Appearance", PhysicalExam.Appearance);
		enumerationsById.put("http://schema.org/CardiovascularExam", PhysicalExam.CardiovascularExam);
		enumerationsById.put("http://schema.org/Ear", PhysicalExam.Ear);
		enumerationsById.put("http://schema.org/Eye", PhysicalExam.Eye);
		enumerationsById.put("http://schema.org/Genitourinary", PhysicalExam.Genitourinary);
		enumerationsById.put("http://schema.org/Head", PhysicalExam.Head);
		enumerationsById.put("http://schema.org/Lung", PhysicalExam.Lung);
		enumerationsById.put("http://schema.org/MusculoskeletalExam", PhysicalExam.MusculoskeletalExam);
		enumerationsById.put("http://schema.org/Neck", PhysicalExam.Neck);
		enumerationsById.put("http://schema.org/Neuro", PhysicalExam.Neuro);
		enumerationsById.put("http://schema.org/Nose", PhysicalExam.Nose);
		enumerationsById.put("http://schema.org/Skin", PhysicalExam.Skin);
		enumerationsById.put("http://schema.org/Throat", PhysicalExam.Throat);
		enumerationsById.put("http://schema.org/VitalSign", PhysicalExam.VitalSign);
		classesById.put("http://schema.org/PhysicalTherapy", PhysicalTherapyImpl.class);
		classesById.put("http://schema.org/Physician", PhysicianImpl.class);
		classesById.put("http://schema.org/Place", PlaceImpl.class);
		classesById.put("http://schema.org/PlaceOfWorship", PlaceOfWorshipImpl.class);
		classesById.put("http://schema.org/PlanAction", PlanActionImpl.class);
		classesById.put("http://schema.org/PlayAction", PlayActionImpl.class);
		classesById.put("http://schema.org/Playground", PlaygroundImpl.class);
		classesById.put("http://schema.org/Plumber", PlumberImpl.class);
		classesById.put("http://schema.org/PoliceStation", PoliceStationImpl.class);
		classesById.put("http://schema.org/Pond", PondImpl.class);
		classesById.put("http://schema.org/PostOffice", PostOfficeImpl.class);
		classesById.put("http://schema.org/PostalAddress", PostalAddressImpl.class);
		classesById.put("http://schema.org/PrependAction", PrependActionImpl.class);
		classesById.put("http://schema.org/Preschool", PreschoolImpl.class);
		classesById.put("http://schema.org/PreventionIndication", PreventionIndicationImpl.class);
		classesById.put("http://schema.org/PriceSpecification", PriceSpecificationImpl.class);
		classesById.put("http://schema.org/Product", ProductImpl.class);
		classesById.put("http://schema.org/ProductModel", ProductModelImpl.class);
		classesById.put("http://schema.org/ProfessionalService", ProfessionalServiceImpl.class);
		classesById.put("http://schema.org/ProfilePage", ProfilePageImpl.class);
		classesById.put("http://schema.org/ProgramMembership", ProgramMembershipImpl.class);
		classesById.put("http://schema.org/Property", PropertyImpl.class);
		classesById.put("http://schema.org/PsychologicalTreatment", PsychologicalTreatmentImpl.class);
		classesById.put("http://schema.org/PublicSwimmingPool", PublicSwimmingPoolImpl.class);
		classesById.put("http://schema.org/PublicationEvent", PublicationEventImpl.class);
		classesById.put("http://schema.org/QAPage", QAPageImpl.class);
		classesById.put("http://schema.org/QualitativeValue", QualitativeValueImpl.class);
		classesById.put("http://schema.org/QuantitativeValue", QuantitativeValueImpl.class);
		classesById.put("http://schema.org/Quantity", QuantityImpl.class);
		classesById.put("http://schema.org/Question", QuestionImpl.class);
		classesById.put("http://schema.org/QuoteAction", QuoteActionImpl.class);
		classesById.put("http://schema.org/RVPark", RVParkImpl.class);
		classesById.put("http://schema.org/RadiationTherapy", RadiationTherapyImpl.class);
		classesById.put("http://schema.org/RadioClip", RadioClipImpl.class);
		classesById.put("http://schema.org/RadioEpisode", RadioEpisodeImpl.class);
		classesById.put("http://schema.org/RadioSeason", RadioSeasonImpl.class);
		classesById.put("http://schema.org/RadioSeries", RadioSeriesImpl.class);
		classesById.put("http://schema.org/RadioStation", RadioStationImpl.class);
		classesById.put("http://schema.org/Rating", RatingImpl.class);
		classesById.put("http://schema.org/ReactAction", ReactActionImpl.class);
		classesById.put("http://schema.org/ReadAction", ReadActionImpl.class);
		classesById.put("http://schema.org/RealEstateAgent", RealEstateAgentImpl.class);
		classesById.put("http://schema.org/ReceiveAction", ReceiveActionImpl.class);
		classesById.put("http://schema.org/Recipe", RecipeImpl.class);
		classesById.put("http://schema.org/RecommendedDoseSchedule", RecommendedDoseScheduleImpl.class);
		classesById.put("http://schema.org/RecyclingCenter", RecyclingCenterImpl.class);
		classesById.put("http://schema.org/RegisterAction", RegisterActionImpl.class);
		classesById.put("http://schema.org/RejectAction", RejectActionImpl.class);
		classesById.put("http://schema.org/RentAction", RentActionImpl.class);
		classesById.put("http://schema.org/RentalCarReservation", RentalCarReservationImpl.class);
		classesById.put("http://schema.org/ReplaceAction", ReplaceActionImpl.class);
		classesById.put("http://schema.org/ReplyAction", ReplyActionImpl.class);
		classesById.put("http://schema.org/ReportedDoseSchedule", ReportedDoseScheduleImpl.class);
		classesById.put("http://schema.org/Reservation", ReservationImpl.class);
		classesById.put("http://schema.org/ReservationPackage", ReservationPackageImpl.class);
		enumerationsById.put("http://schema.org/ReservationCancelled", ReservationStatusType.ReservationCancelled);
		enumerationsById.put("http://schema.org/ReservationConfirmed", ReservationStatusType.ReservationConfirmed);
		enumerationsById.put("http://schema.org/ReservationHold", ReservationStatusType.ReservationHold);
		enumerationsById.put("http://schema.org/ReservationPending", ReservationStatusType.ReservationPending);
		classesById.put("http://schema.org/ReserveAction", ReserveActionImpl.class);
		classesById.put("http://schema.org/Reservoir", ReservoirImpl.class);
		classesById.put("http://schema.org/Residence", ResidenceImpl.class);
		classesById.put("http://schema.org/Restaurant", RestaurantImpl.class);
		classesById.put("http://schema.org/ReturnAction", ReturnActionImpl.class);
		classesById.put("http://schema.org/Review", ReviewImpl.class);
		classesById.put("http://schema.org/ReviewAction", ReviewActionImpl.class);
		classesById.put("http://schema.org/RiverBodyOfWater", RiverBodyOfWaterImpl.class);
		classesById.put("http://schema.org/RoofingContractor", RoofingContractorImpl.class);
		classesById.put("http://schema.org/RsvpAction", RsvpActionImpl.class);
		classesById.put("http://schema.org/SaleEvent", SaleEventImpl.class);
		classesById.put("http://schema.org/ScheduleAction", ScheduleActionImpl.class);
		classesById.put("http://schema.org/ScholarlyArticle", ScholarlyArticleImpl.class);
		classesById.put("http://schema.org/School", SchoolImpl.class);
		classesById.put("http://schema.org/Sculpture", SculptureImpl.class);
		classesById.put("http://schema.org/SeaBodyOfWater", SeaBodyOfWaterImpl.class);
		classesById.put("http://schema.org/SearchAction", SearchActionImpl.class);
		classesById.put("http://schema.org/SearchResultsPage", SearchResultsPageImpl.class);
		classesById.put("http://schema.org/Season", SeasonImpl.class);
		classesById.put("http://schema.org/Seat", SeatImpl.class);
		classesById.put("http://schema.org/SelfStorage", SelfStorageImpl.class);
		classesById.put("http://schema.org/SellAction", SellActionImpl.class);
		classesById.put("http://schema.org/SendAction", SendActionImpl.class);
		classesById.put("http://schema.org/Series", SeriesImpl.class);
		classesById.put("http://schema.org/Service", ServiceImpl.class);
		classesById.put("http://schema.org/ServiceChannel", ServiceChannelImpl.class);
		classesById.put("http://schema.org/ShareAction", ShareActionImpl.class);
		classesById.put("http://schema.org/ShoeStore", ShoeStoreImpl.class);
		classesById.put("http://schema.org/ShoppingCenter", ShoppingCenterImpl.class);
		classesById.put("http://schema.org/SingleFamilyResidence", SingleFamilyResidenceImpl.class);
		classesById.put("http://schema.org/SiteNavigationElement", SiteNavigationElementImpl.class);
		classesById.put("http://schema.org/SkiResort", SkiResortImpl.class);
		classesById.put("http://schema.org/SocialEvent", SocialEventImpl.class);
		classesById.put("http://schema.org/SoftwareApplication", SoftwareApplicationImpl.class);
		classesById.put("http://schema.org/SomeProducts", SomeProductsImpl.class);
		classesById.put("http://schema.org/Specialty", SpecialtyImpl.class);
		classesById.put("http://schema.org/SportingGoodsStore", SportingGoodsStoreImpl.class);
		classesById.put("http://schema.org/SportsActivityLocation", SportsActivityLocationImpl.class);
		classesById.put("http://schema.org/SportsClub", SportsClubImpl.class);
		classesById.put("http://schema.org/SportsEvent", SportsEventImpl.class);
		classesById.put("http://schema.org/SportsTeam", SportsTeamImpl.class);
		classesById.put("http://schema.org/StadiumOrArena", StadiumOrArenaImpl.class);
		classesById.put("http://schema.org/State", StateImpl.class);
		classesById.put("http://schema.org/Store", StoreImpl.class);
		classesById.put("http://schema.org/StructuredValue", StructuredValueImpl.class);
		classesById.put("http://schema.org/SubscribeAction", SubscribeActionImpl.class);
		classesById.put("http://schema.org/SubwayStation", SubwayStationImpl.class);
		classesById.put("http://schema.org/SuperficialAnatomy", SuperficialAnatomyImpl.class);
		classesById.put("http://schema.org/Synagogue", SynagogueImpl.class);
		classesById.put("http://schema.org/TVClip", TVClipImpl.class);
		classesById.put("http://schema.org/TVEpisode", TVEpisodeImpl.class);
		classesById.put("http://schema.org/TVSeason", TVSeasonImpl.class);
		classesById.put("http://schema.org/TVSeries", TVSeriesImpl.class);
		classesById.put("http://schema.org/Table", TableImpl.class);
		classesById.put("http://schema.org/TakeAction", TakeActionImpl.class);
		classesById.put("http://schema.org/TattooParlor", TattooParlorImpl.class);
		classesById.put("http://schema.org/Taxi", TaxiImpl.class);
		classesById.put("http://schema.org/TaxiReservation", TaxiReservationImpl.class);
		classesById.put("http://schema.org/TaxiStand", TaxiStandImpl.class);
		classesById.put("http://schema.org/TechArticle", TechArticleImpl.class);
		classesById.put("http://schema.org/TelevisionStation", TelevisionStationImpl.class);
		classesById.put("http://schema.org/TennisComplex", TennisComplexImpl.class);
		classesById.put("http://schema.org/TheaterEvent", TheaterEventImpl.class);
		classesById.put("http://schema.org/TheaterGroup", TheaterGroupImpl.class);
		classesById.put("http://schema.org/TherapeuticProcedure", TherapeuticProcedureImpl.class);
		classesById.put("http://schema.org/Thing", ThingImpl.class);
		classesById.put("http://schema.org/Ticket", TicketImpl.class);
		classesById.put("http://schema.org/TieAction", TieActionImpl.class);
		classesById.put("http://schema.org/TipAction", TipActionImpl.class);
		classesById.put("http://schema.org/TireShop", TireShopImpl.class);
		classesById.put("http://schema.org/TouristAttraction", TouristAttractionImpl.class);
		classesById.put("http://schema.org/TouristInformationCenter", TouristInformationCenterImpl.class);
		classesById.put("http://schema.org/ToyStore", ToyStoreImpl.class);
		classesById.put("http://schema.org/TrackAction", TrackActionImpl.class);
		classesById.put("http://schema.org/TradeAction", TradeActionImpl.class);
		classesById.put("http://schema.org/TrainReservation", TrainReservationImpl.class);
		classesById.put("http://schema.org/TrainStation", TrainStationImpl.class);
		classesById.put("http://schema.org/TrainTrip", TrainTripImpl.class);
		classesById.put("http://schema.org/TransferAction", TransferActionImpl.class);
		classesById.put("http://schema.org/TravelAction", TravelActionImpl.class);
		classesById.put("http://schema.org/TravelAgency", TravelAgencyImpl.class);
		classesById.put("http://schema.org/TreatmentIndication", TreatmentIndicationImpl.class);
		classesById.put("http://schema.org/TypeAndQuantityNode", TypeAndQuantityNodeImpl.class);
		classesById.put("http://schema.org/UnRegisterAction", UnRegisterActionImpl.class);
		classesById.put("http://schema.org/UnitPriceSpecification", UnitPriceSpecificationImpl.class);
		classesById.put("http://schema.org/UpdateAction", UpdateActionImpl.class);
		classesById.put("http://schema.org/UseAction", UseActionImpl.class);
		classesById.put("http://schema.org/UserBlocks", UserBlocksImpl.class);
		classesById.put("http://schema.org/UserCheckins", UserCheckinsImpl.class);
		classesById.put("http://schema.org/UserComments", UserCommentsImpl.class);
		classesById.put("http://schema.org/UserDownloads", UserDownloadsImpl.class);
		classesById.put("http://schema.org/UserInteraction", UserInteractionImpl.class);
		classesById.put("http://schema.org/UserLikes", UserLikesImpl.class);
		classesById.put("http://schema.org/UserPageVisits", UserPageVisitsImpl.class);
		classesById.put("http://schema.org/UserPlays", UserPlaysImpl.class);
		classesById.put("http://schema.org/UserPlusOnes", UserPlusOnesImpl.class);
		classesById.put("http://schema.org/UserTweets", UserTweetsImpl.class);
		classesById.put("http://schema.org/Vehicle", VehicleImpl.class);
		classesById.put("http://schema.org/Vein", VeinImpl.class);
		classesById.put("http://schema.org/Vessel", VesselImpl.class);
		classesById.put("http://schema.org/VeterinaryCare", VeterinaryCareImpl.class);
		classesById.put("http://schema.org/VideoGallery", VideoGalleryImpl.class);
		classesById.put("http://schema.org/VideoObject", VideoObjectImpl.class);
		classesById.put("http://schema.org/ViewAction", ViewActionImpl.class);
		classesById.put("http://schema.org/VisualArtsEvent", VisualArtsEventImpl.class);
		classesById.put("http://schema.org/Volcano", VolcanoImpl.class);
		classesById.put("http://schema.org/VoteAction", VoteActionImpl.class);
		classesById.put("http://schema.org/WPAdBlock", WPAdBlockImpl.class);
		classesById.put("http://schema.org/WPFooter", WPFooterImpl.class);
		classesById.put("http://schema.org/WPHeader", WPHeaderImpl.class);
		classesById.put("http://schema.org/WPSideBar", WPSideBarImpl.class);
		classesById.put("http://schema.org/WantAction", WantActionImpl.class);
		classesById.put("http://schema.org/WarrantyPromise", WarrantyPromiseImpl.class);
		classesById.put("http://schema.org/WarrantyScope", WarrantyScopeImpl.class);
		classesById.put("http://schema.org/WatchAction", WatchActionImpl.class);
		classesById.put("http://schema.org/Waterfall", WaterfallImpl.class);
		classesById.put("http://schema.org/WearAction", WearActionImpl.class);
		classesById.put("http://schema.org/WebApplication", WebApplicationImpl.class);
		classesById.put("http://schema.org/WebPage", WebPageImpl.class);
		classesById.put("http://schema.org/WebPageElement", WebPageElementImpl.class);
		classesById.put("http://schema.org/WholesaleStore", WholesaleStoreImpl.class);
		classesById.put("http://schema.org/WinAction", WinActionImpl.class);
		classesById.put("http://schema.org/Winery", WineryImpl.class);
		classesById.put("http://schema.org/WriteAction", WriteActionImpl.class);
		classesById.put("http://schema.org/Zoo", ZooImpl.class);
	}
	
	@Override
	public SchemaObject createObject(String type) throws InstantiationException, IllegalAccessException {
		Class c = classesById.get(type);
		return (SchemaObject)c.newInstance();
	}

	@Override
	public Collection<String> getSupportedTypes() {
		return classesById.keySet();
	}

}
