package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Seat;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Used to describe a seat, such as a reserved seat in an event reservation.
 */
public class SeatImpl extends SchemaObjectImpl implements Seat {


  private ThingImpl thing;

  /**
   * The location of the reserved seat (e.g., 27).
   */
  private List<String> seatNumber = new LinkedList<String>();
  
  /**
   * The row location of the reserved seat (e.g., B).
   */
  private List<String> seatRow = new LinkedList<String>();
  
  /**
   * The section location of the reserved seat (e.g. Orchestra).
   */
  private List<String> seatSection = new LinkedList<String>();
  
  /**
   * The type/class of the seat.
   */
  private List<Thing> seatingType = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public SeatImpl() {
    super("http://schema.org/Seat");
  }
  /**
   * Get a single additionalType property value for this Seat object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Seat object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this Seat object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this Seat object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this Seat object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single sameAs property value for this Seat object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seatNumber property value for this Seat object.
   *
   * @return The first seatNumber property value.
   */
  public String getSeatNumber() {
  	return this.seatNumber.isEmpty() ? null : this.seatNumber.get(0);
  }
  
  /**
   * Get a single seatRow property value for this Seat object.
   *
   * @return The first seatRow property value.
   */
  public String getSeatRow() {
  	return this.seatRow.isEmpty() ? null : this.seatRow.get(0);
  }
  
  /**
   * Get a single seatSection property value for this Seat object.
   *
   * @return The first seatSection property value.
   */
  public String getSeatSection() {
  	return this.seatSection.isEmpty() ? null : this.seatSection.get(0);
  }
  
  /**
   * Get a single seatingType property value for this Seat object.
   *
   * @return The first seatingType property value.
   */
  public Thing getSeatingType() {
  	return this.seatingType.isEmpty() ? null : this.seatingType.get(0);
  }
  
  /**
   * Get a single url property value for this Seat object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Seat object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Seat object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this Seat object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this Seat object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this Seat object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the sameAs property values for this Seat object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seatNumber property values for this Seat object.
   *
   * @return A list of seatNumber property values.
   */
  public List<String> getSeatNumbers() {
  	return this.seatNumber;
  }
  
  /**
   * Get all the seatRow property values for this Seat object.
   *
   * @return A list of seatRow property values.
   */
  public List<String> getSeatRows() {
  	return this.seatRow;
  }
  
  /**
   * Get all the seatSection property values for this Seat object.
   *
   * @return A list of seatSection property values.
   */
  public List<String> getSeatSections() {
  	return this.seatSection;
  }
  
  /**
   * Get all the seatingType property values for this Seat object.
   *
   * @return A list of seatingType property values.
   */
  public List<Thing> getSeatingTypes() {
  	return this.seatingType;
  }
  
  /**
   * Get all the url property values for this Seat object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Seat object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Seat object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this Seat object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this Seat object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this Seat object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the sameAs property value for this Seat object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seatNumber property value for this Seat object; overwriting any existing values.
   *
   * @param seatNumber The value to set.
   */
  public void setSeatNumber(String seatNumber) {
  	this.seatNumber.clear();
  	this.seatNumber.add(seatNumber);
  }
  
  /**
   * Set the seatRow property value for this Seat object; overwriting any existing values.
   *
   * @param seatRow The value to set.
   */
  public void setSeatRow(String seatRow) {
  	this.seatRow.clear();
  	this.seatRow.add(seatRow);
  }
  
  /**
   * Set the seatSection property value for this Seat object; overwriting any existing values.
   *
   * @param seatSection The value to set.
   */
  public void setSeatSection(String seatSection) {
  	this.seatSection.clear();
  	this.seatSection.add(seatSection);
  }
  
  /**
   * Set the seatingType property value for this Seat object; overwriting any existing values.
   *
   * @param seatingType The value to set.
   */
  public void setSeatingType(Thing seatingType) {
  	this.seatingType.clear();
  	this.seatingType.add(seatingType);
  }
  
  /**
   * Set the url property value for this Seat object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Seat object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Seat object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this Seat object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this Seat object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this Seat object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the sameAs property values for this Seat object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seatNumber property values for this Seat object; overwriting any existing values.
   *
   * @param seatNumbers The list of values to set.
   */
  public void setSeatNumbers(List<String> seatNumbers) {
  	this.seatNumber = seatNumbers;
  }
  
  /**
   * Set the seatRow property values for this Seat object; overwriting any existing values.
   *
   * @param seatRows The list of values to set.
   */
  public void setSeatRows(List<String> seatRows) {
  	this.seatRow = seatRows;
  }
  
  /**
   * Set the seatSection property values for this Seat object; overwriting any existing values.
   *
   * @param seatSections The list of values to set.
   */
  public void setSeatSections(List<String> seatSections) {
  	this.seatSection = seatSections;
  }
  
  /**
   * Set the seatingType property values for this Seat object; overwriting any existing values.
   *
   * @param seatingTypes The list of values to set.
   */
  public void setSeatingTypes(List<Thing> seatingTypes) {
  	this.seatingType = seatingTypes;
  }
  
  /**
   * Set the url property values for this Seat object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Seat object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Seat object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this Seat object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this Seat object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this Seat object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a sameAs property value for this Seat object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seatNumber property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatNumber The value to add.
   */
  public void addSeatNumber(String seatNumber) {
  	this.seatNumber.add(seatNumber);
  }
  
  /**
   * Adds a seatRow property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatRow The value to add.
   */
  public void addSeatRow(String seatRow) {
  	this.seatRow.add(seatRow);
  }
  
  /**
   * Adds a seatSection property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatSection The value to add.
   */
  public void addSeatSection(String seatSection) {
  	this.seatSection.add(seatSection);
  }
  
  /**
   * Adds a seatingType property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatingType The value to add.
   */
  public void addSeatingType(Thing seatingType) {
  	this.seatingType.add(seatingType);
  }
  
  /**
   * Adds a url property value for this Seat object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}