package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.ContactPoint;
import org.schema.Duration;
import org.schema.Language;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Service;
import org.schema.ServiceChannel;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A means for accessing a service, e.g. a government office location, web site, or phone number.
 */
public class ServiceChannelImpl extends SchemaObjectImpl implements ServiceChannel {


  private ThingImpl thing;

  /**
   * A language someone may use with the item.
   */
  private List<Language> availableLanguage = new LinkedList<Language>();
  
  /**
   * Estimated processing time for the service using this channel.
   */
  private List<Duration> processingTime = new LinkedList<Duration>();
  
  /**
   * The service provided by this channel.
   */
  private List<Service> providesService = new LinkedList<Service>();
  
  /**
   * The location (e.g. civic structure, local business, etc.) where a person can go to access the service.
   */
  private List<Place> serviceLocation = new LinkedList<Place>();
  
  /**
   * The phone number to use to access the service.
   */
  private List<ContactPoint> servicePhone = new LinkedList<ContactPoint>();
  
  /**
   * The address for accessing the service by mail.
   */
  private List<PostalAddress> servicePostalAddress = new LinkedList<PostalAddress>();
  
  /**
   * The number to access the service by text message.
   */
  private List<ContactPoint> serviceSmsNumber = new LinkedList<ContactPoint>();
  
  /**
   * The website to access the service.
   */
  private List<URL> serviceUrl = new LinkedList<URL>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ServiceChannelImpl() {
    super("http://schema.org/ServiceChannel");
  }
  /**
   * Get a single additionalType property value for this ServiceChannel object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this ServiceChannel object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single availableLanguage property value for this ServiceChannel object.
   *
   * @return The first availableLanguage property value.
   */
  public Language getAvailableLanguage() {
  	return this.availableLanguage.isEmpty() ? null : this.availableLanguage.get(0);
  }
  
  /**
   * Get a single description property value for this ServiceChannel object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this ServiceChannel object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this ServiceChannel object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single processingTime property value for this ServiceChannel object.
   *
   * @return The first processingTime property value.
   */
  public Duration getProcessingTime() {
  	return this.processingTime.isEmpty() ? null : this.processingTime.get(0);
  }
  
  /**
   * Get a single providesService property value for this ServiceChannel object.
   *
   * @return The first providesService property value.
   */
  public Service getProvidesService() {
  	return this.providesService.isEmpty() ? null : this.providesService.get(0);
  }
  
  /**
   * Get a single sameAs property value for this ServiceChannel object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single serviceLocation property value for this ServiceChannel object.
   *
   * @return The first serviceLocation property value.
   */
  public Place getServiceLocation() {
  	return this.serviceLocation.isEmpty() ? null : this.serviceLocation.get(0);
  }
  
  /**
   * Get a single servicePhone property value for this ServiceChannel object.
   *
   * @return The first servicePhone property value.
   */
  public ContactPoint getServicePhone() {
  	return this.servicePhone.isEmpty() ? null : this.servicePhone.get(0);
  }
  
  /**
   * Get a single servicePostalAddress property value for this ServiceChannel object.
   *
   * @return The first servicePostalAddress property value.
   */
  public PostalAddress getServicePostalAddress() {
  	return this.servicePostalAddress.isEmpty() ? null : this.servicePostalAddress.get(0);
  }
  
  /**
   * Get a single serviceSmsNumber property value for this ServiceChannel object.
   *
   * @return The first serviceSmsNumber property value.
   */
  public ContactPoint getServiceSmsNumber() {
  	return this.serviceSmsNumber.isEmpty() ? null : this.serviceSmsNumber.get(0);
  }
  
  /**
   * Get a single serviceUrl property value for this ServiceChannel object.
   *
   * @return The first serviceUrl property value.
   */
  public URL getServiceUrl() {
  	return this.serviceUrl.isEmpty() ? null : this.serviceUrl.get(0);
  }
  
  /**
   * Get a single url property value for this ServiceChannel object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this ServiceChannel object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this ServiceChannel object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the availableLanguage property values for this ServiceChannel object.
   *
   * @return A list of availableLanguage property values.
   */
  public List<Language> getAvailableLanguages() {
  	return this.availableLanguage;
  }
  
  /**
   * Get all the description property values for this ServiceChannel object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this ServiceChannel object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this ServiceChannel object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the processingTime property values for this ServiceChannel object.
   *
   * @return A list of processingTime property values.
   */
  public List<Duration> getProcessingTimes() {
  	return this.processingTime;
  }
  
  /**
   * Get all the providesService property values for this ServiceChannel object.
   *
   * @return A list of providesService property values.
   */
  public List<Service> getProvidesServices() {
  	return this.providesService;
  }
  
  /**
   * Get all the sameAs property values for this ServiceChannel object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the serviceLocation property values for this ServiceChannel object.
   *
   * @return A list of serviceLocation property values.
   */
  public List<Place> getServiceLocations() {
  	return this.serviceLocation;
  }
  
  /**
   * Get all the servicePhone property values for this ServiceChannel object.
   *
   * @return A list of servicePhone property values.
   */
  public List<ContactPoint> getServicePhones() {
  	return this.servicePhone;
  }
  
  /**
   * Get all the servicePostalAddress property values for this ServiceChannel object.
   *
   * @return A list of servicePostalAddress property values.
   */
  public List<PostalAddress> getServicePostalAddresses() {
  	return this.servicePostalAddress;
  }
  
  /**
   * Get all the serviceSmsNumber property values for this ServiceChannel object.
   *
   * @return A list of serviceSmsNumber property values.
   */
  public List<ContactPoint> getServiceSmsNumbers() {
  	return this.serviceSmsNumber;
  }
  
  /**
   * Get all the serviceUrl property values for this ServiceChannel object.
   *
   * @return A list of serviceUrl property values.
   */
  public List<URL> getServiceUrls() {
  	return this.serviceUrl;
  }
  
  /**
   * Get all the url property values for this ServiceChannel object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the availableLanguage property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param availableLanguage The value to set.
   */
  public void setAvailableLanguage(Language availableLanguage) {
  	this.availableLanguage.clear();
  	this.availableLanguage.add(availableLanguage);
  }
  
  /**
   * Set the description property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the processingTime property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param processingTime The value to set.
   */
  public void setProcessingTime(Duration processingTime) {
  	this.processingTime.clear();
  	this.processingTime.add(processingTime);
  }
  
  /**
   * Set the providesService property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param providesService The value to set.
   */
  public void setProvidesService(Service providesService) {
  	this.providesService.clear();
  	this.providesService.add(providesService);
  }
  
  /**
   * Set the sameAs property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the serviceLocation property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceLocation The value to set.
   */
  public void setServiceLocation(Place serviceLocation) {
  	this.serviceLocation.clear();
  	this.serviceLocation.add(serviceLocation);
  }
  
  /**
   * Set the servicePhone property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePhone The value to set.
   */
  public void setServicePhone(ContactPoint servicePhone) {
  	this.servicePhone.clear();
  	this.servicePhone.add(servicePhone);
  }
  
  /**
   * Set the servicePostalAddress property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePostalAddress The value to set.
   */
  public void setServicePostalAddress(PostalAddress servicePostalAddress) {
  	this.servicePostalAddress.clear();
  	this.servicePostalAddress.add(servicePostalAddress);
  }
  
  /**
   * Set the serviceSmsNumber property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceSmsNumber The value to set.
   */
  public void setServiceSmsNumber(ContactPoint serviceSmsNumber) {
  	this.serviceSmsNumber.clear();
  	this.serviceSmsNumber.add(serviceSmsNumber);
  }
  
  /**
   * Set the serviceUrl property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceUrl The value to set.
   */
  public void setServiceUrl(URL serviceUrl) {
  	this.serviceUrl.clear();
  	this.serviceUrl.add(serviceUrl);
  }
  
  /**
   * Set the url property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the availableLanguage property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param availableLanguages The list of values to set.
   */
  public void setAvailableLanguages(List<Language> availableLanguages) {
  	this.availableLanguage = availableLanguages;
  }
  
  /**
   * Set the description property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the processingTime property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param processingTimes The list of values to set.
   */
  public void setProcessingTimes(List<Duration> processingTimes) {
  	this.processingTime = processingTimes;
  }
  
  /**
   * Set the providesService property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param providesServices The list of values to set.
   */
  public void setProvidesServices(List<Service> providesServices) {
  	this.providesService = providesServices;
  }
  
  /**
   * Set the sameAs property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the serviceLocation property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceLocations The list of values to set.
   */
  public void setServiceLocations(List<Place> serviceLocations) {
  	this.serviceLocation = serviceLocations;
  }
  
  /**
   * Set the servicePhone property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePhones The list of values to set.
   */
  public void setServicePhones(List<ContactPoint> servicePhones) {
  	this.servicePhone = servicePhones;
  }
  
  /**
   * Set the servicePostalAddress property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePostalAddresses The list of values to set.
   */
  public void setServicePostalAddresses(List<PostalAddress> servicePostalAddresses) {
  	this.servicePostalAddress = servicePostalAddresses;
  }
  
  /**
   * Set the serviceSmsNumber property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceSmsNumbers The list of values to set.
   */
  public void setServiceSmsNumbers(List<ContactPoint> serviceSmsNumbers) {
  	this.serviceSmsNumber = serviceSmsNumbers;
  }
  
  /**
   * Set the serviceUrl property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceUrls The list of values to set.
   */
  public void setServiceUrls(List<URL> serviceUrls) {
  	this.serviceUrl = serviceUrls;
  }
  
  /**
   * Set the url property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a availableLanguage property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param availableLanguage The value to add.
   */
  public void addAvailableLanguage(Language availableLanguage) {
  	this.availableLanguage.add(availableLanguage);
  }
  
  /**
   * Adds a description property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a processingTime property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param processingTime The value to add.
   */
  public void addProcessingTime(Duration processingTime) {
  	this.processingTime.add(processingTime);
  }
  
  /**
   * Adds a providesService property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param providesService The value to add.
   */
  public void addProvidesService(Service providesService) {
  	this.providesService.add(providesService);
  }
  
  /**
   * Adds a sameAs property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a serviceLocation property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param serviceLocation The value to add.
   */
  public void addServiceLocation(Place serviceLocation) {
  	this.serviceLocation.add(serviceLocation);
  }
  
  /**
   * Adds a servicePhone property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param servicePhone The value to add.
   */
  public void addServicePhone(ContactPoint servicePhone) {
  	this.servicePhone.add(servicePhone);
  }
  
  /**
   * Adds a servicePostalAddress property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param servicePostalAddress The value to add.
   */
  public void addServicePostalAddress(PostalAddress servicePostalAddress) {
  	this.servicePostalAddress.add(servicePostalAddress);
  }
  
  /**
   * Adds a serviceSmsNumber property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param serviceSmsNumber The value to add.
   */
  public void addServiceSmsNumber(ContactPoint serviceSmsNumber) {
  	this.serviceSmsNumber.add(serviceSmsNumber);
  }
  
  /**
   * Adds a serviceUrl property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param serviceUrl The value to add.
   */
  public void addServiceUrl(URL serviceUrl) {
  	this.serviceUrl.add(serviceUrl);
  }
  
  /**
   * Adds a url property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}