package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.Audience;
import org.schema.Service;
import org.schema.ServiceChannel;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A service provided by an organization, e.g. delivery service, print services, etc.
 */
public class ServiceImpl extends SchemaObjectImpl implements Service {


  private ThingImpl thing;

  /**
   * A means of accessing the service (e.g. a phone bank, a web site, a location, etc.)
   */
  private List<ServiceChannel> availableChannel = new LinkedList<ServiceChannel>();
  
  /**
   * The tangible thing generated by the service, e.g. a passport, permit, etc.
   */
  private List<Thing> produces = new LinkedList<Thing>();
  
  /**
   * The organization or agency that is providing the service.
   */
  private List<Thing> provider = new LinkedList<Thing>();
  
  /**
   * The geographic area where the service is provided.
   */
  private List<AdministrativeArea> serviceArea = new LinkedList<AdministrativeArea>();
  
  /**
   * The audience eligible for this service.
   */
  private List<Audience> serviceAudience = new LinkedList<Audience>();
  
  /**
   * The type of service being offered, e.g. veterans' benefits, emergency relief, etc.
   */
  private List<String> serviceType = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ServiceImpl() {
    super("http://schema.org/Service");
  }
  /**
   * Get a single additionalType property value for this Service object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Service object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single availableChannel property value for this Service object.
   *
   * @return The first availableChannel property value.
   */
  public ServiceChannel getAvailableChannel() {
  	return this.availableChannel.isEmpty() ? null : this.availableChannel.get(0);
  }
  
  /**
   * Get a single description property value for this Service object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this Service object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this Service object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single produces property value for this Service object.
   *
   * @return The first produces property value.
   */
  public Thing getProduces() {
  	return this.produces.isEmpty() ? null : this.produces.get(0);
  }
  
  /**
   * Get a single provider property value for this Service object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
  	return this.provider.isEmpty() ? null : this.provider.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Service object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single serviceArea property value for this Service object.
   *
   * @return The first serviceArea property value.
   */
  public AdministrativeArea getServiceArea() {
  	return this.serviceArea.isEmpty() ? null : this.serviceArea.get(0);
  }
  
  /**
   * Get a single serviceAudience property value for this Service object.
   *
   * @return The first serviceAudience property value.
   */
  public Audience getServiceAudience() {
  	return this.serviceAudience.isEmpty() ? null : this.serviceAudience.get(0);
  }
  
  /**
   * Get a single serviceType property value for this Service object.
   *
   * @return The first serviceType property value.
   */
  public String getServiceType() {
  	return this.serviceType.isEmpty() ? null : this.serviceType.get(0);
  }
  
  /**
   * Get a single url property value for this Service object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Service object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Service object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the availableChannel property values for this Service object.
   *
   * @return A list of availableChannel property values.
   */
  public List<ServiceChannel> getAvailableChannels() {
  	return this.availableChannel;
  }
  
  /**
   * Get all the description property values for this Service object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this Service object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this Service object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the produces property values for this Service object.
   *
   * @return A list of produces property values.
   */
  public List<Thing> getProducess() {
  	return this.produces;
  }
  
  /**
   * Get all the provider property values for this Service object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
  	return this.provider;
  }
  
  /**
   * Get all the sameAs property values for this Service object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the serviceArea property values for this Service object.
   *
   * @return A list of serviceArea property values.
   */
  public List<AdministrativeArea> getServiceAreas() {
  	return this.serviceArea;
  }
  
  /**
   * Get all the serviceAudience property values for this Service object.
   *
   * @return A list of serviceAudience property values.
   */
  public List<Audience> getServiceAudiences() {
  	return this.serviceAudience;
  }
  
  /**
   * Get all the serviceType property values for this Service object.
   *
   * @return A list of serviceType property values.
   */
  public List<String> getServiceTypes() {
  	return this.serviceType;
  }
  
  /**
   * Get all the url property values for this Service object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Service object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Service object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the availableChannel property value for this Service object; overwriting any existing values.
   *
   * @param availableChannel The value to set.
   */
  public void setAvailableChannel(ServiceChannel availableChannel) {
  	this.availableChannel.clear();
  	this.availableChannel.add(availableChannel);
  }
  
  /**
   * Set the description property value for this Service object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this Service object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this Service object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the produces property value for this Service object; overwriting any existing values.
   *
   * @param produces The value to set.
   */
  public void setProduces(Thing produces) {
  	this.produces.clear();
  	this.produces.add(produces);
  }
  
  /**
   * Set the provider property value for this Service object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
  	this.provider.clear();
  	this.provider.add(provider);
  }
  
  /**
   * Set the sameAs property value for this Service object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the serviceArea property value for this Service object; overwriting any existing values.
   *
   * @param serviceArea The value to set.
   */
  public void setServiceArea(AdministrativeArea serviceArea) {
  	this.serviceArea.clear();
  	this.serviceArea.add(serviceArea);
  }
  
  /**
   * Set the serviceAudience property value for this Service object; overwriting any existing values.
   *
   * @param serviceAudience The value to set.
   */
  public void setServiceAudience(Audience serviceAudience) {
  	this.serviceAudience.clear();
  	this.serviceAudience.add(serviceAudience);
  }
  
  /**
   * Set the serviceType property value for this Service object; overwriting any existing values.
   *
   * @param serviceType The value to set.
   */
  public void setServiceType(String serviceType) {
  	this.serviceType.clear();
  	this.serviceType.add(serviceType);
  }
  
  /**
   * Set the url property value for this Service object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Service object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Service object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the availableChannel property values for this Service object; overwriting any existing values.
   *
   * @param availableChannels The list of values to set.
   */
  public void setAvailableChannels(List<ServiceChannel> availableChannels) {
  	this.availableChannel = availableChannels;
  }
  
  /**
   * Set the description property values for this Service object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this Service object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this Service object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the produces property values for this Service object; overwriting any existing values.
   *
   * @param producess The list of values to set.
   */
  public void setProducess(List<Thing> producess) {
  	this.produces = producess;
  }
  
  /**
   * Set the provider property values for this Service object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
  	this.provider = providers;
  }
  
  /**
   * Set the sameAs property values for this Service object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the serviceArea property values for this Service object; overwriting any existing values.
   *
   * @param serviceAreas The list of values to set.
   */
  public void setServiceAreas(List<AdministrativeArea> serviceAreas) {
  	this.serviceArea = serviceAreas;
  }
  
  /**
   * Set the serviceAudience property values for this Service object; overwriting any existing values.
   *
   * @param serviceAudiences The list of values to set.
   */
  public void setServiceAudiences(List<Audience> serviceAudiences) {
  	this.serviceAudience = serviceAudiences;
  }
  
  /**
   * Set the serviceType property values for this Service object; overwriting any existing values.
   *
   * @param serviceTypes The list of values to set.
   */
  public void setServiceTypes(List<String> serviceTypes) {
  	this.serviceType = serviceTypes;
  }
  
  /**
   * Set the url property values for this Service object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Service object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Service object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a availableChannel property value for this Service object; appending it to the list of existing values.
   *
   * @param availableChannel The value to add.
   */
  public void addAvailableChannel(ServiceChannel availableChannel) {
  	this.availableChannel.add(availableChannel);
  }
  
  /**
   * Adds a description property value for this Service object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this Service object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this Service object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a produces property value for this Service object; appending it to the list of existing values.
   *
   * @param produces The value to add.
   */
  public void addProduces(Thing produces) {
  	this.produces.add(produces);
  }
  
  /**
   * Adds a provider property value for this Service object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
  	this.provider.add(provider);
  }
  
  /**
   * Adds a sameAs property value for this Service object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a serviceArea property value for this Service object; appending it to the list of existing values.
   *
   * @param serviceArea The value to add.
   */
  public void addServiceArea(AdministrativeArea serviceArea) {
  	this.serviceArea.add(serviceArea);
  }
  
  /**
   * Adds a serviceAudience property value for this Service object; appending it to the list of existing values.
   *
   * @param serviceAudience The value to add.
   */
  public void addServiceAudience(Audience serviceAudience) {
  	this.serviceAudience.add(serviceAudience);
  }
  
  /**
   * Adds a serviceType property value for this Service object; appending it to the list of existing values.
   *
   * @param serviceType The value to add.
   */
  public void addServiceType(String serviceType) {
  	this.serviceType.add(serviceType);
  }
  
  /**
   * Adds a url property value for this Service object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}