package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.MedicalCode;
import org.schema.MedicalContraindication;
import org.schema.MedicalEntity;
import org.schema.MedicalGuideline;
import org.schema.MedicalIndication;
import org.schema.MedicalProcedureType;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.TherapeuticProcedure;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A medical procedure intended primarly for therapeutic purposes, aimed at improving a health condition.
 */
public class TherapeuticProcedureImpl extends SchemaObjectImpl implements TherapeuticProcedure {


  private MedicalEntityImpl medicalEntity;
  private MedicalProcedureImpl medicalProcedure;
  private MedicalTherapyImpl medicalTherapy;
  private ThingImpl thing;

  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public TherapeuticProcedureImpl() {
    super("http://schema.org/TherapeuticProcedure");
    medicalProcedure = new MedicalProcedureImpl();
    medicalTherapy = new MedicalTherapyImpl();
  }
  /**
   * Get a single additionalType property value for this TherapeuticProcedure object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single adverseOutcome property value for this TherapeuticProcedure object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome() {
    return medicalTherapy.getAdverseOutcome();
  }
  
  /**
   * Get a single alternateName property value for this TherapeuticProcedure object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single code property value for this TherapeuticProcedure object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single contraindication property value for this TherapeuticProcedure object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication() {
    return medicalTherapy.getContraindication();
  }
  
  /**
   * Get a single description property value for this TherapeuticProcedure object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single duplicateTherapy property value for this TherapeuticProcedure object.
   *
   * @return The first duplicateTherapy property value.
   */
  public MedicalTherapy getDuplicateTherapy() {
    return medicalTherapy.getDuplicateTherapy();
  }
  
  /**
   * Get a single followup property value for this TherapeuticProcedure object.
   *
   * @return The first followup property value.
   */
  public String getFollowup() {
    return medicalProcedure.getFollowup();
  }
  
  /**
   * Get a single guideline property value for this TherapeuticProcedure object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single howPerformed property value for this TherapeuticProcedure object.
   *
   * @return The first howPerformed property value.
   */
  public String getHowPerformed() {
    return medicalProcedure.getHowPerformed();
  }
  
  /**
   * Get a single image property value for this TherapeuticProcedure object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single indication property value for this TherapeuticProcedure object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication() {
    return medicalTherapy.getIndication();
  }
  
  /**
   * Get a single medicineSystem property value for this TherapeuticProcedure object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this TherapeuticProcedure object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single preparation property value for this TherapeuticProcedure object.
   *
   * @return The first preparation property value.
   */
  public String getPreparation() {
    return medicalProcedure.getPreparation();
  }
  
  /**
   * Get a single procedureType property value for this TherapeuticProcedure object.
   *
   * @return The first procedureType property value.
   */
  public MedicalProcedureType getProcedureType() {
    return medicalProcedure.getProcedureType();
  }
  
  /**
   * Get a single recognizingAuthority property value for this TherapeuticProcedure object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single relevantSpecialty property value for this TherapeuticProcedure object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this TherapeuticProcedure object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single seriousAdverseOutcome property value for this TherapeuticProcedure object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome() {
    return medicalTherapy.getSeriousAdverseOutcome();
  }
  
  /**
   * Get a single study property value for this TherapeuticProcedure object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single url property value for this TherapeuticProcedure object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this TherapeuticProcedure object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the adverseOutcome property values for this TherapeuticProcedure object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes() {
    return medicalTherapy.getAdverseOutcomes();
  }
  
  /**
   * Get all the alternateName property values for this TherapeuticProcedure object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the code property values for this TherapeuticProcedure object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the contraindication property values for this TherapeuticProcedure object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications() {
    return medicalTherapy.getContraindications();
  }
  
  /**
   * Get all the description property values for this TherapeuticProcedure object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the duplicateTherapy property values for this TherapeuticProcedure object.
   *
   * @return A list of duplicateTherapy property values.
   */
  public List<MedicalTherapy> getDuplicateTherapies() {
    return medicalTherapy.getDuplicateTherapies();
  }
  
  /**
   * Get all the followup property values for this TherapeuticProcedure object.
   *
   * @return A list of followup property values.
   */
  public List<String> getFollowups() {
    return medicalProcedure.getFollowups();
  }
  
  /**
   * Get all the guideline property values for this TherapeuticProcedure object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the howPerformed property values for this TherapeuticProcedure object.
   *
   * @return A list of howPerformed property values.
   */
  public List<String> getHowPerformeds() {
    return medicalProcedure.getHowPerformeds();
  }
  
  /**
   * Get all the image property values for this TherapeuticProcedure object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the indication property values for this TherapeuticProcedure object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications() {
    return medicalTherapy.getIndications();
  }
  
  /**
   * Get all the medicineSystem property values for this TherapeuticProcedure object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this TherapeuticProcedure object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the preparation property values for this TherapeuticProcedure object.
   *
   * @return A list of preparation property values.
   */
  public List<String> getPreparations() {
    return medicalProcedure.getPreparations();
  }
  
  /**
   * Get all the procedureType property values for this TherapeuticProcedure object.
   *
   * @return A list of procedureType property values.
   */
  public List<MedicalProcedureType> getProcedureTypes() {
    return medicalProcedure.getProcedureTypes();
  }
  
  /**
   * Get all the recognizingAuthority property values for this TherapeuticProcedure object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the relevantSpecialty property values for this TherapeuticProcedure object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this TherapeuticProcedure object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the seriousAdverseOutcome property values for this TherapeuticProcedure object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes() {
    return medicalTherapy.getSeriousAdverseOutcomes();
  }
  
  /**
   * Get all the study property values for this TherapeuticProcedure object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the url property values for this TherapeuticProcedure object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the adverseOutcome property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.setAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Set the alternateName property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the code property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the contraindication property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication) {
    medicalTherapy.setContraindication(contraindication);
  }
  
  /**
   * Set the description property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the duplicateTherapy property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param duplicateTherapy The value to set.
   */
  public void setDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.setDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Set the followup property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param followup The value to set.
   */
  public void setFollowup(String followup) {
    medicalProcedure.setFollowup(followup);
  }
  
  /**
   * Set the guideline property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the howPerformed property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param howPerformed The value to set.
   */
  public void setHowPerformed(String howPerformed) {
    medicalProcedure.setHowPerformed(howPerformed);
  }
  
  /**
   * Set the image property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the indication property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication) {
    medicalTherapy.setIndication(indication);
  }
  
  /**
   * Set the medicineSystem property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the preparation property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param preparation The value to set.
   */
  public void setPreparation(String preparation) {
    medicalProcedure.setPreparation(preparation);
  }
  
  /**
   * Set the procedureType property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param procedureType The value to set.
   */
  public void setProcedureType(MedicalProcedureType procedureType) {
    medicalProcedure.setProcedureType(procedureType);
  }
  
  /**
   * Set the recognizingAuthority property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the relevantSpecialty property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the seriousAdverseOutcome property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.setSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Set the study property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the url property value for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the adverseOutcome property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes) {
    medicalTherapy.setAdverseOutcomes(adverseOutcomes);
  }
  
  /**
   * Set the alternateName property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the code property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the contraindication property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications) {
    medicalTherapy.setContraindications(contraindications);
  }
  
  /**
   * Set the description property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the duplicateTherapy property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param duplicateTherapies The list of values to set.
   */
  public void setDuplicateTherapies(List<MedicalTherapy> duplicateTherapies) {
    medicalTherapy.setDuplicateTherapies(duplicateTherapies);
  }
  
  /**
   * Set the followup property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param followups The list of values to set.
   */
  public void setFollowups(List<String> followups) {
    medicalProcedure.setFollowups(followups);
  }
  
  /**
   * Set the guideline property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the howPerformed property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param howPerformeds The list of values to set.
   */
  public void setHowPerformeds(List<String> howPerformeds) {
    medicalProcedure.setHowPerformeds(howPerformeds);
  }
  
  /**
   * Set the image property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the indication property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications) {
    medicalTherapy.setIndications(indications);
  }
  
  /**
   * Set the medicineSystem property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the preparation property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param preparations The list of values to set.
   */
  public void setPreparations(List<String> preparations) {
    medicalProcedure.setPreparations(preparations);
  }
  
  /**
   * Set the procedureType property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param procedureTypes The list of values to set.
   */
  public void setProcedureTypes(List<MedicalProcedureType> procedureTypes) {
    medicalProcedure.setProcedureTypes(procedureTypes);
  }
  
  /**
   * Set the recognizingAuthority property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the relevantSpecialty property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the seriousAdverseOutcome property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes) {
    medicalTherapy.setSeriousAdverseOutcomes(seriousAdverseOutcomes);
  }
  
  /**
   * Set the study property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the url property values for this TherapeuticProcedure object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a adverseOutcome property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome) {
    medicalTherapy.addAdverseOutcome(adverseOutcome);
  }
  
  /**
   * Adds a alternateName property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a code property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a contraindication property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication) {
    medicalTherapy.addContraindication(contraindication);
  }
  
  /**
   * Adds a description property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a duplicateTherapy property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param duplicateTherapy The value to add.
   */
  public void addDuplicateTherapy(MedicalTherapy duplicateTherapy) {
    medicalTherapy.addDuplicateTherapy(duplicateTherapy);
  }
  
  /**
   * Adds a followup property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param followup The value to add.
   */
  public void addFollowup(String followup) {
    medicalProcedure.addFollowup(followup);
  }
  
  /**
   * Adds a guideline property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a howPerformed property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param howPerformed The value to add.
   */
  public void addHowPerformed(String howPerformed) {
    medicalProcedure.addHowPerformed(howPerformed);
  }
  
  /**
   * Adds a image property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a indication property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication) {
    medicalTherapy.addIndication(indication);
  }
  
  /**
   * Adds a medicineSystem property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a preparation property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param preparation The value to add.
   */
  public void addPreparation(String preparation) {
    medicalProcedure.addPreparation(preparation);
  }
  
  /**
   * Adds a procedureType property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param procedureType The value to add.
   */
  public void addProcedureType(MedicalProcedureType procedureType) {
    medicalProcedure.addProcedureType(procedureType);
  }
  
  /**
   * Adds a recognizingAuthority property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a relevantSpecialty property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a seriousAdverseOutcome property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome) {
    medicalTherapy.addSeriousAdverseOutcome(seriousAdverseOutcome);
  }
  
  /**
   * Adds a study property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a url property value for this TherapeuticProcedure object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}