package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.Thing;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * The most generic type of item.
 */
public class ThingImpl extends SchemaObjectImpl implements Thing {



  /**
   * An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in. In RDFa syntax, it is better to use the native RDFa syntax - the 'typeof' attribute - for multiple types. Schema.org tools may have only weaker understanding of extra types, in particular those defined externally.
   */
  private List<URL> additionalType = new LinkedList<URL>();
  
  /**
   * An alias for the item.
   */
  private List<String> alternateName = new LinkedList<String>();
  
  /**
   * A short description of the item.
   */
  private List<String> description = new LinkedList<String>();
  
  /**
   * URL of an image of the item.
   */
  private List<URL> image = new LinkedList<URL>();
  
  /**
   * The name of the item.
   */
  private List<String> name = new LinkedList<String>();
  
  /**
   * URL of a reference Web page that unambiguously indicates the item's identity. E.g. the URL of the item's Wikipedia page, Freebase page, or official website.
   */
  private List<URL> sameAs = new LinkedList<URL>();
  
  /**
   * URL of the item.
   */
  private List<URL> url = new LinkedList<URL>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public ThingImpl() {
    super("http://schema.org/Thing");
  }
  /**
   * Get a single additionalType property value for this Thing object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
  	return this.additionalType.isEmpty() ? null : this.additionalType.get(0);
  }
  
  /**
   * Get a single alternateName property value for this Thing object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
  	return this.alternateName.isEmpty() ? null : this.alternateName.get(0);
  }
  
  /**
   * Get a single description property value for this Thing object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
  	return this.description.isEmpty() ? null : this.description.get(0);
  }
  
  /**
   * Get a single image property value for this Thing object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
  	return this.image.isEmpty() ? null : this.image.get(0);
  }
  
  /**
   * Get a single name property value for this Thing object.
   *
   * @return The first name property value.
   */
  public String getName() {
  	return this.name.isEmpty() ? null : this.name.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Thing object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
  	return this.sameAs.isEmpty() ? null : this.sameAs.get(0);
  }
  
  /**
   * Get a single url property value for this Thing object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
  	return this.url.isEmpty() ? null : this.url.get(0);
  }
  
  /**
   * Get all the additionalType property values for this Thing object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
  	return this.additionalType;
  }
  
  /**
   * Get all the alternateName property values for this Thing object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
  	return this.alternateName;
  }
  
  /**
   * Get all the description property values for this Thing object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
  	return this.description;
  }
  
  /**
   * Get all the image property values for this Thing object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
  	return this.image;
  }
  
  /**
   * Get all the name property values for this Thing object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
  	return this.name;
  }
  
  /**
   * Get all the sameAs property values for this Thing object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
  	return this.sameAs;
  }
  
  /**
   * Get all the url property values for this Thing object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
  	return this.url;
  }
  
  /**
   * Set the additionalType property value for this Thing object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
  	this.additionalType.clear();
  	this.additionalType.add(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Thing object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
  	this.alternateName.clear();
  	this.alternateName.add(alternateName);
  }
  
  /**
   * Set the description property value for this Thing object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
  	this.description.clear();
  	this.description.add(description);
  }
  
  /**
   * Set the image property value for this Thing object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
  	this.image.clear();
  	this.image.add(image);
  }
  
  /**
   * Set the name property value for this Thing object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
  	this.name.clear();
  	this.name.add(name);
  }
  
  /**
   * Set the sameAs property value for this Thing object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
  	this.sameAs.clear();
  	this.sameAs.add(sameAs);
  }
  
  /**
   * Set the url property value for this Thing object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
  	this.url.clear();
  	this.url.add(url);
  }
  
  /**
   * Set the additionalType property values for this Thing object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
  	this.additionalType = additionalTypes;
  }
  
  /**
   * Set the alternateName property values for this Thing object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
  	this.alternateName = alternateNames;
  }
  
  /**
   * Set the description property values for this Thing object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
  	this.description = descriptions;
  }
  
  /**
   * Set the image property values for this Thing object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
  	this.image = images;
  }
  
  /**
   * Set the name property values for this Thing object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
  	this.name = names;
  }
  
  /**
   * Set the sameAs property values for this Thing object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
  	this.sameAs = sameAss;
  }
  
  /**
   * Set the url property values for this Thing object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
  	this.url = urls;
  }
  
  /**
   * Adds a additionalType property value for this Thing object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
  	this.additionalType.add(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Thing object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
  	this.alternateName.add(alternateName);
  }
  
  /**
   * Adds a description property value for this Thing object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
  	this.description.add(description);
  }
  
  /**
   * Adds a image property value for this Thing object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
  	this.image.add(image);
  }
  
  /**
   * Adds a name property value for this Thing object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
  	this.name.add(name);
  }
  
  /**
   * Adds a sameAs property value for this Thing object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
  	this.sameAs.add(sameAs);
  }
  
  /**
   * Adds a url property value for this Thing object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
  	this.url.add(url);
  }
  
}