package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Organization;
import org.schema.Seat;
import org.schema.Thing;
import org.schema.Ticket;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * Used to describe a ticket to an event, a flight, a bus ride, etc.
 */
public class TicketImpl extends SchemaObjectImpl implements Ticket {


  private ThingImpl thing;

  /**
   * The date the ticket was issued.
   */
  private List<Date> dateIssued = new LinkedList<Date>();
  
  /**
   * The organization issuing the ticket or permit.
   */
  private List<Organization> issuedBy = new LinkedList<Organization>();
  
  /**
   * The currency (in 3-letter ISO 4217 format) of the price or a price component, when attached to PriceSpecification and its subtypes.
   */
  private List<String> priceCurrency = new LinkedList<String>();
  
  /**
   * The unique identifier for the ticket.
   */
  private List<String> ticketNumber = new LinkedList<String>();
  
  /**
   * Reference to an asset (e.g., Barcode, QR code image or PDF) usable for entrance.
   */
  private List<Thing> ticketToken = new LinkedList<Thing>();
  
  /**
   * The seat associated with the ticket.
   */
  private List<Seat> ticketedSeat = new LinkedList<Seat>();
  
  /**
   * The total price for the reservation or ticket, including applicable taxes, shipping, etc.
   */
  private List<Thing> totalPrice = new LinkedList<Thing>();
  
  /**
   * The person or organization the reservation or ticket is for.
   */
  private List<Thing> underName = new LinkedList<Thing>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public TicketImpl() {
    super("http://schema.org/Ticket");
  }
  /**
   * Get a single additionalType property value for this Ticket object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Ticket object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single dateIssued property value for this Ticket object.
   *
   * @return The first dateIssued property value.
   */
  public Date getDateIssued() {
  	return this.dateIssued.isEmpty() ? null : this.dateIssued.get(0);
  }
  
  /**
   * Get a single description property value for this Ticket object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this Ticket object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single issuedBy property value for this Ticket object.
   *
   * @return The first issuedBy property value.
   */
  public Organization getIssuedBy() {
  	return this.issuedBy.isEmpty() ? null : this.issuedBy.get(0);
  }
  
  /**
   * Get a single name property value for this Ticket object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single priceCurrency property value for this Ticket object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency() {
  	return this.priceCurrency.isEmpty() ? null : this.priceCurrency.get(0);
  }
  
  /**
   * Get a single sameAs property value for this Ticket object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single ticketNumber property value for this Ticket object.
   *
   * @return The first ticketNumber property value.
   */
  public String getTicketNumber() {
  	return this.ticketNumber.isEmpty() ? null : this.ticketNumber.get(0);
  }
  
  /**
   * Get a single ticketToken property value for this Ticket object.
   *
   * @return The first ticketToken property value.
   */
  public Thing getTicketToken() {
  	return this.ticketToken.isEmpty() ? null : this.ticketToken.get(0);
  }
  
  /**
   * Get a single ticketedSeat property value for this Ticket object.
   *
   * @return The first ticketedSeat property value.
   */
  public Seat getTicketedSeat() {
  	return this.ticketedSeat.isEmpty() ? null : this.ticketedSeat.get(0);
  }
  
  /**
   * Get a single totalPrice property value for this Ticket object.
   *
   * @return The first totalPrice property value.
   */
  public Thing getTotalPrice() {
  	return this.totalPrice.isEmpty() ? null : this.totalPrice.get(0);
  }
  
  /**
   * Get a single underName property value for this Ticket object.
   *
   * @return The first underName property value.
   */
  public Thing getUnderName() {
  	return this.underName.isEmpty() ? null : this.underName.get(0);
  }
  
  /**
   * Get a single url property value for this Ticket object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Ticket object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Ticket object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the dateIssued property values for this Ticket object.
   *
   * @return A list of dateIssued property values.
   */
  public List<Date> getDateIssueds() {
  	return this.dateIssued;
  }
  
  /**
   * Get all the description property values for this Ticket object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this Ticket object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the issuedBy property values for this Ticket object.
   *
   * @return A list of issuedBy property values.
   */
  public List<Organization> getIssuedBies() {
  	return this.issuedBy;
  }
  
  /**
   * Get all the name property values for this Ticket object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the priceCurrency property values for this Ticket object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies() {
  	return this.priceCurrency;
  }
  
  /**
   * Get all the sameAs property values for this Ticket object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the ticketNumber property values for this Ticket object.
   *
   * @return A list of ticketNumber property values.
   */
  public List<String> getTicketNumbers() {
  	return this.ticketNumber;
  }
  
  /**
   * Get all the ticketToken property values for this Ticket object.
   *
   * @return A list of ticketToken property values.
   */
  public List<Thing> getTicketTokens() {
  	return this.ticketToken;
  }
  
  /**
   * Get all the ticketedSeat property values for this Ticket object.
   *
   * @return A list of ticketedSeat property values.
   */
  public List<Seat> getTicketedSeats() {
  	return this.ticketedSeat;
  }
  
  /**
   * Get all the totalPrice property values for this Ticket object.
   *
   * @return A list of totalPrice property values.
   */
  public List<Thing> getTotalPrices() {
  	return this.totalPrice;
  }
  
  /**
   * Get all the underName property values for this Ticket object.
   *
   * @return A list of underName property values.
   */
  public List<Thing> getUnderNames() {
  	return this.underName;
  }
  
  /**
   * Get all the url property values for this Ticket object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Ticket object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Ticket object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the dateIssued property value for this Ticket object; overwriting any existing values.
   *
   * @param dateIssued The value to set.
   */
  public void setDateIssued(Date dateIssued) {
  	this.dateIssued.clear();
  	this.dateIssued.add(dateIssued);
  }
  
  /**
   * Set the description property value for this Ticket object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this Ticket object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the issuedBy property value for this Ticket object; overwriting any existing values.
   *
   * @param issuedBy The value to set.
   */
  public void setIssuedBy(Organization issuedBy) {
  	this.issuedBy.clear();
  	this.issuedBy.add(issuedBy);
  }
  
  /**
   * Set the name property value for this Ticket object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the priceCurrency property value for this Ticket object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency) {
  	this.priceCurrency.clear();
  	this.priceCurrency.add(priceCurrency);
  }
  
  /**
   * Set the sameAs property value for this Ticket object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the ticketNumber property value for this Ticket object; overwriting any existing values.
   *
   * @param ticketNumber The value to set.
   */
  public void setTicketNumber(String ticketNumber) {
  	this.ticketNumber.clear();
  	this.ticketNumber.add(ticketNumber);
  }
  
  /**
   * Set the ticketToken property value for this Ticket object; overwriting any existing values.
   *
   * @param ticketToken The value to set.
   */
  public void setTicketToken(Thing ticketToken) {
  	this.ticketToken.clear();
  	this.ticketToken.add(ticketToken);
  }
  
  /**
   * Set the ticketedSeat property value for this Ticket object; overwriting any existing values.
   *
   * @param ticketedSeat The value to set.
   */
  public void setTicketedSeat(Seat ticketedSeat) {
  	this.ticketedSeat.clear();
  	this.ticketedSeat.add(ticketedSeat);
  }
  
  /**
   * Set the totalPrice property value for this Ticket object; overwriting any existing values.
   *
   * @param totalPrice The value to set.
   */
  public void setTotalPrice(Thing totalPrice) {
  	this.totalPrice.clear();
  	this.totalPrice.add(totalPrice);
  }
  
  /**
   * Set the underName property value for this Ticket object; overwriting any existing values.
   *
   * @param underName The value to set.
   */
  public void setUnderName(Thing underName) {
  	this.underName.clear();
  	this.underName.add(underName);
  }
  
  /**
   * Set the url property value for this Ticket object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Ticket object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Ticket object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the dateIssued property values for this Ticket object; overwriting any existing values.
   *
   * @param dateIssueds The list of values to set.
   */
  public void setDateIssueds(List<Date> dateIssueds) {
  	this.dateIssued = dateIssueds;
  }
  
  /**
   * Set the description property values for this Ticket object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this Ticket object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the issuedBy property values for this Ticket object; overwriting any existing values.
   *
   * @param issuedBies The list of values to set.
   */
  public void setIssuedBies(List<Organization> issuedBies) {
  	this.issuedBy = issuedBies;
  }
  
  /**
   * Set the name property values for this Ticket object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the priceCurrency property values for this Ticket object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies) {
  	this.priceCurrency = priceCurrencies;
  }
  
  /**
   * Set the sameAs property values for this Ticket object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the ticketNumber property values for this Ticket object; overwriting any existing values.
   *
   * @param ticketNumbers The list of values to set.
   */
  public void setTicketNumbers(List<String> ticketNumbers) {
  	this.ticketNumber = ticketNumbers;
  }
  
  /**
   * Set the ticketToken property values for this Ticket object; overwriting any existing values.
   *
   * @param ticketTokens The list of values to set.
   */
  public void setTicketTokens(List<Thing> ticketTokens) {
  	this.ticketToken = ticketTokens;
  }
  
  /**
   * Set the ticketedSeat property values for this Ticket object; overwriting any existing values.
   *
   * @param ticketedSeats The list of values to set.
   */
  public void setTicketedSeats(List<Seat> ticketedSeats) {
  	this.ticketedSeat = ticketedSeats;
  }
  
  /**
   * Set the totalPrice property values for this Ticket object; overwriting any existing values.
   *
   * @param totalPrices The list of values to set.
   */
  public void setTotalPrices(List<Thing> totalPrices) {
  	this.totalPrice = totalPrices;
  }
  
  /**
   * Set the underName property values for this Ticket object; overwriting any existing values.
   *
   * @param underNames The list of values to set.
   */
  public void setUnderNames(List<Thing> underNames) {
  	this.underName = underNames;
  }
  
  /**
   * Set the url property values for this Ticket object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Ticket object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Ticket object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a dateIssued property value for this Ticket object; appending it to the list of existing values.
   *
   * @param dateIssued The value to add.
   */
  public void addDateIssued(Date dateIssued) {
  	this.dateIssued.add(dateIssued);
  }
  
  /**
   * Adds a description property value for this Ticket object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this Ticket object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a issuedBy property value for this Ticket object; appending it to the list of existing values.
   *
   * @param issuedBy The value to add.
   */
  public void addIssuedBy(Organization issuedBy) {
  	this.issuedBy.add(issuedBy);
  }
  
  /**
   * Adds a name property value for this Ticket object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a priceCurrency property value for this Ticket object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency) {
  	this.priceCurrency.add(priceCurrency);
  }
  
  /**
   * Adds a sameAs property value for this Ticket object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a ticketNumber property value for this Ticket object; appending it to the list of existing values.
   *
   * @param ticketNumber The value to add.
   */
  public void addTicketNumber(String ticketNumber) {
  	this.ticketNumber.add(ticketNumber);
  }
  
  /**
   * Adds a ticketToken property value for this Ticket object; appending it to the list of existing values.
   *
   * @param ticketToken The value to add.
   */
  public void addTicketToken(Thing ticketToken) {
  	this.ticketToken.add(ticketToken);
  }
  
  /**
   * Adds a ticketedSeat property value for this Ticket object; appending it to the list of existing values.
   *
   * @param ticketedSeat The value to add.
   */
  public void addTicketedSeat(Seat ticketedSeat) {
  	this.ticketedSeat.add(ticketedSeat);
  }
  
  /**
   * Adds a totalPrice property value for this Ticket object; appending it to the list of existing values.
   *
   * @param totalPrice The value to add.
   */
  public void addTotalPrice(Thing totalPrice) {
  	this.totalPrice.add(totalPrice);
  }
  
  /**
   * Adds a underName property value for this Ticket object; appending it to the list of existing values.
   *
   * @param underName The value to add.
   */
  public void addUnderName(Thing underName) {
  	this.underName.add(underName);
  }
  
  /**
   * Adds a url property value for this Ticket object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}