package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.LinkedList;
import java.util.List;
import org.schema.Thing;
import org.schema.TrainStation;
import org.schema.TrainTrip;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A trip on a commercial train line.
 */
public class TrainTripImpl extends SchemaObjectImpl implements TrainTrip {


  private ThingImpl thing;

  /**
   * The platform where the train arrives.
   */
  private List<String> arrivalPlatform = new LinkedList<String>();
  
  /**
   * The station where the train trip ends.
   */
  private List<TrainStation> arrivalStation = new LinkedList<TrainStation>();
  
  /**
   * The expected arrival time.
   */
  private List<Date> arrivalTime = new LinkedList<Date>();
  
  /**
   * The platform from which the train departs.
   */
  private List<String> departurePlatform = new LinkedList<String>();
  
  /**
   * The station from which the train departs.
   */
  private List<TrainStation> departureStation = new LinkedList<TrainStation>();
  
  /**
   * The expected departure time.
   */
  private List<Date> departureTime = new LinkedList<Date>();
  
  /**
   * The organization or agency that is providing the service.
   */
  private List<Thing> provider = new LinkedList<Thing>();
  
  /**
   * The name of the train (e.g. The Orient Express).
   */
  private List<String> trainName = new LinkedList<String>();
  
  /**
   * The unique identifier for the train.
   */
  private List<String> trainNumber = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public TrainTripImpl() {
    super("http://schema.org/TrainTrip");
  }
  /**
   * Get a single additionalType property value for this TrainTrip object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this TrainTrip object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single arrivalPlatform property value for this TrainTrip object.
   *
   * @return The first arrivalPlatform property value.
   */
  public String getArrivalPlatform() {
  	return this.arrivalPlatform.isEmpty() ? null : this.arrivalPlatform.get(0);
  }
  
  /**
   * Get a single arrivalStation property value for this TrainTrip object.
   *
   * @return The first arrivalStation property value.
   */
  public TrainStation getArrivalStation() {
  	return this.arrivalStation.isEmpty() ? null : this.arrivalStation.get(0);
  }
  
  /**
   * Get a single arrivalTime property value for this TrainTrip object.
   *
   * @return The first arrivalTime property value.
   */
  public Date getArrivalTime() {
  	return this.arrivalTime.isEmpty() ? null : this.arrivalTime.get(0);
  }
  
  /**
   * Get a single departurePlatform property value for this TrainTrip object.
   *
   * @return The first departurePlatform property value.
   */
  public String getDeparturePlatform() {
  	return this.departurePlatform.isEmpty() ? null : this.departurePlatform.get(0);
  }
  
  /**
   * Get a single departureStation property value for this TrainTrip object.
   *
   * @return The first departureStation property value.
   */
  public TrainStation getDepartureStation() {
  	return this.departureStation.isEmpty() ? null : this.departureStation.get(0);
  }
  
  /**
   * Get a single departureTime property value for this TrainTrip object.
   *
   * @return The first departureTime property value.
   */
  public Date getDepartureTime() {
  	return this.departureTime.isEmpty() ? null : this.departureTime.get(0);
  }
  
  /**
   * Get a single description property value for this TrainTrip object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this TrainTrip object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this TrainTrip object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single provider property value for this TrainTrip object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider() {
  	return this.provider.isEmpty() ? null : this.provider.get(0);
  }
  
  /**
   * Get a single sameAs property value for this TrainTrip object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single trainName property value for this TrainTrip object.
   *
   * @return The first trainName property value.
   */
  public String getTrainName() {
  	return this.trainName.isEmpty() ? null : this.trainName.get(0);
  }
  
  /**
   * Get a single trainNumber property value for this TrainTrip object.
   *
   * @return The first trainNumber property value.
   */
  public String getTrainNumber() {
  	return this.trainNumber.isEmpty() ? null : this.trainNumber.get(0);
  }
  
  /**
   * Get a single url property value for this TrainTrip object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this TrainTrip object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this TrainTrip object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the arrivalPlatform property values for this TrainTrip object.
   *
   * @return A list of arrivalPlatform property values.
   */
  public List<String> getArrivalPlatforms() {
  	return this.arrivalPlatform;
  }
  
  /**
   * Get all the arrivalStation property values for this TrainTrip object.
   *
   * @return A list of arrivalStation property values.
   */
  public List<TrainStation> getArrivalStations() {
  	return this.arrivalStation;
  }
  
  /**
   * Get all the arrivalTime property values for this TrainTrip object.
   *
   * @return A list of arrivalTime property values.
   */
  public List<Date> getArrivalTimes() {
  	return this.arrivalTime;
  }
  
  /**
   * Get all the departurePlatform property values for this TrainTrip object.
   *
   * @return A list of departurePlatform property values.
   */
  public List<String> getDeparturePlatforms() {
  	return this.departurePlatform;
  }
  
  /**
   * Get all the departureStation property values for this TrainTrip object.
   *
   * @return A list of departureStation property values.
   */
  public List<TrainStation> getDepartureStations() {
  	return this.departureStation;
  }
  
  /**
   * Get all the departureTime property values for this TrainTrip object.
   *
   * @return A list of departureTime property values.
   */
  public List<Date> getDepartureTimes() {
  	return this.departureTime;
  }
  
  /**
   * Get all the description property values for this TrainTrip object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this TrainTrip object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this TrainTrip object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the provider property values for this TrainTrip object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders() {
  	return this.provider;
  }
  
  /**
   * Get all the sameAs property values for this TrainTrip object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the trainName property values for this TrainTrip object.
   *
   * @return A list of trainName property values.
   */
  public List<String> getTrainNames() {
  	return this.trainName;
  }
  
  /**
   * Get all the trainNumber property values for this TrainTrip object.
   *
   * @return A list of trainNumber property values.
   */
  public List<String> getTrainNumbers() {
  	return this.trainNumber;
  }
  
  /**
   * Get all the url property values for this TrainTrip object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this TrainTrip object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this TrainTrip object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the arrivalPlatform property value for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalPlatform The value to set.
   */
  public void setArrivalPlatform(String arrivalPlatform) {
  	this.arrivalPlatform.clear();
  	this.arrivalPlatform.add(arrivalPlatform);
  }
  
  /**
   * Set the arrivalStation property value for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalStation The value to set.
   */
  public void setArrivalStation(TrainStation arrivalStation) {
  	this.arrivalStation.clear();
  	this.arrivalStation.add(arrivalStation);
  }
  
  /**
   * Set the arrivalTime property value for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalTime The value to set.
   */
  public void setArrivalTime(Date arrivalTime) {
  	this.arrivalTime.clear();
  	this.arrivalTime.add(arrivalTime);
  }
  
  /**
   * Set the departurePlatform property value for this TrainTrip object; overwriting any existing values.
   *
   * @param departurePlatform The value to set.
   */
  public void setDeparturePlatform(String departurePlatform) {
  	this.departurePlatform.clear();
  	this.departurePlatform.add(departurePlatform);
  }
  
  /**
   * Set the departureStation property value for this TrainTrip object; overwriting any existing values.
   *
   * @param departureStation The value to set.
   */
  public void setDepartureStation(TrainStation departureStation) {
  	this.departureStation.clear();
  	this.departureStation.add(departureStation);
  }
  
  /**
   * Set the departureTime property value for this TrainTrip object; overwriting any existing values.
   *
   * @param departureTime The value to set.
   */
  public void setDepartureTime(Date departureTime) {
  	this.departureTime.clear();
  	this.departureTime.add(departureTime);
  }
  
  /**
   * Set the description property value for this TrainTrip object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this TrainTrip object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this TrainTrip object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the provider property value for this TrainTrip object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider) {
  	this.provider.clear();
  	this.provider.add(provider);
  }
  
  /**
   * Set the sameAs property value for this TrainTrip object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the trainName property value for this TrainTrip object; overwriting any existing values.
   *
   * @param trainName The value to set.
   */
  public void setTrainName(String trainName) {
  	this.trainName.clear();
  	this.trainName.add(trainName);
  }
  
  /**
   * Set the trainNumber property value for this TrainTrip object; overwriting any existing values.
   *
   * @param trainNumber The value to set.
   */
  public void setTrainNumber(String trainNumber) {
  	this.trainNumber.clear();
  	this.trainNumber.add(trainNumber);
  }
  
  /**
   * Set the url property value for this TrainTrip object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this TrainTrip object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this TrainTrip object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the arrivalPlatform property values for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalPlatforms The list of values to set.
   */
  public void setArrivalPlatforms(List<String> arrivalPlatforms) {
  	this.arrivalPlatform = arrivalPlatforms;
  }
  
  /**
   * Set the arrivalStation property values for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalStations The list of values to set.
   */
  public void setArrivalStations(List<TrainStation> arrivalStations) {
  	this.arrivalStation = arrivalStations;
  }
  
  /**
   * Set the arrivalTime property values for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalTimes The list of values to set.
   */
  public void setArrivalTimes(List<Date> arrivalTimes) {
  	this.arrivalTime = arrivalTimes;
  }
  
  /**
   * Set the departurePlatform property values for this TrainTrip object; overwriting any existing values.
   *
   * @param departurePlatforms The list of values to set.
   */
  public void setDeparturePlatforms(List<String> departurePlatforms) {
  	this.departurePlatform = departurePlatforms;
  }
  
  /**
   * Set the departureStation property values for this TrainTrip object; overwriting any existing values.
   *
   * @param departureStations The list of values to set.
   */
  public void setDepartureStations(List<TrainStation> departureStations) {
  	this.departureStation = departureStations;
  }
  
  /**
   * Set the departureTime property values for this TrainTrip object; overwriting any existing values.
   *
   * @param departureTimes The list of values to set.
   */
  public void setDepartureTimes(List<Date> departureTimes) {
  	this.departureTime = departureTimes;
  }
  
  /**
   * Set the description property values for this TrainTrip object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this TrainTrip object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this TrainTrip object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the provider property values for this TrainTrip object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers) {
  	this.provider = providers;
  }
  
  /**
   * Set the sameAs property values for this TrainTrip object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the trainName property values for this TrainTrip object; overwriting any existing values.
   *
   * @param trainNames The list of values to set.
   */
  public void setTrainNames(List<String> trainNames) {
  	this.trainName = trainNames;
  }
  
  /**
   * Set the trainNumber property values for this TrainTrip object; overwriting any existing values.
   *
   * @param trainNumbers The list of values to set.
   */
  public void setTrainNumbers(List<String> trainNumbers) {
  	this.trainNumber = trainNumbers;
  }
  
  /**
   * Set the url property values for this TrainTrip object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a arrivalPlatform property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param arrivalPlatform The value to add.
   */
  public void addArrivalPlatform(String arrivalPlatform) {
  	this.arrivalPlatform.add(arrivalPlatform);
  }
  
  /**
   * Adds a arrivalStation property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param arrivalStation The value to add.
   */
  public void addArrivalStation(TrainStation arrivalStation) {
  	this.arrivalStation.add(arrivalStation);
  }
  
  /**
   * Adds a arrivalTime property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param arrivalTime The value to add.
   */
  public void addArrivalTime(Date arrivalTime) {
  	this.arrivalTime.add(arrivalTime);
  }
  
  /**
   * Adds a departurePlatform property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param departurePlatform The value to add.
   */
  public void addDeparturePlatform(String departurePlatform) {
  	this.departurePlatform.add(departurePlatform);
  }
  
  /**
   * Adds a departureStation property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param departureStation The value to add.
   */
  public void addDepartureStation(TrainStation departureStation) {
  	this.departureStation.add(departureStation);
  }
  
  /**
   * Adds a departureTime property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param departureTime The value to add.
   */
  public void addDepartureTime(Date departureTime) {
  	this.departureTime.add(departureTime);
  }
  
  /**
   * Adds a description property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a provider property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider) {
  	this.provider.add(provider);
  }
  
  /**
   * Adds a sameAs property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a trainName property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param trainName The value to add.
   */
  public void addTrainName(String trainName) {
  	this.trainName.add(trainName);
  }
  
  /**
   * Adds a trainNumber property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param trainNumber The value to add.
   */
  public void addTrainNumber(String trainNumber) {
  	this.trainNumber.add(trainNumber);
  }
  
  /**
   * Adds a url property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}