package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.BusinessFunction;
import org.schema.Number;
import org.schema.Product;
import org.schema.TypeAndQuantityNode;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer.
 */
public class TypeAndQuantityNodeImpl extends SchemaObjectImpl implements TypeAndQuantityNode {


  private ThingImpl thing;

  /**
   * The quantity of the goods included in the offer.
   */
  private List<Number> amountOfThisGood = new LinkedList<Number>();
  
  /**
   * The business function (e.g. sell, lease, repair, dispose) of the offer or component of a bundle (TypeAndQuantityNode). The default is http://purl.org/goodrelations/v1#Sell.
   */
  private List<BusinessFunction> businessFunction = new LinkedList<BusinessFunction>();
  
  /**
   * The product that this structured value is referring to.
   */
  private List<Product> typeOfGood = new LinkedList<Product>();
  
  /**
   * The unit of measurement given using the UN/CEFACT Common Code (3 characters).
   */
  private List<String> unitCode = new LinkedList<String>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public TypeAndQuantityNodeImpl() {
    super("http://schema.org/TypeAndQuantityNode");
  }
  /**
   * Get a single additionalType property value for this TypeAndQuantityNode object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this TypeAndQuantityNode object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single amountOfThisGood property value for this TypeAndQuantityNode object.
   *
   * @return The first amountOfThisGood property value.
   */
  public Number getAmountOfThisGood() {
  	return this.amountOfThisGood.isEmpty() ? null : this.amountOfThisGood.get(0);
  }
  
  /**
   * Get a single businessFunction property value for this TypeAndQuantityNode object.
   *
   * @return The first businessFunction property value.
   */
  public BusinessFunction getBusinessFunction() {
  	return this.businessFunction.isEmpty() ? null : this.businessFunction.get(0);
  }
  
  /**
   * Get a single description property value for this TypeAndQuantityNode object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single image property value for this TypeAndQuantityNode object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this TypeAndQuantityNode object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single sameAs property value for this TypeAndQuantityNode object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single typeOfGood property value for this TypeAndQuantityNode object.
   *
   * @return The first typeOfGood property value.
   */
  public Product getTypeOfGood() {
  	return this.typeOfGood.isEmpty() ? null : this.typeOfGood.get(0);
  }
  
  /**
   * Get a single unitCode property value for this TypeAndQuantityNode object.
   *
   * @return The first unitCode property value.
   */
  public String getUnitCode() {
  	return this.unitCode.isEmpty() ? null : this.unitCode.get(0);
  }
  
  /**
   * Get a single url property value for this TypeAndQuantityNode object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this TypeAndQuantityNode object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this TypeAndQuantityNode object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the amountOfThisGood property values for this TypeAndQuantityNode object.
   *
   * @return A list of amountOfThisGood property values.
   */
  public List<Number> getAmountOfThisGoods() {
  	return this.amountOfThisGood;
  }
  
  /**
   * Get all the businessFunction property values for this TypeAndQuantityNode object.
   *
   * @return A list of businessFunction property values.
   */
  public List<BusinessFunction> getBusinessFunctions() {
  	return this.businessFunction;
  }
  
  /**
   * Get all the description property values for this TypeAndQuantityNode object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the image property values for this TypeAndQuantityNode object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this TypeAndQuantityNode object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the sameAs property values for this TypeAndQuantityNode object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the typeOfGood property values for this TypeAndQuantityNode object.
   *
   * @return A list of typeOfGood property values.
   */
  public List<Product> getTypeOfGoods() {
  	return this.typeOfGood;
  }
  
  /**
   * Get all the unitCode property values for this TypeAndQuantityNode object.
   *
   * @return A list of unitCode property values.
   */
  public List<String> getUnitCodes() {
  	return this.unitCode;
  }
  
  /**
   * Get all the url property values for this TypeAndQuantityNode object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the amountOfThisGood property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param amountOfThisGood The value to set.
   */
  public void setAmountOfThisGood(Number amountOfThisGood) {
  	this.amountOfThisGood.clear();
  	this.amountOfThisGood.add(amountOfThisGood);
  }
  
  /**
   * Set the businessFunction property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param businessFunction The value to set.
   */
  public void setBusinessFunction(BusinessFunction businessFunction) {
  	this.businessFunction.clear();
  	this.businessFunction.add(businessFunction);
  }
  
  /**
   * Set the description property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the image property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the sameAs property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the typeOfGood property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param typeOfGood The value to set.
   */
  public void setTypeOfGood(Product typeOfGood) {
  	this.typeOfGood.clear();
  	this.typeOfGood.add(typeOfGood);
  }
  
  /**
   * Set the unitCode property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param unitCode The value to set.
   */
  public void setUnitCode(String unitCode) {
  	this.unitCode.clear();
  	this.unitCode.add(unitCode);
  }
  
  /**
   * Set the url property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the amountOfThisGood property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param amountOfThisGoods The list of values to set.
   */
  public void setAmountOfThisGoods(List<Number> amountOfThisGoods) {
  	this.amountOfThisGood = amountOfThisGoods;
  }
  
  /**
   * Set the businessFunction property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param businessFunctions The list of values to set.
   */
  public void setBusinessFunctions(List<BusinessFunction> businessFunctions) {
  	this.businessFunction = businessFunctions;
  }
  
  /**
   * Set the description property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the image property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the sameAs property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the typeOfGood property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param typeOfGoods The list of values to set.
   */
  public void setTypeOfGoods(List<Product> typeOfGoods) {
  	this.typeOfGood = typeOfGoods;
  }
  
  /**
   * Set the unitCode property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param unitCodes The list of values to set.
   */
  public void setUnitCodes(List<String> unitCodes) {
  	this.unitCode = unitCodes;
  }
  
  /**
   * Set the url property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a amountOfThisGood property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param amountOfThisGood The value to add.
   */
  public void addAmountOfThisGood(Number amountOfThisGood) {
  	this.amountOfThisGood.add(amountOfThisGood);
  }
  
  /**
   * Adds a businessFunction property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param businessFunction The value to add.
   */
  public void addBusinessFunction(BusinessFunction businessFunction) {
  	this.businessFunction.add(businessFunction);
  }
  
  /**
   * Adds a description property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a image property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a sameAs property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a typeOfGood property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param typeOfGood The value to add.
   */
  public void addTypeOfGood(Product typeOfGood) {
  	this.typeOfGood.add(typeOfGood);
  }
  
  /**
   * Adds a unitCode property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param unitCode The value to add.
   */
  public void addUnitCode(String unitCode) {
  	this.unitCode.add(unitCode);
  }
  
  /**
   * Adds a url property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}