package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.AnatomicalSystem;
import org.schema.ImageObject;
import org.schema.MedicalCode;
import org.schema.MedicalCondition;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicalTherapy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.Thing;
import org.schema.Vein;
import org.schema.Vessel;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A type of blood vessel that specifically carries blood to the heart.
 */
public class VeinImpl extends SchemaObjectImpl implements Vein {


  private AnatomicalStructureImpl anatomicalStructure;
  private MedicalEntityImpl medicalEntity;
  private ThingImpl thing;

  /**
   * The vasculature that the vein drains into.
   */
  private List<Vessel> drainsTo = new LinkedList<Vessel>();
  
  /**
   * The anatomical or organ system drained by this vessel; generally refers to a specific part of an organ.
   */
  private List<Thing> regionDrained = new LinkedList<Thing>();
  
  /**
   * The anatomical or organ system that the vein flows into; a larger structure that the vein connects to.
   */
  private List<AnatomicalStructure> tributary = new LinkedList<AnatomicalStructure>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public VeinImpl() {
    super("http://schema.org/Vein");
  }
  /**
   * Get a single additionalType property value for this Vein object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this Vein object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single associatedPathophysiology property value for this Vein object.
   *
   * @return The first associatedPathophysiology property value.
   */
  public String getAssociatedPathophysiology() {
    return anatomicalStructure.getAssociatedPathophysiology();
  }
  
  /**
   * Get a single bodyLocation property value for this Vein object.
   *
   * @return The first bodyLocation property value.
   */
  public String getBodyLocation() {
    return anatomicalStructure.getBodyLocation();
  }
  
  /**
   * Get a single code property value for this Vein object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode() {
    return medicalEntity.getCode();
  }
  
  /**
   * Get a single connectedTo property value for this Vein object.
   *
   * @return The first connectedTo property value.
   */
  public AnatomicalStructure getConnectedTo() {
    return anatomicalStructure.getConnectedTo();
  }
  
  /**
   * Get a single description property value for this Vein object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single diagram property value for this Vein object.
   *
   * @return The first diagram property value.
   */
  public ImageObject getDiagram() {
    return anatomicalStructure.getDiagram();
  }
  
  /**
   * Get a single drainsTo property value for this Vein object.
   *
   * @return The first drainsTo property value.
   */
  public Vessel getDrainsTo() {
  	return this.drainsTo.isEmpty() ? null : this.drainsTo.get(0);
  }
  
  /**
   * Get a single function property value for this Vein object.
   *
   * @return The first function property value.
   */
  public String getFunction() {
    return anatomicalStructure.getFunction();
  }
  
  /**
   * Get a single guideline property value for this Vein object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline() {
    return medicalEntity.getGuideline();
  }
  
  /**
   * Get a single image property value for this Vein object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single medicineSystem property value for this Vein object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem() {
    return medicalEntity.getMedicineSystem();
  }
  
  /**
   * Get a single name property value for this Vein object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single partOfSystem property value for this Vein object.
   *
   * @return The first partOfSystem property value.
   */
  public AnatomicalSystem getPartOfSystem() {
    return anatomicalStructure.getPartOfSystem();
  }
  
  /**
   * Get a single recognizingAuthority property value for this Vein object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority() {
    return medicalEntity.getRecognizingAuthority();
  }
  
  /**
   * Get a single regionDrained property value for this Vein object.
   *
   * @return The first regionDrained property value.
   */
  public Thing getRegionDrained() {
  	return this.regionDrained.isEmpty() ? null : this.regionDrained.get(0);
  }
  
  /**
   * Get a single relatedCondition property value for this Vein object.
   *
   * @return The first relatedCondition property value.
   */
  public MedicalCondition getRelatedCondition() {
    return anatomicalStructure.getRelatedCondition();
  }
  
  /**
   * Get a single relatedTherapy property value for this Vein object.
   *
   * @return The first relatedTherapy property value.
   */
  public MedicalTherapy getRelatedTherapy() {
    return anatomicalStructure.getRelatedTherapy();
  }
  
  /**
   * Get a single relevantSpecialty property value for this Vein object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty() {
    return medicalEntity.getRelevantSpecialty();
  }
  
  /**
   * Get a single sameAs property value for this Vein object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single study property value for this Vein object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy() {
    return medicalEntity.getStudy();
  }
  
  /**
   * Get a single subStructure property value for this Vein object.
   *
   * @return The first subStructure property value.
   */
  public AnatomicalStructure getSubStructure() {
    return anatomicalStructure.getSubStructure();
  }
  
  /**
   * Get a single tributary property value for this Vein object.
   *
   * @return The first tributary property value.
   */
  public AnatomicalStructure getTributary() {
  	return this.tributary.isEmpty() ? null : this.tributary.get(0);
  }
  
  /**
   * Get a single url property value for this Vein object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get all the additionalType property values for this Vein object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this Vein object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the associatedPathophysiology property values for this Vein object.
   *
   * @return A list of associatedPathophysiology property values.
   */
  public List<String> getAssociatedPathophysiologies() {
    return anatomicalStructure.getAssociatedPathophysiologies();
  }
  
  /**
   * Get all the bodyLocation property values for this Vein object.
   *
   * @return A list of bodyLocation property values.
   */
  public List<String> getBodyLocations() {
    return anatomicalStructure.getBodyLocations();
  }
  
  /**
   * Get all the code property values for this Vein object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes() {
    return medicalEntity.getCodes();
  }
  
  /**
   * Get all the connectedTo property values for this Vein object.
   *
   * @return A list of connectedTo property values.
   */
  public List<AnatomicalStructure> getConnectedToes() {
    return anatomicalStructure.getConnectedToes();
  }
  
  /**
   * Get all the description property values for this Vein object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the diagram property values for this Vein object.
   *
   * @return A list of diagram property values.
   */
  public List<ImageObject> getDiagrams() {
    return anatomicalStructure.getDiagrams();
  }
  
  /**
   * Get all the drainsTo property values for this Vein object.
   *
   * @return A list of drainsTo property values.
   */
  public List<Vessel> getDrainsToes() {
  	return this.drainsTo;
  }
  
  /**
   * Get all the function property values for this Vein object.
   *
   * @return A list of function property values.
   */
  public List<String> getFunctions() {
    return anatomicalStructure.getFunctions();
  }
  
  /**
   * Get all the guideline property values for this Vein object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines() {
    return medicalEntity.getGuidelines();
  }
  
  /**
   * Get all the image property values for this Vein object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the medicineSystem property values for this Vein object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems() {
    return medicalEntity.getMedicineSystems();
  }
  
  /**
   * Get all the name property values for this Vein object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the partOfSystem property values for this Vein object.
   *
   * @return A list of partOfSystem property values.
   */
  public List<AnatomicalSystem> getPartOfSystems() {
    return anatomicalStructure.getPartOfSystems();
  }
  
  /**
   * Get all the recognizingAuthority property values for this Vein object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities() {
    return medicalEntity.getRecognizingAuthorities();
  }
  
  /**
   * Get all the regionDrained property values for this Vein object.
   *
   * @return A list of regionDrained property values.
   */
  public List<Thing> getRegionDraineds() {
  	return this.regionDrained;
  }
  
  /**
   * Get all the relatedCondition property values for this Vein object.
   *
   * @return A list of relatedCondition property values.
   */
  public List<MedicalCondition> getRelatedConditions() {
    return anatomicalStructure.getRelatedConditions();
  }
  
  /**
   * Get all the relatedTherapy property values for this Vein object.
   *
   * @return A list of relatedTherapy property values.
   */
  public List<MedicalTherapy> getRelatedTherapies() {
    return anatomicalStructure.getRelatedTherapies();
  }
  
  /**
   * Get all the relevantSpecialty property values for this Vein object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties() {
    return medicalEntity.getRelevantSpecialties();
  }
  
  /**
   * Get all the sameAs property values for this Vein object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the study property values for this Vein object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies() {
    return medicalEntity.getStudies();
  }
  
  /**
   * Get all the subStructure property values for this Vein object.
   *
   * @return A list of subStructure property values.
   */
  public List<AnatomicalStructure> getSubStructures() {
    return anatomicalStructure.getSubStructures();
  }
  
  /**
   * Get all the tributary property values for this Vein object.
   *
   * @return A list of tributary property values.
   */
  public List<AnatomicalStructure> getTributaries() {
  	return this.tributary;
  }
  
  /**
   * Get all the url property values for this Vein object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Set the additionalType property value for this Vein object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this Vein object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the associatedPathophysiology property value for this Vein object; overwriting any existing values.
   *
   * @param associatedPathophysiology The value to set.
   */
  public void setAssociatedPathophysiology(String associatedPathophysiology) {
    anatomicalStructure.setAssociatedPathophysiology(associatedPathophysiology);
  }
  
  /**
   * Set the bodyLocation property value for this Vein object; overwriting any existing values.
   *
   * @param bodyLocation The value to set.
   */
  public void setBodyLocation(String bodyLocation) {
    anatomicalStructure.setBodyLocation(bodyLocation);
  }
  
  /**
   * Set the code property value for this Vein object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code) {
    medicalEntity.setCode(code);
  }
  
  /**
   * Set the connectedTo property value for this Vein object; overwriting any existing values.
   *
   * @param connectedTo The value to set.
   */
  public void setConnectedTo(AnatomicalStructure connectedTo) {
    anatomicalStructure.setConnectedTo(connectedTo);
  }
  
  /**
   * Set the description property value for this Vein object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the diagram property value for this Vein object; overwriting any existing values.
   *
   * @param diagram The value to set.
   */
  public void setDiagram(ImageObject diagram) {
    anatomicalStructure.setDiagram(diagram);
  }
  
  /**
   * Set the drainsTo property value for this Vein object; overwriting any existing values.
   *
   * @param drainsTo The value to set.
   */
  public void setDrainsTo(Vessel drainsTo) {
  	this.drainsTo.clear();
  	this.drainsTo.add(drainsTo);
  }
  
  /**
   * Set the function property value for this Vein object; overwriting any existing values.
   *
   * @param function The value to set.
   */
  public void setFunction(String function) {
    anatomicalStructure.setFunction(function);
  }
  
  /**
   * Set the guideline property value for this Vein object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline) {
    medicalEntity.setGuideline(guideline);
  }
  
  /**
   * Set the image property value for this Vein object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the medicineSystem property value for this Vein object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.setMedicineSystem(medicineSystem);
  }
  
  /**
   * Set the name property value for this Vein object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the partOfSystem property value for this Vein object; overwriting any existing values.
   *
   * @param partOfSystem The value to set.
   */
  public void setPartOfSystem(AnatomicalSystem partOfSystem) {
    anatomicalStructure.setPartOfSystem(partOfSystem);
  }
  
  /**
   * Set the recognizingAuthority property value for this Vein object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.setRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Set the regionDrained property value for this Vein object; overwriting any existing values.
   *
   * @param regionDrained The value to set.
   */
  public void setRegionDrained(Thing regionDrained) {
  	this.regionDrained.clear();
  	this.regionDrained.add(regionDrained);
  }
  
  /**
   * Set the relatedCondition property value for this Vein object; overwriting any existing values.
   *
   * @param relatedCondition The value to set.
   */
  public void setRelatedCondition(MedicalCondition relatedCondition) {
    anatomicalStructure.setRelatedCondition(relatedCondition);
  }
  
  /**
   * Set the relatedTherapy property value for this Vein object; overwriting any existing values.
   *
   * @param relatedTherapy The value to set.
   */
  public void setRelatedTherapy(MedicalTherapy relatedTherapy) {
    anatomicalStructure.setRelatedTherapy(relatedTherapy);
  }
  
  /**
   * Set the relevantSpecialty property value for this Vein object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.setRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Set the sameAs property value for this Vein object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the study property value for this Vein object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study) {
    medicalEntity.setStudy(study);
  }
  
  /**
   * Set the subStructure property value for this Vein object; overwriting any existing values.
   *
   * @param subStructure The value to set.
   */
  public void setSubStructure(AnatomicalStructure subStructure) {
    anatomicalStructure.setSubStructure(subStructure);
  }
  
  /**
   * Set the tributary property value for this Vein object; overwriting any existing values.
   *
   * @param tributary The value to set.
   */
  public void setTributary(AnatomicalStructure tributary) {
  	this.tributary.clear();
  	this.tributary.add(tributary);
  }
  
  /**
   * Set the url property value for this Vein object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the additionalType property values for this Vein object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this Vein object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the associatedPathophysiology property values for this Vein object; overwriting any existing values.
   *
   * @param associatedPathophysiologies The list of values to set.
   */
  public void setAssociatedPathophysiologies(List<String> associatedPathophysiologies) {
    anatomicalStructure.setAssociatedPathophysiologies(associatedPathophysiologies);
  }
  
  /**
   * Set the bodyLocation property values for this Vein object; overwriting any existing values.
   *
   * @param bodyLocations The list of values to set.
   */
  public void setBodyLocations(List<String> bodyLocations) {
    anatomicalStructure.setBodyLocations(bodyLocations);
  }
  
  /**
   * Set the code property values for this Vein object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes) {
    medicalEntity.setCodes(codes);
  }
  
  /**
   * Set the connectedTo property values for this Vein object; overwriting any existing values.
   *
   * @param connectedToes The list of values to set.
   */
  public void setConnectedToes(List<AnatomicalStructure> connectedToes) {
    anatomicalStructure.setConnectedToes(connectedToes);
  }
  
  /**
   * Set the description property values for this Vein object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the diagram property values for this Vein object; overwriting any existing values.
   *
   * @param diagrams The list of values to set.
   */
  public void setDiagrams(List<ImageObject> diagrams) {
    anatomicalStructure.setDiagrams(diagrams);
  }
  
  /**
   * Set the drainsTo property values for this Vein object; overwriting any existing values.
   *
   * @param drainsToes The list of values to set.
   */
  public void setDrainsToes(List<Vessel> drainsToes) {
  	this.drainsTo = drainsToes;
  }
  
  /**
   * Set the function property values for this Vein object; overwriting any existing values.
   *
   * @param functions The list of values to set.
   */
  public void setFunctions(List<String> functions) {
    anatomicalStructure.setFunctions(functions);
  }
  
  /**
   * Set the guideline property values for this Vein object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines) {
    medicalEntity.setGuidelines(guidelines);
  }
  
  /**
   * Set the image property values for this Vein object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the medicineSystem property values for this Vein object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems) {
    medicalEntity.setMedicineSystems(medicineSystems);
  }
  
  /**
   * Set the name property values for this Vein object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the partOfSystem property values for this Vein object; overwriting any existing values.
   *
   * @param partOfSystems The list of values to set.
   */
  public void setPartOfSystems(List<AnatomicalSystem> partOfSystems) {
    anatomicalStructure.setPartOfSystems(partOfSystems);
  }
  
  /**
   * Set the recognizingAuthority property values for this Vein object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities) {
    medicalEntity.setRecognizingAuthorities(recognizingAuthorities);
  }
  
  /**
   * Set the regionDrained property values for this Vein object; overwriting any existing values.
   *
   * @param regionDraineds The list of values to set.
   */
  public void setRegionDraineds(List<Thing> regionDraineds) {
  	this.regionDrained = regionDraineds;
  }
  
  /**
   * Set the relatedCondition property values for this Vein object; overwriting any existing values.
   *
   * @param relatedConditions The list of values to set.
   */
  public void setRelatedConditions(List<MedicalCondition> relatedConditions) {
    anatomicalStructure.setRelatedConditions(relatedConditions);
  }
  
  /**
   * Set the relatedTherapy property values for this Vein object; overwriting any existing values.
   *
   * @param relatedTherapies The list of values to set.
   */
  public void setRelatedTherapies(List<MedicalTherapy> relatedTherapies) {
    anatomicalStructure.setRelatedTherapies(relatedTherapies);
  }
  
  /**
   * Set the relevantSpecialty property values for this Vein object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties) {
    medicalEntity.setRelevantSpecialties(relevantSpecialties);
  }
  
  /**
   * Set the sameAs property values for this Vein object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the study property values for this Vein object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies) {
    medicalEntity.setStudies(studies);
  }
  
  /**
   * Set the subStructure property values for this Vein object; overwriting any existing values.
   *
   * @param subStructures The list of values to set.
   */
  public void setSubStructures(List<AnatomicalStructure> subStructures) {
    anatomicalStructure.setSubStructures(subStructures);
  }
  
  /**
   * Set the tributary property values for this Vein object; overwriting any existing values.
   *
   * @param tributaries The list of values to set.
   */
  public void setTributaries(List<AnatomicalStructure> tributaries) {
  	this.tributary = tributaries;
  }
  
  /**
   * Set the url property values for this Vein object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Adds a additionalType property value for this Vein object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this Vein object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a associatedPathophysiology property value for this Vein object; appending it to the list of existing values.
   *
   * @param associatedPathophysiology The value to add.
   */
  public void addAssociatedPathophysiology(String associatedPathophysiology) {
    anatomicalStructure.addAssociatedPathophysiology(associatedPathophysiology);
  }
  
  /**
   * Adds a bodyLocation property value for this Vein object; appending it to the list of existing values.
   *
   * @param bodyLocation The value to add.
   */
  public void addBodyLocation(String bodyLocation) {
    anatomicalStructure.addBodyLocation(bodyLocation);
  }
  
  /**
   * Adds a code property value for this Vein object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code) {
    medicalEntity.addCode(code);
  }
  
  /**
   * Adds a connectedTo property value for this Vein object; appending it to the list of existing values.
   *
   * @param connectedTo The value to add.
   */
  public void addConnectedTo(AnatomicalStructure connectedTo) {
    anatomicalStructure.addConnectedTo(connectedTo);
  }
  
  /**
   * Adds a description property value for this Vein object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a diagram property value for this Vein object; appending it to the list of existing values.
   *
   * @param diagram The value to add.
   */
  public void addDiagram(ImageObject diagram) {
    anatomicalStructure.addDiagram(diagram);
  }
  
  /**
   * Adds a drainsTo property value for this Vein object; appending it to the list of existing values.
   *
   * @param drainsTo The value to add.
   */
  public void addDrainsTo(Vessel drainsTo) {
  	this.drainsTo.add(drainsTo);
  }
  
  /**
   * Adds a function property value for this Vein object; appending it to the list of existing values.
   *
   * @param function The value to add.
   */
  public void addFunction(String function) {
    anatomicalStructure.addFunction(function);
  }
  
  /**
   * Adds a guideline property value for this Vein object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline) {
    medicalEntity.addGuideline(guideline);
  }
  
  /**
   * Adds a image property value for this Vein object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a medicineSystem property value for this Vein object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem) {
    medicalEntity.addMedicineSystem(medicineSystem);
  }
  
  /**
   * Adds a name property value for this Vein object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a partOfSystem property value for this Vein object; appending it to the list of existing values.
   *
   * @param partOfSystem The value to add.
   */
  public void addPartOfSystem(AnatomicalSystem partOfSystem) {
    anatomicalStructure.addPartOfSystem(partOfSystem);
  }
  
  /**
   * Adds a recognizingAuthority property value for this Vein object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority) {
    medicalEntity.addRecognizingAuthority(recognizingAuthority);
  }
  
  /**
   * Adds a regionDrained property value for this Vein object; appending it to the list of existing values.
   *
   * @param regionDrained The value to add.
   */
  public void addRegionDrained(Thing regionDrained) {
  	this.regionDrained.add(regionDrained);
  }
  
  /**
   * Adds a relatedCondition property value for this Vein object; appending it to the list of existing values.
   *
   * @param relatedCondition The value to add.
   */
  public void addRelatedCondition(MedicalCondition relatedCondition) {
    anatomicalStructure.addRelatedCondition(relatedCondition);
  }
  
  /**
   * Adds a relatedTherapy property value for this Vein object; appending it to the list of existing values.
   *
   * @param relatedTherapy The value to add.
   */
  public void addRelatedTherapy(MedicalTherapy relatedTherapy) {
    anatomicalStructure.addRelatedTherapy(relatedTherapy);
  }
  
  /**
   * Adds a relevantSpecialty property value for this Vein object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty) {
    medicalEntity.addRelevantSpecialty(relevantSpecialty);
  }
  
  /**
   * Adds a sameAs property value for this Vein object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a study property value for this Vein object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study) {
    medicalEntity.addStudy(study);
  }
  
  /**
   * Adds a subStructure property value for this Vein object; appending it to the list of existing values.
   *
   * @param subStructure The value to add.
   */
  public void addSubStructure(AnatomicalStructure subStructure) {
    anatomicalStructure.addSubStructure(subStructure);
  }
  
  /**
   * Adds a tributary property value for this Vein object; appending it to the list of existing values.
   *
   * @param tributary The value to add.
   */
  public void addTributary(AnatomicalStructure tributary) {
  	this.tributary.add(tributary);
  }
  
  /**
   * Adds a url property value for this Vein object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
}