package com.google.developers.schemas.impl;

import java.lang.String;
import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.schema.QuantitativeValue;
import org.schema.WarrantyPromise;
import org.schema.WarrantyScope;
import com.google.developers.schemas.impl.SchemaObjectImpl;

/**
 * A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.
 */
public class WarrantyPromiseImpl extends SchemaObjectImpl implements WarrantyPromise {


  private ThingImpl thing;

  /**
   * The duration of the warranty promise. Common unitCode values are ANN for year, MON for months, or DAY for days.
   */
  private List<QuantitativeValue> durationOfWarranty = new LinkedList<QuantitativeValue>();
  
  /**
   * The scope of the warranty promise.
   */
  private List<WarrantyScope> warrantyScope = new LinkedList<WarrantyScope>();
  
  /**
   * Default constructor. Sets class URI and initializes superclass instances.
   */
  public WarrantyPromiseImpl() {
    super("http://schema.org/WarrantyPromise");
  }
  /**
   * Get a single additionalType property value for this WarrantyPromise object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType() {
    return thing.getAdditionalType();
  }
  
  /**
   * Get a single alternateName property value for this WarrantyPromise object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName() {
    return thing.getAlternateName();
  }
  
  /**
   * Get a single description property value for this WarrantyPromise object.
   *
   * @return The first description property value.
   */
  public String getDescription() {
    return thing.getDescription();
  }
  
  /**
   * Get a single durationOfWarranty property value for this WarrantyPromise object.
   *
   * @return The first durationOfWarranty property value.
   */
  public QuantitativeValue getDurationOfWarranty() {
  	return this.durationOfWarranty.isEmpty() ? null : this.durationOfWarranty.get(0);
  }
  
  /**
   * Get a single image property value for this WarrantyPromise object.
   *
   * @return The first image property value.
   */
  public URL getImage() {
    return thing.getImage();
  }
  
  /**
   * Get a single name property value for this WarrantyPromise object.
   *
   * @return The first name property value.
   */
  public String getName() {
    return thing.getName();
  }
  
  /**
   * Get a single sameAs property value for this WarrantyPromise object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs() {
    return thing.getSameAs();
  }
  
  /**
   * Get a single url property value for this WarrantyPromise object.
   *
   * @return The first url property value.
   */
  public URL getUrl() {
    return thing.getUrl();
  }
  
  /**
   * Get a single warrantyScope property value for this WarrantyPromise object.
   *
   * @return The first warrantyScope property value.
   */
  public WarrantyScope getWarrantyScope() {
  	return this.warrantyScope.isEmpty() ? null : this.warrantyScope.get(0);
  }
  
  /**
   * Get all the additionalType property values for this WarrantyPromise object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes() {
    return thing.getAdditionalTypes();
  }
  
  /**
   * Get all the alternateName property values for this WarrantyPromise object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames() {
    return thing.getAlternateNames();
  }
  
  /**
   * Get all the description property values for this WarrantyPromise object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions() {
    return thing.getDescriptions();
  }
  
  /**
   * Get all the durationOfWarranty property values for this WarrantyPromise object.
   *
   * @return A list of durationOfWarranty property values.
   */
  public List<QuantitativeValue> getDurationOfWarranties() {
  	return this.durationOfWarranty;
  }
  
  /**
   * Get all the image property values for this WarrantyPromise object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages() {
    return thing.getImages();
  }
  
  /**
   * Get all the name property values for this WarrantyPromise object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames() {
    return thing.getNames();
  }
  
  /**
   * Get all the sameAs property values for this WarrantyPromise object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss() {
    return thing.getSameAss();
  }
  
  /**
   * Get all the url property values for this WarrantyPromise object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls() {
    return thing.getUrls();
  }
  
  /**
   * Get all the warrantyScope property values for this WarrantyPromise object.
   *
   * @return A list of warrantyScope property values.
   */
  public List<WarrantyScope> getWarrantyScopes() {
  	return this.warrantyScope;
  }
  
  /**
   * Set the additionalType property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType) {
    thing.setAdditionalType(additionalType);
  }
  
  /**
   * Set the alternateName property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName) {
    thing.setAlternateName(alternateName);
  }
  
  /**
   * Set the description property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description) {
    thing.setDescription(description);
  }
  
  /**
   * Set the durationOfWarranty property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param durationOfWarranty The value to set.
   */
  public void setDurationOfWarranty(QuantitativeValue durationOfWarranty) {
  	this.durationOfWarranty.clear();
  	this.durationOfWarranty.add(durationOfWarranty);
  }
  
  /**
   * Set the image property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image) {
    thing.setImage(image);
  }
  
  /**
   * Set the name property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name) {
    thing.setName(name);
  }
  
  /**
   * Set the sameAs property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs) {
    thing.setSameAs(sameAs);
  }
  
  /**
   * Set the url property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url) {
    thing.setUrl(url);
  }
  
  /**
   * Set the warrantyScope property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param warrantyScope The value to set.
   */
  public void setWarrantyScope(WarrantyScope warrantyScope) {
  	this.warrantyScope.clear();
  	this.warrantyScope.add(warrantyScope);
  }
  
  /**
   * Set the additionalType property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes) {
    thing.setAdditionalTypes(additionalTypes);
  }
  
  /**
   * Set the alternateName property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames) {
    thing.setAlternateNames(alternateNames);
  }
  
  /**
   * Set the description property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions) {
    thing.setDescriptions(descriptions);
  }
  
  /**
   * Set the durationOfWarranty property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param durationOfWarranties The list of values to set.
   */
  public void setDurationOfWarranties(List<QuantitativeValue> durationOfWarranties) {
  	this.durationOfWarranty = durationOfWarranties;
  }
  
  /**
   * Set the image property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images) {
    thing.setImages(images);
  }
  
  /**
   * Set the name property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names) {
    thing.setNames(names);
  }
  
  /**
   * Set the sameAs property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss) {
    thing.setSameAss(sameAss);
  }
  
  /**
   * Set the url property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls) {
    thing.setUrls(urls);
  }
  
  /**
   * Set the warrantyScope property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param warrantyScopes The list of values to set.
   */
  public void setWarrantyScopes(List<WarrantyScope> warrantyScopes) {
  	this.warrantyScope = warrantyScopes;
  }
  
  /**
   * Adds a additionalType property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType) {
    thing.addAdditionalType(additionalType);
  }
  
  /**
   * Adds a alternateName property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName) {
    thing.addAlternateName(alternateName);
  }
  
  /**
   * Adds a description property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description) {
    thing.addDescription(description);
  }
  
  /**
   * Adds a durationOfWarranty property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param durationOfWarranty The value to add.
   */
  public void addDurationOfWarranty(QuantitativeValue durationOfWarranty) {
  	this.durationOfWarranty.add(durationOfWarranty);
  }
  
  /**
   * Adds a image property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image) {
    thing.addImage(image);
  }
  
  /**
   * Adds a name property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name) {
    thing.addName(name);
  }
  
  /**
   * Adds a sameAs property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs) {
    thing.addSameAs(sameAs);
  }
  
  /**
   * Adds a url property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url) {
    thing.addUrl(url);
  }
  
  /**
   * Adds a warrantyScope property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param warrantyScope The value to add.
   */
  public void addWarrantyScope(WarrantyScope warrantyScope) {
  	this.warrantyScope.add(warrantyScope);
  }
  
}