package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.SchemaObject;
import org.schema.TechArticle;

/**
 * Reference documentation for application programming interfaces (APIs).
 */
public interface APIReference extends TechArticle, SchemaObject {

  /**
   * Get a single assembly property value for this APIReference object.
   *
   * @return The first assembly property value.
   */
  public String getAssembly();
  
  /**
   * Get a single assemblyVersion property value for this APIReference object.
   *
   * @return The first assemblyVersion property value.
   */
  public String getAssemblyVersion();
  
  /**
   * Get a single programmingModel property value for this APIReference object.
   *
   * @return The first programmingModel property value.
   */
  public String getProgrammingModel();
  
  /**
   * Get a single targetPlatform property value for this APIReference object.
   *
   * @return The first targetPlatform property value.
   */
  public String getTargetPlatform();
  
  /**
   * Get all the assembly property values for this APIReference object.
   *
   * @return A list of assembly property values.
   */
  public List<String> getAssemblies();
  
  /**
   * Get all the assemblyVersion property values for this APIReference object.
   *
   * @return A list of assemblyVersion property values.
   */
  public List<String> getAssemblyVersions();
  
  /**
   * Get all the programmingModel property values for this APIReference object.
   *
   * @return A list of programmingModel property values.
   */
  public List<String> getProgrammingModels();
  
  /**
   * Get all the targetPlatform property values for this APIReference object.
   *
   * @return A list of targetPlatform property values.
   */
  public List<String> getTargetPlatforms();
  
  /**
   * Set the assembly property value for this APIReference object; overwriting any existing values.
   *
   * @param assembly The value to set.
   */
  public void setAssembly(String assembly);
  
  /**
   * Set the assemblyVersion property value for this APIReference object; overwriting any existing values.
   *
   * @param assemblyVersion The value to set.
   */
  public void setAssemblyVersion(String assemblyVersion);
  
  /**
   * Set the programmingModel property value for this APIReference object; overwriting any existing values.
   *
   * @param programmingModel The value to set.
   */
  public void setProgrammingModel(String programmingModel);
  
  /**
   * Set the targetPlatform property value for this APIReference object; overwriting any existing values.
   *
   * @param targetPlatform The value to set.
   */
  public void setTargetPlatform(String targetPlatform);
  
  /**
   * Set the assembly property values for this APIReference object; overwriting any existing values.
   *
   * @param assemblies The list of values to set.
   */
  public void setAssemblies(List<String> assemblies);
  
  /**
   * Set the assemblyVersion property values for this APIReference object; overwriting any existing values.
   *
   * @param assemblyVersions The list of values to set.
   */
  public void setAssemblyVersions(List<String> assemblyVersions);
  
  /**
   * Set the programmingModel property values for this APIReference object; overwriting any existing values.
   *
   * @param programmingModels The list of values to set.
   */
  public void setProgrammingModels(List<String> programmingModels);
  
  /**
   * Set the targetPlatform property values for this APIReference object; overwriting any existing values.
   *
   * @param targetPlatforms The list of values to set.
   */
  public void setTargetPlatforms(List<String> targetPlatforms);
  
  /**
   * Adds a assembly property value for this APIReference object; appending it to the list of existing values.
   *
   * @param assembly The value to add.
   */
  public void addAssembly(String assembly);
  
  /**
   * Adds a assemblyVersion property value for this APIReference object; appending it to the list of existing values.
   *
   * @param assemblyVersion The value to add.
   */
  public void addAssemblyVersion(String assemblyVersion);
  
  /**
   * Adds a programmingModel property value for this APIReference object; appending it to the list of existing values.
   *
   * @param programmingModel The value to add.
   */
  public void addProgrammingModel(String programmingModel);
  
  /**
   * Adds a targetPlatform property value for this APIReference object; appending it to the list of existing values.
   *
   * @param targetPlatform The value to add.
   */
  public void addTargetPlatform(String targetPlatform);
  
}