package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An action performed by a direct agent and indirect     participants upon a direct object. Optionally happens at a location     with the help of an inanimate instrument. The execution of the action     may produce a result. Specific action sub-type documentation specifies     the exact expectation of each argument/role.
 */
public interface Action extends Thing, SchemaObject {

  /**
   * Get a single agent property value for this Action object.
   *
   * @return The first agent property value.
   */
  public Thing getAgent();
  
  /**
   * Get a single endTime property value for this Action object.
   *
   * @return The first endTime property value.
   */
  public Date getEndTime();
  
  /**
   * Get a single instrument property value for this Action object.
   *
   * @return The first instrument property value.
   */
  public Thing getInstrument();
  
  /**
   * Get a single location property value for this Action object.
   *
   * @return The first location property value.
   */
  public Thing getLocation();
  
  /**
   * Get a single object property value for this Action object.
   *
   * @return The first object property value.
   */
  public Thing getObject();
  
  /**
   * Get a single participant property value for this Action object.
   *
   * @return The first participant property value.
   */
  public Thing getParticipant();
  
  /**
   * Get a single result property value for this Action object.
   *
   * @return The first result property value.
   */
  public Thing getResult();
  
  /**
   * Get a single startTime property value for this Action object.
   *
   * @return The first startTime property value.
   */
  public Date getStartTime();
  
  /**
   * Get all the agent property values for this Action object.
   *
   * @return A list of agent property values.
   */
  public List<Thing> getAgents();
  
  /**
   * Get all the endTime property values for this Action object.
   *
   * @return A list of endTime property values.
   */
  public List<Date> getEndTimes();
  
  /**
   * Get all the instrument property values for this Action object.
   *
   * @return A list of instrument property values.
   */
  public List<Thing> getInstruments();
  
  /**
   * Get all the location property values for this Action object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations();
  
  /**
   * Get all the object property values for this Action object.
   *
   * @return A list of object property values.
   */
  public List<Thing> getObjects();
  
  /**
   * Get all the participant property values for this Action object.
   *
   * @return A list of participant property values.
   */
  public List<Thing> getParticipants();
  
  /**
   * Get all the result property values for this Action object.
   *
   * @return A list of result property values.
   */
  public List<Thing> getResults();
  
  /**
   * Get all the startTime property values for this Action object.
   *
   * @return A list of startTime property values.
   */
  public List<Date> getStartTimes();
  
  /**
   * Set the agent property value for this Action object; overwriting any existing values.
   *
   * @param agent The value to set.
   */
  public void setAgent(Thing agent);
  
  /**
   * Set the endTime property value for this Action object; overwriting any existing values.
   *
   * @param endTime The value to set.
   */
  public void setEndTime(Date endTime);
  
  /**
   * Set the instrument property value for this Action object; overwriting any existing values.
   *
   * @param instrument The value to set.
   */
  public void setInstrument(Thing instrument);
  
  /**
   * Set the location property value for this Action object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location);
  
  /**
   * Set the object property value for this Action object; overwriting any existing values.
   *
   * @param object The value to set.
   */
  public void setObject(Thing object);
  
  /**
   * Set the participant property value for this Action object; overwriting any existing values.
   *
   * @param participant The value to set.
   */
  public void setParticipant(Thing participant);
  
  /**
   * Set the result property value for this Action object; overwriting any existing values.
   *
   * @param result The value to set.
   */
  public void setResult(Thing result);
  
  /**
   * Set the startTime property value for this Action object; overwriting any existing values.
   *
   * @param startTime The value to set.
   */
  public void setStartTime(Date startTime);
  
  /**
   * Set the agent property values for this Action object; overwriting any existing values.
   *
   * @param agents The list of values to set.
   */
  public void setAgents(List<Thing> agents);
  
  /**
   * Set the endTime property values for this Action object; overwriting any existing values.
   *
   * @param endTimes The list of values to set.
   */
  public void setEndTimes(List<Date> endTimes);
  
  /**
   * Set the instrument property values for this Action object; overwriting any existing values.
   *
   * @param instruments The list of values to set.
   */
  public void setInstruments(List<Thing> instruments);
  
  /**
   * Set the location property values for this Action object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations);
  
  /**
   * Set the object property values for this Action object; overwriting any existing values.
   *
   * @param objects The list of values to set.
   */
  public void setObjects(List<Thing> objects);
  
  /**
   * Set the participant property values for this Action object; overwriting any existing values.
   *
   * @param participants The list of values to set.
   */
  public void setParticipants(List<Thing> participants);
  
  /**
   * Set the result property values for this Action object; overwriting any existing values.
   *
   * @param results The list of values to set.
   */
  public void setResults(List<Thing> results);
  
  /**
   * Set the startTime property values for this Action object; overwriting any existing values.
   *
   * @param startTimes The list of values to set.
   */
  public void setStartTimes(List<Date> startTimes);
  
  /**
   * Adds a agent property value for this Action object; appending it to the list of existing values.
   *
   * @param agent The value to add.
   */
  public void addAgent(Thing agent);
  
  /**
   * Adds a endTime property value for this Action object; appending it to the list of existing values.
   *
   * @param endTime The value to add.
   */
  public void addEndTime(Date endTime);
  
  /**
   * Adds a instrument property value for this Action object; appending it to the list of existing values.
   *
   * @param instrument The value to add.
   */
  public void addInstrument(Thing instrument);
  
  /**
   * Adds a location property value for this Action object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location);
  
  /**
   * Adds a object property value for this Action object; appending it to the list of existing values.
   *
   * @param object The value to add.
   */
  public void addObject(Thing object);
  
  /**
   * Adds a participant property value for this Action object; appending it to the list of existing values.
   *
   * @param participant The value to add.
   */
  public void addParticipant(Thing participant);
  
  /**
   * Adds a result property value for this Action object; appending it to the list of existing values.
   *
   * @param result The value to add.
   */
  public void addResult(Thing result);
  
  /**
   * Adds a startTime property value for this Action object; appending it to the list of existing values.
   *
   * @param startTime The value to add.
   */
  public void addStartTime(Date startTime);
  
}