package org.schema;

import java.lang.Long;
import java.util.List;
import org.schema.Offer;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.
 */
public interface AggregateOffer extends Offer, SchemaObject {

  /**
   * Get a single highPrice property value for this AggregateOffer object.
   *
   * @return The first highPrice property value.
   */
  public Thing getHighPrice();
  
  /**
   * Get a single lowPrice property value for this AggregateOffer object.
   *
   * @return The first lowPrice property value.
   */
  public Thing getLowPrice();
  
  /**
   * Get a single offerCount property value for this AggregateOffer object.
   *
   * @return The first offerCount property value.
   */
  public Long getOfferCount();
  
  /**
   * Get all the highPrice property values for this AggregateOffer object.
   *
   * @return A list of highPrice property values.
   */
  public List<Thing> getHighPrices();
  
  /**
   * Get all the lowPrice property values for this AggregateOffer object.
   *
   * @return A list of lowPrice property values.
   */
  public List<Thing> getLowPrices();
  
  /**
   * Get all the offerCount property values for this AggregateOffer object.
   *
   * @return A list of offerCount property values.
   */
  public List<Long> getOfferCounts();
  
  /**
   * Set the highPrice property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param highPrice The value to set.
   */
  public void setHighPrice(Thing highPrice);
  
  /**
   * Set the lowPrice property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param lowPrice The value to set.
   */
  public void setLowPrice(Thing lowPrice);
  
  /**
   * Set the offerCount property value for this AggregateOffer object; overwriting any existing values.
   *
   * @param offerCount The value to set.
   */
  public void setOfferCount(Long offerCount);
  
  /**
   * Set the highPrice property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param highPrices The list of values to set.
   */
  public void setHighPrices(List<Thing> highPrices);
  
  /**
   * Set the lowPrice property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param lowPrices The list of values to set.
   */
  public void setLowPrices(List<Thing> lowPrices);
  
  /**
   * Set the offerCount property values for this AggregateOffer object; overwriting any existing values.
   *
   * @param offerCounts The list of values to set.
   */
  public void setOfferCounts(List<Long> offerCounts);
  
  /**
   * Adds a highPrice property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param highPrice The value to add.
   */
  public void addHighPrice(Thing highPrice);
  
  /**
   * Adds a lowPrice property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param lowPrice The value to add.
   */
  public void addLowPrice(Thing lowPrice);
  
  /**
   * Adds a offerCount property value for this AggregateOffer object; appending it to the list of existing values.
   *
   * @param offerCount The value to add.
   */
  public void addOfferCount(Long offerCount);
  
}