package org.schema;

import java.util.List;
import org.schema.Number;
import org.schema.Rating;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The average rating based on multiple ratings or reviews.
 */
public interface AggregateRating extends Rating, SchemaObject {

  /**
   * Get a single itemReviewed property value for this AggregateRating object.
   *
   * @return The first itemReviewed property value.
   */
  public Thing getItemReviewed();
  
  /**
   * Get a single ratingCount property value for this AggregateRating object.
   *
   * @return The first ratingCount property value.
   */
  public Number getRatingCount();
  
  /**
   * Get a single reviewCount property value for this AggregateRating object.
   *
   * @return The first reviewCount property value.
   */
  public Number getReviewCount();
  
  /**
   * Get all the itemReviewed property values for this AggregateRating object.
   *
   * @return A list of itemReviewed property values.
   */
  public List<Thing> getItemRevieweds();
  
  /**
   * Get all the ratingCount property values for this AggregateRating object.
   *
   * @return A list of ratingCount property values.
   */
  public List<Number> getRatingCounts();
  
  /**
   * Get all the reviewCount property values for this AggregateRating object.
   *
   * @return A list of reviewCount property values.
   */
  public List<Number> getReviewCounts();
  
  /**
   * Set the itemReviewed property value for this AggregateRating object; overwriting any existing values.
   *
   * @param itemReviewed The value to set.
   */
  public void setItemReviewed(Thing itemReviewed);
  
  /**
   * Set the ratingCount property value for this AggregateRating object; overwriting any existing values.
   *
   * @param ratingCount The value to set.
   */
  public void setRatingCount(Number ratingCount);
  
  /**
   * Set the reviewCount property value for this AggregateRating object; overwriting any existing values.
   *
   * @param reviewCount The value to set.
   */
  public void setReviewCount(Number reviewCount);
  
  /**
   * Set the itemReviewed property values for this AggregateRating object; overwriting any existing values.
   *
   * @param itemRevieweds The list of values to set.
   */
  public void setItemRevieweds(List<Thing> itemRevieweds);
  
  /**
   * Set the ratingCount property values for this AggregateRating object; overwriting any existing values.
   *
   * @param ratingCounts The list of values to set.
   */
  public void setRatingCounts(List<Number> ratingCounts);
  
  /**
   * Set the reviewCount property values for this AggregateRating object; overwriting any existing values.
   *
   * @param reviewCounts The list of values to set.
   */
  public void setReviewCounts(List<Number> reviewCounts);
  
  /**
   * Adds a itemReviewed property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param itemReviewed The value to add.
   */
  public void addItemReviewed(Thing itemReviewed);
  
  /**
   * Adds a ratingCount property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param ratingCount The value to add.
   */
  public void addRatingCount(Number ratingCount);
  
  /**
   * Adds a reviewCount property value for this AggregateRating object; appending it to the list of existing values.
   *
   * @param reviewCount The value to add.
   */
  public void addReviewCount(Number reviewCount);
  
}