package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.Intangible;
import org.schema.SchemaObject;

/**
 * An intangible item that describes an alignment between a learning resource and a node in an educational framework.
 */
public interface AlignmentObject extends Intangible, SchemaObject {

  /**
   * Get a single alignmentType property value for this AlignmentObject object.
   *
   * @return The first alignmentType property value.
   */
  public String getAlignmentType();
  
  /**
   * Get a single educationalFramework property value for this AlignmentObject object.
   *
   * @return The first educationalFramework property value.
   */
  public String getEducationalFramework();
  
  /**
   * Get a single targetDescription property value for this AlignmentObject object.
   *
   * @return The first targetDescription property value.
   */
  public String getTargetDescription();
  
  /**
   * Get a single targetName property value for this AlignmentObject object.
   *
   * @return The first targetName property value.
   */
  public String getTargetName();
  
  /**
   * Get a single targetUrl property value for this AlignmentObject object.
   *
   * @return The first targetUrl property value.
   */
  public URL getTargetUrl();
  
  /**
   * Get all the alignmentType property values for this AlignmentObject object.
   *
   * @return A list of alignmentType property values.
   */
  public List<String> getAlignmentTypes();
  
  /**
   * Get all the educationalFramework property values for this AlignmentObject object.
   *
   * @return A list of educationalFramework property values.
   */
  public List<String> getEducationalFrameworks();
  
  /**
   * Get all the targetDescription property values for this AlignmentObject object.
   *
   * @return A list of targetDescription property values.
   */
  public List<String> getTargetDescriptions();
  
  /**
   * Get all the targetName property values for this AlignmentObject object.
   *
   * @return A list of targetName property values.
   */
  public List<String> getTargetNames();
  
  /**
   * Get all the targetUrl property values for this AlignmentObject object.
   *
   * @return A list of targetUrl property values.
   */
  public List<URL> getTargetUrls();
  
  /**
   * Set the alignmentType property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param alignmentType The value to set.
   */
  public void setAlignmentType(String alignmentType);
  
  /**
   * Set the educationalFramework property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param educationalFramework The value to set.
   */
  public void setEducationalFramework(String educationalFramework);
  
  /**
   * Set the targetDescription property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetDescription The value to set.
   */
  public void setTargetDescription(String targetDescription);
  
  /**
   * Set the targetName property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetName The value to set.
   */
  public void setTargetName(String targetName);
  
  /**
   * Set the targetUrl property value for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetUrl The value to set.
   */
  public void setTargetUrl(URL targetUrl);
  
  /**
   * Set the alignmentType property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param alignmentTypes The list of values to set.
   */
  public void setAlignmentTypes(List<String> alignmentTypes);
  
  /**
   * Set the educationalFramework property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param educationalFrameworks The list of values to set.
   */
  public void setEducationalFrameworks(List<String> educationalFrameworks);
  
  /**
   * Set the targetDescription property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetDescriptions The list of values to set.
   */
  public void setTargetDescriptions(List<String> targetDescriptions);
  
  /**
   * Set the targetName property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetNames The list of values to set.
   */
  public void setTargetNames(List<String> targetNames);
  
  /**
   * Set the targetUrl property values for this AlignmentObject object; overwriting any existing values.
   *
   * @param targetUrls The list of values to set.
   */
  public void setTargetUrls(List<URL> targetUrls);
  
  /**
   * Adds a alignmentType property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param alignmentType The value to add.
   */
  public void addAlignmentType(String alignmentType);
  
  /**
   * Adds a educationalFramework property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param educationalFramework The value to add.
   */
  public void addEducationalFramework(String educationalFramework);
  
  /**
   * Adds a targetDescription property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param targetDescription The value to add.
   */
  public void addTargetDescription(String targetDescription);
  
  /**
   * Adds a targetName property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param targetName The value to add.
   */
  public void addTargetName(String targetName);
  
  /**
   * Adds a targetUrl property value for this AlignmentObject object; appending it to the list of existing values.
   *
   * @param targetUrl The value to add.
   */
  public void addTargetUrl(URL targetUrl);
  
}