package org.schema;

import java.util.List;
import org.schema.OrganizeAction;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of organizing tasks/objects/events by associating resources to it.
 */
public interface AllocateAction extends OrganizeAction, SchemaObject {

  /**
   * Get a single purpose property value for this AllocateAction object.
   *
   * @return The first purpose property value.
   */
  public Thing getPurpose();
  
  /**
   * Get all the purpose property values for this AllocateAction object.
   *
   * @return A list of purpose property values.
   */
  public List<Thing> getPurposes();
  
  /**
   * Set the purpose property value for this AllocateAction object; overwriting any existing values.
   *
   * @param purpose The value to set.
   */
  public void setPurpose(Thing purpose);
  
  /**
   * Set the purpose property values for this AllocateAction object; overwriting any existing values.
   *
   * @param purposes The list of values to set.
   */
  public void setPurposes(List<Thing> purposes);
  
  /**
   * Adds a purpose property value for this AllocateAction object; appending it to the list of existing values.
   *
   * @param purpose The value to add.
   */
  public void addPurpose(Thing purpose);
  
}