package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.AnatomicalSystem;
import org.schema.ImageObject;
import org.schema.MedicalCondition;
import org.schema.MedicalEntity;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;

/**
 * Any part of the human body, typically a component of an anatomical system. Organs, tissues, and cells are all anatomical structures.
 */
public interface AnatomicalStructure extends MedicalEntity, SchemaObject {

  /**
   * Get a single associatedPathophysiology property value for this AnatomicalStructure object.
   *
   * @return The first associatedPathophysiology property value.
   */
  public String getAssociatedPathophysiology();
  
  /**
   * Get a single bodyLocation property value for this AnatomicalStructure object.
   *
   * @return The first bodyLocation property value.
   */
  public String getBodyLocation();
  
  /**
   * Get a single connectedTo property value for this AnatomicalStructure object.
   *
   * @return The first connectedTo property value.
   */
  public AnatomicalStructure getConnectedTo();
  
  /**
   * Get a single diagram property value for this AnatomicalStructure object.
   *
   * @return The first diagram property value.
   */
  public ImageObject getDiagram();
  
  /**
   * Get a single function property value for this AnatomicalStructure object.
   *
   * @return The first function property value.
   */
  public String getFunction();
  
  /**
   * Get a single partOfSystem property value for this AnatomicalStructure object.
   *
   * @return The first partOfSystem property value.
   */
  public AnatomicalSystem getPartOfSystem();
  
  /**
   * Get a single relatedCondition property value for this AnatomicalStructure object.
   *
   * @return The first relatedCondition property value.
   */
  public MedicalCondition getRelatedCondition();
  
  /**
   * Get a single relatedTherapy property value for this AnatomicalStructure object.
   *
   * @return The first relatedTherapy property value.
   */
  public MedicalTherapy getRelatedTherapy();
  
  /**
   * Get a single subStructure property value for this AnatomicalStructure object.
   *
   * @return The first subStructure property value.
   */
  public AnatomicalStructure getSubStructure();
  
  /**
   * Get all the associatedPathophysiology property values for this AnatomicalStructure object.
   *
   * @return A list of associatedPathophysiology property values.
   */
  public List<String> getAssociatedPathophysiologies();
  
  /**
   * Get all the bodyLocation property values for this AnatomicalStructure object.
   *
   * @return A list of bodyLocation property values.
   */
  public List<String> getBodyLocations();
  
  /**
   * Get all the connectedTo property values for this AnatomicalStructure object.
   *
   * @return A list of connectedTo property values.
   */
  public List<AnatomicalStructure> getConnectedToes();
  
  /**
   * Get all the diagram property values for this AnatomicalStructure object.
   *
   * @return A list of diagram property values.
   */
  public List<ImageObject> getDiagrams();
  
  /**
   * Get all the function property values for this AnatomicalStructure object.
   *
   * @return A list of function property values.
   */
  public List<String> getFunctions();
  
  /**
   * Get all the partOfSystem property values for this AnatomicalStructure object.
   *
   * @return A list of partOfSystem property values.
   */
  public List<AnatomicalSystem> getPartOfSystems();
  
  /**
   * Get all the relatedCondition property values for this AnatomicalStructure object.
   *
   * @return A list of relatedCondition property values.
   */
  public List<MedicalCondition> getRelatedConditions();
  
  /**
   * Get all the relatedTherapy property values for this AnatomicalStructure object.
   *
   * @return A list of relatedTherapy property values.
   */
  public List<MedicalTherapy> getRelatedTherapies();
  
  /**
   * Get all the subStructure property values for this AnatomicalStructure object.
   *
   * @return A list of subStructure property values.
   */
  public List<AnatomicalStructure> getSubStructures();
  
  /**
   * Set the associatedPathophysiology property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param associatedPathophysiology The value to set.
   */
  public void setAssociatedPathophysiology(String associatedPathophysiology);
  
  /**
   * Set the bodyLocation property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param bodyLocation The value to set.
   */
  public void setBodyLocation(String bodyLocation);
  
  /**
   * Set the connectedTo property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param connectedTo The value to set.
   */
  public void setConnectedTo(AnatomicalStructure connectedTo);
  
  /**
   * Set the diagram property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param diagram The value to set.
   */
  public void setDiagram(ImageObject diagram);
  
  /**
   * Set the function property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param function The value to set.
   */
  public void setFunction(String function);
  
  /**
   * Set the partOfSystem property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param partOfSystem The value to set.
   */
  public void setPartOfSystem(AnatomicalSystem partOfSystem);
  
  /**
   * Set the relatedCondition property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param relatedCondition The value to set.
   */
  public void setRelatedCondition(MedicalCondition relatedCondition);
  
  /**
   * Set the relatedTherapy property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param relatedTherapy The value to set.
   */
  public void setRelatedTherapy(MedicalTherapy relatedTherapy);
  
  /**
   * Set the subStructure property value for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param subStructure The value to set.
   */
  public void setSubStructure(AnatomicalStructure subStructure);
  
  /**
   * Set the associatedPathophysiology property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param associatedPathophysiologies The list of values to set.
   */
  public void setAssociatedPathophysiologies(List<String> associatedPathophysiologies);
  
  /**
   * Set the bodyLocation property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param bodyLocations The list of values to set.
   */
  public void setBodyLocations(List<String> bodyLocations);
  
  /**
   * Set the connectedTo property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param connectedToes The list of values to set.
   */
  public void setConnectedToes(List<AnatomicalStructure> connectedToes);
  
  /**
   * Set the diagram property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param diagrams The list of values to set.
   */
  public void setDiagrams(List<ImageObject> diagrams);
  
  /**
   * Set the function property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param functions The list of values to set.
   */
  public void setFunctions(List<String> functions);
  
  /**
   * Set the partOfSystem property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param partOfSystems The list of values to set.
   */
  public void setPartOfSystems(List<AnatomicalSystem> partOfSystems);
  
  /**
   * Set the relatedCondition property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param relatedConditions The list of values to set.
   */
  public void setRelatedConditions(List<MedicalCondition> relatedConditions);
  
  /**
   * Set the relatedTherapy property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param relatedTherapies The list of values to set.
   */
  public void setRelatedTherapies(List<MedicalTherapy> relatedTherapies);
  
  /**
   * Set the subStructure property values for this AnatomicalStructure object; overwriting any existing values.
   *
   * @param subStructures The list of values to set.
   */
  public void setSubStructures(List<AnatomicalStructure> subStructures);
  
  /**
   * Adds a associatedPathophysiology property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param associatedPathophysiology The value to add.
   */
  public void addAssociatedPathophysiology(String associatedPathophysiology);
  
  /**
   * Adds a bodyLocation property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param bodyLocation The value to add.
   */
  public void addBodyLocation(String bodyLocation);
  
  /**
   * Adds a connectedTo property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param connectedTo The value to add.
   */
  public void addConnectedTo(AnatomicalStructure connectedTo);
  
  /**
   * Adds a diagram property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param diagram The value to add.
   */
  public void addDiagram(ImageObject diagram);
  
  /**
   * Adds a function property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param function The value to add.
   */
  public void addFunction(String function);
  
  /**
   * Adds a partOfSystem property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param partOfSystem The value to add.
   */
  public void addPartOfSystem(AnatomicalSystem partOfSystem);
  
  /**
   * Adds a relatedCondition property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param relatedCondition The value to add.
   */
  public void addRelatedCondition(MedicalCondition relatedCondition);
  
  /**
   * Adds a relatedTherapy property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param relatedTherapy The value to add.
   */
  public void addRelatedTherapy(MedicalTherapy relatedTherapy);
  
  /**
   * Adds a subStructure property value for this AnatomicalStructure object; appending it to the list of existing values.
   *
   * @param subStructure The value to add.
   */
  public void addSubStructure(AnatomicalStructure subStructure);
  
}