package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.MedicalCondition;
import org.schema.MedicalEntity;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An anatomical system is a group of anatomical structures that work together to perform a certain task. Anatomical systems, such as organ systems, are one organizing principle of anatomy, and can includes circulatory, digestive, endocrine, integumentary, immune, lymphatic, muscular, nervous, reproductive, respiratory, skeletal, urinary, vestibular, and other systems.
 */
public interface AnatomicalSystem extends MedicalEntity, SchemaObject {

  /**
   * Get a single associatedPathophysiology property value for this AnatomicalSystem object.
   *
   * @return The first associatedPathophysiology property value.
   */
  public String getAssociatedPathophysiology();
  
  /**
   * Get a single comprisedOf property value for this AnatomicalSystem object.
   *
   * @return The first comprisedOf property value.
   */
  public Thing getComprisedOf();
  
  /**
   * Get a single relatedCondition property value for this AnatomicalSystem object.
   *
   * @return The first relatedCondition property value.
   */
  public MedicalCondition getRelatedCondition();
  
  /**
   * Get a single relatedStructure property value for this AnatomicalSystem object.
   *
   * @return The first relatedStructure property value.
   */
  public AnatomicalStructure getRelatedStructure();
  
  /**
   * Get a single relatedTherapy property value for this AnatomicalSystem object.
   *
   * @return The first relatedTherapy property value.
   */
  public MedicalTherapy getRelatedTherapy();
  
  /**
   * Get all the associatedPathophysiology property values for this AnatomicalSystem object.
   *
   * @return A list of associatedPathophysiology property values.
   */
  public List<String> getAssociatedPathophysiologies();
  
  /**
   * Get all the comprisedOf property values for this AnatomicalSystem object.
   *
   * @return A list of comprisedOf property values.
   */
  public List<Thing> getComprisedsOf();
  
  /**
   * Get all the relatedCondition property values for this AnatomicalSystem object.
   *
   * @return A list of relatedCondition property values.
   */
  public List<MedicalCondition> getRelatedConditions();
  
  /**
   * Get all the relatedStructure property values for this AnatomicalSystem object.
   *
   * @return A list of relatedStructure property values.
   */
  public List<AnatomicalStructure> getRelatedStructures();
  
  /**
   * Get all the relatedTherapy property values for this AnatomicalSystem object.
   *
   * @return A list of relatedTherapy property values.
   */
  public List<MedicalTherapy> getRelatedTherapies();
  
  /**
   * Set the associatedPathophysiology property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param associatedPathophysiology The value to set.
   */
  public void setAssociatedPathophysiology(String associatedPathophysiology);
  
  /**
   * Set the comprisedOf property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param comprisedOf The value to set.
   */
  public void setComprisedOf(Thing comprisedOf);
  
  /**
   * Set the relatedCondition property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedCondition The value to set.
   */
  public void setRelatedCondition(MedicalCondition relatedCondition);
  
  /**
   * Set the relatedStructure property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedStructure The value to set.
   */
  public void setRelatedStructure(AnatomicalStructure relatedStructure);
  
  /**
   * Set the relatedTherapy property value for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedTherapy The value to set.
   */
  public void setRelatedTherapy(MedicalTherapy relatedTherapy);
  
  /**
   * Set the associatedPathophysiology property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param associatedPathophysiologies The list of values to set.
   */
  public void setAssociatedPathophysiologies(List<String> associatedPathophysiologies);
  
  /**
   * Set the comprisedOf property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param comprisedsOf The list of values to set.
   */
  public void setComprisedsOf(List<Thing> comprisedsOf);
  
  /**
   * Set the relatedCondition property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedConditions The list of values to set.
   */
  public void setRelatedConditions(List<MedicalCondition> relatedConditions);
  
  /**
   * Set the relatedStructure property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedStructures The list of values to set.
   */
  public void setRelatedStructures(List<AnatomicalStructure> relatedStructures);
  
  /**
   * Set the relatedTherapy property values for this AnatomicalSystem object; overwriting any existing values.
   *
   * @param relatedTherapies The list of values to set.
   */
  public void setRelatedTherapies(List<MedicalTherapy> relatedTherapies);
  
  /**
   * Adds a associatedPathophysiology property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param associatedPathophysiology The value to add.
   */
  public void addAssociatedPathophysiology(String associatedPathophysiology);
  
  /**
   * Adds a comprisedOf property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param comprisedOf The value to add.
   */
  public void addComprisedOf(Thing comprisedOf);
  
  /**
   * Adds a relatedCondition property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relatedCondition The value to add.
   */
  public void addRelatedCondition(MedicalCondition relatedCondition);
  
  /**
   * Adds a relatedStructure property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relatedStructure The value to add.
   */
  public void addRelatedStructure(AnatomicalStructure relatedStructure);
  
  /**
   * Adds a relatedTherapy property value for this AnatomicalSystem object; appending it to the list of existing values.
   *
   * @param relatedTherapy The value to add.
   */
  public void addRelatedTherapy(MedicalTherapy relatedTherapy);
  
}