package org.schema;

import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.SchemaObject;
import org.schema.Vessel;

/**
 * A type of blood vessel that specifically carries blood away from the heart.
 */
public interface Artery extends Vessel, SchemaObject {

  /**
   * Get a single arterialBranch property value for this Artery object.
   *
   * @return The first arterialBranch property value.
   */
  public AnatomicalStructure getArterialBranch();
  
  /**
   * Get a single source property value for this Artery object.
   *
   * @return The first source property value.
   */
  public AnatomicalStructure getSource();
  
  /**
   * Get a single supplyTo property value for this Artery object.
   *
   * @return The first supplyTo property value.
   */
  public AnatomicalStructure getSupplyTo();
  
  /**
   * Get all the arterialBranch property values for this Artery object.
   *
   * @return A list of arterialBranch property values.
   */
  public List<AnatomicalStructure> getArterialBranches();
  
  /**
   * Get all the source property values for this Artery object.
   *
   * @return A list of source property values.
   */
  public List<AnatomicalStructure> getSources();
  
  /**
   * Get all the supplyTo property values for this Artery object.
   *
   * @return A list of supplyTo property values.
   */
  public List<AnatomicalStructure> getSupplyToes();
  
  /**
   * Set the arterialBranch property value for this Artery object; overwriting any existing values.
   *
   * @param arterialBranch The value to set.
   */
  public void setArterialBranch(AnatomicalStructure arterialBranch);
  
  /**
   * Set the source property value for this Artery object; overwriting any existing values.
   *
   * @param source The value to set.
   */
  public void setSource(AnatomicalStructure source);
  
  /**
   * Set the supplyTo property value for this Artery object; overwriting any existing values.
   *
   * @param supplyTo The value to set.
   */
  public void setSupplyTo(AnatomicalStructure supplyTo);
  
  /**
   * Set the arterialBranch property values for this Artery object; overwriting any existing values.
   *
   * @param arterialBranches The list of values to set.
   */
  public void setArterialBranches(List<AnatomicalStructure> arterialBranches);
  
  /**
   * Set the source property values for this Artery object; overwriting any existing values.
   *
   * @param sources The list of values to set.
   */
  public void setSources(List<AnatomicalStructure> sources);
  
  /**
   * Set the supplyTo property values for this Artery object; overwriting any existing values.
   *
   * @param supplyToes The list of values to set.
   */
  public void setSupplyToes(List<AnatomicalStructure> supplyToes);
  
  /**
   * Adds a arterialBranch property value for this Artery object; appending it to the list of existing values.
   *
   * @param arterialBranch The value to add.
   */
  public void addArterialBranch(AnatomicalStructure arterialBranch);
  
  /**
   * Adds a source property value for this Artery object; appending it to the list of existing values.
   *
   * @param source The value to add.
   */
  public void addSource(AnatomicalStructure source);
  
  /**
   * Adds a supplyTo property value for this Artery object; appending it to the list of existing values.
   *
   * @param supplyTo The value to add.
   */
  public void addSupplyTo(AnatomicalStructure supplyTo);
  
}