package org.schema;

import java.lang.Long;
import java.lang.String;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.SchemaObject;

/**
 * An article, such as a news article or piece of investigative report. Newspapers and magazines have articles of many different types and this is intended to cover them all.
 */
public interface Article extends CreativeWork, SchemaObject {

  /**
   * Get a single articleBody property value for this Article object.
   *
   * @return The first articleBody property value.
   */
  public String getArticleBody();
  
  /**
   * Get a single articleSection property value for this Article object.
   *
   * @return The first articleSection property value.
   */
  public String getArticleSection();
  
  /**
   * Get a single wordCount property value for this Article object.
   *
   * @return The first wordCount property value.
   */
  public Long getWordCount();
  
  /**
   * Get all the articleBody property values for this Article object.
   *
   * @return A list of articleBody property values.
   */
  public List<String> getArticleBodies();
  
  /**
   * Get all the articleSection property values for this Article object.
   *
   * @return A list of articleSection property values.
   */
  public List<String> getArticleSections();
  
  /**
   * Get all the wordCount property values for this Article object.
   *
   * @return A list of wordCount property values.
   */
  public List<Long> getWordCounts();
  
  /**
   * Set the articleBody property value for this Article object; overwriting any existing values.
   *
   * @param articleBody The value to set.
   */
  public void setArticleBody(String articleBody);
  
  /**
   * Set the articleSection property value for this Article object; overwriting any existing values.
   *
   * @param articleSection The value to set.
   */
  public void setArticleSection(String articleSection);
  
  /**
   * Set the wordCount property value for this Article object; overwriting any existing values.
   *
   * @param wordCount The value to set.
   */
  public void setWordCount(Long wordCount);
  
  /**
   * Set the articleBody property values for this Article object; overwriting any existing values.
   *
   * @param articleBodies The list of values to set.
   */
  public void setArticleBodies(List<String> articleBodies);
  
  /**
   * Set the articleSection property values for this Article object; overwriting any existing values.
   *
   * @param articleSections The list of values to set.
   */
  public void setArticleSections(List<String> articleSections);
  
  /**
   * Set the wordCount property values for this Article object; overwriting any existing values.
   *
   * @param wordCounts The list of values to set.
   */
  public void setWordCounts(List<Long> wordCounts);
  
  /**
   * Adds a articleBody property value for this Article object; appending it to the list of existing values.
   *
   * @param articleBody The value to add.
   */
  public void addArticleBody(String articleBody);
  
  /**
   * Adds a articleSection property value for this Article object; appending it to the list of existing values.
   *
   * @param articleSection The value to add.
   */
  public void addArticleSection(String articleSection);
  
  /**
   * Adds a wordCount property value for this Article object; appending it to the list of existing values.
   *
   * @param wordCount The value to add.
   */
  public void addWordCount(Long wordCount);
  
}