package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.CommunicateAction;
import org.schema.SchemaObject;

/**
 * The act of posing a question / favor to someone.<p>Related actions:</p><ul><li><a href="http://schema.org/ReplyAction">ReplyAction</a>: Appears generally as a response to AskAction.</li></ul>
 */
public interface AskAction extends CommunicateAction, SchemaObject {

  /**
   * Get a single question property value for this AskAction object.
   *
   * @return The first question property value.
   */
  public String getQuestion();
  
  /**
   * Get all the question property values for this AskAction object.
   *
   * @return A list of question property values.
   */
  public List<String> getQuestions();
  
  /**
   * Set the question property value for this AskAction object; overwriting any existing values.
   *
   * @param question The value to set.
   */
  public void setQuestion(String question);
  
  /**
   * Set the question property values for this AskAction object; overwriting any existing values.
   *
   * @param questions The list of values to set.
   */
  public void setQuestions(List<String> questions);
  
  /**
   * Adds a question property value for this AskAction object; appending it to the list of existing values.
   *
   * @param question The value to add.
   */
  public void addQuestion(String question);
  
}