package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MediaObject;
import org.schema.SchemaObject;

/**
 * An audio file.
 */
public interface AudioObject extends MediaObject, SchemaObject {

  /**
   * Get a single transcript property value for this AudioObject object.
   *
   * @return The first transcript property value.
   */
  public String getTranscript();
  
  /**
   * Get all the transcript property values for this AudioObject object.
   *
   * @return A list of transcript property values.
   */
  public List<String> getTranscripts();
  
  /**
   * Set the transcript property value for this AudioObject object; overwriting any existing values.
   *
   * @param transcript The value to set.
   */
  public void setTranscript(String transcript);
  
  /**
   * Set the transcript property values for this AudioObject object; overwriting any existing values.
   *
   * @param transcripts The list of values to set.
   */
  public void setTranscripts(List<String> transcripts);
  
  /**
   * Adds a transcript property value for this AudioObject object; appending it to the list of existing values.
   *
   * @param transcript The value to add.
   */
  public void addTranscript(String transcript);
  
}