package org.schema;

import java.lang.Long;
import java.lang.String;
import java.util.List;
import org.schema.BookFormatType;
import org.schema.CreativeWork;
import org.schema.Person;
import org.schema.SchemaObject;

/**
 * A book.
 */
public interface Book extends CreativeWork, SchemaObject {

  /**
   * Get a single bookEdition property value for this Book object.
   *
   * @return The first bookEdition property value.
   */
  public String getBookEdition();
  
  /**
   * Get a single bookFormat property value for this Book object.
   *
   * @return The first bookFormat property value.
   */
  public BookFormatType getBookFormat();
  
  /**
   * Get a single illustrator property value for this Book object.
   *
   * @return The first illustrator property value.
   */
  public Person getIllustrator();
  
  /**
   * Get a single isbn property value for this Book object.
   *
   * @return The first isbn property value.
   */
  public String getIsbn();
  
  /**
   * Get a single numberOfPages property value for this Book object.
   *
   * @return The first numberOfPages property value.
   */
  public Long getNumberOfPages();
  
  /**
   * Get all the bookEdition property values for this Book object.
   *
   * @return A list of bookEdition property values.
   */
  public List<String> getBookEditions();
  
  /**
   * Get all the bookFormat property values for this Book object.
   *
   * @return A list of bookFormat property values.
   */
  public List<BookFormatType> getBookFormats();
  
  /**
   * Get all the illustrator property values for this Book object.
   *
   * @return A list of illustrator property values.
   */
  public List<Person> getIllustrators();
  
  /**
   * Get all the isbn property values for this Book object.
   *
   * @return A list of isbn property values.
   */
  public List<String> getIsbns();
  
  /**
   * Get all the numberOfPages property values for this Book object.
   *
   * @return A list of numberOfPages property values.
   */
  public List<Long> getNumberOfPagess();
  
  /**
   * Set the bookEdition property value for this Book object; overwriting any existing values.
   *
   * @param bookEdition The value to set.
   */
  public void setBookEdition(String bookEdition);
  
  /**
   * Set the bookFormat property value for this Book object; overwriting any existing values.
   *
   * @param bookFormat The value to set.
   */
  public void setBookFormat(BookFormatType bookFormat);
  
  /**
   * Set the illustrator property value for this Book object; overwriting any existing values.
   *
   * @param illustrator The value to set.
   */
  public void setIllustrator(Person illustrator);
  
  /**
   * Set the isbn property value for this Book object; overwriting any existing values.
   *
   * @param isbn The value to set.
   */
  public void setIsbn(String isbn);
  
  /**
   * Set the numberOfPages property value for this Book object; overwriting any existing values.
   *
   * @param numberOfPages The value to set.
   */
  public void setNumberOfPages(Long numberOfPages);
  
  /**
   * Set the bookEdition property values for this Book object; overwriting any existing values.
   *
   * @param bookEditions The list of values to set.
   */
  public void setBookEditions(List<String> bookEditions);
  
  /**
   * Set the bookFormat property values for this Book object; overwriting any existing values.
   *
   * @param bookFormats The list of values to set.
   */
  public void setBookFormats(List<BookFormatType> bookFormats);
  
  /**
   * Set the illustrator property values for this Book object; overwriting any existing values.
   *
   * @param illustrators The list of values to set.
   */
  public void setIllustrators(List<Person> illustrators);
  
  /**
   * Set the isbn property values for this Book object; overwriting any existing values.
   *
   * @param isbns The list of values to set.
   */
  public void setIsbns(List<String> isbns);
  
  /**
   * Set the numberOfPages property values for this Book object; overwriting any existing values.
   *
   * @param numberOfPagess The list of values to set.
   */
  public void setNumberOfPagess(List<Long> numberOfPagess);
  
  /**
   * Adds a bookEdition property value for this Book object; appending it to the list of existing values.
   *
   * @param bookEdition The value to add.
   */
  public void addBookEdition(String bookEdition);
  
  /**
   * Adds a bookFormat property value for this Book object; appending it to the list of existing values.
   *
   * @param bookFormat The value to add.
   */
  public void addBookFormat(BookFormatType bookFormat);
  
  /**
   * Adds a illustrator property value for this Book object; appending it to the list of existing values.
   *
   * @param illustrator The value to add.
   */
  public void addIllustrator(Person illustrator);
  
  /**
   * Adds a isbn property value for this Book object; appending it to the list of existing values.
   *
   * @param isbn The value to add.
   */
  public void addIsbn(String isbn);
  
  /**
   * Adds a numberOfPages property value for this Book object; appending it to the list of existing values.
   *
   * @param numberOfPages The value to add.
   */
  public void addNumberOfPages(Long numberOfPages);
  
}