package org.schema;

import java.util.List;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.TransferAction;

/**
 * The act of obtaining an object under an agreement to return it at a later date. Reciprocal of LendAction.<p>Related actions:</p><ul><li><a href="http://schema.org/LendAction">LendAction</a>: Reciprocal of BorrowAction.</li></ul>
 */
public interface BorrowAction extends TransferAction, SchemaObject {

  /**
   * Get a single lender property value for this BorrowAction object.
   *
   * @return The first lender property value.
   */
  public Person getLender();
  
  /**
   * Get all the lender property values for this BorrowAction object.
   *
   * @return A list of lender property values.
   */
  public List<Person> getLenders();
  
  /**
   * Set the lender property value for this BorrowAction object; overwriting any existing values.
   *
   * @param lender The value to set.
   */
  public void setLender(Person lender);
  
  /**
   * Set the lender property values for this BorrowAction object; overwriting any existing values.
   *
   * @param lenders The list of values to set.
   */
  public void setLenders(List<Person> lenders);
  
  /**
   * Adds a lender property value for this BorrowAction object; appending it to the list of existing values.
   *
   * @param lender The value to add.
   */
  public void addLender(Person lender);
  
}