package org.schema;

import java.util.List;
import org.schema.Intangible;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A brand is a name used by an organization or business person for labeling a product, product group, or similar.
 */
public interface Brand extends Intangible, SchemaObject {

  /**
   * Get a single logo property value for this Brand object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo();
  
  /**
   * Get all the logo property values for this Brand object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes();
  
  /**
   * Set the logo property value for this Brand object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo);
  
  /**
   * Set the logo property values for this Brand object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes);
  
  /**
   * Adds a logo property value for this Brand object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo);
  
}