package org.schema;

import java.util.List;
import org.schema.BroadcastService;
import org.schema.Organization;
import org.schema.Place;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A delivery service through which content is provided via broadcast over the air or online.
 */
public interface BroadcastService extends Thing, SchemaObject {

  /**
   * Get a single area property value for this BroadcastService object.
   *
   * @return The first area property value.
   */
  public Place getArea();
  
  /**
   * Get a single broadcaster property value for this BroadcastService object.
   *
   * @return The first broadcaster property value.
   */
  public Organization getBroadcaster();
  
  /**
   * Get a single parentService property value for this BroadcastService object.
   *
   * @return The first parentService property value.
   */
  public BroadcastService getParentService();
  
  /**
   * Get all the area property values for this BroadcastService object.
   *
   * @return A list of area property values.
   */
  public List<Place> getAreas();
  
  /**
   * Get all the broadcaster property values for this BroadcastService object.
   *
   * @return A list of broadcaster property values.
   */
  public List<Organization> getBroadcasters();
  
  /**
   * Get all the parentService property values for this BroadcastService object.
   *
   * @return A list of parentService property values.
   */
  public List<BroadcastService> getParentServices();
  
  /**
   * Set the area property value for this BroadcastService object; overwriting any existing values.
   *
   * @param area The value to set.
   */
  public void setArea(Place area);
  
  /**
   * Set the broadcaster property value for this BroadcastService object; overwriting any existing values.
   *
   * @param broadcaster The value to set.
   */
  public void setBroadcaster(Organization broadcaster);
  
  /**
   * Set the parentService property value for this BroadcastService object; overwriting any existing values.
   *
   * @param parentService The value to set.
   */
  public void setParentService(BroadcastService parentService);
  
  /**
   * Set the area property values for this BroadcastService object; overwriting any existing values.
   *
   * @param areas The list of values to set.
   */
  public void setAreas(List<Place> areas);
  
  /**
   * Set the broadcaster property values for this BroadcastService object; overwriting any existing values.
   *
   * @param broadcasters The list of values to set.
   */
  public void setBroadcasters(List<Organization> broadcasters);
  
  /**
   * Set the parentService property values for this BroadcastService object; overwriting any existing values.
   *
   * @param parentServices The list of values to set.
   */
  public void setParentServices(List<BroadcastService> parentServices);
  
  /**
   * Adds a area property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param area The value to add.
   */
  public void addArea(Place area);
  
  /**
   * Adds a broadcaster property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param broadcaster The value to add.
   */
  public void addBroadcaster(Organization broadcaster);
  
  /**
   * Adds a parentService property value for this BroadcastService object; appending it to the list of existing values.
   *
   * @param parentService The value to add.
   */
  public void addParentService(BroadcastService parentService);
  
}