package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TradeAction;
import org.schema.WarrantyPromise;

/**
 * The act of giving money to a seller in exchange for goods or services rendered. An agent buys an object, product, or service from a seller for a price. Reciprocal of SellAction.
 */
public interface BuyAction extends TradeAction, SchemaObject {

  /**
   * Get a single vendor property value for this BuyAction object.
   *
   * @return The first vendor property value.
   */
  public Thing getVendor();
  
  /**
   * Get a single warrantyPromise property value for this BuyAction object.
   *
   * @return The first warrantyPromise property value.
   */
  public WarrantyPromise getWarrantyPromise();
  
  /**
   * Get all the vendor property values for this BuyAction object.
   *
   * @return A list of vendor property values.
   */
  public List<Thing> getVendors();
  
  /**
   * Get all the warrantyPromise property values for this BuyAction object.
   *
   * @return A list of warrantyPromise property values.
   */
  public List<WarrantyPromise> getWarrantyPromises();
  
  /**
   * Set the vendor property value for this BuyAction object; overwriting any existing values.
   *
   * @param vendor The value to set.
   */
  public void setVendor(Thing vendor);
  
  /**
   * Set the warrantyPromise property value for this BuyAction object; overwriting any existing values.
   *
   * @param warrantyPromise The value to set.
   */
  public void setWarrantyPromise(WarrantyPromise warrantyPromise);
  
  /**
   * Set the vendor property values for this BuyAction object; overwriting any existing values.
   *
   * @param vendors The list of values to set.
   */
  public void setVendors(List<Thing> vendors);
  
  /**
   * Set the warrantyPromise property values for this BuyAction object; overwriting any existing values.
   *
   * @param warrantyPromises The list of values to set.
   */
  public void setWarrantyPromises(List<WarrantyPromise> warrantyPromises);
  
  /**
   * Adds a vendor property value for this BuyAction object; appending it to the list of existing values.
   *
   * @param vendor The value to add.
   */
  public void addVendor(Thing vendor);
  
  /**
   * Adds a warrantyPromise property value for this BuyAction object; appending it to the list of existing values.
   *
   * @param warrantyPromise The value to add.
   */
  public void addWarrantyPromise(WarrantyPromise warrantyPromise);
  
}