package org.schema;

import java.util.List;
import org.schema.AssessAction;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of expressing a preference from a set of options or a large or unbounded set of choices/options.
 */
public interface ChooseAction extends AssessAction, SchemaObject {

  /**
   * Get a single option property value for this ChooseAction object.
   *
   * @return The first option property value.
   */
  public Thing getOption();
  
  /**
   * Get all the option property values for this ChooseAction object.
   *
   * @return A list of option property values.
   */
  public List<Thing> getOptions();
  
  /**
   * Set the option property value for this ChooseAction object; overwriting any existing values.
   *
   * @param option The value to set.
   */
  public void setOption(Thing option);
  
  /**
   * Set the option property values for this ChooseAction object; overwriting any existing values.
   *
   * @param options The list of values to set.
   */
  public void setOptions(List<Thing> options);
  
  /**
   * Adds a option property value for this ChooseAction object; appending it to the list of existing values.
   *
   * @param option The value to add.
   */
  public void addOption(Thing option);
  
}