package org.schema;

import java.lang.Long;
import java.lang.String;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Episode;
import org.schema.PublicationEvent;
import org.schema.SchemaObject;
import org.schema.Season;

/**
 * A short TV or radio program or a segment/part of a program.
 */
public interface Clip extends CreativeWork, SchemaObject {

  /**
   * Get a single clipNumber property value for this Clip object.
   *
   * @return The first clipNumber property value.
   */
  public Long getClipNumber();
  
  /**
   * Get a single partOfEpisode property value for this Clip object.
   *
   * @return The first partOfEpisode property value.
   */
  public Episode getPartOfEpisode();
  
  /**
   * Get a single partOfSeason property value for this Clip object.
   *
   * @return The first partOfSeason property value.
   */
  public Season getPartOfSeason();
  
  /**
   * Get a single position property value for this Clip object.
   *
   * @return The first position property value.
   */
  public String getPosition();
  
  /**
   * Get a single publication property value for this Clip object.
   *
   * @return The first publication property value.
   */
  public PublicationEvent getPublication();
  
  /**
   * Get all the clipNumber property values for this Clip object.
   *
   * @return A list of clipNumber property values.
   */
  public List<Long> getClipNumbers();
  
  /**
   * Get all the partOfEpisode property values for this Clip object.
   *
   * @return A list of partOfEpisode property values.
   */
  public List<Episode> getPartOfEpisodes();
  
  /**
   * Get all the partOfSeason property values for this Clip object.
   *
   * @return A list of partOfSeason property values.
   */
  public List<Season> getPartOfSeasons();
  
  /**
   * Get all the position property values for this Clip object.
   *
   * @return A list of position property values.
   */
  public List<String> getPositions();
  
  /**
   * Get all the publication property values for this Clip object.
   *
   * @return A list of publication property values.
   */
  public List<PublicationEvent> getPublications();
  
  /**
   * Set the clipNumber property value for this Clip object; overwriting any existing values.
   *
   * @param clipNumber The value to set.
   */
  public void setClipNumber(Long clipNumber);
  
  /**
   * Set the partOfEpisode property value for this Clip object; overwriting any existing values.
   *
   * @param partOfEpisode The value to set.
   */
  public void setPartOfEpisode(Episode partOfEpisode);
  
  /**
   * Set the partOfSeason property value for this Clip object; overwriting any existing values.
   *
   * @param partOfSeason The value to set.
   */
  public void setPartOfSeason(Season partOfSeason);
  
  /**
   * Set the position property value for this Clip object; overwriting any existing values.
   *
   * @param position The value to set.
   */
  public void setPosition(String position);
  
  /**
   * Set the publication property value for this Clip object; overwriting any existing values.
   *
   * @param publication The value to set.
   */
  public void setPublication(PublicationEvent publication);
  
  /**
   * Set the clipNumber property values for this Clip object; overwriting any existing values.
   *
   * @param clipNumbers The list of values to set.
   */
  public void setClipNumbers(List<Long> clipNumbers);
  
  /**
   * Set the partOfEpisode property values for this Clip object; overwriting any existing values.
   *
   * @param partOfEpisodes The list of values to set.
   */
  public void setPartOfEpisodes(List<Episode> partOfEpisodes);
  
  /**
   * Set the partOfSeason property values for this Clip object; overwriting any existing values.
   *
   * @param partOfSeasons The list of values to set.
   */
  public void setPartOfSeasons(List<Season> partOfSeasons);
  
  /**
   * Set the position property values for this Clip object; overwriting any existing values.
   *
   * @param positions The list of values to set.
   */
  public void setPositions(List<String> positions);
  
  /**
   * Set the publication property values for this Clip object; overwriting any existing values.
   *
   * @param publications The list of values to set.
   */
  public void setPublications(List<PublicationEvent> publications);
  
  /**
   * Adds a clipNumber property value for this Clip object; appending it to the list of existing values.
   *
   * @param clipNumber The value to add.
   */
  public void addClipNumber(Long clipNumber);
  
  /**
   * Adds a partOfEpisode property value for this Clip object; appending it to the list of existing values.
   *
   * @param partOfEpisode The value to add.
   */
  public void addPartOfEpisode(Episode partOfEpisode);
  
  /**
   * Adds a partOfSeason property value for this Clip object; appending it to the list of existing values.
   *
   * @param partOfSeason The value to add.
   */
  public void addPartOfSeason(Season partOfSeason);
  
  /**
   * Adds a position property value for this Clip object; appending it to the list of existing values.
   *
   * @param position The value to add.
   */
  public void addPosition(String position);
  
  /**
   * Adds a publication property value for this Clip object; appending it to the list of existing values.
   *
   * @param publication The value to add.
   */
  public void addPublication(PublicationEvent publication);
  
}