package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.SchemaObject;
import org.schema.SoftwareApplication;
import org.schema.Thing;

/**
 * Computer programming source code. Example: Full (compile ready) solutions, code snippet samples, scripts, templates.
 */
public interface Code extends CreativeWork, SchemaObject {

  /**
   * Get a single codeRepository property value for this Code object.
   *
   * @return The first codeRepository property value.
   */
  public URL getCodeRepository();
  
  /**
   * Get a single programmingLanguage property value for this Code object.
   *
   * @return The first programmingLanguage property value.
   */
  public Thing getProgrammingLanguage();
  
  /**
   * Get a single runtime property value for this Code object.
   *
   * @return The first runtime property value.
   */
  public String getRuntime();
  
  /**
   * Get a single sampleType property value for this Code object.
   *
   * @return The first sampleType property value.
   */
  public String getSampleType();
  
  /**
   * Get a single targetProduct property value for this Code object.
   *
   * @return The first targetProduct property value.
   */
  public SoftwareApplication getTargetProduct();
  
  /**
   * Get all the codeRepository property values for this Code object.
   *
   * @return A list of codeRepository property values.
   */
  public List<URL> getCodeRepositories();
  
  /**
   * Get all the programmingLanguage property values for this Code object.
   *
   * @return A list of programmingLanguage property values.
   */
  public List<Thing> getProgrammingLanguages();
  
  /**
   * Get all the runtime property values for this Code object.
   *
   * @return A list of runtime property values.
   */
  public List<String> getRuntimes();
  
  /**
   * Get all the sampleType property values for this Code object.
   *
   * @return A list of sampleType property values.
   */
  public List<String> getSampleTypes();
  
  /**
   * Get all the targetProduct property values for this Code object.
   *
   * @return A list of targetProduct property values.
   */
  public List<SoftwareApplication> getTargetProducts();
  
  /**
   * Set the codeRepository property value for this Code object; overwriting any existing values.
   *
   * @param codeRepository The value to set.
   */
  public void setCodeRepository(URL codeRepository);
  
  /**
   * Set the programmingLanguage property value for this Code object; overwriting any existing values.
   *
   * @param programmingLanguage The value to set.
   */
  public void setProgrammingLanguage(Thing programmingLanguage);
  
  /**
   * Set the runtime property value for this Code object; overwriting any existing values.
   *
   * @param runtime The value to set.
   */
  public void setRuntime(String runtime);
  
  /**
   * Set the sampleType property value for this Code object; overwriting any existing values.
   *
   * @param sampleType The value to set.
   */
  public void setSampleType(String sampleType);
  
  /**
   * Set the targetProduct property value for this Code object; overwriting any existing values.
   *
   * @param targetProduct The value to set.
   */
  public void setTargetProduct(SoftwareApplication targetProduct);
  
  /**
   * Set the codeRepository property values for this Code object; overwriting any existing values.
   *
   * @param codeRepositories The list of values to set.
   */
  public void setCodeRepositories(List<URL> codeRepositories);
  
  /**
   * Set the programmingLanguage property values for this Code object; overwriting any existing values.
   *
   * @param programmingLanguages The list of values to set.
   */
  public void setProgrammingLanguages(List<Thing> programmingLanguages);
  
  /**
   * Set the runtime property values for this Code object; overwriting any existing values.
   *
   * @param runtimes The list of values to set.
   */
  public void setRuntimes(List<String> runtimes);
  
  /**
   * Set the sampleType property values for this Code object; overwriting any existing values.
   *
   * @param sampleTypes The list of values to set.
   */
  public void setSampleTypes(List<String> sampleTypes);
  
  /**
   * Set the targetProduct property values for this Code object; overwriting any existing values.
   *
   * @param targetProducts The list of values to set.
   */
  public void setTargetProducts(List<SoftwareApplication> targetProducts);
  
  /**
   * Adds a codeRepository property value for this Code object; appending it to the list of existing values.
   *
   * @param codeRepository The value to add.
   */
  public void addCodeRepository(URL codeRepository);
  
  /**
   * Adds a programmingLanguage property value for this Code object; appending it to the list of existing values.
   *
   * @param programmingLanguage The value to add.
   */
  public void addProgrammingLanguage(Thing programmingLanguage);
  
  /**
   * Adds a runtime property value for this Code object; appending it to the list of existing values.
   *
   * @param runtime The value to add.
   */
  public void addRuntime(String runtime);
  
  /**
   * Adds a sampleType property value for this Code object; appending it to the list of existing values.
   *
   * @param sampleType The value to add.
   */
  public void addSampleType(String sampleType);
  
  /**
   * Adds a targetProduct property value for this Code object; appending it to the list of existing values.
   *
   * @param targetProduct The value to add.
   */
  public void addTargetProduct(SoftwareApplication targetProduct);
  
}