package org.schema;

import java.lang.Long;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Question;
import org.schema.SchemaObject;

/**
 * A comment on an item - for example, a comment on a blog post. The comment's content is expressed via the "text" property, and its topic via "about", properties shared with all CreativeWorks.
 */
public interface Comment extends CreativeWork, SchemaObject {

  /**
   * Get a single downvoteCount property value for this Comment object.
   *
   * @return The first downvoteCount property value.
   */
  public Long getDownvoteCount();
  
  /**
   * Get a single parentItem property value for this Comment object.
   *
   * @return The first parentItem property value.
   */
  public Question getParentItem();
  
  /**
   * Get a single upvoteCount property value for this Comment object.
   *
   * @return The first upvoteCount property value.
   */
  public Long getUpvoteCount();
  
  /**
   * Get all the downvoteCount property values for this Comment object.
   *
   * @return A list of downvoteCount property values.
   */
  public List<Long> getDownvoteCounts();
  
  /**
   * Get all the parentItem property values for this Comment object.
   *
   * @return A list of parentItem property values.
   */
  public List<Question> getParentItems();
  
  /**
   * Get all the upvoteCount property values for this Comment object.
   *
   * @return A list of upvoteCount property values.
   */
  public List<Long> getUpvoteCounts();
  
  /**
   * Set the downvoteCount property value for this Comment object; overwriting any existing values.
   *
   * @param downvoteCount The value to set.
   */
  public void setDownvoteCount(Long downvoteCount);
  
  /**
   * Set the parentItem property value for this Comment object; overwriting any existing values.
   *
   * @param parentItem The value to set.
   */
  public void setParentItem(Question parentItem);
  
  /**
   * Set the upvoteCount property value for this Comment object; overwriting any existing values.
   *
   * @param upvoteCount The value to set.
   */
  public void setUpvoteCount(Long upvoteCount);
  
  /**
   * Set the downvoteCount property values for this Comment object; overwriting any existing values.
   *
   * @param downvoteCounts The list of values to set.
   */
  public void setDownvoteCounts(List<Long> downvoteCounts);
  
  /**
   * Set the parentItem property values for this Comment object; overwriting any existing values.
   *
   * @param parentItems The list of values to set.
   */
  public void setParentItems(List<Question> parentItems);
  
  /**
   * Set the upvoteCount property values for this Comment object; overwriting any existing values.
   *
   * @param upvoteCounts The list of values to set.
   */
  public void setUpvoteCounts(List<Long> upvoteCounts);
  
  /**
   * Adds a downvoteCount property value for this Comment object; appending it to the list of existing values.
   *
   * @param downvoteCount The value to add.
   */
  public void addDownvoteCount(Long downvoteCount);
  
  /**
   * Adds a parentItem property value for this Comment object; appending it to the list of existing values.
   *
   * @param parentItem The value to add.
   */
  public void addParentItem(Question parentItem);
  
  /**
   * Adds a upvoteCount property value for this Comment object; appending it to the list of existing values.
   *
   * @param upvoteCount The value to add.
   */
  public void addUpvoteCount(Long upvoteCount);
  
}