package org.schema;

import java.util.List;
import org.schema.InteractAction;
import org.schema.Language;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of conveying information to another person via a communication medium (instrument) such as speech, email, or telephone conversation.
 */
public interface CommunicateAction extends InteractAction, SchemaObject {

  /**
   * Get a single about property value for this CommunicateAction object.
   *
   * @return The first about property value.
   */
  public Thing getAbout();
  
  /**
   * Get a single language property value for this CommunicateAction object.
   *
   * @return The first language property value.
   */
  public Language getLanguage();
  
  /**
   * Get a single recipient property value for this CommunicateAction object.
   *
   * @return The first recipient property value.
   */
  public Thing getRecipient();
  
  /**
   * Get all the about property values for this CommunicateAction object.
   *
   * @return A list of about property values.
   */
  public List<Thing> getAbouts();
  
  /**
   * Get all the language property values for this CommunicateAction object.
   *
   * @return A list of language property values.
   */
  public List<Language> getLanguages();
  
  /**
   * Get all the recipient property values for this CommunicateAction object.
   *
   * @return A list of recipient property values.
   */
  public List<Thing> getRecipients();
  
  /**
   * Set the about property value for this CommunicateAction object; overwriting any existing values.
   *
   * @param about The value to set.
   */
  public void setAbout(Thing about);
  
  /**
   * Set the language property value for this CommunicateAction object; overwriting any existing values.
   *
   * @param language The value to set.
   */
  public void setLanguage(Language language);
  
  /**
   * Set the recipient property value for this CommunicateAction object; overwriting any existing values.
   *
   * @param recipient The value to set.
   */
  public void setRecipient(Thing recipient);
  
  /**
   * Set the about property values for this CommunicateAction object; overwriting any existing values.
   *
   * @param abouts The list of values to set.
   */
  public void setAbouts(List<Thing> abouts);
  
  /**
   * Set the language property values for this CommunicateAction object; overwriting any existing values.
   *
   * @param languages The list of values to set.
   */
  public void setLanguages(List<Language> languages);
  
  /**
   * Set the recipient property values for this CommunicateAction object; overwriting any existing values.
   *
   * @param recipients The list of values to set.
   */
  public void setRecipients(List<Thing> recipients);
  
  /**
   * Adds a about property value for this CommunicateAction object; appending it to the list of existing values.
   *
   * @param about The value to add.
   */
  public void addAbout(Thing about);
  
  /**
   * Adds a language property value for this CommunicateAction object; appending it to the list of existing values.
   *
   * @param language The value to add.
   */
  public void addLanguage(Language language);
  
  /**
   * Adds a recipient property value for this CommunicateAction object; appending it to the list of existing values.
   *
   * @param recipient The value to add.
   */
  public void addRecipient(Thing recipient);
  
}