package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.ContactPointOption;
import org.schema.Language;
import org.schema.OpeningHoursSpecification;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.Thing;

/**
 * A contact point&#x2014;for example, a Customer Complaints department.
 */
public interface ContactPoint extends StructuredValue, SchemaObject {

  /**
   * Get a single areaServed property value for this ContactPoint object.
   *
   * @return The first areaServed property value.
   */
  public AdministrativeArea getAreaServed();
  
  /**
   * Get a single availableLanguage property value for this ContactPoint object.
   *
   * @return The first availableLanguage property value.
   */
  public Language getAvailableLanguage();
  
  /**
   * Get a single contactOption property value for this ContactPoint object.
   *
   * @return The first contactOption property value.
   */
  public ContactPointOption getContactOption();
  
  /**
   * Get a single contactType property value for this ContactPoint object.
   *
   * @return The first contactType property value.
   */
  public String getContactType();
  
  /**
   * Get a single email property value for this ContactPoint object.
   *
   * @return The first email property value.
   */
  public String getEmail();
  
  /**
   * Get a single faxNumber property value for this ContactPoint object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber();
  
  /**
   * Get a single hoursAvailable property value for this ContactPoint object.
   *
   * @return The first hoursAvailable property value.
   */
  public OpeningHoursSpecification getHoursAvailable();
  
  /**
   * Get a single productSupported property value for this ContactPoint object.
   *
   * @return The first productSupported property value.
   */
  public Thing getProductSupported();
  
  /**
   * Get a single telephone property value for this ContactPoint object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone();
  
  /**
   * Get all the areaServed property values for this ContactPoint object.
   *
   * @return A list of areaServed property values.
   */
  public List<AdministrativeArea> getAreaServeds();
  
  /**
   * Get all the availableLanguage property values for this ContactPoint object.
   *
   * @return A list of availableLanguage property values.
   */
  public List<Language> getAvailableLanguages();
  
  /**
   * Get all the contactOption property values for this ContactPoint object.
   *
   * @return A list of contactOption property values.
   */
  public List<ContactPointOption> getContactOptions();
  
  /**
   * Get all the contactType property values for this ContactPoint object.
   *
   * @return A list of contactType property values.
   */
  public List<String> getContactTypes();
  
  /**
   * Get all the email property values for this ContactPoint object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails();
  
  /**
   * Get all the faxNumber property values for this ContactPoint object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers();
  
  /**
   * Get all the hoursAvailable property values for this ContactPoint object.
   *
   * @return A list of hoursAvailable property values.
   */
  public List<OpeningHoursSpecification> getHoursAvailables();
  
  /**
   * Get all the productSupported property values for this ContactPoint object.
   *
   * @return A list of productSupported property values.
   */
  public List<Thing> getProductSupporteds();
  
  /**
   * Get all the telephone property values for this ContactPoint object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones();
  
  /**
   * Set the areaServed property value for this ContactPoint object; overwriting any existing values.
   *
   * @param areaServed The value to set.
   */
  public void setAreaServed(AdministrativeArea areaServed);
  
  /**
   * Set the availableLanguage property value for this ContactPoint object; overwriting any existing values.
   *
   * @param availableLanguage The value to set.
   */
  public void setAvailableLanguage(Language availableLanguage);
  
  /**
   * Set the contactOption property value for this ContactPoint object; overwriting any existing values.
   *
   * @param contactOption The value to set.
   */
  public void setContactOption(ContactPointOption contactOption);
  
  /**
   * Set the contactType property value for this ContactPoint object; overwriting any existing values.
   *
   * @param contactType The value to set.
   */
  public void setContactType(String contactType);
  
  /**
   * Set the email property value for this ContactPoint object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email);
  
  /**
   * Set the faxNumber property value for this ContactPoint object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber);
  
  /**
   * Set the hoursAvailable property value for this ContactPoint object; overwriting any existing values.
   *
   * @param hoursAvailable The value to set.
   */
  public void setHoursAvailable(OpeningHoursSpecification hoursAvailable);
  
  /**
   * Set the productSupported property value for this ContactPoint object; overwriting any existing values.
   *
   * @param productSupported The value to set.
   */
  public void setProductSupported(Thing productSupported);
  
  /**
   * Set the telephone property value for this ContactPoint object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone);
  
  /**
   * Set the areaServed property values for this ContactPoint object; overwriting any existing values.
   *
   * @param areaServeds The list of values to set.
   */
  public void setAreaServeds(List<AdministrativeArea> areaServeds);
  
  /**
   * Set the availableLanguage property values for this ContactPoint object; overwriting any existing values.
   *
   * @param availableLanguages The list of values to set.
   */
  public void setAvailableLanguages(List<Language> availableLanguages);
  
  /**
   * Set the contactOption property values for this ContactPoint object; overwriting any existing values.
   *
   * @param contactOptions The list of values to set.
   */
  public void setContactOptions(List<ContactPointOption> contactOptions);
  
  /**
   * Set the contactType property values for this ContactPoint object; overwriting any existing values.
   *
   * @param contactTypes The list of values to set.
   */
  public void setContactTypes(List<String> contactTypes);
  
  /**
   * Set the email property values for this ContactPoint object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails);
  
  /**
   * Set the faxNumber property values for this ContactPoint object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers);
  
  /**
   * Set the hoursAvailable property values for this ContactPoint object; overwriting any existing values.
   *
   * @param hoursAvailables The list of values to set.
   */
  public void setHoursAvailables(List<OpeningHoursSpecification> hoursAvailables);
  
  /**
   * Set the productSupported property values for this ContactPoint object; overwriting any existing values.
   *
   * @param productSupporteds The list of values to set.
   */
  public void setProductSupporteds(List<Thing> productSupporteds);
  
  /**
   * Set the telephone property values for this ContactPoint object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones);
  
  /**
   * Adds a areaServed property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param areaServed The value to add.
   */
  public void addAreaServed(AdministrativeArea areaServed);
  
  /**
   * Adds a availableLanguage property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param availableLanguage The value to add.
   */
  public void addAvailableLanguage(Language availableLanguage);
  
  /**
   * Adds a contactOption property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param contactOption The value to add.
   */
  public void addContactOption(ContactPointOption contactOption);
  
  /**
   * Adds a contactType property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param contactType The value to add.
   */
  public void addContactType(String contactType);
  
  /**
   * Adds a email property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email);
  
  /**
   * Adds a faxNumber property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber);
  
  /**
   * Adds a hoursAvailable property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param hoursAvailable The value to add.
   */
  public void addHoursAvailable(OpeningHoursSpecification hoursAvailable);
  
  /**
   * Adds a productSupported property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param productSupported The value to add.
   */
  public void addProductSupported(Thing productSupported);
  
  /**
   * Adds a telephone property value for this ContactPoint object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone);
  
}