package org.schema;

import java.util.List;
import org.schema.CreateAction;
import org.schema.FoodEvent;
import org.schema.Recipe;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of producing/preparing food.
 */
public interface CookAction extends CreateAction, SchemaObject {

  /**
   * Get a single foodEstablishment property value for this CookAction object.
   *
   * @return The first foodEstablishment property value.
   */
  public Thing getFoodEstablishment();
  
  /**
   * Get a single foodEvent property value for this CookAction object.
   *
   * @return The first foodEvent property value.
   */
  public FoodEvent getFoodEvent();
  
  /**
   * Get a single recipe property value for this CookAction object.
   *
   * @return The first recipe property value.
   */
  public Recipe getRecipe();
  
  /**
   * Get all the foodEstablishment property values for this CookAction object.
   *
   * @return A list of foodEstablishment property values.
   */
  public List<Thing> getFoodEstablishments();
  
  /**
   * Get all the foodEvent property values for this CookAction object.
   *
   * @return A list of foodEvent property values.
   */
  public List<FoodEvent> getFoodEvents();
  
  /**
   * Get all the recipe property values for this CookAction object.
   *
   * @return A list of recipe property values.
   */
  public List<Recipe> getRecipes();
  
  /**
   * Set the foodEstablishment property value for this CookAction object; overwriting any existing values.
   *
   * @param foodEstablishment The value to set.
   */
  public void setFoodEstablishment(Thing foodEstablishment);
  
  /**
   * Set the foodEvent property value for this CookAction object; overwriting any existing values.
   *
   * @param foodEvent The value to set.
   */
  public void setFoodEvent(FoodEvent foodEvent);
  
  /**
   * Set the recipe property value for this CookAction object; overwriting any existing values.
   *
   * @param recipe The value to set.
   */
  public void setRecipe(Recipe recipe);
  
  /**
   * Set the foodEstablishment property values for this CookAction object; overwriting any existing values.
   *
   * @param foodEstablishments The list of values to set.
   */
  public void setFoodEstablishments(List<Thing> foodEstablishments);
  
  /**
   * Set the foodEvent property values for this CookAction object; overwriting any existing values.
   *
   * @param foodEvents The list of values to set.
   */
  public void setFoodEvents(List<FoodEvent> foodEvents);
  
  /**
   * Set the recipe property values for this CookAction object; overwriting any existing values.
   *
   * @param recipes The list of values to set.
   */
  public void setRecipes(List<Recipe> recipes);
  
  /**
   * Adds a foodEstablishment property value for this CookAction object; appending it to the list of existing values.
   *
   * @param foodEstablishment The value to add.
   */
  public void addFoodEstablishment(Thing foodEstablishment);
  
  /**
   * Adds a foodEvent property value for this CookAction object; appending it to the list of existing values.
   *
   * @param foodEvent The value to add.
   */
  public void addFoodEvent(FoodEvent foodEvent);
  
  /**
   * Adds a recipe property value for this CookAction object; appending it to the list of existing values.
   *
   * @param recipe The value to add.
   */
  public void addRecipe(Recipe recipe);
  
}