package org.schema;

import java.lang.Boolean;
import java.lang.Long;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.AlignmentObject;
import org.schema.Audience;
import org.schema.AudioObject;
import org.schema.Duration;
import org.schema.MediaObject;
import org.schema.Number;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.Review;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.VideoObject;

/**
 * The most generic kind of creative work, including books, movies, photographs, software programs, etc.
 */
public interface CreativeWork extends Thing, SchemaObject {

  /**
   * Get a single about property value for this CreativeWork object.
   *
   * @return The first about property value.
   */
  public Thing getAbout();
  
  /**
   * Get a single accessibilityAPI property value for this CreativeWork object.
   *
   * @return The first accessibilityAPI property value.
   */
  public String getAccessibilityAPI();
  
  /**
   * Get a single accessibilityControl property value for this CreativeWork object.
   *
   * @return The first accessibilityControl property value.
   */
  public String getAccessibilityControl();
  
  /**
   * Get a single accessibilityFeature property value for this CreativeWork object.
   *
   * @return The first accessibilityFeature property value.
   */
  public String getAccessibilityFeature();
  
  /**
   * Get a single accessibilityHazard property value for this CreativeWork object.
   *
   * @return The first accessibilityHazard property value.
   */
  public String getAccessibilityHazard();
  
  /**
   * Get a single accountablePerson property value for this CreativeWork object.
   *
   * @return The first accountablePerson property value.
   */
  public Person getAccountablePerson();
  
  /**
   * Get a single aggregateRating property value for this CreativeWork object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating();
  
  /**
   * Get a single alternativeHeadline property value for this CreativeWork object.
   *
   * @return The first alternativeHeadline property value.
   */
  public String getAlternativeHeadline();
  
  /**
   * Get a single associatedMedia property value for this CreativeWork object.
   *
   * @return The first associatedMedia property value.
   */
  public MediaObject getAssociatedMedia();
  
  /**
   * Get a single audience property value for this CreativeWork object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience();
  
  /**
   * Get a single audio property value for this CreativeWork object.
   *
   * @return The first audio property value.
   */
  public AudioObject getAudio();
  
  /**
   * Get a single author property value for this CreativeWork object.
   *
   * @return The first author property value.
   */
  public Thing getAuthor();
  
  /**
   * Get a single award property value for this CreativeWork object.
   *
   * @return The first award property value.
   */
  public String getAward();
  
  /**
   * Get a single citation property value for this CreativeWork object.
   *
   * @return The first citation property value.
   */
  public Thing getCitation();
  
  /**
   * Get a single comment property value for this CreativeWork object.
   *
   * @return The first comment property value.
   */
  public Thing getComment();
  
  /**
   * Get a single commentCount property value for this CreativeWork object.
   *
   * @return The first commentCount property value.
   */
  public Long getCommentCount();
  
  /**
   * Get a single contentLocation property value for this CreativeWork object.
   *
   * @return The first contentLocation property value.
   */
  public Place getContentLocation();
  
  /**
   * Get a single contentRating property value for this CreativeWork object.
   *
   * @return The first contentRating property value.
   */
  public String getContentRating();
  
  /**
   * Get a single contributor property value for this CreativeWork object.
   *
   * @return The first contributor property value.
   */
  public Thing getContributor();
  
  /**
   * Get a single copyrightHolder property value for this CreativeWork object.
   *
   * @return The first copyrightHolder property value.
   */
  public Thing getCopyrightHolder();
  
  /**
   * Get a single copyrightYear property value for this CreativeWork object.
   *
   * @return The first copyrightYear property value.
   */
  public Number getCopyrightYear();
  
  /**
   * Get a single creator property value for this CreativeWork object.
   *
   * @return The first creator property value.
   */
  public Thing getCreator();
  
  /**
   * Get a single dateCreated property value for this CreativeWork object.
   *
   * @return The first dateCreated property value.
   */
  public Date getDateCreated();
  
  /**
   * Get a single dateModified property value for this CreativeWork object.
   *
   * @return The first dateModified property value.
   */
  public Date getDateModified();
  
  /**
   * Get a single datePublished property value for this CreativeWork object.
   *
   * @return The first datePublished property value.
   */
  public Date getDatePublished();
  
  /**
   * Get a single discussionUrl property value for this CreativeWork object.
   *
   * @return The first discussionUrl property value.
   */
  public URL getDiscussionUrl();
  
  /**
   * Get a single editor property value for this CreativeWork object.
   *
   * @return The first editor property value.
   */
  public Person getEditor();
  
  /**
   * Get a single educationalAlignment property value for this CreativeWork object.
   *
   * @return The first educationalAlignment property value.
   */
  public AlignmentObject getEducationalAlignment();
  
  /**
   * Get a single educationalUse property value for this CreativeWork object.
   *
   * @return The first educationalUse property value.
   */
  public String getEducationalUse();
  
  /**
   * Get a single encoding property value for this CreativeWork object.
   *
   * @return The first encoding property value.
   */
  public MediaObject getEncoding();
  
  /**
   * Get a single genre property value for this CreativeWork object.
   *
   * @return The first genre property value.
   */
  public String getGenre();
  
  /**
   * Get a single headline property value for this CreativeWork object.
   *
   * @return The first headline property value.
   */
  public String getHeadline();
  
  /**
   * Get a single inLanguage property value for this CreativeWork object.
   *
   * @return The first inLanguage property value.
   */
  public String getInLanguage();
  
  /**
   * Get a single interactionCount property value for this CreativeWork object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount();
  
  /**
   * Get a single interactivityType property value for this CreativeWork object.
   *
   * @return The first interactivityType property value.
   */
  public String getInteractivityType();
  
  /**
   * Get a single isBasedOnUrl property value for this CreativeWork object.
   *
   * @return The first isBasedOnUrl property value.
   */
  public URL getIsBasedOnUrl();
  
  /**
   * Get a single isFamilyFriendly property value for this CreativeWork object.
   *
   * @return The first isFamilyFriendly property value.
   */
  public Boolean getIsFamilyFriendly();
  
  /**
   * Get a single keywords property value for this CreativeWork object.
   *
   * @return The first keywords property value.
   */
  public String getKeywords();
  
  /**
   * Get a single learningResourceType property value for this CreativeWork object.
   *
   * @return The first learningResourceType property value.
   */
  public String getLearningResourceType();
  
  /**
   * Get a single mentions property value for this CreativeWork object.
   *
   * @return The first mentions property value.
   */
  public Thing getMentions();
  
  /**
   * Get a single offers property value for this CreativeWork object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers();
  
  /**
   * Get a single provider property value for this CreativeWork object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider();
  
  /**
   * Get a single publisher property value for this CreativeWork object.
   *
   * @return The first publisher property value.
   */
  public Organization getPublisher();
  
  /**
   * Get a single publishingPrinciples property value for this CreativeWork object.
   *
   * @return The first publishingPrinciples property value.
   */
  public URL getPublishingPrinciples();
  
  /**
   * Get a single review property value for this CreativeWork object.
   *
   * @return The first review property value.
   */
  public Review getReview();
  
  /**
   * Get a single sourceOrganization property value for this CreativeWork object.
   *
   * @return The first sourceOrganization property value.
   */
  public Organization getSourceOrganization();
  
  /**
   * Get a single text property value for this CreativeWork object.
   *
   * @return The first text property value.
   */
  public String getText();
  
  /**
   * Get a single thumbnailUrl property value for this CreativeWork object.
   *
   * @return The first thumbnailUrl property value.
   */
  public URL getThumbnailUrl();
  
  /**
   * Get a single timeRequired property value for this CreativeWork object.
   *
   * @return The first timeRequired property value.
   */
  public Duration getTimeRequired();
  
  /**
   * Get a single typicalAgeRange property value for this CreativeWork object.
   *
   * @return The first typicalAgeRange property value.
   */
  public String getTypicalAgeRange();
  
  /**
   * Get a single version property value for this CreativeWork object.
   *
   * @return The first version property value.
   */
  public Number getVersion();
  
  /**
   * Get a single video property value for this CreativeWork object.
   *
   * @return The first video property value.
   */
  public VideoObject getVideo();
  
  /**
   * Get all the about property values for this CreativeWork object.
   *
   * @return A list of about property values.
   */
  public List<Thing> getAbouts();
  
  /**
   * Get all the accessibilityAPI property values for this CreativeWork object.
   *
   * @return A list of accessibilityAPI property values.
   */
  public List<String> getAccessibilityAPIs();
  
  /**
   * Get all the accessibilityControl property values for this CreativeWork object.
   *
   * @return A list of accessibilityControl property values.
   */
  public List<String> getAccessibilityControls();
  
  /**
   * Get all the accessibilityFeature property values for this CreativeWork object.
   *
   * @return A list of accessibilityFeature property values.
   */
  public List<String> getAccessibilityFeatures();
  
  /**
   * Get all the accessibilityHazard property values for this CreativeWork object.
   *
   * @return A list of accessibilityHazard property values.
   */
  public List<String> getAccessibilityHazards();
  
  /**
   * Get all the accountablePerson property values for this CreativeWork object.
   *
   * @return A list of accountablePerson property values.
   */
  public List<Person> getAccountablePersons();
  
  /**
   * Get all the aggregateRating property values for this CreativeWork object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings();
  
  /**
   * Get all the alternativeHeadline property values for this CreativeWork object.
   *
   * @return A list of alternativeHeadline property values.
   */
  public List<String> getAlternativeHeadlines();
  
  /**
   * Get all the associatedMedia property values for this CreativeWork object.
   *
   * @return A list of associatedMedia property values.
   */
  public List<MediaObject> getAssociatedMedias();
  
  /**
   * Get all the audience property values for this CreativeWork object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences();
  
  /**
   * Get all the audio property values for this CreativeWork object.
   *
   * @return A list of audio property values.
   */
  public List<AudioObject> getAudios();
  
  /**
   * Get all the author property values for this CreativeWork object.
   *
   * @return A list of author property values.
   */
  public List<Thing> getAuthors();
  
  /**
   * Get all the award property values for this CreativeWork object.
   *
   * @return A list of award property values.
   */
  public List<String> getAwards();
  
  /**
   * Get all the citation property values for this CreativeWork object.
   *
   * @return A list of citation property values.
   */
  public List<Thing> getCitations();
  
  /**
   * Get all the comment property values for this CreativeWork object.
   *
   * @return A list of comment property values.
   */
  public List<Thing> getComments();
  
  /**
   * Get all the commentCount property values for this CreativeWork object.
   *
   * @return A list of commentCount property values.
   */
  public List<Long> getCommentCounts();
  
  /**
   * Get all the contentLocation property values for this CreativeWork object.
   *
   * @return A list of contentLocation property values.
   */
  public List<Place> getContentLocations();
  
  /**
   * Get all the contentRating property values for this CreativeWork object.
   *
   * @return A list of contentRating property values.
   */
  public List<String> getContentRatings();
  
  /**
   * Get all the contributor property values for this CreativeWork object.
   *
   * @return A list of contributor property values.
   */
  public List<Thing> getContributors();
  
  /**
   * Get all the copyrightHolder property values for this CreativeWork object.
   *
   * @return A list of copyrightHolder property values.
   */
  public List<Thing> getCopyrightHolders();
  
  /**
   * Get all the copyrightYear property values for this CreativeWork object.
   *
   * @return A list of copyrightYear property values.
   */
  public List<Number> getCopyrightYears();
  
  /**
   * Get all the creator property values for this CreativeWork object.
   *
   * @return A list of creator property values.
   */
  public List<Thing> getCreators();
  
  /**
   * Get all the dateCreated property values for this CreativeWork object.
   *
   * @return A list of dateCreated property values.
   */
  public List<Date> getDateCreateds();
  
  /**
   * Get all the dateModified property values for this CreativeWork object.
   *
   * @return A list of dateModified property values.
   */
  public List<Date> getDateModifieds();
  
  /**
   * Get all the datePublished property values for this CreativeWork object.
   *
   * @return A list of datePublished property values.
   */
  public List<Date> getDatePublisheds();
  
  /**
   * Get all the discussionUrl property values for this CreativeWork object.
   *
   * @return A list of discussionUrl property values.
   */
  public List<URL> getDiscussionUrls();
  
  /**
   * Get all the editor property values for this CreativeWork object.
   *
   * @return A list of editor property values.
   */
  public List<Person> getEditors();
  
  /**
   * Get all the educationalAlignment property values for this CreativeWork object.
   *
   * @return A list of educationalAlignment property values.
   */
  public List<AlignmentObject> getEducationalAlignments();
  
  /**
   * Get all the educationalUse property values for this CreativeWork object.
   *
   * @return A list of educationalUse property values.
   */
  public List<String> getEducationalUses();
  
  /**
   * Get all the encoding property values for this CreativeWork object.
   *
   * @return A list of encoding property values.
   */
  public List<MediaObject> getEncodings();
  
  /**
   * Get all the genre property values for this CreativeWork object.
   *
   * @return A list of genre property values.
   */
  public List<String> getGenres();
  
  /**
   * Get all the headline property values for this CreativeWork object.
   *
   * @return A list of headline property values.
   */
  public List<String> getHeadlines();
  
  /**
   * Get all the inLanguage property values for this CreativeWork object.
   *
   * @return A list of inLanguage property values.
   */
  public List<String> getInLanguages();
  
  /**
   * Get all the interactionCount property values for this CreativeWork object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts();
  
  /**
   * Get all the interactivityType property values for this CreativeWork object.
   *
   * @return A list of interactivityType property values.
   */
  public List<String> getInteractivityTypes();
  
  /**
   * Get all the isBasedOnUrl property values for this CreativeWork object.
   *
   * @return A list of isBasedOnUrl property values.
   */
  public List<URL> getIsBasedOnUrls();
  
  /**
   * Get all the isFamilyFriendly property values for this CreativeWork object.
   *
   * @return A list of isFamilyFriendly property values.
   */
  public List<Boolean> getIsFamilyFriendlies();
  
  /**
   * Get all the keywords property values for this CreativeWork object.
   *
   * @return A list of keywords property values.
   */
  public List<String> getKeywordss();
  
  /**
   * Get all the learningResourceType property values for this CreativeWork object.
   *
   * @return A list of learningResourceType property values.
   */
  public List<String> getLearningResourceTypes();
  
  /**
   * Get all the mentions property values for this CreativeWork object.
   *
   * @return A list of mentions property values.
   */
  public List<Thing> getMentionss();
  
  /**
   * Get all the offers property values for this CreativeWork object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss();
  
  /**
   * Get all the provider property values for this CreativeWork object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders();
  
  /**
   * Get all the publisher property values for this CreativeWork object.
   *
   * @return A list of publisher property values.
   */
  public List<Organization> getPublishers();
  
  /**
   * Get all the publishingPrinciples property values for this CreativeWork object.
   *
   * @return A list of publishingPrinciples property values.
   */
  public List<URL> getPublishingPrincipless();
  
  /**
   * Get all the review property values for this CreativeWork object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews();
  
  /**
   * Get all the sourceOrganization property values for this CreativeWork object.
   *
   * @return A list of sourceOrganization property values.
   */
  public List<Organization> getSourceOrganizations();
  
  /**
   * Get all the text property values for this CreativeWork object.
   *
   * @return A list of text property values.
   */
  public List<String> getTexts();
  
  /**
   * Get all the thumbnailUrl property values for this CreativeWork object.
   *
   * @return A list of thumbnailUrl property values.
   */
  public List<URL> getThumbnailUrls();
  
  /**
   * Get all the timeRequired property values for this CreativeWork object.
   *
   * @return A list of timeRequired property values.
   */
  public List<Duration> getTimeRequireds();
  
  /**
   * Get all the typicalAgeRange property values for this CreativeWork object.
   *
   * @return A list of typicalAgeRange property values.
   */
  public List<String> getTypicalAgeRanges();
  
  /**
   * Get all the version property values for this CreativeWork object.
   *
   * @return A list of version property values.
   */
  public List<Number> getVersions();
  
  /**
   * Get all the video property values for this CreativeWork object.
   *
   * @return A list of video property values.
   */
  public List<VideoObject> getVideos();
  
  /**
   * Set the about property value for this CreativeWork object; overwriting any existing values.
   *
   * @param about The value to set.
   */
  public void setAbout(Thing about);
  
  /**
   * Set the accessibilityAPI property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityAPI The value to set.
   */
  public void setAccessibilityAPI(String accessibilityAPI);
  
  /**
   * Set the accessibilityControl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityControl The value to set.
   */
  public void setAccessibilityControl(String accessibilityControl);
  
  /**
   * Set the accessibilityFeature property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityFeature The value to set.
   */
  public void setAccessibilityFeature(String accessibilityFeature);
  
  /**
   * Set the accessibilityHazard property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityHazard The value to set.
   */
  public void setAccessibilityHazard(String accessibilityHazard);
  
  /**
   * Set the accountablePerson property value for this CreativeWork object; overwriting any existing values.
   *
   * @param accountablePerson The value to set.
   */
  public void setAccountablePerson(Person accountablePerson);
  
  /**
   * Set the aggregateRating property value for this CreativeWork object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Set the alternativeHeadline property value for this CreativeWork object; overwriting any existing values.
   *
   * @param alternativeHeadline The value to set.
   */
  public void setAlternativeHeadline(String alternativeHeadline);
  
  /**
   * Set the associatedMedia property value for this CreativeWork object; overwriting any existing values.
   *
   * @param associatedMedia The value to set.
   */
  public void setAssociatedMedia(MediaObject associatedMedia);
  
  /**
   * Set the audience property value for this CreativeWork object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience);
  
  /**
   * Set the audio property value for this CreativeWork object; overwriting any existing values.
   *
   * @param audio The value to set.
   */
  public void setAudio(AudioObject audio);
  
  /**
   * Set the author property value for this CreativeWork object; overwriting any existing values.
   *
   * @param author The value to set.
   */
  public void setAuthor(Thing author);
  
  /**
   * Set the award property value for this CreativeWork object; overwriting any existing values.
   *
   * @param award The value to set.
   */
  public void setAward(String award);
  
  /**
   * Set the citation property value for this CreativeWork object; overwriting any existing values.
   *
   * @param citation The value to set.
   */
  public void setCitation(Thing citation);
  
  /**
   * Set the comment property value for this CreativeWork object; overwriting any existing values.
   *
   * @param comment The value to set.
   */
  public void setComment(Thing comment);
  
  /**
   * Set the commentCount property value for this CreativeWork object; overwriting any existing values.
   *
   * @param commentCount The value to set.
   */
  public void setCommentCount(Long commentCount);
  
  /**
   * Set the contentLocation property value for this CreativeWork object; overwriting any existing values.
   *
   * @param contentLocation The value to set.
   */
  public void setContentLocation(Place contentLocation);
  
  /**
   * Set the contentRating property value for this CreativeWork object; overwriting any existing values.
   *
   * @param contentRating The value to set.
   */
  public void setContentRating(String contentRating);
  
  /**
   * Set the contributor property value for this CreativeWork object; overwriting any existing values.
   *
   * @param contributor The value to set.
   */
  public void setContributor(Thing contributor);
  
  /**
   * Set the copyrightHolder property value for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightHolder The value to set.
   */
  public void setCopyrightHolder(Thing copyrightHolder);
  
  /**
   * Set the copyrightYear property value for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightYear The value to set.
   */
  public void setCopyrightYear(Number copyrightYear);
  
  /**
   * Set the creator property value for this CreativeWork object; overwriting any existing values.
   *
   * @param creator The value to set.
   */
  public void setCreator(Thing creator);
  
  /**
   * Set the dateCreated property value for this CreativeWork object; overwriting any existing values.
   *
   * @param dateCreated The value to set.
   */
  public void setDateCreated(Date dateCreated);
  
  /**
   * Set the dateModified property value for this CreativeWork object; overwriting any existing values.
   *
   * @param dateModified The value to set.
   */
  public void setDateModified(Date dateModified);
  
  /**
   * Set the datePublished property value for this CreativeWork object; overwriting any existing values.
   *
   * @param datePublished The value to set.
   */
  public void setDatePublished(Date datePublished);
  
  /**
   * Set the discussionUrl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param discussionUrl The value to set.
   */
  public void setDiscussionUrl(URL discussionUrl);
  
  /**
   * Set the editor property value for this CreativeWork object; overwriting any existing values.
   *
   * @param editor The value to set.
   */
  public void setEditor(Person editor);
  
  /**
   * Set the educationalAlignment property value for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalAlignment The value to set.
   */
  public void setEducationalAlignment(AlignmentObject educationalAlignment);
  
  /**
   * Set the educationalUse property value for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalUse The value to set.
   */
  public void setEducationalUse(String educationalUse);
  
  /**
   * Set the encoding property value for this CreativeWork object; overwriting any existing values.
   *
   * @param encoding The value to set.
   */
  public void setEncoding(MediaObject encoding);
  
  /**
   * Set the genre property value for this CreativeWork object; overwriting any existing values.
   *
   * @param genre The value to set.
   */
  public void setGenre(String genre);
  
  /**
   * Set the headline property value for this CreativeWork object; overwriting any existing values.
   *
   * @param headline The value to set.
   */
  public void setHeadline(String headline);
  
  /**
   * Set the inLanguage property value for this CreativeWork object; overwriting any existing values.
   *
   * @param inLanguage The value to set.
   */
  public void setInLanguage(String inLanguage);
  
  /**
   * Set the interactionCount property value for this CreativeWork object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount);
  
  /**
   * Set the interactivityType property value for this CreativeWork object; overwriting any existing values.
   *
   * @param interactivityType The value to set.
   */
  public void setInteractivityType(String interactivityType);
  
  /**
   * Set the isBasedOnUrl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param isBasedOnUrl The value to set.
   */
  public void setIsBasedOnUrl(URL isBasedOnUrl);
  
  /**
   * Set the isFamilyFriendly property value for this CreativeWork object; overwriting any existing values.
   *
   * @param isFamilyFriendly The value to set.
   */
  public void setIsFamilyFriendly(Boolean isFamilyFriendly);
  
  /**
   * Set the keywords property value for this CreativeWork object; overwriting any existing values.
   *
   * @param keywords The value to set.
   */
  public void setKeywords(String keywords);
  
  /**
   * Set the learningResourceType property value for this CreativeWork object; overwriting any existing values.
   *
   * @param learningResourceType The value to set.
   */
  public void setLearningResourceType(String learningResourceType);
  
  /**
   * Set the mentions property value for this CreativeWork object; overwriting any existing values.
   *
   * @param mentions The value to set.
   */
  public void setMentions(Thing mentions);
  
  /**
   * Set the offers property value for this CreativeWork object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers);
  
  /**
   * Set the provider property value for this CreativeWork object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider);
  
  /**
   * Set the publisher property value for this CreativeWork object; overwriting any existing values.
   *
   * @param publisher The value to set.
   */
  public void setPublisher(Organization publisher);
  
  /**
   * Set the publishingPrinciples property value for this CreativeWork object; overwriting any existing values.
   *
   * @param publishingPrinciples The value to set.
   */
  public void setPublishingPrinciples(URL publishingPrinciples);
  
  /**
   * Set the review property value for this CreativeWork object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review);
  
  /**
   * Set the sourceOrganization property value for this CreativeWork object; overwriting any existing values.
   *
   * @param sourceOrganization The value to set.
   */
  public void setSourceOrganization(Organization sourceOrganization);
  
  /**
   * Set the text property value for this CreativeWork object; overwriting any existing values.
   *
   * @param text The value to set.
   */
  public void setText(String text);
  
  /**
   * Set the thumbnailUrl property value for this CreativeWork object; overwriting any existing values.
   *
   * @param thumbnailUrl The value to set.
   */
  public void setThumbnailUrl(URL thumbnailUrl);
  
  /**
   * Set the timeRequired property value for this CreativeWork object; overwriting any existing values.
   *
   * @param timeRequired The value to set.
   */
  public void setTimeRequired(Duration timeRequired);
  
  /**
   * Set the typicalAgeRange property value for this CreativeWork object; overwriting any existing values.
   *
   * @param typicalAgeRange The value to set.
   */
  public void setTypicalAgeRange(String typicalAgeRange);
  
  /**
   * Set the version property value for this CreativeWork object; overwriting any existing values.
   *
   * @param version The value to set.
   */
  public void setVersion(Number version);
  
  /**
   * Set the video property value for this CreativeWork object; overwriting any existing values.
   *
   * @param video The value to set.
   */
  public void setVideo(VideoObject video);
  
  /**
   * Set the about property values for this CreativeWork object; overwriting any existing values.
   *
   * @param abouts The list of values to set.
   */
  public void setAbouts(List<Thing> abouts);
  
  /**
   * Set the accessibilityAPI property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityAPIs The list of values to set.
   */
  public void setAccessibilityAPIs(List<String> accessibilityAPIs);
  
  /**
   * Set the accessibilityControl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityControls The list of values to set.
   */
  public void setAccessibilityControls(List<String> accessibilityControls);
  
  /**
   * Set the accessibilityFeature property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityFeatures The list of values to set.
   */
  public void setAccessibilityFeatures(List<String> accessibilityFeatures);
  
  /**
   * Set the accessibilityHazard property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accessibilityHazards The list of values to set.
   */
  public void setAccessibilityHazards(List<String> accessibilityHazards);
  
  /**
   * Set the accountablePerson property values for this CreativeWork object; overwriting any existing values.
   *
   * @param accountablePersons The list of values to set.
   */
  public void setAccountablePersons(List<Person> accountablePersons);
  
  /**
   * Set the aggregateRating property values for this CreativeWork object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings);
  
  /**
   * Set the alternativeHeadline property values for this CreativeWork object; overwriting any existing values.
   *
   * @param alternativeHeadlines The list of values to set.
   */
  public void setAlternativeHeadlines(List<String> alternativeHeadlines);
  
  /**
   * Set the associatedMedia property values for this CreativeWork object; overwriting any existing values.
   *
   * @param associatedMedias The list of values to set.
   */
  public void setAssociatedMedias(List<MediaObject> associatedMedias);
  
  /**
   * Set the audience property values for this CreativeWork object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences);
  
  /**
   * Set the audio property values for this CreativeWork object; overwriting any existing values.
   *
   * @param audios The list of values to set.
   */
  public void setAudios(List<AudioObject> audios);
  
  /**
   * Set the author property values for this CreativeWork object; overwriting any existing values.
   *
   * @param authors The list of values to set.
   */
  public void setAuthors(List<Thing> authors);
  
  /**
   * Set the award property values for this CreativeWork object; overwriting any existing values.
   *
   * @param awards The list of values to set.
   */
  public void setAwards(List<String> awards);
  
  /**
   * Set the citation property values for this CreativeWork object; overwriting any existing values.
   *
   * @param citations The list of values to set.
   */
  public void setCitations(List<Thing> citations);
  
  /**
   * Set the comment property values for this CreativeWork object; overwriting any existing values.
   *
   * @param comments The list of values to set.
   */
  public void setComments(List<Thing> comments);
  
  /**
   * Set the commentCount property values for this CreativeWork object; overwriting any existing values.
   *
   * @param commentCounts The list of values to set.
   */
  public void setCommentCounts(List<Long> commentCounts);
  
  /**
   * Set the contentLocation property values for this CreativeWork object; overwriting any existing values.
   *
   * @param contentLocations The list of values to set.
   */
  public void setContentLocations(List<Place> contentLocations);
  
  /**
   * Set the contentRating property values for this CreativeWork object; overwriting any existing values.
   *
   * @param contentRatings The list of values to set.
   */
  public void setContentRatings(List<String> contentRatings);
  
  /**
   * Set the contributor property values for this CreativeWork object; overwriting any existing values.
   *
   * @param contributors The list of values to set.
   */
  public void setContributors(List<Thing> contributors);
  
  /**
   * Set the copyrightHolder property values for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightHolders The list of values to set.
   */
  public void setCopyrightHolders(List<Thing> copyrightHolders);
  
  /**
   * Set the copyrightYear property values for this CreativeWork object; overwriting any existing values.
   *
   * @param copyrightYears The list of values to set.
   */
  public void setCopyrightYears(List<Number> copyrightYears);
  
  /**
   * Set the creator property values for this CreativeWork object; overwriting any existing values.
   *
   * @param creators The list of values to set.
   */
  public void setCreators(List<Thing> creators);
  
  /**
   * Set the dateCreated property values for this CreativeWork object; overwriting any existing values.
   *
   * @param dateCreateds The list of values to set.
   */
  public void setDateCreateds(List<Date> dateCreateds);
  
  /**
   * Set the dateModified property values for this CreativeWork object; overwriting any existing values.
   *
   * @param dateModifieds The list of values to set.
   */
  public void setDateModifieds(List<Date> dateModifieds);
  
  /**
   * Set the datePublished property values for this CreativeWork object; overwriting any existing values.
   *
   * @param datePublisheds The list of values to set.
   */
  public void setDatePublisheds(List<Date> datePublisheds);
  
  /**
   * Set the discussionUrl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param discussionUrls The list of values to set.
   */
  public void setDiscussionUrls(List<URL> discussionUrls);
  
  /**
   * Set the editor property values for this CreativeWork object; overwriting any existing values.
   *
   * @param editors The list of values to set.
   */
  public void setEditors(List<Person> editors);
  
  /**
   * Set the educationalAlignment property values for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalAlignments The list of values to set.
   */
  public void setEducationalAlignments(List<AlignmentObject> educationalAlignments);
  
  /**
   * Set the educationalUse property values for this CreativeWork object; overwriting any existing values.
   *
   * @param educationalUses The list of values to set.
   */
  public void setEducationalUses(List<String> educationalUses);
  
  /**
   * Set the encoding property values for this CreativeWork object; overwriting any existing values.
   *
   * @param encodings The list of values to set.
   */
  public void setEncodings(List<MediaObject> encodings);
  
  /**
   * Set the genre property values for this CreativeWork object; overwriting any existing values.
   *
   * @param genres The list of values to set.
   */
  public void setGenres(List<String> genres);
  
  /**
   * Set the headline property values for this CreativeWork object; overwriting any existing values.
   *
   * @param headlines The list of values to set.
   */
  public void setHeadlines(List<String> headlines);
  
  /**
   * Set the inLanguage property values for this CreativeWork object; overwriting any existing values.
   *
   * @param inLanguages The list of values to set.
   */
  public void setInLanguages(List<String> inLanguages);
  
  /**
   * Set the interactionCount property values for this CreativeWork object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts);
  
  /**
   * Set the interactivityType property values for this CreativeWork object; overwriting any existing values.
   *
   * @param interactivityTypes The list of values to set.
   */
  public void setInteractivityTypes(List<String> interactivityTypes);
  
  /**
   * Set the isBasedOnUrl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param isBasedOnUrls The list of values to set.
   */
  public void setIsBasedOnUrls(List<URL> isBasedOnUrls);
  
  /**
   * Set the isFamilyFriendly property values for this CreativeWork object; overwriting any existing values.
   *
   * @param isFamilyFriendlies The list of values to set.
   */
  public void setIsFamilyFriendlies(List<Boolean> isFamilyFriendlies);
  
  /**
   * Set the keywords property values for this CreativeWork object; overwriting any existing values.
   *
   * @param keywordss The list of values to set.
   */
  public void setKeywordss(List<String> keywordss);
  
  /**
   * Set the learningResourceType property values for this CreativeWork object; overwriting any existing values.
   *
   * @param learningResourceTypes The list of values to set.
   */
  public void setLearningResourceTypes(List<String> learningResourceTypes);
  
  /**
   * Set the mentions property values for this CreativeWork object; overwriting any existing values.
   *
   * @param mentionss The list of values to set.
   */
  public void setMentionss(List<Thing> mentionss);
  
  /**
   * Set the offers property values for this CreativeWork object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss);
  
  /**
   * Set the provider property values for this CreativeWork object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers);
  
  /**
   * Set the publisher property values for this CreativeWork object; overwriting any existing values.
   *
   * @param publishers The list of values to set.
   */
  public void setPublishers(List<Organization> publishers);
  
  /**
   * Set the publishingPrinciples property values for this CreativeWork object; overwriting any existing values.
   *
   * @param publishingPrincipless The list of values to set.
   */
  public void setPublishingPrincipless(List<URL> publishingPrincipless);
  
  /**
   * Set the review property values for this CreativeWork object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews);
  
  /**
   * Set the sourceOrganization property values for this CreativeWork object; overwriting any existing values.
   *
   * @param sourceOrganizations The list of values to set.
   */
  public void setSourceOrganizations(List<Organization> sourceOrganizations);
  
  /**
   * Set the text property values for this CreativeWork object; overwriting any existing values.
   *
   * @param texts The list of values to set.
   */
  public void setTexts(List<String> texts);
  
  /**
   * Set the thumbnailUrl property values for this CreativeWork object; overwriting any existing values.
   *
   * @param thumbnailUrls The list of values to set.
   */
  public void setThumbnailUrls(List<URL> thumbnailUrls);
  
  /**
   * Set the timeRequired property values for this CreativeWork object; overwriting any existing values.
   *
   * @param timeRequireds The list of values to set.
   */
  public void setTimeRequireds(List<Duration> timeRequireds);
  
  /**
   * Set the typicalAgeRange property values for this CreativeWork object; overwriting any existing values.
   *
   * @param typicalAgeRanges The list of values to set.
   */
  public void setTypicalAgeRanges(List<String> typicalAgeRanges);
  
  /**
   * Set the version property values for this CreativeWork object; overwriting any existing values.
   *
   * @param versions The list of values to set.
   */
  public void setVersions(List<Number> versions);
  
  /**
   * Set the video property values for this CreativeWork object; overwriting any existing values.
   *
   * @param videos The list of values to set.
   */
  public void setVideos(List<VideoObject> videos);
  
  /**
   * Adds a about property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param about The value to add.
   */
  public void addAbout(Thing about);
  
  /**
   * Adds a accessibilityAPI property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityAPI The value to add.
   */
  public void addAccessibilityAPI(String accessibilityAPI);
  
  /**
   * Adds a accessibilityControl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityControl The value to add.
   */
  public void addAccessibilityControl(String accessibilityControl);
  
  /**
   * Adds a accessibilityFeature property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityFeature The value to add.
   */
  public void addAccessibilityFeature(String accessibilityFeature);
  
  /**
   * Adds a accessibilityHazard property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accessibilityHazard The value to add.
   */
  public void addAccessibilityHazard(String accessibilityHazard);
  
  /**
   * Adds a accountablePerson property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param accountablePerson The value to add.
   */
  public void addAccountablePerson(Person accountablePerson);
  
  /**
   * Adds a aggregateRating property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Adds a alternativeHeadline property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param alternativeHeadline The value to add.
   */
  public void addAlternativeHeadline(String alternativeHeadline);
  
  /**
   * Adds a associatedMedia property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param associatedMedia The value to add.
   */
  public void addAssociatedMedia(MediaObject associatedMedia);
  
  /**
   * Adds a audience property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience);
  
  /**
   * Adds a audio property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param audio The value to add.
   */
  public void addAudio(AudioObject audio);
  
  /**
   * Adds a author property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param author The value to add.
   */
  public void addAuthor(Thing author);
  
  /**
   * Adds a award property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param award The value to add.
   */
  public void addAward(String award);
  
  /**
   * Adds a citation property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param citation The value to add.
   */
  public void addCitation(Thing citation);
  
  /**
   * Adds a comment property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param comment The value to add.
   */
  public void addComment(Thing comment);
  
  /**
   * Adds a commentCount property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param commentCount The value to add.
   */
  public void addCommentCount(Long commentCount);
  
  /**
   * Adds a contentLocation property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param contentLocation The value to add.
   */
  public void addContentLocation(Place contentLocation);
  
  /**
   * Adds a contentRating property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param contentRating The value to add.
   */
  public void addContentRating(String contentRating);
  
  /**
   * Adds a contributor property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param contributor The value to add.
   */
  public void addContributor(Thing contributor);
  
  /**
   * Adds a copyrightHolder property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param copyrightHolder The value to add.
   */
  public void addCopyrightHolder(Thing copyrightHolder);
  
  /**
   * Adds a copyrightYear property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param copyrightYear The value to add.
   */
  public void addCopyrightYear(Number copyrightYear);
  
  /**
   * Adds a creator property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param creator The value to add.
   */
  public void addCreator(Thing creator);
  
  /**
   * Adds a dateCreated property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param dateCreated The value to add.
   */
  public void addDateCreated(Date dateCreated);
  
  /**
   * Adds a dateModified property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param dateModified The value to add.
   */
  public void addDateModified(Date dateModified);
  
  /**
   * Adds a datePublished property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param datePublished The value to add.
   */
  public void addDatePublished(Date datePublished);
  
  /**
   * Adds a discussionUrl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param discussionUrl The value to add.
   */
  public void addDiscussionUrl(URL discussionUrl);
  
  /**
   * Adds a editor property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param editor The value to add.
   */
  public void addEditor(Person editor);
  
  /**
   * Adds a educationalAlignment property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param educationalAlignment The value to add.
   */
  public void addEducationalAlignment(AlignmentObject educationalAlignment);
  
  /**
   * Adds a educationalUse property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param educationalUse The value to add.
   */
  public void addEducationalUse(String educationalUse);
  
  /**
   * Adds a encoding property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param encoding The value to add.
   */
  public void addEncoding(MediaObject encoding);
  
  /**
   * Adds a genre property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param genre The value to add.
   */
  public void addGenre(String genre);
  
  /**
   * Adds a headline property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param headline The value to add.
   */
  public void addHeadline(String headline);
  
  /**
   * Adds a inLanguage property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param inLanguage The value to add.
   */
  public void addInLanguage(String inLanguage);
  
  /**
   * Adds a interactionCount property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount);
  
  /**
   * Adds a interactivityType property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param interactivityType The value to add.
   */
  public void addInteractivityType(String interactivityType);
  
  /**
   * Adds a isBasedOnUrl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param isBasedOnUrl The value to add.
   */
  public void addIsBasedOnUrl(URL isBasedOnUrl);
  
  /**
   * Adds a isFamilyFriendly property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param isFamilyFriendly The value to add.
   */
  public void addIsFamilyFriendly(Boolean isFamilyFriendly);
  
  /**
   * Adds a keywords property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param keywords The value to add.
   */
  public void addKeywords(String keywords);
  
  /**
   * Adds a learningResourceType property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param learningResourceType The value to add.
   */
  public void addLearningResourceType(String learningResourceType);
  
  /**
   * Adds a mentions property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param mentions The value to add.
   */
  public void addMentions(Thing mentions);
  
  /**
   * Adds a offers property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers);
  
  /**
   * Adds a provider property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider);
  
  /**
   * Adds a publisher property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param publisher The value to add.
   */
  public void addPublisher(Organization publisher);
  
  /**
   * Adds a publishingPrinciples property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param publishingPrinciples The value to add.
   */
  public void addPublishingPrinciples(URL publishingPrinciples);
  
  /**
   * Adds a review property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review);
  
  /**
   * Adds a sourceOrganization property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param sourceOrganization The value to add.
   */
  public void addSourceOrganization(Organization sourceOrganization);
  
  /**
   * Adds a text property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param text The value to add.
   */
  public void addText(String text);
  
  /**
   * Adds a thumbnailUrl property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param thumbnailUrl The value to add.
   */
  public void addThumbnailUrl(URL thumbnailUrl);
  
  /**
   * Adds a timeRequired property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param timeRequired The value to add.
   */
  public void addTimeRequired(Duration timeRequired);
  
  /**
   * Adds a typicalAgeRange property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param typicalAgeRange The value to add.
   */
  public void addTypicalAgeRange(String typicalAgeRange);
  
  /**
   * Adds a version property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param version The value to add.
   */
  public void addVersion(Number version);
  
  /**
   * Adds a video property value for this CreativeWork object; appending it to the list of existing values.
   *
   * @param video The value to add.
   */
  public void addVideo(VideoObject video);
  
}