package org.schema;

import java.util.List;
import org.schema.MedicalCondition;
import org.schema.MedicalIntangible;
import org.schema.MedicalSignOrSymptom;
import org.schema.SchemaObject;

/**
 * An alternative, closely-related condition typically considered later in the differential diagnosis process along with the signs that are used to distinguish it.
 */
public interface DDxElement extends MedicalIntangible, SchemaObject {

  /**
   * Get a single diagnosis property value for this DDxElement object.
   *
   * @return The first diagnosis property value.
   */
  public MedicalCondition getDiagnosis();
  
  /**
   * Get a single distinguishingSign property value for this DDxElement object.
   *
   * @return The first distinguishingSign property value.
   */
  public MedicalSignOrSymptom getDistinguishingSign();
  
  /**
   * Get all the diagnosis property values for this DDxElement object.
   *
   * @return A list of diagnosis property values.
   */
  public List<MedicalCondition> getDiagnoses();
  
  /**
   * Get all the distinguishingSign property values for this DDxElement object.
   *
   * @return A list of distinguishingSign property values.
   */
  public List<MedicalSignOrSymptom> getDistinguishingSigns();
  
  /**
   * Set the diagnosis property value for this DDxElement object; overwriting any existing values.
   *
   * @param diagnosis The value to set.
   */
  public void setDiagnosis(MedicalCondition diagnosis);
  
  /**
   * Set the distinguishingSign property value for this DDxElement object; overwriting any existing values.
   *
   * @param distinguishingSign The value to set.
   */
  public void setDistinguishingSign(MedicalSignOrSymptom distinguishingSign);
  
  /**
   * Set the diagnosis property values for this DDxElement object; overwriting any existing values.
   *
   * @param diagnoses The list of values to set.
   */
  public void setDiagnoses(List<MedicalCondition> diagnoses);
  
  /**
   * Set the distinguishingSign property values for this DDxElement object; overwriting any existing values.
   *
   * @param distinguishingSigns The list of values to set.
   */
  public void setDistinguishingSigns(List<MedicalSignOrSymptom> distinguishingSigns);
  
  /**
   * Adds a diagnosis property value for this DDxElement object; appending it to the list of existing values.
   *
   * @param diagnosis The value to add.
   */
  public void addDiagnosis(MedicalCondition diagnosis);
  
  /**
   * Adds a distinguishingSign property value for this DDxElement object; appending it to the list of existing values.
   *
   * @param distinguishingSign The value to add.
   */
  public void addDistinguishingSign(MedicalSignOrSymptom distinguishingSign);
  
}