package org.schema;

import java.util.List;
import org.schema.DeliveryMethod;
import org.schema.PriceSpecification;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The price for the delivery of an offer using a particular delivery method.
 */
public interface DeliveryChargeSpecification extends PriceSpecification, SchemaObject {

  /**
   * Get a single appliesToDeliveryMethod property value for this DeliveryChargeSpecification object.
   *
   * @return The first appliesToDeliveryMethod property value.
   */
  public DeliveryMethod getAppliesToDeliveryMethod();
  
  /**
   * Get a single eligibleRegion property value for this DeliveryChargeSpecification object.
   *
   * @return The first eligibleRegion property value.
   */
  public Thing getEligibleRegion();
  
  /**
   * Get all the appliesToDeliveryMethod property values for this DeliveryChargeSpecification object.
   *
   * @return A list of appliesToDeliveryMethod property values.
   */
  public List<DeliveryMethod> getAppliesToDeliveryMethods();
  
  /**
   * Get all the eligibleRegion property values for this DeliveryChargeSpecification object.
   *
   * @return A list of eligibleRegion property values.
   */
  public List<Thing> getEligibleRegions();
  
  /**
   * Set the appliesToDeliveryMethod property value for this DeliveryChargeSpecification object; overwriting any existing values.
   *
   * @param appliesToDeliveryMethod The value to set.
   */
  public void setAppliesToDeliveryMethod(DeliveryMethod appliesToDeliveryMethod);
  
  /**
   * Set the eligibleRegion property value for this DeliveryChargeSpecification object; overwriting any existing values.
   *
   * @param eligibleRegion The value to set.
   */
  public void setEligibleRegion(Thing eligibleRegion);
  
  /**
   * Set the appliesToDeliveryMethod property values for this DeliveryChargeSpecification object; overwriting any existing values.
   *
   * @param appliesToDeliveryMethods The list of values to set.
   */
  public void setAppliesToDeliveryMethods(List<DeliveryMethod> appliesToDeliveryMethods);
  
  /**
   * Set the eligibleRegion property values for this DeliveryChargeSpecification object; overwriting any existing values.
   *
   * @param eligibleRegions The list of values to set.
   */
  public void setEligibleRegions(List<Thing> eligibleRegions);
  
  /**
   * Adds a appliesToDeliveryMethod property value for this DeliveryChargeSpecification object; appending it to the list of existing values.
   *
   * @param appliesToDeliveryMethod The value to add.
   */
  public void addAppliesToDeliveryMethod(DeliveryMethod appliesToDeliveryMethod);
  
  /**
   * Adds a eligibleRegion property value for this DeliveryChargeSpecification object; appending it to the list of existing values.
   *
   * @param eligibleRegion The value to add.
   */
  public void addEligibleRegion(Thing eligibleRegion);
  
}