package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.DeliveryMethod;
import org.schema.Event;
import org.schema.SchemaObject;

/**
 * An event involving the delivery of an item.
 */
public interface DeliveryEvent extends Event, SchemaObject {

  /**
   * Get a single accessCode property value for this DeliveryEvent object.
   *
   * @return The first accessCode property value.
   */
  public String getAccessCode();
  
  /**
   * Get a single availableFrom property value for this DeliveryEvent object.
   *
   * @return The first availableFrom property value.
   */
  public Date getAvailableFrom();
  
  /**
   * Get a single availableThrough property value for this DeliveryEvent object.
   *
   * @return The first availableThrough property value.
   */
  public Date getAvailableThrough();
  
  /**
   * Get a single hasDeliveryMethod property value for this DeliveryEvent object.
   *
   * @return The first hasDeliveryMethod property value.
   */
  public DeliveryMethod getHasDeliveryMethod();
  
  /**
   * Get all the accessCode property values for this DeliveryEvent object.
   *
   * @return A list of accessCode property values.
   */
  public List<String> getAccessCodes();
  
  /**
   * Get all the availableFrom property values for this DeliveryEvent object.
   *
   * @return A list of availableFrom property values.
   */
  public List<Date> getAvailableFroms();
  
  /**
   * Get all the availableThrough property values for this DeliveryEvent object.
   *
   * @return A list of availableThrough property values.
   */
  public List<Date> getAvailableThroughs();
  
  /**
   * Get all the hasDeliveryMethod property values for this DeliveryEvent object.
   *
   * @return A list of hasDeliveryMethod property values.
   */
  public List<DeliveryMethod> getHasDeliveryMethods();
  
  /**
   * Set the accessCode property value for this DeliveryEvent object; overwriting any existing values.
   *
   * @param accessCode The value to set.
   */
  public void setAccessCode(String accessCode);
  
  /**
   * Set the availableFrom property value for this DeliveryEvent object; overwriting any existing values.
   *
   * @param availableFrom The value to set.
   */
  public void setAvailableFrom(Date availableFrom);
  
  /**
   * Set the availableThrough property value for this DeliveryEvent object; overwriting any existing values.
   *
   * @param availableThrough The value to set.
   */
  public void setAvailableThrough(Date availableThrough);
  
  /**
   * Set the hasDeliveryMethod property value for this DeliveryEvent object; overwriting any existing values.
   *
   * @param hasDeliveryMethod The value to set.
   */
  public void setHasDeliveryMethod(DeliveryMethod hasDeliveryMethod);
  
  /**
   * Set the accessCode property values for this DeliveryEvent object; overwriting any existing values.
   *
   * @param accessCodes The list of values to set.
   */
  public void setAccessCodes(List<String> accessCodes);
  
  /**
   * Set the availableFrom property values for this DeliveryEvent object; overwriting any existing values.
   *
   * @param availableFroms The list of values to set.
   */
  public void setAvailableFroms(List<Date> availableFroms);
  
  /**
   * Set the availableThrough property values for this DeliveryEvent object; overwriting any existing values.
   *
   * @param availableThroughs The list of values to set.
   */
  public void setAvailableThroughs(List<Date> availableThroughs);
  
  /**
   * Set the hasDeliveryMethod property values for this DeliveryEvent object; overwriting any existing values.
   *
   * @param hasDeliveryMethods The list of values to set.
   */
  public void setHasDeliveryMethods(List<DeliveryMethod> hasDeliveryMethods);
  
  /**
   * Adds a accessCode property value for this DeliveryEvent object; appending it to the list of existing values.
   *
   * @param accessCode The value to add.
   */
  public void addAccessCode(String accessCode);
  
  /**
   * Adds a availableFrom property value for this DeliveryEvent object; appending it to the list of existing values.
   *
   * @param availableFrom The value to add.
   */
  public void addAvailableFrom(Date availableFrom);
  
  /**
   * Adds a availableThrough property value for this DeliveryEvent object; appending it to the list of existing values.
   *
   * @param availableThrough The value to add.
   */
  public void addAvailableThrough(Date availableThrough);
  
  /**
   * Adds a hasDeliveryMethod property value for this DeliveryEvent object; appending it to the list of existing values.
   *
   * @param hasDeliveryMethod The value to add.
   */
  public void addHasDeliveryMethod(DeliveryMethod hasDeliveryMethod);
  
}