package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.BusinessEntityType;
import org.schema.BusinessFunction;
import org.schema.DeliveryMethod;
import org.schema.Intangible;
import org.schema.ItemAvailability;
import org.schema.OfferItemCondition;
import org.schema.PaymentMethod;
import org.schema.Place;
import org.schema.PriceSpecification;
import org.schema.Product;
import org.schema.QuantitativeValue;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TypeAndQuantityNode;
import org.schema.WarrantyPromise;

/**
 * A demand entity represents the public, not necessarily binding, not necessarily exclusive, announcement by an organization or person to seek a certain type of goods or services. For describing demand using this type, the very same properties used for Offer apply.
 */
public interface Demand extends Intangible, SchemaObject {

  /**
   * Get a single acceptedPaymentMethod property value for this Demand object.
   *
   * @return The first acceptedPaymentMethod property value.
   */
  public PaymentMethod getAcceptedPaymentMethod();
  
  /**
   * Get a single advanceBookingRequirement property value for this Demand object.
   *
   * @return The first advanceBookingRequirement property value.
   */
  public QuantitativeValue getAdvanceBookingRequirement();
  
  /**
   * Get a single availability property value for this Demand object.
   *
   * @return The first availability property value.
   */
  public ItemAvailability getAvailability();
  
  /**
   * Get a single availabilityEnds property value for this Demand object.
   *
   * @return The first availabilityEnds property value.
   */
  public Date getAvailabilityEnds();
  
  /**
   * Get a single availabilityStarts property value for this Demand object.
   *
   * @return The first availabilityStarts property value.
   */
  public Date getAvailabilityStarts();
  
  /**
   * Get a single availableAtOrFrom property value for this Demand object.
   *
   * @return The first availableAtOrFrom property value.
   */
  public Place getAvailableAtOrFrom();
  
  /**
   * Get a single availableDeliveryMethod property value for this Demand object.
   *
   * @return The first availableDeliveryMethod property value.
   */
  public DeliveryMethod getAvailableDeliveryMethod();
  
  /**
   * Get a single businessFunction property value for this Demand object.
   *
   * @return The first businessFunction property value.
   */
  public BusinessFunction getBusinessFunction();
  
  /**
   * Get a single deliveryLeadTime property value for this Demand object.
   *
   * @return The first deliveryLeadTime property value.
   */
  public QuantitativeValue getDeliveryLeadTime();
  
  /**
   * Get a single eligibleCustomerType property value for this Demand object.
   *
   * @return The first eligibleCustomerType property value.
   */
  public BusinessEntityType getEligibleCustomerType();
  
  /**
   * Get a single eligibleDuration property value for this Demand object.
   *
   * @return The first eligibleDuration property value.
   */
  public QuantitativeValue getEligibleDuration();
  
  /**
   * Get a single eligibleQuantity property value for this Demand object.
   *
   * @return The first eligibleQuantity property value.
   */
  public QuantitativeValue getEligibleQuantity();
  
  /**
   * Get a single eligibleRegion property value for this Demand object.
   *
   * @return The first eligibleRegion property value.
   */
  public Thing getEligibleRegion();
  
  /**
   * Get a single eligibleTransactionVolume property value for this Demand object.
   *
   * @return The first eligibleTransactionVolume property value.
   */
  public PriceSpecification getEligibleTransactionVolume();
  
  /**
   * Get a single gtin13 property value for this Demand object.
   *
   * @return The first gtin13 property value.
   */
  public String getGtin13();
  
  /**
   * Get a single gtin14 property value for this Demand object.
   *
   * @return The first gtin14 property value.
   */
  public String getGtin14();
  
  /**
   * Get a single gtin8 property value for this Demand object.
   *
   * @return The first gtin8 property value.
   */
  public String getGtin8();
  
  /**
   * Get a single includesObject property value for this Demand object.
   *
   * @return The first includesObject property value.
   */
  public TypeAndQuantityNode getIncludesObject();
  
  /**
   * Get a single inventoryLevel property value for this Demand object.
   *
   * @return The first inventoryLevel property value.
   */
  public QuantitativeValue getInventoryLevel();
  
  /**
   * Get a single itemCondition property value for this Demand object.
   *
   * @return The first itemCondition property value.
   */
  public OfferItemCondition getItemCondition();
  
  /**
   * Get a single itemOffered property value for this Demand object.
   *
   * @return The first itemOffered property value.
   */
  public Product getItemOffered();
  
  /**
   * Get a single mpn property value for this Demand object.
   *
   * @return The first mpn property value.
   */
  public String getMpn();
  
  /**
   * Get a single priceSpecification property value for this Demand object.
   *
   * @return The first priceSpecification property value.
   */
  public PriceSpecification getPriceSpecification();
  
  /**
   * Get a single seller property value for this Demand object.
   *
   * @return The first seller property value.
   */
  public Thing getSeller();
  
  /**
   * Get a single serialNumber property value for this Demand object.
   *
   * @return The first serialNumber property value.
   */
  public String getSerialNumber();
  
  /**
   * Get a single sku property value for this Demand object.
   *
   * @return The first sku property value.
   */
  public String getSku();
  
  /**
   * Get a single validFrom property value for this Demand object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom();
  
  /**
   * Get a single validThrough property value for this Demand object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough();
  
  /**
   * Get a single warranty property value for this Demand object.
   *
   * @return The first warranty property value.
   */
  public WarrantyPromise getWarranty();
  
  /**
   * Get all the acceptedPaymentMethod property values for this Demand object.
   *
   * @return A list of acceptedPaymentMethod property values.
   */
  public List<PaymentMethod> getAcceptedPaymentMethods();
  
  /**
   * Get all the advanceBookingRequirement property values for this Demand object.
   *
   * @return A list of advanceBookingRequirement property values.
   */
  public List<QuantitativeValue> getAdvanceBookingRequirements();
  
  /**
   * Get all the availability property values for this Demand object.
   *
   * @return A list of availability property values.
   */
  public List<ItemAvailability> getAvailabilities();
  
  /**
   * Get all the availabilityEnds property values for this Demand object.
   *
   * @return A list of availabilityEnds property values.
   */
  public List<Date> getAvailabilityEndss();
  
  /**
   * Get all the availabilityStarts property values for this Demand object.
   *
   * @return A list of availabilityStarts property values.
   */
  public List<Date> getAvailabilityStartss();
  
  /**
   * Get all the availableAtOrFrom property values for this Demand object.
   *
   * @return A list of availableAtOrFrom property values.
   */
  public List<Place> getAvailableAtOrFroms();
  
  /**
   * Get all the availableDeliveryMethod property values for this Demand object.
   *
   * @return A list of availableDeliveryMethod property values.
   */
  public List<DeliveryMethod> getAvailableDeliveryMethods();
  
  /**
   * Get all the businessFunction property values for this Demand object.
   *
   * @return A list of businessFunction property values.
   */
  public List<BusinessFunction> getBusinessFunctions();
  
  /**
   * Get all the deliveryLeadTime property values for this Demand object.
   *
   * @return A list of deliveryLeadTime property values.
   */
  public List<QuantitativeValue> getDeliveryLeadTimes();
  
  /**
   * Get all the eligibleCustomerType property values for this Demand object.
   *
   * @return A list of eligibleCustomerType property values.
   */
  public List<BusinessEntityType> getEligibleCustomerTypes();
  
  /**
   * Get all the eligibleDuration property values for this Demand object.
   *
   * @return A list of eligibleDuration property values.
   */
  public List<QuantitativeValue> getEligibleDurations();
  
  /**
   * Get all the eligibleQuantity property values for this Demand object.
   *
   * @return A list of eligibleQuantity property values.
   */
  public List<QuantitativeValue> getEligibleQuantities();
  
  /**
   * Get all the eligibleRegion property values for this Demand object.
   *
   * @return A list of eligibleRegion property values.
   */
  public List<Thing> getEligibleRegions();
  
  /**
   * Get all the eligibleTransactionVolume property values for this Demand object.
   *
   * @return A list of eligibleTransactionVolume property values.
   */
  public List<PriceSpecification> getEligibleTransactionVolumes();
  
  /**
   * Get all the gtin13 property values for this Demand object.
   *
   * @return A list of gtin13 property values.
   */
  public List<String> getGtin13s();
  
  /**
   * Get all the gtin14 property values for this Demand object.
   *
   * @return A list of gtin14 property values.
   */
  public List<String> getGtin14s();
  
  /**
   * Get all the gtin8 property values for this Demand object.
   *
   * @return A list of gtin8 property values.
   */
  public List<String> getGtin8s();
  
  /**
   * Get all the includesObject property values for this Demand object.
   *
   * @return A list of includesObject property values.
   */
  public List<TypeAndQuantityNode> getIncludesObjects();
  
  /**
   * Get all the inventoryLevel property values for this Demand object.
   *
   * @return A list of inventoryLevel property values.
   */
  public List<QuantitativeValue> getInventoryLevels();
  
  /**
   * Get all the itemCondition property values for this Demand object.
   *
   * @return A list of itemCondition property values.
   */
  public List<OfferItemCondition> getItemConditions();
  
  /**
   * Get all the itemOffered property values for this Demand object.
   *
   * @return A list of itemOffered property values.
   */
  public List<Product> getItemOffereds();
  
  /**
   * Get all the mpn property values for this Demand object.
   *
   * @return A list of mpn property values.
   */
  public List<String> getMpns();
  
  /**
   * Get all the priceSpecification property values for this Demand object.
   *
   * @return A list of priceSpecification property values.
   */
  public List<PriceSpecification> getPriceSpecifications();
  
  /**
   * Get all the seller property values for this Demand object.
   *
   * @return A list of seller property values.
   */
  public List<Thing> getSellers();
  
  /**
   * Get all the serialNumber property values for this Demand object.
   *
   * @return A list of serialNumber property values.
   */
  public List<String> getSerialNumbers();
  
  /**
   * Get all the sku property values for this Demand object.
   *
   * @return A list of sku property values.
   */
  public List<String> getSkus();
  
  /**
   * Get all the validFrom property values for this Demand object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms();
  
  /**
   * Get all the validThrough property values for this Demand object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs();
  
  /**
   * Get all the warranty property values for this Demand object.
   *
   * @return A list of warranty property values.
   */
  public List<WarrantyPromise> getWarranties();
  
  /**
   * Set the acceptedPaymentMethod property value for this Demand object; overwriting any existing values.
   *
   * @param acceptedPaymentMethod The value to set.
   */
  public void setAcceptedPaymentMethod(PaymentMethod acceptedPaymentMethod);
  
  /**
   * Set the advanceBookingRequirement property value for this Demand object; overwriting any existing values.
   *
   * @param advanceBookingRequirement The value to set.
   */
  public void setAdvanceBookingRequirement(QuantitativeValue advanceBookingRequirement);
  
  /**
   * Set the availability property value for this Demand object; overwriting any existing values.
   *
   * @param availability The value to set.
   */
  public void setAvailability(ItemAvailability availability);
  
  /**
   * Set the availabilityEnds property value for this Demand object; overwriting any existing values.
   *
   * @param availabilityEnds The value to set.
   */
  public void setAvailabilityEnds(Date availabilityEnds);
  
  /**
   * Set the availabilityStarts property value for this Demand object; overwriting any existing values.
   *
   * @param availabilityStarts The value to set.
   */
  public void setAvailabilityStarts(Date availabilityStarts);
  
  /**
   * Set the availableAtOrFrom property value for this Demand object; overwriting any existing values.
   *
   * @param availableAtOrFrom The value to set.
   */
  public void setAvailableAtOrFrom(Place availableAtOrFrom);
  
  /**
   * Set the availableDeliveryMethod property value for this Demand object; overwriting any existing values.
   *
   * @param availableDeliveryMethod The value to set.
   */
  public void setAvailableDeliveryMethod(DeliveryMethod availableDeliveryMethod);
  
  /**
   * Set the businessFunction property value for this Demand object; overwriting any existing values.
   *
   * @param businessFunction The value to set.
   */
  public void setBusinessFunction(BusinessFunction businessFunction);
  
  /**
   * Set the deliveryLeadTime property value for this Demand object; overwriting any existing values.
   *
   * @param deliveryLeadTime The value to set.
   */
  public void setDeliveryLeadTime(QuantitativeValue deliveryLeadTime);
  
  /**
   * Set the eligibleCustomerType property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleCustomerType The value to set.
   */
  public void setEligibleCustomerType(BusinessEntityType eligibleCustomerType);
  
  /**
   * Set the eligibleDuration property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleDuration The value to set.
   */
  public void setEligibleDuration(QuantitativeValue eligibleDuration);
  
  /**
   * Set the eligibleQuantity property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleQuantity The value to set.
   */
  public void setEligibleQuantity(QuantitativeValue eligibleQuantity);
  
  /**
   * Set the eligibleRegion property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleRegion The value to set.
   */
  public void setEligibleRegion(Thing eligibleRegion);
  
  /**
   * Set the eligibleTransactionVolume property value for this Demand object; overwriting any existing values.
   *
   * @param eligibleTransactionVolume The value to set.
   */
  public void setEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume);
  
  /**
   * Set the gtin13 property value for this Demand object; overwriting any existing values.
   *
   * @param gtin13 The value to set.
   */
  public void setGtin13(String gtin13);
  
  /**
   * Set the gtin14 property value for this Demand object; overwriting any existing values.
   *
   * @param gtin14 The value to set.
   */
  public void setGtin14(String gtin14);
  
  /**
   * Set the gtin8 property value for this Demand object; overwriting any existing values.
   *
   * @param gtin8 The value to set.
   */
  public void setGtin8(String gtin8);
  
  /**
   * Set the includesObject property value for this Demand object; overwriting any existing values.
   *
   * @param includesObject The value to set.
   */
  public void setIncludesObject(TypeAndQuantityNode includesObject);
  
  /**
   * Set the inventoryLevel property value for this Demand object; overwriting any existing values.
   *
   * @param inventoryLevel The value to set.
   */
  public void setInventoryLevel(QuantitativeValue inventoryLevel);
  
  /**
   * Set the itemCondition property value for this Demand object; overwriting any existing values.
   *
   * @param itemCondition The value to set.
   */
  public void setItemCondition(OfferItemCondition itemCondition);
  
  /**
   * Set the itemOffered property value for this Demand object; overwriting any existing values.
   *
   * @param itemOffered The value to set.
   */
  public void setItemOffered(Product itemOffered);
  
  /**
   * Set the mpn property value for this Demand object; overwriting any existing values.
   *
   * @param mpn The value to set.
   */
  public void setMpn(String mpn);
  
  /**
   * Set the priceSpecification property value for this Demand object; overwriting any existing values.
   *
   * @param priceSpecification The value to set.
   */
  public void setPriceSpecification(PriceSpecification priceSpecification);
  
  /**
   * Set the seller property value for this Demand object; overwriting any existing values.
   *
   * @param seller The value to set.
   */
  public void setSeller(Thing seller);
  
  /**
   * Set the serialNumber property value for this Demand object; overwriting any existing values.
   *
   * @param serialNumber The value to set.
   */
  public void setSerialNumber(String serialNumber);
  
  /**
   * Set the sku property value for this Demand object; overwriting any existing values.
   *
   * @param sku The value to set.
   */
  public void setSku(String sku);
  
  /**
   * Set the validFrom property value for this Demand object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom);
  
  /**
   * Set the validThrough property value for this Demand object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough);
  
  /**
   * Set the warranty property value for this Demand object; overwriting any existing values.
   *
   * @param warranty The value to set.
   */
  public void setWarranty(WarrantyPromise warranty);
  
  /**
   * Set the acceptedPaymentMethod property values for this Demand object; overwriting any existing values.
   *
   * @param acceptedPaymentMethods The list of values to set.
   */
  public void setAcceptedPaymentMethods(List<PaymentMethod> acceptedPaymentMethods);
  
  /**
   * Set the advanceBookingRequirement property values for this Demand object; overwriting any existing values.
   *
   * @param advanceBookingRequirements The list of values to set.
   */
  public void setAdvanceBookingRequirements(List<QuantitativeValue> advanceBookingRequirements);
  
  /**
   * Set the availability property values for this Demand object; overwriting any existing values.
   *
   * @param availabilities The list of values to set.
   */
  public void setAvailabilities(List<ItemAvailability> availabilities);
  
  /**
   * Set the availabilityEnds property values for this Demand object; overwriting any existing values.
   *
   * @param availabilityEndss The list of values to set.
   */
  public void setAvailabilityEndss(List<Date> availabilityEndss);
  
  /**
   * Set the availabilityStarts property values for this Demand object; overwriting any existing values.
   *
   * @param availabilityStartss The list of values to set.
   */
  public void setAvailabilityStartss(List<Date> availabilityStartss);
  
  /**
   * Set the availableAtOrFrom property values for this Demand object; overwriting any existing values.
   *
   * @param availableAtOrFroms The list of values to set.
   */
  public void setAvailableAtOrFroms(List<Place> availableAtOrFroms);
  
  /**
   * Set the availableDeliveryMethod property values for this Demand object; overwriting any existing values.
   *
   * @param availableDeliveryMethods The list of values to set.
   */
  public void setAvailableDeliveryMethods(List<DeliveryMethod> availableDeliveryMethods);
  
  /**
   * Set the businessFunction property values for this Demand object; overwriting any existing values.
   *
   * @param businessFunctions The list of values to set.
   */
  public void setBusinessFunctions(List<BusinessFunction> businessFunctions);
  
  /**
   * Set the deliveryLeadTime property values for this Demand object; overwriting any existing values.
   *
   * @param deliveryLeadTimes The list of values to set.
   */
  public void setDeliveryLeadTimes(List<QuantitativeValue> deliveryLeadTimes);
  
  /**
   * Set the eligibleCustomerType property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleCustomerTypes The list of values to set.
   */
  public void setEligibleCustomerTypes(List<BusinessEntityType> eligibleCustomerTypes);
  
  /**
   * Set the eligibleDuration property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleDurations The list of values to set.
   */
  public void setEligibleDurations(List<QuantitativeValue> eligibleDurations);
  
  /**
   * Set the eligibleQuantity property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleQuantities The list of values to set.
   */
  public void setEligibleQuantities(List<QuantitativeValue> eligibleQuantities);
  
  /**
   * Set the eligibleRegion property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleRegions The list of values to set.
   */
  public void setEligibleRegions(List<Thing> eligibleRegions);
  
  /**
   * Set the eligibleTransactionVolume property values for this Demand object; overwriting any existing values.
   *
   * @param eligibleTransactionVolumes The list of values to set.
   */
  public void setEligibleTransactionVolumes(List<PriceSpecification> eligibleTransactionVolumes);
  
  /**
   * Set the gtin13 property values for this Demand object; overwriting any existing values.
   *
   * @param gtin13s The list of values to set.
   */
  public void setGtin13s(List<String> gtin13s);
  
  /**
   * Set the gtin14 property values for this Demand object; overwriting any existing values.
   *
   * @param gtin14s The list of values to set.
   */
  public void setGtin14s(List<String> gtin14s);
  
  /**
   * Set the gtin8 property values for this Demand object; overwriting any existing values.
   *
   * @param gtin8s The list of values to set.
   */
  public void setGtin8s(List<String> gtin8s);
  
  /**
   * Set the includesObject property values for this Demand object; overwriting any existing values.
   *
   * @param includesObjects The list of values to set.
   */
  public void setIncludesObjects(List<TypeAndQuantityNode> includesObjects);
  
  /**
   * Set the inventoryLevel property values for this Demand object; overwriting any existing values.
   *
   * @param inventoryLevels The list of values to set.
   */
  public void setInventoryLevels(List<QuantitativeValue> inventoryLevels);
  
  /**
   * Set the itemCondition property values for this Demand object; overwriting any existing values.
   *
   * @param itemConditions The list of values to set.
   */
  public void setItemConditions(List<OfferItemCondition> itemConditions);
  
  /**
   * Set the itemOffered property values for this Demand object; overwriting any existing values.
   *
   * @param itemOffereds The list of values to set.
   */
  public void setItemOffereds(List<Product> itemOffereds);
  
  /**
   * Set the mpn property values for this Demand object; overwriting any existing values.
   *
   * @param mpns The list of values to set.
   */
  public void setMpns(List<String> mpns);
  
  /**
   * Set the priceSpecification property values for this Demand object; overwriting any existing values.
   *
   * @param priceSpecifications The list of values to set.
   */
  public void setPriceSpecifications(List<PriceSpecification> priceSpecifications);
  
  /**
   * Set the seller property values for this Demand object; overwriting any existing values.
   *
   * @param sellers The list of values to set.
   */
  public void setSellers(List<Thing> sellers);
  
  /**
   * Set the serialNumber property values for this Demand object; overwriting any existing values.
   *
   * @param serialNumbers The list of values to set.
   */
  public void setSerialNumbers(List<String> serialNumbers);
  
  /**
   * Set the sku property values for this Demand object; overwriting any existing values.
   *
   * @param skus The list of values to set.
   */
  public void setSkus(List<String> skus);
  
  /**
   * Set the validFrom property values for this Demand object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms);
  
  /**
   * Set the validThrough property values for this Demand object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs);
  
  /**
   * Set the warranty property values for this Demand object; overwriting any existing values.
   *
   * @param warranties The list of values to set.
   */
  public void setWarranties(List<WarrantyPromise> warranties);
  
  /**
   * Adds a acceptedPaymentMethod property value for this Demand object; appending it to the list of existing values.
   *
   * @param acceptedPaymentMethod The value to add.
   */
  public void addAcceptedPaymentMethod(PaymentMethod acceptedPaymentMethod);
  
  /**
   * Adds a advanceBookingRequirement property value for this Demand object; appending it to the list of existing values.
   *
   * @param advanceBookingRequirement The value to add.
   */
  public void addAdvanceBookingRequirement(QuantitativeValue advanceBookingRequirement);
  
  /**
   * Adds a availability property value for this Demand object; appending it to the list of existing values.
   *
   * @param availability The value to add.
   */
  public void addAvailability(ItemAvailability availability);
  
  /**
   * Adds a availabilityEnds property value for this Demand object; appending it to the list of existing values.
   *
   * @param availabilityEnds The value to add.
   */
  public void addAvailabilityEnds(Date availabilityEnds);
  
  /**
   * Adds a availabilityStarts property value for this Demand object; appending it to the list of existing values.
   *
   * @param availabilityStarts The value to add.
   */
  public void addAvailabilityStarts(Date availabilityStarts);
  
  /**
   * Adds a availableAtOrFrom property value for this Demand object; appending it to the list of existing values.
   *
   * @param availableAtOrFrom The value to add.
   */
  public void addAvailableAtOrFrom(Place availableAtOrFrom);
  
  /**
   * Adds a availableDeliveryMethod property value for this Demand object; appending it to the list of existing values.
   *
   * @param availableDeliveryMethod The value to add.
   */
  public void addAvailableDeliveryMethod(DeliveryMethod availableDeliveryMethod);
  
  /**
   * Adds a businessFunction property value for this Demand object; appending it to the list of existing values.
   *
   * @param businessFunction The value to add.
   */
  public void addBusinessFunction(BusinessFunction businessFunction);
  
  /**
   * Adds a deliveryLeadTime property value for this Demand object; appending it to the list of existing values.
   *
   * @param deliveryLeadTime The value to add.
   */
  public void addDeliveryLeadTime(QuantitativeValue deliveryLeadTime);
  
  /**
   * Adds a eligibleCustomerType property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleCustomerType The value to add.
   */
  public void addEligibleCustomerType(BusinessEntityType eligibleCustomerType);
  
  /**
   * Adds a eligibleDuration property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleDuration The value to add.
   */
  public void addEligibleDuration(QuantitativeValue eligibleDuration);
  
  /**
   * Adds a eligibleQuantity property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleQuantity The value to add.
   */
  public void addEligibleQuantity(QuantitativeValue eligibleQuantity);
  
  /**
   * Adds a eligibleRegion property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleRegion The value to add.
   */
  public void addEligibleRegion(Thing eligibleRegion);
  
  /**
   * Adds a eligibleTransactionVolume property value for this Demand object; appending it to the list of existing values.
   *
   * @param eligibleTransactionVolume The value to add.
   */
  public void addEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume);
  
  /**
   * Adds a gtin13 property value for this Demand object; appending it to the list of existing values.
   *
   * @param gtin13 The value to add.
   */
  public void addGtin13(String gtin13);
  
  /**
   * Adds a gtin14 property value for this Demand object; appending it to the list of existing values.
   *
   * @param gtin14 The value to add.
   */
  public void addGtin14(String gtin14);
  
  /**
   * Adds a gtin8 property value for this Demand object; appending it to the list of existing values.
   *
   * @param gtin8 The value to add.
   */
  public void addGtin8(String gtin8);
  
  /**
   * Adds a includesObject property value for this Demand object; appending it to the list of existing values.
   *
   * @param includesObject The value to add.
   */
  public void addIncludesObject(TypeAndQuantityNode includesObject);
  
  /**
   * Adds a inventoryLevel property value for this Demand object; appending it to the list of existing values.
   *
   * @param inventoryLevel The value to add.
   */
  public void addInventoryLevel(QuantitativeValue inventoryLevel);
  
  /**
   * Adds a itemCondition property value for this Demand object; appending it to the list of existing values.
   *
   * @param itemCondition The value to add.
   */
  public void addItemCondition(OfferItemCondition itemCondition);
  
  /**
   * Adds a itemOffered property value for this Demand object; appending it to the list of existing values.
   *
   * @param itemOffered The value to add.
   */
  public void addItemOffered(Product itemOffered);
  
  /**
   * Adds a mpn property value for this Demand object; appending it to the list of existing values.
   *
   * @param mpn The value to add.
   */
  public void addMpn(String mpn);
  
  /**
   * Adds a priceSpecification property value for this Demand object; appending it to the list of existing values.
   *
   * @param priceSpecification The value to add.
   */
  public void addPriceSpecification(PriceSpecification priceSpecification);
  
  /**
   * Adds a seller property value for this Demand object; appending it to the list of existing values.
   *
   * @param seller The value to add.
   */
  public void addSeller(Thing seller);
  
  /**
   * Adds a serialNumber property value for this Demand object; appending it to the list of existing values.
   *
   * @param serialNumber The value to add.
   */
  public void addSerialNumber(String serialNumber);
  
  /**
   * Adds a sku property value for this Demand object; appending it to the list of existing values.
   *
   * @param sku The value to add.
   */
  public void addSku(String sku);
  
  /**
   * Adds a validFrom property value for this Demand object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom);
  
  /**
   * Adds a validThrough property value for this Demand object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough);
  
  /**
   * Adds a warranty property value for this Demand object; appending it to the list of existing values.
   *
   * @param warranty The value to add.
   */
  public void addWarranty(WarrantyPromise warranty);
  
}