package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.LifestyleModification;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A strategy of regulating the intake of food to achieve or maintain a specific health-related goal.
 */
public interface Diet extends CreativeWork, LifestyleModification, SchemaObject {

  /**
   * Get a single dietFeatures property value for this Diet object.
   *
   * @return The first dietFeatures property value.
   */
  public String getDietFeatures();
  
  /**
   * Get a single endorsers property value for this Diet object.
   *
   * @return The first endorsers property value.
   */
  public Thing getEndorsers();
  
  /**
   * Get a single expertConsiderations property value for this Diet object.
   *
   * @return The first expertConsiderations property value.
   */
  public String getExpertConsiderations();
  
  /**
   * Get a single overview property value for this Diet object.
   *
   * @return The first overview property value.
   */
  public String getOverview();
  
  /**
   * Get a single physiologicalBenefits property value for this Diet object.
   *
   * @return The first physiologicalBenefits property value.
   */
  public String getPhysiologicalBenefits();
  
  /**
   * Get a single proprietaryName property value for this Diet object.
   *
   * @return The first proprietaryName property value.
   */
  public String getProprietaryName();
  
  /**
   * Get a single risks property value for this Diet object.
   *
   * @return The first risks property value.
   */
  public String getRisks();
  
  /**
   * Get all the dietFeatures property values for this Diet object.
   *
   * @return A list of dietFeatures property values.
   */
  public List<String> getDietFeaturess();
  
  /**
   * Get all the endorsers property values for this Diet object.
   *
   * @return A list of endorsers property values.
   */
  public List<Thing> getEndorserss();
  
  /**
   * Get all the expertConsiderations property values for this Diet object.
   *
   * @return A list of expertConsiderations property values.
   */
  public List<String> getExpertConsiderationss();
  
  /**
   * Get all the overview property values for this Diet object.
   *
   * @return A list of overview property values.
   */
  public List<String> getOverviews();
  
  /**
   * Get all the physiologicalBenefits property values for this Diet object.
   *
   * @return A list of physiologicalBenefits property values.
   */
  public List<String> getPhysiologicalBenefitss();
  
  /**
   * Get all the proprietaryName property values for this Diet object.
   *
   * @return A list of proprietaryName property values.
   */
  public List<String> getProprietaryNames();
  
  /**
   * Get all the risks property values for this Diet object.
   *
   * @return A list of risks property values.
   */
  public List<String> getRiskss();
  
  /**
   * Set the dietFeatures property value for this Diet object; overwriting any existing values.
   *
   * @param dietFeatures The value to set.
   */
  public void setDietFeatures(String dietFeatures);
  
  /**
   * Set the endorsers property value for this Diet object; overwriting any existing values.
   *
   * @param endorsers The value to set.
   */
  public void setEndorsers(Thing endorsers);
  
  /**
   * Set the expertConsiderations property value for this Diet object; overwriting any existing values.
   *
   * @param expertConsiderations The value to set.
   */
  public void setExpertConsiderations(String expertConsiderations);
  
  /**
   * Set the overview property value for this Diet object; overwriting any existing values.
   *
   * @param overview The value to set.
   */
  public void setOverview(String overview);
  
  /**
   * Set the physiologicalBenefits property value for this Diet object; overwriting any existing values.
   *
   * @param physiologicalBenefits The value to set.
   */
  public void setPhysiologicalBenefits(String physiologicalBenefits);
  
  /**
   * Set the proprietaryName property value for this Diet object; overwriting any existing values.
   *
   * @param proprietaryName The value to set.
   */
  public void setProprietaryName(String proprietaryName);
  
  /**
   * Set the risks property value for this Diet object; overwriting any existing values.
   *
   * @param risks The value to set.
   */
  public void setRisks(String risks);
  
  /**
   * Set the dietFeatures property values for this Diet object; overwriting any existing values.
   *
   * @param dietFeaturess The list of values to set.
   */
  public void setDietFeaturess(List<String> dietFeaturess);
  
  /**
   * Set the endorsers property values for this Diet object; overwriting any existing values.
   *
   * @param endorserss The list of values to set.
   */
  public void setEndorserss(List<Thing> endorserss);
  
  /**
   * Set the expertConsiderations property values for this Diet object; overwriting any existing values.
   *
   * @param expertConsiderationss The list of values to set.
   */
  public void setExpertConsiderationss(List<String> expertConsiderationss);
  
  /**
   * Set the overview property values for this Diet object; overwriting any existing values.
   *
   * @param overviews The list of values to set.
   */
  public void setOverviews(List<String> overviews);
  
  /**
   * Set the physiologicalBenefits property values for this Diet object; overwriting any existing values.
   *
   * @param physiologicalBenefitss The list of values to set.
   */
  public void setPhysiologicalBenefitss(List<String> physiologicalBenefitss);
  
  /**
   * Set the proprietaryName property values for this Diet object; overwriting any existing values.
   *
   * @param proprietaryNames The list of values to set.
   */
  public void setProprietaryNames(List<String> proprietaryNames);
  
  /**
   * Set the risks property values for this Diet object; overwriting any existing values.
   *
   * @param riskss The list of values to set.
   */
  public void setRiskss(List<String> riskss);
  
  /**
   * Adds a dietFeatures property value for this Diet object; appending it to the list of existing values.
   *
   * @param dietFeatures The value to add.
   */
  public void addDietFeatures(String dietFeatures);
  
  /**
   * Adds a endorsers property value for this Diet object; appending it to the list of existing values.
   *
   * @param endorsers The value to add.
   */
  public void addEndorsers(Thing endorsers);
  
  /**
   * Adds a expertConsiderations property value for this Diet object; appending it to the list of existing values.
   *
   * @param expertConsiderations The value to add.
   */
  public void addExpertConsiderations(String expertConsiderations);
  
  /**
   * Adds a overview property value for this Diet object; appending it to the list of existing values.
   *
   * @param overview The value to add.
   */
  public void addOverview(String overview);
  
  /**
   * Adds a physiologicalBenefits property value for this Diet object; appending it to the list of existing values.
   *
   * @param physiologicalBenefits The value to add.
   */
  public void addPhysiologicalBenefits(String physiologicalBenefits);
  
  /**
   * Adds a proprietaryName property value for this Diet object; appending it to the list of existing values.
   *
   * @param proprietaryName The value to add.
   */
  public void addProprietaryName(String proprietaryName);
  
  /**
   * Adds a risks property value for this Diet object; appending it to the list of existing values.
   *
   * @param risks The value to add.
   */
  public void addRisks(String risks);
  
}