package org.schema;

import java.lang.Boolean;
import java.lang.String;
import java.util.List;
import org.schema.DrugLegalStatus;
import org.schema.MaximumDoseSchedule;
import org.schema.MedicalTherapy;
import org.schema.Organization;
import org.schema.RecommendedDoseSchedule;
import org.schema.SchemaObject;

/**
 * A product taken by mouth that contains a dietary ingredient intended to supplement the diet. Dietary ingredients may include vitamins, minerals, herbs or other botanicals, amino acids, and substances such as enzymes, organ tissues, glandulars and metabolites.
 */
public interface DietarySupplement extends MedicalTherapy, SchemaObject {

  /**
   * Get a single activeIngredient property value for this DietarySupplement object.
   *
   * @return The first activeIngredient property value.
   */
  public String getActiveIngredient();
  
  /**
   * Get a single background property value for this DietarySupplement object.
   *
   * @return The first background property value.
   */
  public String getBackground();
  
  /**
   * Get a single dosageForm property value for this DietarySupplement object.
   *
   * @return The first dosageForm property value.
   */
  public String getDosageForm();
  
  /**
   * Get a single isProprietary property value for this DietarySupplement object.
   *
   * @return The first isProprietary property value.
   */
  public Boolean getIsProprietary();
  
  /**
   * Get a single legalStatus property value for this DietarySupplement object.
   *
   * @return The first legalStatus property value.
   */
  public DrugLegalStatus getLegalStatus();
  
  /**
   * Get a single manufacturer property value for this DietarySupplement object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer();
  
  /**
   * Get a single maximumIntake property value for this DietarySupplement object.
   *
   * @return The first maximumIntake property value.
   */
  public MaximumDoseSchedule getMaximumIntake();
  
  /**
   * Get a single mechanismOfAction property value for this DietarySupplement object.
   *
   * @return The first mechanismOfAction property value.
   */
  public String getMechanismOfAction();
  
  /**
   * Get a single nonProprietaryName property value for this DietarySupplement object.
   *
   * @return The first nonProprietaryName property value.
   */
  public String getNonProprietaryName();
  
  /**
   * Get a single recommendedIntake property value for this DietarySupplement object.
   *
   * @return The first recommendedIntake property value.
   */
  public RecommendedDoseSchedule getRecommendedIntake();
  
  /**
   * Get a single safetyConsideration property value for this DietarySupplement object.
   *
   * @return The first safetyConsideration property value.
   */
  public String getSafetyConsideration();
  
  /**
   * Get a single targetPopulation property value for this DietarySupplement object.
   *
   * @return The first targetPopulation property value.
   */
  public String getTargetPopulation();
  
  /**
   * Get all the activeIngredient property values for this DietarySupplement object.
   *
   * @return A list of activeIngredient property values.
   */
  public List<String> getActiveIngredients();
  
  /**
   * Get all the background property values for this DietarySupplement object.
   *
   * @return A list of background property values.
   */
  public List<String> getBackgrounds();
  
  /**
   * Get all the dosageForm property values for this DietarySupplement object.
   *
   * @return A list of dosageForm property values.
   */
  public List<String> getDosageForms();
  
  /**
   * Get all the isProprietary property values for this DietarySupplement object.
   *
   * @return A list of isProprietary property values.
   */
  public List<Boolean> getIsProprietaries();
  
  /**
   * Get all the legalStatus property values for this DietarySupplement object.
   *
   * @return A list of legalStatus property values.
   */
  public List<DrugLegalStatus> getLegalStatuses();
  
  /**
   * Get all the manufacturer property values for this DietarySupplement object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers();
  
  /**
   * Get all the maximumIntake property values for this DietarySupplement object.
   *
   * @return A list of maximumIntake property values.
   */
  public List<MaximumDoseSchedule> getMaximumIntakes();
  
  /**
   * Get all the mechanismOfAction property values for this DietarySupplement object.
   *
   * @return A list of mechanismOfAction property values.
   */
  public List<String> getMechanismOfActions();
  
  /**
   * Get all the nonProprietaryName property values for this DietarySupplement object.
   *
   * @return A list of nonProprietaryName property values.
   */
  public List<String> getNonProprietaryNames();
  
  /**
   * Get all the recommendedIntake property values for this DietarySupplement object.
   *
   * @return A list of recommendedIntake property values.
   */
  public List<RecommendedDoseSchedule> getRecommendedIntakes();
  
  /**
   * Get all the safetyConsideration property values for this DietarySupplement object.
   *
   * @return A list of safetyConsideration property values.
   */
  public List<String> getSafetyConsiderations();
  
  /**
   * Get all the targetPopulation property values for this DietarySupplement object.
   *
   * @return A list of targetPopulation property values.
   */
  public List<String> getTargetPopulations();
  
  /**
   * Set the activeIngredient property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param activeIngredient The value to set.
   */
  public void setActiveIngredient(String activeIngredient);
  
  /**
   * Set the background property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param background The value to set.
   */
  public void setBackground(String background);
  
  /**
   * Set the dosageForm property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param dosageForm The value to set.
   */
  public void setDosageForm(String dosageForm);
  
  /**
   * Set the isProprietary property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param isProprietary The value to set.
   */
  public void setIsProprietary(Boolean isProprietary);
  
  /**
   * Set the legalStatus property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param legalStatus The value to set.
   */
  public void setLegalStatus(DrugLegalStatus legalStatus);
  
  /**
   * Set the manufacturer property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer);
  
  /**
   * Set the maximumIntake property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param maximumIntake The value to set.
   */
  public void setMaximumIntake(MaximumDoseSchedule maximumIntake);
  
  /**
   * Set the mechanismOfAction property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param mechanismOfAction The value to set.
   */
  public void setMechanismOfAction(String mechanismOfAction);
  
  /**
   * Set the nonProprietaryName property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param nonProprietaryName The value to set.
   */
  public void setNonProprietaryName(String nonProprietaryName);
  
  /**
   * Set the recommendedIntake property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param recommendedIntake The value to set.
   */
  public void setRecommendedIntake(RecommendedDoseSchedule recommendedIntake);
  
  /**
   * Set the safetyConsideration property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param safetyConsideration The value to set.
   */
  public void setSafetyConsideration(String safetyConsideration);
  
  /**
   * Set the targetPopulation property value for this DietarySupplement object; overwriting any existing values.
   *
   * @param targetPopulation The value to set.
   */
  public void setTargetPopulation(String targetPopulation);
  
  /**
   * Set the activeIngredient property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param activeIngredients The list of values to set.
   */
  public void setActiveIngredients(List<String> activeIngredients);
  
  /**
   * Set the background property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param backgrounds The list of values to set.
   */
  public void setBackgrounds(List<String> backgrounds);
  
  /**
   * Set the dosageForm property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param dosageForms The list of values to set.
   */
  public void setDosageForms(List<String> dosageForms);
  
  /**
   * Set the isProprietary property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param isProprietaries The list of values to set.
   */
  public void setIsProprietaries(List<Boolean> isProprietaries);
  
  /**
   * Set the legalStatus property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param legalStatuses The list of values to set.
   */
  public void setLegalStatuses(List<DrugLegalStatus> legalStatuses);
  
  /**
   * Set the manufacturer property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers);
  
  /**
   * Set the maximumIntake property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param maximumIntakes The list of values to set.
   */
  public void setMaximumIntakes(List<MaximumDoseSchedule> maximumIntakes);
  
  /**
   * Set the mechanismOfAction property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param mechanismOfActions The list of values to set.
   */
  public void setMechanismOfActions(List<String> mechanismOfActions);
  
  /**
   * Set the nonProprietaryName property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param nonProprietaryNames The list of values to set.
   */
  public void setNonProprietaryNames(List<String> nonProprietaryNames);
  
  /**
   * Set the recommendedIntake property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param recommendedIntakes The list of values to set.
   */
  public void setRecommendedIntakes(List<RecommendedDoseSchedule> recommendedIntakes);
  
  /**
   * Set the safetyConsideration property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param safetyConsiderations The list of values to set.
   */
  public void setSafetyConsiderations(List<String> safetyConsiderations);
  
  /**
   * Set the targetPopulation property values for this DietarySupplement object; overwriting any existing values.
   *
   * @param targetPopulations The list of values to set.
   */
  public void setTargetPopulations(List<String> targetPopulations);
  
  /**
   * Adds a activeIngredient property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param activeIngredient The value to add.
   */
  public void addActiveIngredient(String activeIngredient);
  
  /**
   * Adds a background property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param background The value to add.
   */
  public void addBackground(String background);
  
  /**
   * Adds a dosageForm property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param dosageForm The value to add.
   */
  public void addDosageForm(String dosageForm);
  
  /**
   * Adds a isProprietary property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param isProprietary The value to add.
   */
  public void addIsProprietary(Boolean isProprietary);
  
  /**
   * Adds a legalStatus property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param legalStatus The value to add.
   */
  public void addLegalStatus(DrugLegalStatus legalStatus);
  
  /**
   * Adds a manufacturer property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer);
  
  /**
   * Adds a maximumIntake property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param maximumIntake The value to add.
   */
  public void addMaximumIntake(MaximumDoseSchedule maximumIntake);
  
  /**
   * Adds a mechanismOfAction property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param mechanismOfAction The value to add.
   */
  public void addMechanismOfAction(String mechanismOfAction);
  
  /**
   * Adds a nonProprietaryName property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param nonProprietaryName The value to add.
   */
  public void addNonProprietaryName(String nonProprietaryName);
  
  /**
   * Adds a recommendedIntake property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param recommendedIntake The value to add.
   */
  public void addRecommendedIntake(RecommendedDoseSchedule recommendedIntake);
  
  /**
   * Adds a safetyConsideration property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param safetyConsideration The value to add.
   */
  public void addSafetyConsideration(String safetyConsideration);
  
  /**
   * Adds a targetPopulation property value for this DietarySupplement object; appending it to the list of existing values.
   *
   * @param targetPopulation The value to add.
   */
  public void addTargetPopulation(String targetPopulation);
  
}