package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalIntangible;
import org.schema.Number;
import org.schema.SchemaObject;

/**
 * A specific dosing schedule for a drug or supplement.
 */
public interface DoseSchedule extends MedicalIntangible, SchemaObject {

  /**
   * Get a single doseUnit property value for this DoseSchedule object.
   *
   * @return The first doseUnit property value.
   */
  public String getDoseUnit();
  
  /**
   * Get a single doseValue property value for this DoseSchedule object.
   *
   * @return The first doseValue property value.
   */
  public Number getDoseValue();
  
  /**
   * Get a single frequency property value for this DoseSchedule object.
   *
   * @return The first frequency property value.
   */
  public String getFrequency();
  
  /**
   * Get a single targetPopulation property value for this DoseSchedule object.
   *
   * @return The first targetPopulation property value.
   */
  public String getTargetPopulation();
  
  /**
   * Get all the doseUnit property values for this DoseSchedule object.
   *
   * @return A list of doseUnit property values.
   */
  public List<String> getDoseUnits();
  
  /**
   * Get all the doseValue property values for this DoseSchedule object.
   *
   * @return A list of doseValue property values.
   */
  public List<Number> getDoseValues();
  
  /**
   * Get all the frequency property values for this DoseSchedule object.
   *
   * @return A list of frequency property values.
   */
  public List<String> getFrequencies();
  
  /**
   * Get all the targetPopulation property values for this DoseSchedule object.
   *
   * @return A list of targetPopulation property values.
   */
  public List<String> getTargetPopulations();
  
  /**
   * Set the doseUnit property value for this DoseSchedule object; overwriting any existing values.
   *
   * @param doseUnit The value to set.
   */
  public void setDoseUnit(String doseUnit);
  
  /**
   * Set the doseValue property value for this DoseSchedule object; overwriting any existing values.
   *
   * @param doseValue The value to set.
   */
  public void setDoseValue(Number doseValue);
  
  /**
   * Set the frequency property value for this DoseSchedule object; overwriting any existing values.
   *
   * @param frequency The value to set.
   */
  public void setFrequency(String frequency);
  
  /**
   * Set the targetPopulation property value for this DoseSchedule object; overwriting any existing values.
   *
   * @param targetPopulation The value to set.
   */
  public void setTargetPopulation(String targetPopulation);
  
  /**
   * Set the doseUnit property values for this DoseSchedule object; overwriting any existing values.
   *
   * @param doseUnits The list of values to set.
   */
  public void setDoseUnits(List<String> doseUnits);
  
  /**
   * Set the doseValue property values for this DoseSchedule object; overwriting any existing values.
   *
   * @param doseValues The list of values to set.
   */
  public void setDoseValues(List<Number> doseValues);
  
  /**
   * Set the frequency property values for this DoseSchedule object; overwriting any existing values.
   *
   * @param frequencies The list of values to set.
   */
  public void setFrequencies(List<String> frequencies);
  
  /**
   * Set the targetPopulation property values for this DoseSchedule object; overwriting any existing values.
   *
   * @param targetPopulations The list of values to set.
   */
  public void setTargetPopulations(List<String> targetPopulations);
  
  /**
   * Adds a doseUnit property value for this DoseSchedule object; appending it to the list of existing values.
   *
   * @param doseUnit The value to add.
   */
  public void addDoseUnit(String doseUnit);
  
  /**
   * Adds a doseValue property value for this DoseSchedule object; appending it to the list of existing values.
   *
   * @param doseValue The value to add.
   */
  public void addDoseValue(Number doseValue);
  
  /**
   * Adds a frequency property value for this DoseSchedule object; appending it to the list of existing values.
   *
   * @param frequency The value to add.
   */
  public void addFrequency(String frequency);
  
  /**
   * Adds a targetPopulation property value for this DoseSchedule object; appending it to the list of existing values.
   *
   * @param targetPopulation The value to add.
   */
  public void addTargetPopulation(String targetPopulation);
  
}