package org.schema;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.DoseSchedule;
import org.schema.Drug;
import org.schema.DrugClass;
import org.schema.DrugCost;
import org.schema.DrugLegalStatus;
import org.schema.DrugPregnancyCategory;
import org.schema.DrugPrescriptionStatus;
import org.schema.DrugStrength;
import org.schema.MedicalTherapy;
import org.schema.Organization;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A chemical or biologic substance, used as a medical therapy, that has a physiological effect on an organism.
 */
public interface Drug extends MedicalTherapy, SchemaObject {

  /**
   * Get a single activeIngredient property value for this Drug object.
   *
   * @return The first activeIngredient property value.
   */
  public String getActiveIngredient();
  
  /**
   * Get a single administrationRoute property value for this Drug object.
   *
   * @return The first administrationRoute property value.
   */
  public String getAdministrationRoute();
  
  /**
   * Get a single alcoholWarning property value for this Drug object.
   *
   * @return The first alcoholWarning property value.
   */
  public String getAlcoholWarning();
  
  /**
   * Get a single availableStrength property value for this Drug object.
   *
   * @return The first availableStrength property value.
   */
  public DrugStrength getAvailableStrength();
  
  /**
   * Get a single breastfeedingWarning property value for this Drug object.
   *
   * @return The first breastfeedingWarning property value.
   */
  public String getBreastfeedingWarning();
  
  /**
   * Get a single clincalPharmacology property value for this Drug object.
   *
   * @return The first clincalPharmacology property value.
   */
  public String getClincalPharmacology();
  
  /**
   * Get a single cost property value for this Drug object.
   *
   * @return The first cost property value.
   */
  public DrugCost getCost();
  
  /**
   * Get a single dosageForm property value for this Drug object.
   *
   * @return The first dosageForm property value.
   */
  public String getDosageForm();
  
  /**
   * Get a single doseSchedule property value for this Drug object.
   *
   * @return The first doseSchedule property value.
   */
  public DoseSchedule getDoseSchedule();
  
  /**
   * Get a single drugClass property value for this Drug object.
   *
   * @return The first drugClass property value.
   */
  public DrugClass getDrugClass();
  
  /**
   * Get a single foodWarning property value for this Drug object.
   *
   * @return The first foodWarning property value.
   */
  public String getFoodWarning();
  
  /**
   * Get a single interactingDrug property value for this Drug object.
   *
   * @return The first interactingDrug property value.
   */
  public Drug getInteractingDrug();
  
  /**
   * Get a single isAvailableGenerically property value for this Drug object.
   *
   * @return The first isAvailableGenerically property value.
   */
  public Boolean getIsAvailableGenerically();
  
  /**
   * Get a single isProprietary property value for this Drug object.
   *
   * @return The first isProprietary property value.
   */
  public Boolean getIsProprietary();
  
  /**
   * Get a single labelDetails property value for this Drug object.
   *
   * @return The first labelDetails property value.
   */
  public URL getLabelDetails();
  
  /**
   * Get a single legalStatus property value for this Drug object.
   *
   * @return The first legalStatus property value.
   */
  public DrugLegalStatus getLegalStatus();
  
  /**
   * Get a single manufacturer property value for this Drug object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer();
  
  /**
   * Get a single mechanismOfAction property value for this Drug object.
   *
   * @return The first mechanismOfAction property value.
   */
  public String getMechanismOfAction();
  
  /**
   * Get a single nonProprietaryName property value for this Drug object.
   *
   * @return The first nonProprietaryName property value.
   */
  public String getNonProprietaryName();
  
  /**
   * Get a single overdosage property value for this Drug object.
   *
   * @return The first overdosage property value.
   */
  public String getOverdosage();
  
  /**
   * Get a single pregnancyCategory property value for this Drug object.
   *
   * @return The first pregnancyCategory property value.
   */
  public DrugPregnancyCategory getPregnancyCategory();
  
  /**
   * Get a single pregnancyWarning property value for this Drug object.
   *
   * @return The first pregnancyWarning property value.
   */
  public String getPregnancyWarning();
  
  /**
   * Get a single prescribingInfo property value for this Drug object.
   *
   * @return The first prescribingInfo property value.
   */
  public URL getPrescribingInfo();
  
  /**
   * Get a single prescriptionStatus property value for this Drug object.
   *
   * @return The first prescriptionStatus property value.
   */
  public DrugPrescriptionStatus getPrescriptionStatus();
  
  /**
   * Get a single relatedDrug property value for this Drug object.
   *
   * @return The first relatedDrug property value.
   */
  public Drug getRelatedDrug();
  
  /**
   * Get a single warning property value for this Drug object.
   *
   * @return The first warning property value.
   */
  public Thing getWarning();
  
  /**
   * Get all the activeIngredient property values for this Drug object.
   *
   * @return A list of activeIngredient property values.
   */
  public List<String> getActiveIngredients();
  
  /**
   * Get all the administrationRoute property values for this Drug object.
   *
   * @return A list of administrationRoute property values.
   */
  public List<String> getAdministrationRoutes();
  
  /**
   * Get all the alcoholWarning property values for this Drug object.
   *
   * @return A list of alcoholWarning property values.
   */
  public List<String> getAlcoholWarnings();
  
  /**
   * Get all the availableStrength property values for this Drug object.
   *
   * @return A list of availableStrength property values.
   */
  public List<DrugStrength> getAvailableStrengths();
  
  /**
   * Get all the breastfeedingWarning property values for this Drug object.
   *
   * @return A list of breastfeedingWarning property values.
   */
  public List<String> getBreastfeedingWarnings();
  
  /**
   * Get all the clincalPharmacology property values for this Drug object.
   *
   * @return A list of clincalPharmacology property values.
   */
  public List<String> getClincalPharmacologies();
  
  /**
   * Get all the cost property values for this Drug object.
   *
   * @return A list of cost property values.
   */
  public List<DrugCost> getCosts();
  
  /**
   * Get all the dosageForm property values for this Drug object.
   *
   * @return A list of dosageForm property values.
   */
  public List<String> getDosageForms();
  
  /**
   * Get all the doseSchedule property values for this Drug object.
   *
   * @return A list of doseSchedule property values.
   */
  public List<DoseSchedule> getDoseSchedules();
  
  /**
   * Get all the drugClass property values for this Drug object.
   *
   * @return A list of drugClass property values.
   */
  public List<DrugClass> getDrugClasses();
  
  /**
   * Get all the foodWarning property values for this Drug object.
   *
   * @return A list of foodWarning property values.
   */
  public List<String> getFoodWarnings();
  
  /**
   * Get all the interactingDrug property values for this Drug object.
   *
   * @return A list of interactingDrug property values.
   */
  public List<Drug> getInteractingDrugs();
  
  /**
   * Get all the isAvailableGenerically property values for this Drug object.
   *
   * @return A list of isAvailableGenerically property values.
   */
  public List<Boolean> getIsAvailableGenericallies();
  
  /**
   * Get all the isProprietary property values for this Drug object.
   *
   * @return A list of isProprietary property values.
   */
  public List<Boolean> getIsProprietaries();
  
  /**
   * Get all the labelDetails property values for this Drug object.
   *
   * @return A list of labelDetails property values.
   */
  public List<URL> getLabelDetailss();
  
  /**
   * Get all the legalStatus property values for this Drug object.
   *
   * @return A list of legalStatus property values.
   */
  public List<DrugLegalStatus> getLegalStatuses();
  
  /**
   * Get all the manufacturer property values for this Drug object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers();
  
  /**
   * Get all the mechanismOfAction property values for this Drug object.
   *
   * @return A list of mechanismOfAction property values.
   */
  public List<String> getMechanismOfActions();
  
  /**
   * Get all the nonProprietaryName property values for this Drug object.
   *
   * @return A list of nonProprietaryName property values.
   */
  public List<String> getNonProprietaryNames();
  
  /**
   * Get all the overdosage property values for this Drug object.
   *
   * @return A list of overdosage property values.
   */
  public List<String> getOverdosages();
  
  /**
   * Get all the pregnancyCategory property values for this Drug object.
   *
   * @return A list of pregnancyCategory property values.
   */
  public List<DrugPregnancyCategory> getPregnancyCategories();
  
  /**
   * Get all the pregnancyWarning property values for this Drug object.
   *
   * @return A list of pregnancyWarning property values.
   */
  public List<String> getPregnancyWarnings();
  
  /**
   * Get all the prescribingInfo property values for this Drug object.
   *
   * @return A list of prescribingInfo property values.
   */
  public List<URL> getPrescribingInfoes();
  
  /**
   * Get all the prescriptionStatus property values for this Drug object.
   *
   * @return A list of prescriptionStatus property values.
   */
  public List<DrugPrescriptionStatus> getPrescriptionStatuses();
  
  /**
   * Get all the relatedDrug property values for this Drug object.
   *
   * @return A list of relatedDrug property values.
   */
  public List<Drug> getRelatedDrugs();
  
  /**
   * Get all the warning property values for this Drug object.
   *
   * @return A list of warning property values.
   */
  public List<Thing> getWarnings();
  
  /**
   * Set the activeIngredient property value for this Drug object; overwriting any existing values.
   *
   * @param activeIngredient The value to set.
   */
  public void setActiveIngredient(String activeIngredient);
  
  /**
   * Set the administrationRoute property value for this Drug object; overwriting any existing values.
   *
   * @param administrationRoute The value to set.
   */
  public void setAdministrationRoute(String administrationRoute);
  
  /**
   * Set the alcoholWarning property value for this Drug object; overwriting any existing values.
   *
   * @param alcoholWarning The value to set.
   */
  public void setAlcoholWarning(String alcoholWarning);
  
  /**
   * Set the availableStrength property value for this Drug object; overwriting any existing values.
   *
   * @param availableStrength The value to set.
   */
  public void setAvailableStrength(DrugStrength availableStrength);
  
  /**
   * Set the breastfeedingWarning property value for this Drug object; overwriting any existing values.
   *
   * @param breastfeedingWarning The value to set.
   */
  public void setBreastfeedingWarning(String breastfeedingWarning);
  
  /**
   * Set the clincalPharmacology property value for this Drug object; overwriting any existing values.
   *
   * @param clincalPharmacology The value to set.
   */
  public void setClincalPharmacology(String clincalPharmacology);
  
  /**
   * Set the cost property value for this Drug object; overwriting any existing values.
   *
   * @param cost The value to set.
   */
  public void setCost(DrugCost cost);
  
  /**
   * Set the dosageForm property value for this Drug object; overwriting any existing values.
   *
   * @param dosageForm The value to set.
   */
  public void setDosageForm(String dosageForm);
  
  /**
   * Set the doseSchedule property value for this Drug object; overwriting any existing values.
   *
   * @param doseSchedule The value to set.
   */
  public void setDoseSchedule(DoseSchedule doseSchedule);
  
  /**
   * Set the drugClass property value for this Drug object; overwriting any existing values.
   *
   * @param drugClass The value to set.
   */
  public void setDrugClass(DrugClass drugClass);
  
  /**
   * Set the foodWarning property value for this Drug object; overwriting any existing values.
   *
   * @param foodWarning The value to set.
   */
  public void setFoodWarning(String foodWarning);
  
  /**
   * Set the interactingDrug property value for this Drug object; overwriting any existing values.
   *
   * @param interactingDrug The value to set.
   */
  public void setInteractingDrug(Drug interactingDrug);
  
  /**
   * Set the isAvailableGenerically property value for this Drug object; overwriting any existing values.
   *
   * @param isAvailableGenerically The value to set.
   */
  public void setIsAvailableGenerically(Boolean isAvailableGenerically);
  
  /**
   * Set the isProprietary property value for this Drug object; overwriting any existing values.
   *
   * @param isProprietary The value to set.
   */
  public void setIsProprietary(Boolean isProprietary);
  
  /**
   * Set the labelDetails property value for this Drug object; overwriting any existing values.
   *
   * @param labelDetails The value to set.
   */
  public void setLabelDetails(URL labelDetails);
  
  /**
   * Set the legalStatus property value for this Drug object; overwriting any existing values.
   *
   * @param legalStatus The value to set.
   */
  public void setLegalStatus(DrugLegalStatus legalStatus);
  
  /**
   * Set the manufacturer property value for this Drug object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer);
  
  /**
   * Set the mechanismOfAction property value for this Drug object; overwriting any existing values.
   *
   * @param mechanismOfAction The value to set.
   */
  public void setMechanismOfAction(String mechanismOfAction);
  
  /**
   * Set the nonProprietaryName property value for this Drug object; overwriting any existing values.
   *
   * @param nonProprietaryName The value to set.
   */
  public void setNonProprietaryName(String nonProprietaryName);
  
  /**
   * Set the overdosage property value for this Drug object; overwriting any existing values.
   *
   * @param overdosage The value to set.
   */
  public void setOverdosage(String overdosage);
  
  /**
   * Set the pregnancyCategory property value for this Drug object; overwriting any existing values.
   *
   * @param pregnancyCategory The value to set.
   */
  public void setPregnancyCategory(DrugPregnancyCategory pregnancyCategory);
  
  /**
   * Set the pregnancyWarning property value for this Drug object; overwriting any existing values.
   *
   * @param pregnancyWarning The value to set.
   */
  public void setPregnancyWarning(String pregnancyWarning);
  
  /**
   * Set the prescribingInfo property value for this Drug object; overwriting any existing values.
   *
   * @param prescribingInfo The value to set.
   */
  public void setPrescribingInfo(URL prescribingInfo);
  
  /**
   * Set the prescriptionStatus property value for this Drug object; overwriting any existing values.
   *
   * @param prescriptionStatus The value to set.
   */
  public void setPrescriptionStatus(DrugPrescriptionStatus prescriptionStatus);
  
  /**
   * Set the relatedDrug property value for this Drug object; overwriting any existing values.
   *
   * @param relatedDrug The value to set.
   */
  public void setRelatedDrug(Drug relatedDrug);
  
  /**
   * Set the warning property value for this Drug object; overwriting any existing values.
   *
   * @param warning The value to set.
   */
  public void setWarning(Thing warning);
  
  /**
   * Set the activeIngredient property values for this Drug object; overwriting any existing values.
   *
   * @param activeIngredients The list of values to set.
   */
  public void setActiveIngredients(List<String> activeIngredients);
  
  /**
   * Set the administrationRoute property values for this Drug object; overwriting any existing values.
   *
   * @param administrationRoutes The list of values to set.
   */
  public void setAdministrationRoutes(List<String> administrationRoutes);
  
  /**
   * Set the alcoholWarning property values for this Drug object; overwriting any existing values.
   *
   * @param alcoholWarnings The list of values to set.
   */
  public void setAlcoholWarnings(List<String> alcoholWarnings);
  
  /**
   * Set the availableStrength property values for this Drug object; overwriting any existing values.
   *
   * @param availableStrengths The list of values to set.
   */
  public void setAvailableStrengths(List<DrugStrength> availableStrengths);
  
  /**
   * Set the breastfeedingWarning property values for this Drug object; overwriting any existing values.
   *
   * @param breastfeedingWarnings The list of values to set.
   */
  public void setBreastfeedingWarnings(List<String> breastfeedingWarnings);
  
  /**
   * Set the clincalPharmacology property values for this Drug object; overwriting any existing values.
   *
   * @param clincalPharmacologies The list of values to set.
   */
  public void setClincalPharmacologies(List<String> clincalPharmacologies);
  
  /**
   * Set the cost property values for this Drug object; overwriting any existing values.
   *
   * @param costs The list of values to set.
   */
  public void setCosts(List<DrugCost> costs);
  
  /**
   * Set the dosageForm property values for this Drug object; overwriting any existing values.
   *
   * @param dosageForms The list of values to set.
   */
  public void setDosageForms(List<String> dosageForms);
  
  /**
   * Set the doseSchedule property values for this Drug object; overwriting any existing values.
   *
   * @param doseSchedules The list of values to set.
   */
  public void setDoseSchedules(List<DoseSchedule> doseSchedules);
  
  /**
   * Set the drugClass property values for this Drug object; overwriting any existing values.
   *
   * @param drugClasses The list of values to set.
   */
  public void setDrugClasses(List<DrugClass> drugClasses);
  
  /**
   * Set the foodWarning property values for this Drug object; overwriting any existing values.
   *
   * @param foodWarnings The list of values to set.
   */
  public void setFoodWarnings(List<String> foodWarnings);
  
  /**
   * Set the interactingDrug property values for this Drug object; overwriting any existing values.
   *
   * @param interactingDrugs The list of values to set.
   */
  public void setInteractingDrugs(List<Drug> interactingDrugs);
  
  /**
   * Set the isAvailableGenerically property values for this Drug object; overwriting any existing values.
   *
   * @param isAvailableGenericallies The list of values to set.
   */
  public void setIsAvailableGenericallies(List<Boolean> isAvailableGenericallies);
  
  /**
   * Set the isProprietary property values for this Drug object; overwriting any existing values.
   *
   * @param isProprietaries The list of values to set.
   */
  public void setIsProprietaries(List<Boolean> isProprietaries);
  
  /**
   * Set the labelDetails property values for this Drug object; overwriting any existing values.
   *
   * @param labelDetailss The list of values to set.
   */
  public void setLabelDetailss(List<URL> labelDetailss);
  
  /**
   * Set the legalStatus property values for this Drug object; overwriting any existing values.
   *
   * @param legalStatuses The list of values to set.
   */
  public void setLegalStatuses(List<DrugLegalStatus> legalStatuses);
  
  /**
   * Set the manufacturer property values for this Drug object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers);
  
  /**
   * Set the mechanismOfAction property values for this Drug object; overwriting any existing values.
   *
   * @param mechanismOfActions The list of values to set.
   */
  public void setMechanismOfActions(List<String> mechanismOfActions);
  
  /**
   * Set the nonProprietaryName property values for this Drug object; overwriting any existing values.
   *
   * @param nonProprietaryNames The list of values to set.
   */
  public void setNonProprietaryNames(List<String> nonProprietaryNames);
  
  /**
   * Set the overdosage property values for this Drug object; overwriting any existing values.
   *
   * @param overdosages The list of values to set.
   */
  public void setOverdosages(List<String> overdosages);
  
  /**
   * Set the pregnancyCategory property values for this Drug object; overwriting any existing values.
   *
   * @param pregnancyCategories The list of values to set.
   */
  public void setPregnancyCategories(List<DrugPregnancyCategory> pregnancyCategories);
  
  /**
   * Set the pregnancyWarning property values for this Drug object; overwriting any existing values.
   *
   * @param pregnancyWarnings The list of values to set.
   */
  public void setPregnancyWarnings(List<String> pregnancyWarnings);
  
  /**
   * Set the prescribingInfo property values for this Drug object; overwriting any existing values.
   *
   * @param prescribingInfoes The list of values to set.
   */
  public void setPrescribingInfoes(List<URL> prescribingInfoes);
  
  /**
   * Set the prescriptionStatus property values for this Drug object; overwriting any existing values.
   *
   * @param prescriptionStatuses The list of values to set.
   */
  public void setPrescriptionStatuses(List<DrugPrescriptionStatus> prescriptionStatuses);
  
  /**
   * Set the relatedDrug property values for this Drug object; overwriting any existing values.
   *
   * @param relatedDrugs The list of values to set.
   */
  public void setRelatedDrugs(List<Drug> relatedDrugs);
  
  /**
   * Set the warning property values for this Drug object; overwriting any existing values.
   *
   * @param warnings The list of values to set.
   */
  public void setWarnings(List<Thing> warnings);
  
  /**
   * Adds a activeIngredient property value for this Drug object; appending it to the list of existing values.
   *
   * @param activeIngredient The value to add.
   */
  public void addActiveIngredient(String activeIngredient);
  
  /**
   * Adds a administrationRoute property value for this Drug object; appending it to the list of existing values.
   *
   * @param administrationRoute The value to add.
   */
  public void addAdministrationRoute(String administrationRoute);
  
  /**
   * Adds a alcoholWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param alcoholWarning The value to add.
   */
  public void addAlcoholWarning(String alcoholWarning);
  
  /**
   * Adds a availableStrength property value for this Drug object; appending it to the list of existing values.
   *
   * @param availableStrength The value to add.
   */
  public void addAvailableStrength(DrugStrength availableStrength);
  
  /**
   * Adds a breastfeedingWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param breastfeedingWarning The value to add.
   */
  public void addBreastfeedingWarning(String breastfeedingWarning);
  
  /**
   * Adds a clincalPharmacology property value for this Drug object; appending it to the list of existing values.
   *
   * @param clincalPharmacology The value to add.
   */
  public void addClincalPharmacology(String clincalPharmacology);
  
  /**
   * Adds a cost property value for this Drug object; appending it to the list of existing values.
   *
   * @param cost The value to add.
   */
  public void addCost(DrugCost cost);
  
  /**
   * Adds a dosageForm property value for this Drug object; appending it to the list of existing values.
   *
   * @param dosageForm The value to add.
   */
  public void addDosageForm(String dosageForm);
  
  /**
   * Adds a doseSchedule property value for this Drug object; appending it to the list of existing values.
   *
   * @param doseSchedule The value to add.
   */
  public void addDoseSchedule(DoseSchedule doseSchedule);
  
  /**
   * Adds a drugClass property value for this Drug object; appending it to the list of existing values.
   *
   * @param drugClass The value to add.
   */
  public void addDrugClass(DrugClass drugClass);
  
  /**
   * Adds a foodWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param foodWarning The value to add.
   */
  public void addFoodWarning(String foodWarning);
  
  /**
   * Adds a interactingDrug property value for this Drug object; appending it to the list of existing values.
   *
   * @param interactingDrug The value to add.
   */
  public void addInteractingDrug(Drug interactingDrug);
  
  /**
   * Adds a isAvailableGenerically property value for this Drug object; appending it to the list of existing values.
   *
   * @param isAvailableGenerically The value to add.
   */
  public void addIsAvailableGenerically(Boolean isAvailableGenerically);
  
  /**
   * Adds a isProprietary property value for this Drug object; appending it to the list of existing values.
   *
   * @param isProprietary The value to add.
   */
  public void addIsProprietary(Boolean isProprietary);
  
  /**
   * Adds a labelDetails property value for this Drug object; appending it to the list of existing values.
   *
   * @param labelDetails The value to add.
   */
  public void addLabelDetails(URL labelDetails);
  
  /**
   * Adds a legalStatus property value for this Drug object; appending it to the list of existing values.
   *
   * @param legalStatus The value to add.
   */
  public void addLegalStatus(DrugLegalStatus legalStatus);
  
  /**
   * Adds a manufacturer property value for this Drug object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer);
  
  /**
   * Adds a mechanismOfAction property value for this Drug object; appending it to the list of existing values.
   *
   * @param mechanismOfAction The value to add.
   */
  public void addMechanismOfAction(String mechanismOfAction);
  
  /**
   * Adds a nonProprietaryName property value for this Drug object; appending it to the list of existing values.
   *
   * @param nonProprietaryName The value to add.
   */
  public void addNonProprietaryName(String nonProprietaryName);
  
  /**
   * Adds a overdosage property value for this Drug object; appending it to the list of existing values.
   *
   * @param overdosage The value to add.
   */
  public void addOverdosage(String overdosage);
  
  /**
   * Adds a pregnancyCategory property value for this Drug object; appending it to the list of existing values.
   *
   * @param pregnancyCategory The value to add.
   */
  public void addPregnancyCategory(DrugPregnancyCategory pregnancyCategory);
  
  /**
   * Adds a pregnancyWarning property value for this Drug object; appending it to the list of existing values.
   *
   * @param pregnancyWarning The value to add.
   */
  public void addPregnancyWarning(String pregnancyWarning);
  
  /**
   * Adds a prescribingInfo property value for this Drug object; appending it to the list of existing values.
   *
   * @param prescribingInfo The value to add.
   */
  public void addPrescribingInfo(URL prescribingInfo);
  
  /**
   * Adds a prescriptionStatus property value for this Drug object; appending it to the list of existing values.
   *
   * @param prescriptionStatus The value to add.
   */
  public void addPrescriptionStatus(DrugPrescriptionStatus prescriptionStatus);
  
  /**
   * Adds a relatedDrug property value for this Drug object; appending it to the list of existing values.
   *
   * @param relatedDrug The value to add.
   */
  public void addRelatedDrug(Drug relatedDrug);
  
  /**
   * Adds a warning property value for this Drug object; appending it to the list of existing values.
   *
   * @param warning The value to add.
   */
  public void addWarning(Thing warning);
  
}