package org.schema;

import java.util.List;
import org.schema.Drug;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;

/**
 * A class of medical drugs, e.g., statins. Classes can represent general pharmacological class, common mechanisms of action, common physiological effects, etc.
 */
public interface DrugClass extends MedicalTherapy, SchemaObject {

  /**
   * Get a single drug property value for this DrugClass object.
   *
   * @return The first drug property value.
   */
  public Drug getDrug();
  
  /**
   * Get all the drug property values for this DrugClass object.
   *
   * @return A list of drug property values.
   */
  public List<Drug> getDrugs();
  
  /**
   * Set the drug property value for this DrugClass object; overwriting any existing values.
   *
   * @param drug The value to set.
   */
  public void setDrug(Drug drug);
  
  /**
   * Set the drug property values for this DrugClass object; overwriting any existing values.
   *
   * @param drugs The list of values to set.
   */
  public void setDrugs(List<Drug> drugs);
  
  /**
   * Adds a drug property value for this DrugClass object; appending it to the list of existing values.
   *
   * @param drug The value to add.
   */
  public void addDrug(Drug drug);
  
}