package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.DrugCostCategory;
import org.schema.MedicalIntangible;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The cost per unit of a medical drug. Note that this type is not meant to represent the price in an offer of a drug for sale; see the Offer type for that. This type will typically be used to tag wholesale or average retail cost of a drug, or maximum reimbursable cost. Costs of medical drugs vary widely depending on how and where they are paid for, so while this type captures some of the variables, costs should be used with caution by consumers of this schema's markup.
 */
public interface DrugCost extends MedicalIntangible, SchemaObject {

  /**
   * Get a single applicableLocation property value for this DrugCost object.
   *
   * @return The first applicableLocation property value.
   */
  public AdministrativeArea getApplicableLocation();
  
  /**
   * Get a single costCategory property value for this DrugCost object.
   *
   * @return The first costCategory property value.
   */
  public DrugCostCategory getCostCategory();
  
  /**
   * Get a single costCurrency property value for this DrugCost object.
   *
   * @return The first costCurrency property value.
   */
  public String getCostCurrency();
  
  /**
   * Get a single costOrigin property value for this DrugCost object.
   *
   * @return The first costOrigin property value.
   */
  public String getCostOrigin();
  
  /**
   * Get a single costPerUnit property value for this DrugCost object.
   *
   * @return The first costPerUnit property value.
   */
  public Thing getCostPerUnit();
  
  /**
   * Get a single drugUnit property value for this DrugCost object.
   *
   * @return The first drugUnit property value.
   */
  public String getDrugUnit();
  
  /**
   * Get all the applicableLocation property values for this DrugCost object.
   *
   * @return A list of applicableLocation property values.
   */
  public List<AdministrativeArea> getApplicableLocations();
  
  /**
   * Get all the costCategory property values for this DrugCost object.
   *
   * @return A list of costCategory property values.
   */
  public List<DrugCostCategory> getCostCategories();
  
  /**
   * Get all the costCurrency property values for this DrugCost object.
   *
   * @return A list of costCurrency property values.
   */
  public List<String> getCostCurrencies();
  
  /**
   * Get all the costOrigin property values for this DrugCost object.
   *
   * @return A list of costOrigin property values.
   */
  public List<String> getCostOrigins();
  
  /**
   * Get all the costPerUnit property values for this DrugCost object.
   *
   * @return A list of costPerUnit property values.
   */
  public List<Thing> getCostPerUnits();
  
  /**
   * Get all the drugUnit property values for this DrugCost object.
   *
   * @return A list of drugUnit property values.
   */
  public List<String> getDrugUnits();
  
  /**
   * Set the applicableLocation property value for this DrugCost object; overwriting any existing values.
   *
   * @param applicableLocation The value to set.
   */
  public void setApplicableLocation(AdministrativeArea applicableLocation);
  
  /**
   * Set the costCategory property value for this DrugCost object; overwriting any existing values.
   *
   * @param costCategory The value to set.
   */
  public void setCostCategory(DrugCostCategory costCategory);
  
  /**
   * Set the costCurrency property value for this DrugCost object; overwriting any existing values.
   *
   * @param costCurrency The value to set.
   */
  public void setCostCurrency(String costCurrency);
  
  /**
   * Set the costOrigin property value for this DrugCost object; overwriting any existing values.
   *
   * @param costOrigin The value to set.
   */
  public void setCostOrigin(String costOrigin);
  
  /**
   * Set the costPerUnit property value for this DrugCost object; overwriting any existing values.
   *
   * @param costPerUnit The value to set.
   */
  public void setCostPerUnit(Thing costPerUnit);
  
  /**
   * Set the drugUnit property value for this DrugCost object; overwriting any existing values.
   *
   * @param drugUnit The value to set.
   */
  public void setDrugUnit(String drugUnit);
  
  /**
   * Set the applicableLocation property values for this DrugCost object; overwriting any existing values.
   *
   * @param applicableLocations The list of values to set.
   */
  public void setApplicableLocations(List<AdministrativeArea> applicableLocations);
  
  /**
   * Set the costCategory property values for this DrugCost object; overwriting any existing values.
   *
   * @param costCategories The list of values to set.
   */
  public void setCostCategories(List<DrugCostCategory> costCategories);
  
  /**
   * Set the costCurrency property values for this DrugCost object; overwriting any existing values.
   *
   * @param costCurrencies The list of values to set.
   */
  public void setCostCurrencies(List<String> costCurrencies);
  
  /**
   * Set the costOrigin property values for this DrugCost object; overwriting any existing values.
   *
   * @param costOrigins The list of values to set.
   */
  public void setCostOrigins(List<String> costOrigins);
  
  /**
   * Set the costPerUnit property values for this DrugCost object; overwriting any existing values.
   *
   * @param costPerUnits The list of values to set.
   */
  public void setCostPerUnits(List<Thing> costPerUnits);
  
  /**
   * Set the drugUnit property values for this DrugCost object; overwriting any existing values.
   *
   * @param drugUnits The list of values to set.
   */
  public void setDrugUnits(List<String> drugUnits);
  
  /**
   * Adds a applicableLocation property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param applicableLocation The value to add.
   */
  public void addApplicableLocation(AdministrativeArea applicableLocation);
  
  /**
   * Adds a costCategory property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costCategory The value to add.
   */
  public void addCostCategory(DrugCostCategory costCategory);
  
  /**
   * Adds a costCurrency property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costCurrency The value to add.
   */
  public void addCostCurrency(String costCurrency);
  
  /**
   * Adds a costOrigin property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costOrigin The value to add.
   */
  public void addCostOrigin(String costOrigin);
  
  /**
   * Adds a costPerUnit property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param costPerUnit The value to add.
   */
  public void addCostPerUnit(Thing costPerUnit);
  
  /**
   * Adds a drugUnit property value for this DrugCost object; appending it to the list of existing values.
   *
   * @param drugUnit The value to add.
   */
  public void addDrugUnit(String drugUnit);
  
}