package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.MedicalIntangible;
import org.schema.Number;
import org.schema.SchemaObject;

/**
 * A specific strength in which a medical drug is available in a specific country.
 */
public interface DrugStrength extends MedicalIntangible, SchemaObject {

  /**
   * Get a single activeIngredient property value for this DrugStrength object.
   *
   * @return The first activeIngredient property value.
   */
  public String getActiveIngredient();
  
  /**
   * Get a single availableIn property value for this DrugStrength object.
   *
   * @return The first availableIn property value.
   */
  public AdministrativeArea getAvailableIn();
  
  /**
   * Get a single strengthUnit property value for this DrugStrength object.
   *
   * @return The first strengthUnit property value.
   */
  public String getStrengthUnit();
  
  /**
   * Get a single strengthValue property value for this DrugStrength object.
   *
   * @return The first strengthValue property value.
   */
  public Number getStrengthValue();
  
  /**
   * Get all the activeIngredient property values for this DrugStrength object.
   *
   * @return A list of activeIngredient property values.
   */
  public List<String> getActiveIngredients();
  
  /**
   * Get all the availableIn property values for this DrugStrength object.
   *
   * @return A list of availableIn property values.
   */
  public List<AdministrativeArea> getAvailablesIn();
  
  /**
   * Get all the strengthUnit property values for this DrugStrength object.
   *
   * @return A list of strengthUnit property values.
   */
  public List<String> getStrengthUnits();
  
  /**
   * Get all the strengthValue property values for this DrugStrength object.
   *
   * @return A list of strengthValue property values.
   */
  public List<Number> getStrengthValues();
  
  /**
   * Set the activeIngredient property value for this DrugStrength object; overwriting any existing values.
   *
   * @param activeIngredient The value to set.
   */
  public void setActiveIngredient(String activeIngredient);
  
  /**
   * Set the availableIn property value for this DrugStrength object; overwriting any existing values.
   *
   * @param availableIn The value to set.
   */
  public void setAvailableIn(AdministrativeArea availableIn);
  
  /**
   * Set the strengthUnit property value for this DrugStrength object; overwriting any existing values.
   *
   * @param strengthUnit The value to set.
   */
  public void setStrengthUnit(String strengthUnit);
  
  /**
   * Set the strengthValue property value for this DrugStrength object; overwriting any existing values.
   *
   * @param strengthValue The value to set.
   */
  public void setStrengthValue(Number strengthValue);
  
  /**
   * Set the activeIngredient property values for this DrugStrength object; overwriting any existing values.
   *
   * @param activeIngredients The list of values to set.
   */
  public void setActiveIngredients(List<String> activeIngredients);
  
  /**
   * Set the availableIn property values for this DrugStrength object; overwriting any existing values.
   *
   * @param availablesIn The list of values to set.
   */
  public void setAvailablesIn(List<AdministrativeArea> availablesIn);
  
  /**
   * Set the strengthUnit property values for this DrugStrength object; overwriting any existing values.
   *
   * @param strengthUnits The list of values to set.
   */
  public void setStrengthUnits(List<String> strengthUnits);
  
  /**
   * Set the strengthValue property values for this DrugStrength object; overwriting any existing values.
   *
   * @param strengthValues The list of values to set.
   */
  public void setStrengthValues(List<Number> strengthValues);
  
  /**
   * Adds a activeIngredient property value for this DrugStrength object; appending it to the list of existing values.
   *
   * @param activeIngredient The value to add.
   */
  public void addActiveIngredient(String activeIngredient);
  
  /**
   * Adds a availableIn property value for this DrugStrength object; appending it to the list of existing values.
   *
   * @param availableIn The value to add.
   */
  public void addAvailableIn(AdministrativeArea availableIn);
  
  /**
   * Adds a strengthUnit property value for this DrugStrength object; appending it to the list of existing values.
   *
   * @param strengthUnit The value to add.
   */
  public void addStrengthUnit(String strengthUnit);
  
  /**
   * Adds a strengthValue property value for this DrugStrength object; appending it to the list of existing values.
   *
   * @param strengthValue The value to add.
   */
  public void addStrengthValue(Number strengthValue);
  
}