package org.schema;

import java.util.List;
import org.schema.Organization;
import org.schema.Person;
import org.schema.SchemaObject;

/**
 * An educational organization.
 */
public interface EducationalOrganization extends Organization, SchemaObject {

  /**
   * Get a single alumni property value for this EducationalOrganization object.
   *
   * @return The first alumni property value.
   */
  public Person getAlumni();
  
  /**
   * Get all the alumni property values for this EducationalOrganization object.
   *
   * @return A list of alumni property values.
   */
  public List<Person> getAlumnis();
  
  /**
   * Set the alumni property value for this EducationalOrganization object; overwriting any existing values.
   *
   * @param alumni The value to set.
   */
  public void setAlumni(Person alumni);
  
  /**
   * Set the alumni property values for this EducationalOrganization object; overwriting any existing values.
   *
   * @param alumnis The list of values to set.
   */
  public void setAlumnis(List<Person> alumnis);
  
  /**
   * Adds a alumni property value for this EducationalOrganization object; appending it to the list of existing values.
   *
   * @param alumni The value to add.
   */
  public void addAlumni(Person alumni);
  
}