package org.schema;

import java.util.List;
import org.schema.ReactAction;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An agent approves/certifies/likes/supports/sanction an object.
 */
public interface EndorseAction extends ReactAction, SchemaObject {

  /**
   * Get a single endorsee property value for this EndorseAction object.
   *
   * @return The first endorsee property value.
   */
  public Thing getEndorsee();
  
  /**
   * Get all the endorsee property values for this EndorseAction object.
   *
   * @return A list of endorsee property values.
   */
  public List<Thing> getEndorsees();
  
  /**
   * Set the endorsee property value for this EndorseAction object; overwriting any existing values.
   *
   * @param endorsee The value to set.
   */
  public void setEndorsee(Thing endorsee);
  
  /**
   * Set the endorsee property values for this EndorseAction object; overwriting any existing values.
   *
   * @param endorsees The list of values to set.
   */
  public void setEndorsees(List<Thing> endorsees);
  
  /**
   * Adds a endorsee property value for this EndorseAction object; appending it to the list of existing values.
   *
   * @param endorsee The value to add.
   */
  public void addEndorsee(Thing endorsee);
  
}