package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Duration;
import org.schema.Event;
import org.schema.EventStatusType;
import org.schema.Offer;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An event happening at a certain time and location, such as a concert, lecture, or festival. Ticketing information may be added via the 'offers' property. Repeated events may be structured as separate Event objects.
 */
public interface Event extends Thing, SchemaObject {

  /**
   * Get a single attendee property value for this Event object.
   *
   * @return The first attendee property value.
   */
  public Thing getAttendee();
  
  /**
   * Get a single doorTime property value for this Event object.
   *
   * @return The first doorTime property value.
   */
  public Date getDoorTime();
  
  /**
   * Get a single duration property value for this Event object.
   *
   * @return The first duration property value.
   */
  public Duration getDuration();
  
  /**
   * Get a single endDate property value for this Event object.
   *
   * @return The first endDate property value.
   */
  public Date getEndDate();
  
  /**
   * Get a single eventStatus property value for this Event object.
   *
   * @return The first eventStatus property value.
   */
  public EventStatusType getEventStatus();
  
  /**
   * Get a single location property value for this Event object.
   *
   * @return The first location property value.
   */
  public Thing getLocation();
  
  /**
   * Get a single offers property value for this Event object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers();
  
  /**
   * Get a single performer property value for this Event object.
   *
   * @return The first performer property value.
   */
  public Thing getPerformer();
  
  /**
   * Get a single previousStartDate property value for this Event object.
   *
   * @return The first previousStartDate property value.
   */
  public Date getPreviousStartDate();
  
  /**
   * Get a single startDate property value for this Event object.
   *
   * @return The first startDate property value.
   */
  public Date getStartDate();
  
  /**
   * Get a single subEvent property value for this Event object.
   *
   * @return The first subEvent property value.
   */
  public Event getSubEvent();
  
  /**
   * Get a single superEvent property value for this Event object.
   *
   * @return The first superEvent property value.
   */
  public Event getSuperEvent();
  
  /**
   * Get a single typicalAgeRange property value for this Event object.
   *
   * @return The first typicalAgeRange property value.
   */
  public String getTypicalAgeRange();
  
  /**
   * Get all the attendee property values for this Event object.
   *
   * @return A list of attendee property values.
   */
  public List<Thing> getAttendees();
  
  /**
   * Get all the doorTime property values for this Event object.
   *
   * @return A list of doorTime property values.
   */
  public List<Date> getDoorTimes();
  
  /**
   * Get all the duration property values for this Event object.
   *
   * @return A list of duration property values.
   */
  public List<Duration> getDurations();
  
  /**
   * Get all the endDate property values for this Event object.
   *
   * @return A list of endDate property values.
   */
  public List<Date> getEndDates();
  
  /**
   * Get all the eventStatus property values for this Event object.
   *
   * @return A list of eventStatus property values.
   */
  public List<EventStatusType> getEventStatuses();
  
  /**
   * Get all the location property values for this Event object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations();
  
  /**
   * Get all the offers property values for this Event object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss();
  
  /**
   * Get all the performer property values for this Event object.
   *
   * @return A list of performer property values.
   */
  public List<Thing> getPerformers();
  
  /**
   * Get all the previousStartDate property values for this Event object.
   *
   * @return A list of previousStartDate property values.
   */
  public List<Date> getPreviousStartDates();
  
  /**
   * Get all the startDate property values for this Event object.
   *
   * @return A list of startDate property values.
   */
  public List<Date> getStartDates();
  
  /**
   * Get all the subEvent property values for this Event object.
   *
   * @return A list of subEvent property values.
   */
  public List<Event> getSubEvents();
  
  /**
   * Get all the superEvent property values for this Event object.
   *
   * @return A list of superEvent property values.
   */
  public List<Event> getSuperEvents();
  
  /**
   * Get all the typicalAgeRange property values for this Event object.
   *
   * @return A list of typicalAgeRange property values.
   */
  public List<String> getTypicalAgeRanges();
  
  /**
   * Set the attendee property value for this Event object; overwriting any existing values.
   *
   * @param attendee The value to set.
   */
  public void setAttendee(Thing attendee);
  
  /**
   * Set the doorTime property value for this Event object; overwriting any existing values.
   *
   * @param doorTime The value to set.
   */
  public void setDoorTime(Date doorTime);
  
  /**
   * Set the duration property value for this Event object; overwriting any existing values.
   *
   * @param duration The value to set.
   */
  public void setDuration(Duration duration);
  
  /**
   * Set the endDate property value for this Event object; overwriting any existing values.
   *
   * @param endDate The value to set.
   */
  public void setEndDate(Date endDate);
  
  /**
   * Set the eventStatus property value for this Event object; overwriting any existing values.
   *
   * @param eventStatus The value to set.
   */
  public void setEventStatus(EventStatusType eventStatus);
  
  /**
   * Set the location property value for this Event object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location);
  
  /**
   * Set the offers property value for this Event object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers);
  
  /**
   * Set the performer property value for this Event object; overwriting any existing values.
   *
   * @param performer The value to set.
   */
  public void setPerformer(Thing performer);
  
  /**
   * Set the previousStartDate property value for this Event object; overwriting any existing values.
   *
   * @param previousStartDate The value to set.
   */
  public void setPreviousStartDate(Date previousStartDate);
  
  /**
   * Set the startDate property value for this Event object; overwriting any existing values.
   *
   * @param startDate The value to set.
   */
  public void setStartDate(Date startDate);
  
  /**
   * Set the subEvent property value for this Event object; overwriting any existing values.
   *
   * @param subEvent The value to set.
   */
  public void setSubEvent(Event subEvent);
  
  /**
   * Set the superEvent property value for this Event object; overwriting any existing values.
   *
   * @param superEvent The value to set.
   */
  public void setSuperEvent(Event superEvent);
  
  /**
   * Set the typicalAgeRange property value for this Event object; overwriting any existing values.
   *
   * @param typicalAgeRange The value to set.
   */
  public void setTypicalAgeRange(String typicalAgeRange);
  
  /**
   * Set the attendee property values for this Event object; overwriting any existing values.
   *
   * @param attendees The list of values to set.
   */
  public void setAttendees(List<Thing> attendees);
  
  /**
   * Set the doorTime property values for this Event object; overwriting any existing values.
   *
   * @param doorTimes The list of values to set.
   */
  public void setDoorTimes(List<Date> doorTimes);
  
  /**
   * Set the duration property values for this Event object; overwriting any existing values.
   *
   * @param durations The list of values to set.
   */
  public void setDurations(List<Duration> durations);
  
  /**
   * Set the endDate property values for this Event object; overwriting any existing values.
   *
   * @param endDates The list of values to set.
   */
  public void setEndDates(List<Date> endDates);
  
  /**
   * Set the eventStatus property values for this Event object; overwriting any existing values.
   *
   * @param eventStatuses The list of values to set.
   */
  public void setEventStatuses(List<EventStatusType> eventStatuses);
  
  /**
   * Set the location property values for this Event object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations);
  
  /**
   * Set the offers property values for this Event object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss);
  
  /**
   * Set the performer property values for this Event object; overwriting any existing values.
   *
   * @param performers The list of values to set.
   */
  public void setPerformers(List<Thing> performers);
  
  /**
   * Set the previousStartDate property values for this Event object; overwriting any existing values.
   *
   * @param previousStartDates The list of values to set.
   */
  public void setPreviousStartDates(List<Date> previousStartDates);
  
  /**
   * Set the startDate property values for this Event object; overwriting any existing values.
   *
   * @param startDates The list of values to set.
   */
  public void setStartDates(List<Date> startDates);
  
  /**
   * Set the subEvent property values for this Event object; overwriting any existing values.
   *
   * @param subEvents The list of values to set.
   */
  public void setSubEvents(List<Event> subEvents);
  
  /**
   * Set the superEvent property values for this Event object; overwriting any existing values.
   *
   * @param superEvents The list of values to set.
   */
  public void setSuperEvents(List<Event> superEvents);
  
  /**
   * Set the typicalAgeRange property values for this Event object; overwriting any existing values.
   *
   * @param typicalAgeRanges The list of values to set.
   */
  public void setTypicalAgeRanges(List<String> typicalAgeRanges);
  
  /**
   * Adds a attendee property value for this Event object; appending it to the list of existing values.
   *
   * @param attendee The value to add.
   */
  public void addAttendee(Thing attendee);
  
  /**
   * Adds a doorTime property value for this Event object; appending it to the list of existing values.
   *
   * @param doorTime The value to add.
   */
  public void addDoorTime(Date doorTime);
  
  /**
   * Adds a duration property value for this Event object; appending it to the list of existing values.
   *
   * @param duration The value to add.
   */
  public void addDuration(Duration duration);
  
  /**
   * Adds a endDate property value for this Event object; appending it to the list of existing values.
   *
   * @param endDate The value to add.
   */
  public void addEndDate(Date endDate);
  
  /**
   * Adds a eventStatus property value for this Event object; appending it to the list of existing values.
   *
   * @param eventStatus The value to add.
   */
  public void addEventStatus(EventStatusType eventStatus);
  
  /**
   * Adds a location property value for this Event object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location);
  
  /**
   * Adds a offers property value for this Event object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers);
  
  /**
   * Adds a performer property value for this Event object; appending it to the list of existing values.
   *
   * @param performer The value to add.
   */
  public void addPerformer(Thing performer);
  
  /**
   * Adds a previousStartDate property value for this Event object; appending it to the list of existing values.
   *
   * @param previousStartDate The value to add.
   */
  public void addPreviousStartDate(Date previousStartDate);
  
  /**
   * Adds a startDate property value for this Event object; appending it to the list of existing values.
   *
   * @param startDate The value to add.
   */
  public void addStartDate(Date startDate);
  
  /**
   * Adds a subEvent property value for this Event object; appending it to the list of existing values.
   *
   * @param subEvent The value to add.
   */
  public void addSubEvent(Event subEvent);
  
  /**
   * Adds a superEvent property value for this Event object; appending it to the list of existing values.
   *
   * @param superEvent The value to add.
   */
  public void addSuperEvent(Event superEvent);
  
  /**
   * Adds a typicalAgeRange property value for this Event object; appending it to the list of existing values.
   *
   * @param typicalAgeRange The value to add.
   */
  public void addTypicalAgeRange(String typicalAgeRange);
  
}