package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Diet;
import org.schema.Distance;
import org.schema.ExercisePlan;
import org.schema.Person;
import org.schema.Place;
import org.schema.PlayAction;
import org.schema.SchemaObject;
import org.schema.SportsActivityLocation;
import org.schema.SportsEvent;
import org.schema.SportsTeam;
import org.schema.Thing;

/**
 * The act of participating in exertive activity for the purposes of improving health and fitness
 */
public interface ExerciseAction extends PlayAction, SchemaObject {

  /**
   * Get a single course property value for this ExerciseAction object.
   *
   * @return The first course property value.
   */
  public Place getCourse();
  
  /**
   * Get a single diet property value for this ExerciseAction object.
   *
   * @return The first diet property value.
   */
  public Diet getDiet();
  
  /**
   * Get a single distance property value for this ExerciseAction object.
   *
   * @return The first distance property value.
   */
  public Distance getDistance();
  
  /**
   * Get a single exercisePlan property value for this ExerciseAction object.
   *
   * @return The first exercisePlan property value.
   */
  public ExercisePlan getExercisePlan();
  
  /**
   * Get a single exerciseType property value for this ExerciseAction object.
   *
   * @return The first exerciseType property value.
   */
  public String getExerciseType();
  
  /**
   * Get a single fromLocation property value for this ExerciseAction object.
   *
   * @return The first fromLocation property value.
   */
  public Thing getFromLocation();
  
  /**
   * Get a single oponent property value for this ExerciseAction object.
   *
   * @return The first oponent property value.
   */
  public Person getOponent();
  
  /**
   * Get a single sportsActivityLocation property value for this ExerciseAction object.
   *
   * @return The first sportsActivityLocation property value.
   */
  public SportsActivityLocation getSportsActivityLocation();
  
  /**
   * Get a single sportsEvent property value for this ExerciseAction object.
   *
   * @return The first sportsEvent property value.
   */
  public SportsEvent getSportsEvent();
  
  /**
   * Get a single sportsTeam property value for this ExerciseAction object.
   *
   * @return The first sportsTeam property value.
   */
  public SportsTeam getSportsTeam();
  
  /**
   * Get a single toLocation property value for this ExerciseAction object.
   *
   * @return The first toLocation property value.
   */
  public Thing getToLocation();
  
  /**
   * Get all the course property values for this ExerciseAction object.
   *
   * @return A list of course property values.
   */
  public List<Place> getCourses();
  
  /**
   * Get all the diet property values for this ExerciseAction object.
   *
   * @return A list of diet property values.
   */
  public List<Diet> getDiets();
  
  /**
   * Get all the distance property values for this ExerciseAction object.
   *
   * @return A list of distance property values.
   */
  public List<Distance> getDistances();
  
  /**
   * Get all the exercisePlan property values for this ExerciseAction object.
   *
   * @return A list of exercisePlan property values.
   */
  public List<ExercisePlan> getExercisePlans();
  
  /**
   * Get all the exerciseType property values for this ExerciseAction object.
   *
   * @return A list of exerciseType property values.
   */
  public List<String> getExerciseTypes();
  
  /**
   * Get all the fromLocation property values for this ExerciseAction object.
   *
   * @return A list of fromLocation property values.
   */
  public List<Thing> getFromLocations();
  
  /**
   * Get all the oponent property values for this ExerciseAction object.
   *
   * @return A list of oponent property values.
   */
  public List<Person> getOponents();
  
  /**
   * Get all the sportsActivityLocation property values for this ExerciseAction object.
   *
   * @return A list of sportsActivityLocation property values.
   */
  public List<SportsActivityLocation> getSportsActivityLocations();
  
  /**
   * Get all the sportsEvent property values for this ExerciseAction object.
   *
   * @return A list of sportsEvent property values.
   */
  public List<SportsEvent> getSportsEvents();
  
  /**
   * Get all the sportsTeam property values for this ExerciseAction object.
   *
   * @return A list of sportsTeam property values.
   */
  public List<SportsTeam> getSportsTeams();
  
  /**
   * Get all the toLocation property values for this ExerciseAction object.
   *
   * @return A list of toLocation property values.
   */
  public List<Thing> getToLocations();
  
  /**
   * Set the course property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param course The value to set.
   */
  public void setCourse(Place course);
  
  /**
   * Set the diet property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param diet The value to set.
   */
  public void setDiet(Diet diet);
  
  /**
   * Set the distance property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param distance The value to set.
   */
  public void setDistance(Distance distance);
  
  /**
   * Set the exercisePlan property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param exercisePlan The value to set.
   */
  public void setExercisePlan(ExercisePlan exercisePlan);
  
  /**
   * Set the exerciseType property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param exerciseType The value to set.
   */
  public void setExerciseType(String exerciseType);
  
  /**
   * Set the fromLocation property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param fromLocation The value to set.
   */
  public void setFromLocation(Thing fromLocation);
  
  /**
   * Set the oponent property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param oponent The value to set.
   */
  public void setOponent(Person oponent);
  
  /**
   * Set the sportsActivityLocation property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsActivityLocation The value to set.
   */
  public void setSportsActivityLocation(SportsActivityLocation sportsActivityLocation);
  
  /**
   * Set the sportsEvent property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsEvent The value to set.
   */
  public void setSportsEvent(SportsEvent sportsEvent);
  
  /**
   * Set the sportsTeam property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsTeam The value to set.
   */
  public void setSportsTeam(SportsTeam sportsTeam);
  
  /**
   * Set the toLocation property value for this ExerciseAction object; overwriting any existing values.
   *
   * @param toLocation The value to set.
   */
  public void setToLocation(Thing toLocation);
  
  /**
   * Set the course property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param courses The list of values to set.
   */
  public void setCourses(List<Place> courses);
  
  /**
   * Set the diet property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param diets The list of values to set.
   */
  public void setDiets(List<Diet> diets);
  
  /**
   * Set the distance property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param distances The list of values to set.
   */
  public void setDistances(List<Distance> distances);
  
  /**
   * Set the exercisePlan property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param exercisePlans The list of values to set.
   */
  public void setExercisePlans(List<ExercisePlan> exercisePlans);
  
  /**
   * Set the exerciseType property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param exerciseTypes The list of values to set.
   */
  public void setExerciseTypes(List<String> exerciseTypes);
  
  /**
   * Set the fromLocation property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param fromLocations The list of values to set.
   */
  public void setFromLocations(List<Thing> fromLocations);
  
  /**
   * Set the oponent property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param oponents The list of values to set.
   */
  public void setOponents(List<Person> oponents);
  
  /**
   * Set the sportsActivityLocation property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsActivityLocations The list of values to set.
   */
  public void setSportsActivityLocations(List<SportsActivityLocation> sportsActivityLocations);
  
  /**
   * Set the sportsEvent property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsEvents The list of values to set.
   */
  public void setSportsEvents(List<SportsEvent> sportsEvents);
  
  /**
   * Set the sportsTeam property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param sportsTeams The list of values to set.
   */
  public void setSportsTeams(List<SportsTeam> sportsTeams);
  
  /**
   * Set the toLocation property values for this ExerciseAction object; overwriting any existing values.
   *
   * @param toLocations The list of values to set.
   */
  public void setToLocations(List<Thing> toLocations);
  
  /**
   * Adds a course property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param course The value to add.
   */
  public void addCourse(Place course);
  
  /**
   * Adds a diet property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param diet The value to add.
   */
  public void addDiet(Diet diet);
  
  /**
   * Adds a distance property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param distance The value to add.
   */
  public void addDistance(Distance distance);
  
  /**
   * Adds a exercisePlan property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param exercisePlan The value to add.
   */
  public void addExercisePlan(ExercisePlan exercisePlan);
  
  /**
   * Adds a exerciseType property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param exerciseType The value to add.
   */
  public void addExerciseType(String exerciseType);
  
  /**
   * Adds a fromLocation property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param fromLocation The value to add.
   */
  public void addFromLocation(Thing fromLocation);
  
  /**
   * Adds a oponent property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param oponent The value to add.
   */
  public void addOponent(Person oponent);
  
  /**
   * Adds a sportsActivityLocation property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sportsActivityLocation The value to add.
   */
  public void addSportsActivityLocation(SportsActivityLocation sportsActivityLocation);
  
  /**
   * Adds a sportsEvent property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sportsEvent The value to add.
   */
  public void addSportsEvent(SportsEvent sportsEvent);
  
  /**
   * Adds a sportsTeam property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param sportsTeam The value to add.
   */
  public void addSportsTeam(SportsTeam sportsTeam);
  
  /**
   * Adds a toLocation property value for this ExerciseAction object; appending it to the list of existing values.
   *
   * @param toLocation The value to add.
   */
  public void addToLocation(Thing toLocation);
  
}