package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.Energy;
import org.schema.Number;
import org.schema.PhysicalActivity;
import org.schema.SchemaObject;

/**
 * Fitness-related activity designed for a specific health-related purpose, including defined exercise routines as well as activity prescribed by a clinician.
 */
public interface ExercisePlan extends CreativeWork, PhysicalActivity, SchemaObject {

  /**
   * Get a single activityDuration property value for this ExercisePlan object.
   *
   * @return The first activityDuration property value.
   */
  public Duration getActivityDuration();
  
  /**
   * Get a single activityFrequency property value for this ExercisePlan object.
   *
   * @return The first activityFrequency property value.
   */
  public String getActivityFrequency();
  
  /**
   * Get a single additionalVariable property value for this ExercisePlan object.
   *
   * @return The first additionalVariable property value.
   */
  public String getAdditionalVariable();
  
  /**
   * Get a single exerciseType property value for this ExercisePlan object.
   *
   * @return The first exerciseType property value.
   */
  public String getExerciseType();
  
  /**
   * Get a single intensity property value for this ExercisePlan object.
   *
   * @return The first intensity property value.
   */
  public String getIntensity();
  
  /**
   * Get a single repetitions property value for this ExercisePlan object.
   *
   * @return The first repetitions property value.
   */
  public Number getRepetitions();
  
  /**
   * Get a single restPeriods property value for this ExercisePlan object.
   *
   * @return The first restPeriods property value.
   */
  public String getRestPeriods();
  
  /**
   * Get a single workload property value for this ExercisePlan object.
   *
   * @return The first workload property value.
   */
  public Energy getWorkload();
  
  /**
   * Get all the activityDuration property values for this ExercisePlan object.
   *
   * @return A list of activityDuration property values.
   */
  public List<Duration> getActivityDurations();
  
  /**
   * Get all the activityFrequency property values for this ExercisePlan object.
   *
   * @return A list of activityFrequency property values.
   */
  public List<String> getActivityFrequencies();
  
  /**
   * Get all the additionalVariable property values for this ExercisePlan object.
   *
   * @return A list of additionalVariable property values.
   */
  public List<String> getAdditionalVariables();
  
  /**
   * Get all the exerciseType property values for this ExercisePlan object.
   *
   * @return A list of exerciseType property values.
   */
  public List<String> getExerciseTypes();
  
  /**
   * Get all the intensity property values for this ExercisePlan object.
   *
   * @return A list of intensity property values.
   */
  public List<String> getIntensities();
  
  /**
   * Get all the repetitions property values for this ExercisePlan object.
   *
   * @return A list of repetitions property values.
   */
  public List<Number> getRepetitionss();
  
  /**
   * Get all the restPeriods property values for this ExercisePlan object.
   *
   * @return A list of restPeriods property values.
   */
  public List<String> getRestPeriodss();
  
  /**
   * Get all the workload property values for this ExercisePlan object.
   *
   * @return A list of workload property values.
   */
  public List<Energy> getWorkloads();
  
  /**
   * Set the activityDuration property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityDuration The value to set.
   */
  public void setActivityDuration(Duration activityDuration);
  
  /**
   * Set the activityFrequency property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityFrequency The value to set.
   */
  public void setActivityFrequency(String activityFrequency);
  
  /**
   * Set the additionalVariable property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param additionalVariable The value to set.
   */
  public void setAdditionalVariable(String additionalVariable);
  
  /**
   * Set the exerciseType property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param exerciseType The value to set.
   */
  public void setExerciseType(String exerciseType);
  
  /**
   * Set the intensity property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param intensity The value to set.
   */
  public void setIntensity(String intensity);
  
  /**
   * Set the repetitions property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param repetitions The value to set.
   */
  public void setRepetitions(Number repetitions);
  
  /**
   * Set the restPeriods property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param restPeriods The value to set.
   */
  public void setRestPeriods(String restPeriods);
  
  /**
   * Set the workload property value for this ExercisePlan object; overwriting any existing values.
   *
   * @param workload The value to set.
   */
  public void setWorkload(Energy workload);
  
  /**
   * Set the activityDuration property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityDurations The list of values to set.
   */
  public void setActivityDurations(List<Duration> activityDurations);
  
  /**
   * Set the activityFrequency property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param activityFrequencies The list of values to set.
   */
  public void setActivityFrequencies(List<String> activityFrequencies);
  
  /**
   * Set the additionalVariable property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param additionalVariables The list of values to set.
   */
  public void setAdditionalVariables(List<String> additionalVariables);
  
  /**
   * Set the exerciseType property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param exerciseTypes The list of values to set.
   */
  public void setExerciseTypes(List<String> exerciseTypes);
  
  /**
   * Set the intensity property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param intensities The list of values to set.
   */
  public void setIntensities(List<String> intensities);
  
  /**
   * Set the repetitions property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param repetitionss The list of values to set.
   */
  public void setRepetitionss(List<Number> repetitionss);
  
  /**
   * Set the restPeriods property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param restPeriodss The list of values to set.
   */
  public void setRestPeriodss(List<String> restPeriodss);
  
  /**
   * Set the workload property values for this ExercisePlan object; overwriting any existing values.
   *
   * @param workloads The list of values to set.
   */
  public void setWorkloads(List<Energy> workloads);
  
  /**
   * Adds a activityDuration property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param activityDuration The value to add.
   */
  public void addActivityDuration(Duration activityDuration);
  
  /**
   * Adds a activityFrequency property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param activityFrequency The value to add.
   */
  public void addActivityFrequency(String activityFrequency);
  
  /**
   * Adds a additionalVariable property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param additionalVariable The value to add.
   */
  public void addAdditionalVariable(String additionalVariable);
  
  /**
   * Adds a exerciseType property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param exerciseType The value to add.
   */
  public void addExerciseType(String exerciseType);
  
  /**
   * Adds a intensity property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param intensity The value to add.
   */
  public void addIntensity(String intensity);
  
  /**
   * Adds a repetitions property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param repetitions The value to add.
   */
  public void addRepetitions(Number repetitions);
  
  /**
   * Adds a restPeriods property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param restPeriods The value to add.
   */
  public void addRestPeriods(String restPeriods);
  
  /**
   * Adds a workload property value for this ExercisePlan object; appending it to the list of existing values.
   *
   * @param workload The value to add.
   */
  public void addWorkload(Energy workload);
  
}