package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Airport;
import org.schema.Intangible;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An airline flight.
 */
public interface Flight extends Intangible, SchemaObject {

  /**
   * Get a single aircraft property value for this Flight object.
   *
   * @return The first aircraft property value.
   */
  public Thing getAircraft();
  
  /**
   * Get a single arrivalAirport property value for this Flight object.
   *
   * @return The first arrivalAirport property value.
   */
  public Airport getArrivalAirport();
  
  /**
   * Get a single arrivalGate property value for this Flight object.
   *
   * @return The first arrivalGate property value.
   */
  public String getArrivalGate();
  
  /**
   * Get a single arrivalTerminal property value for this Flight object.
   *
   * @return The first arrivalTerminal property value.
   */
  public String getArrivalTerminal();
  
  /**
   * Get a single arrivalTime property value for this Flight object.
   *
   * @return The first arrivalTime property value.
   */
  public Date getArrivalTime();
  
  /**
   * Get a single carrier property value for this Flight object.
   *
   * @return The first carrier property value.
   */
  public Thing getCarrier();
  
  /**
   * Get a single departureAirport property value for this Flight object.
   *
   * @return The first departureAirport property value.
   */
  public Airport getDepartureAirport();
  
  /**
   * Get a single departureGate property value for this Flight object.
   *
   * @return The first departureGate property value.
   */
  public String getDepartureGate();
  
  /**
   * Get a single departureTerminal property value for this Flight object.
   *
   * @return The first departureTerminal property value.
   */
  public String getDepartureTerminal();
  
  /**
   * Get a single departureTime property value for this Flight object.
   *
   * @return The first departureTime property value.
   */
  public Date getDepartureTime();
  
  /**
   * Get a single estimatedFlightDuration property value for this Flight object.
   *
   * @return The first estimatedFlightDuration property value.
   */
  public Thing getEstimatedFlightDuration();
  
  /**
   * Get a single flightDistance property value for this Flight object.
   *
   * @return The first flightDistance property value.
   */
  public Thing getFlightDistance();
  
  /**
   * Get a single flightNumber property value for this Flight object.
   *
   * @return The first flightNumber property value.
   */
  public String getFlightNumber();
  
  /**
   * Get a single mealService property value for this Flight object.
   *
   * @return The first mealService property value.
   */
  public String getMealService();
  
  /**
   * Get a single provider property value for this Flight object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider();
  
  /**
   * Get a single webCheckinTime property value for this Flight object.
   *
   * @return The first webCheckinTime property value.
   */
  public Date getWebCheckinTime();
  
  /**
   * Get all the aircraft property values for this Flight object.
   *
   * @return A list of aircraft property values.
   */
  public List<Thing> getAircrafts();
  
  /**
   * Get all the arrivalAirport property values for this Flight object.
   *
   * @return A list of arrivalAirport property values.
   */
  public List<Airport> getArrivalAirports();
  
  /**
   * Get all the arrivalGate property values for this Flight object.
   *
   * @return A list of arrivalGate property values.
   */
  public List<String> getArrivalGates();
  
  /**
   * Get all the arrivalTerminal property values for this Flight object.
   *
   * @return A list of arrivalTerminal property values.
   */
  public List<String> getArrivalTerminals();
  
  /**
   * Get all the arrivalTime property values for this Flight object.
   *
   * @return A list of arrivalTime property values.
   */
  public List<Date> getArrivalTimes();
  
  /**
   * Get all the carrier property values for this Flight object.
   *
   * @return A list of carrier property values.
   */
  public List<Thing> getCarriers();
  
  /**
   * Get all the departureAirport property values for this Flight object.
   *
   * @return A list of departureAirport property values.
   */
  public List<Airport> getDepartureAirports();
  
  /**
   * Get all the departureGate property values for this Flight object.
   *
   * @return A list of departureGate property values.
   */
  public List<String> getDepartureGates();
  
  /**
   * Get all the departureTerminal property values for this Flight object.
   *
   * @return A list of departureTerminal property values.
   */
  public List<String> getDepartureTerminals();
  
  /**
   * Get all the departureTime property values for this Flight object.
   *
   * @return A list of departureTime property values.
   */
  public List<Date> getDepartureTimes();
  
  /**
   * Get all the estimatedFlightDuration property values for this Flight object.
   *
   * @return A list of estimatedFlightDuration property values.
   */
  public List<Thing> getEstimatedFlightDurations();
  
  /**
   * Get all the flightDistance property values for this Flight object.
   *
   * @return A list of flightDistance property values.
   */
  public List<Thing> getFlightDistances();
  
  /**
   * Get all the flightNumber property values for this Flight object.
   *
   * @return A list of flightNumber property values.
   */
  public List<String> getFlightNumbers();
  
  /**
   * Get all the mealService property values for this Flight object.
   *
   * @return A list of mealService property values.
   */
  public List<String> getMealServices();
  
  /**
   * Get all the provider property values for this Flight object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders();
  
  /**
   * Get all the webCheckinTime property values for this Flight object.
   *
   * @return A list of webCheckinTime property values.
   */
  public List<Date> getWebCheckinTimes();
  
  /**
   * Set the aircraft property value for this Flight object; overwriting any existing values.
   *
   * @param aircraft The value to set.
   */
  public void setAircraft(Thing aircraft);
  
  /**
   * Set the arrivalAirport property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalAirport The value to set.
   */
  public void setArrivalAirport(Airport arrivalAirport);
  
  /**
   * Set the arrivalGate property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalGate The value to set.
   */
  public void setArrivalGate(String arrivalGate);
  
  /**
   * Set the arrivalTerminal property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalTerminal The value to set.
   */
  public void setArrivalTerminal(String arrivalTerminal);
  
  /**
   * Set the arrivalTime property value for this Flight object; overwriting any existing values.
   *
   * @param arrivalTime The value to set.
   */
  public void setArrivalTime(Date arrivalTime);
  
  /**
   * Set the carrier property value for this Flight object; overwriting any existing values.
   *
   * @param carrier The value to set.
   */
  public void setCarrier(Thing carrier);
  
  /**
   * Set the departureAirport property value for this Flight object; overwriting any existing values.
   *
   * @param departureAirport The value to set.
   */
  public void setDepartureAirport(Airport departureAirport);
  
  /**
   * Set the departureGate property value for this Flight object; overwriting any existing values.
   *
   * @param departureGate The value to set.
   */
  public void setDepartureGate(String departureGate);
  
  /**
   * Set the departureTerminal property value for this Flight object; overwriting any existing values.
   *
   * @param departureTerminal The value to set.
   */
  public void setDepartureTerminal(String departureTerminal);
  
  /**
   * Set the departureTime property value for this Flight object; overwriting any existing values.
   *
   * @param departureTime The value to set.
   */
  public void setDepartureTime(Date departureTime);
  
  /**
   * Set the estimatedFlightDuration property value for this Flight object; overwriting any existing values.
   *
   * @param estimatedFlightDuration The value to set.
   */
  public void setEstimatedFlightDuration(Thing estimatedFlightDuration);
  
  /**
   * Set the flightDistance property value for this Flight object; overwriting any existing values.
   *
   * @param flightDistance The value to set.
   */
  public void setFlightDistance(Thing flightDistance);
  
  /**
   * Set the flightNumber property value for this Flight object; overwriting any existing values.
   *
   * @param flightNumber The value to set.
   */
  public void setFlightNumber(String flightNumber);
  
  /**
   * Set the mealService property value for this Flight object; overwriting any existing values.
   *
   * @param mealService The value to set.
   */
  public void setMealService(String mealService);
  
  /**
   * Set the provider property value for this Flight object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider);
  
  /**
   * Set the webCheckinTime property value for this Flight object; overwriting any existing values.
   *
   * @param webCheckinTime The value to set.
   */
  public void setWebCheckinTime(Date webCheckinTime);
  
  /**
   * Set the aircraft property values for this Flight object; overwriting any existing values.
   *
   * @param aircrafts The list of values to set.
   */
  public void setAircrafts(List<Thing> aircrafts);
  
  /**
   * Set the arrivalAirport property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalAirports The list of values to set.
   */
  public void setArrivalAirports(List<Airport> arrivalAirports);
  
  /**
   * Set the arrivalGate property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalGates The list of values to set.
   */
  public void setArrivalGates(List<String> arrivalGates);
  
  /**
   * Set the arrivalTerminal property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalTerminals The list of values to set.
   */
  public void setArrivalTerminals(List<String> arrivalTerminals);
  
  /**
   * Set the arrivalTime property values for this Flight object; overwriting any existing values.
   *
   * @param arrivalTimes The list of values to set.
   */
  public void setArrivalTimes(List<Date> arrivalTimes);
  
  /**
   * Set the carrier property values for this Flight object; overwriting any existing values.
   *
   * @param carriers The list of values to set.
   */
  public void setCarriers(List<Thing> carriers);
  
  /**
   * Set the departureAirport property values for this Flight object; overwriting any existing values.
   *
   * @param departureAirports The list of values to set.
   */
  public void setDepartureAirports(List<Airport> departureAirports);
  
  /**
   * Set the departureGate property values for this Flight object; overwriting any existing values.
   *
   * @param departureGates The list of values to set.
   */
  public void setDepartureGates(List<String> departureGates);
  
  /**
   * Set the departureTerminal property values for this Flight object; overwriting any existing values.
   *
   * @param departureTerminals The list of values to set.
   */
  public void setDepartureTerminals(List<String> departureTerminals);
  
  /**
   * Set the departureTime property values for this Flight object; overwriting any existing values.
   *
   * @param departureTimes The list of values to set.
   */
  public void setDepartureTimes(List<Date> departureTimes);
  
  /**
   * Set the estimatedFlightDuration property values for this Flight object; overwriting any existing values.
   *
   * @param estimatedFlightDurations The list of values to set.
   */
  public void setEstimatedFlightDurations(List<Thing> estimatedFlightDurations);
  
  /**
   * Set the flightDistance property values for this Flight object; overwriting any existing values.
   *
   * @param flightDistances The list of values to set.
   */
  public void setFlightDistances(List<Thing> flightDistances);
  
  /**
   * Set the flightNumber property values for this Flight object; overwriting any existing values.
   *
   * @param flightNumbers The list of values to set.
   */
  public void setFlightNumbers(List<String> flightNumbers);
  
  /**
   * Set the mealService property values for this Flight object; overwriting any existing values.
   *
   * @param mealServices The list of values to set.
   */
  public void setMealServices(List<String> mealServices);
  
  /**
   * Set the provider property values for this Flight object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers);
  
  /**
   * Set the webCheckinTime property values for this Flight object; overwriting any existing values.
   *
   * @param webCheckinTimes The list of values to set.
   */
  public void setWebCheckinTimes(List<Date> webCheckinTimes);
  
  /**
   * Adds a aircraft property value for this Flight object; appending it to the list of existing values.
   *
   * @param aircraft The value to add.
   */
  public void addAircraft(Thing aircraft);
  
  /**
   * Adds a arrivalAirport property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalAirport The value to add.
   */
  public void addArrivalAirport(Airport arrivalAirport);
  
  /**
   * Adds a arrivalGate property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalGate The value to add.
   */
  public void addArrivalGate(String arrivalGate);
  
  /**
   * Adds a arrivalTerminal property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalTerminal The value to add.
   */
  public void addArrivalTerminal(String arrivalTerminal);
  
  /**
   * Adds a arrivalTime property value for this Flight object; appending it to the list of existing values.
   *
   * @param arrivalTime The value to add.
   */
  public void addArrivalTime(Date arrivalTime);
  
  /**
   * Adds a carrier property value for this Flight object; appending it to the list of existing values.
   *
   * @param carrier The value to add.
   */
  public void addCarrier(Thing carrier);
  
  /**
   * Adds a departureAirport property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureAirport The value to add.
   */
  public void addDepartureAirport(Airport departureAirport);
  
  /**
   * Adds a departureGate property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureGate The value to add.
   */
  public void addDepartureGate(String departureGate);
  
  /**
   * Adds a departureTerminal property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureTerminal The value to add.
   */
  public void addDepartureTerminal(String departureTerminal);
  
  /**
   * Adds a departureTime property value for this Flight object; appending it to the list of existing values.
   *
   * @param departureTime The value to add.
   */
  public void addDepartureTime(Date departureTime);
  
  /**
   * Adds a estimatedFlightDuration property value for this Flight object; appending it to the list of existing values.
   *
   * @param estimatedFlightDuration The value to add.
   */
  public void addEstimatedFlightDuration(Thing estimatedFlightDuration);
  
  /**
   * Adds a flightDistance property value for this Flight object; appending it to the list of existing values.
   *
   * @param flightDistance The value to add.
   */
  public void addFlightDistance(Thing flightDistance);
  
  /**
   * Adds a flightNumber property value for this Flight object; appending it to the list of existing values.
   *
   * @param flightNumber The value to add.
   */
  public void addFlightNumber(String flightNumber);
  
  /**
   * Adds a mealService property value for this Flight object; appending it to the list of existing values.
   *
   * @param mealService The value to add.
   */
  public void addMealService(String mealService);
  
  /**
   * Adds a provider property value for this Flight object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider);
  
  /**
   * Adds a webCheckinTime property value for this Flight object; appending it to the list of existing values.
   *
   * @param webCheckinTime The value to add.
   */
  public void addWebCheckinTime(Date webCheckinTime);
  
}