package org.schema;

import java.util.List;
import org.schema.InteractAction;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of forming a personal connection with someone/something (object) unidirectionally/asymmetrically to get updates polled from.<p>Related actions:</p><ul><li><a href="http://schema.org/BefriendAction">BefriendAction</a>: Unlike BefriendAction, FollowAction implies that the connection is *not* necessarily reciprocal.</li><li><a href="http://schema.org/SubscribeAction">SubscribeAction</a>: Unlike SubscribeAction, FollowAction implies that the follower acts as an active agent constantly/actively polling for updates.</li><li><a href="http://schema.org/RegisterAction">RegisterAction</a>: Unlike RegisterAction, FollowAction implies that the agent is interested in continuing receiving updates from the object.</li><li><a href="http://schema.org/JoinAction">JoinAction</a>: Unlike JoinAction, FollowAction implies that the agent is interested in getting updates from the object.</li><li><a href="http://schema.org/TrackAction">TrackAction</a>: Unlike TrackAction, FollowAction refers to the polling of updates of all aspects of animate objects rather than the location of inanimate objects (e.g. you track a package, but you don't follow it).</li></ul>
 */
public interface FollowAction extends InteractAction, SchemaObject {

  /**
   * Get a single followee property value for this FollowAction object.
   *
   * @return The first followee property value.
   */
  public Thing getFollowee();
  
  /**
   * Get all the followee property values for this FollowAction object.
   *
   * @return A list of followee property values.
   */
  public List<Thing> getFollowees();
  
  /**
   * Set the followee property value for this FollowAction object; overwriting any existing values.
   *
   * @param followee The value to set.
   */
  public void setFollowee(Thing followee);
  
  /**
   * Set the followee property values for this FollowAction object; overwriting any existing values.
   *
   * @param followees The list of values to set.
   */
  public void setFollowees(List<Thing> followees);
  
  /**
   * Adds a followee property value for this FollowAction object; appending it to the list of existing values.
   *
   * @param followee The value to add.
   */
  public void addFollowee(Thing followee);
  
}