package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.Thing;

/**
 * The geographic coordinates of a place or event.
 */
public interface GeoCoordinates extends StructuredValue, SchemaObject {

  /**
   * Get a single elevation property value for this GeoCoordinates object.
   *
   * @return The first elevation property value.
   */
  public Thing getElevation();
  
  /**
   * Get a single latitude property value for this GeoCoordinates object.
   *
   * @return The first latitude property value.
   */
  public Thing getLatitude();
  
  /**
   * Get a single longitude property value for this GeoCoordinates object.
   *
   * @return The first longitude property value.
   */
  public Thing getLongitude();
  
  /**
   * Get all the elevation property values for this GeoCoordinates object.
   *
   * @return A list of elevation property values.
   */
  public List<Thing> getElevations();
  
  /**
   * Get all the latitude property values for this GeoCoordinates object.
   *
   * @return A list of latitude property values.
   */
  public List<Thing> getLatitudes();
  
  /**
   * Get all the longitude property values for this GeoCoordinates object.
   *
   * @return A list of longitude property values.
   */
  public List<Thing> getLongitudes();
  
  /**
   * Set the elevation property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param elevation The value to set.
   */
  public void setElevation(Thing elevation);
  
  /**
   * Set the latitude property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param latitude The value to set.
   */
  public void setLatitude(Thing latitude);
  
  /**
   * Set the longitude property value for this GeoCoordinates object; overwriting any existing values.
   *
   * @param longitude The value to set.
   */
  public void setLongitude(Thing longitude);
  
  /**
   * Set the elevation property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param elevations The list of values to set.
   */
  public void setElevations(List<Thing> elevations);
  
  /**
   * Set the latitude property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param latitudes The list of values to set.
   */
  public void setLatitudes(List<Thing> latitudes);
  
  /**
   * Set the longitude property values for this GeoCoordinates object; overwriting any existing values.
   *
   * @param longitudes The list of values to set.
   */
  public void setLongitudes(List<Thing> longitudes);
  
  /**
   * Adds a elevation property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param elevation The value to add.
   */
  public void addElevation(Thing elevation);
  
  /**
   * Adds a latitude property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param latitude The value to add.
   */
  public void addLatitude(Thing latitude);
  
  /**
   * Adds a longitude property value for this GeoCoordinates object; appending it to the list of existing values.
   *
   * @param longitude The value to add.
   */
  public void addLongitude(Thing longitude);
  
}