package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.Thing;

/**
 * The geographic shape of a place.
 */
public interface GeoShape extends StructuredValue, SchemaObject {

  /**
   * Get a single box property value for this GeoShape object.
   *
   * @return The first box property value.
   */
  public String getBox();
  
  /**
   * Get a single circle property value for this GeoShape object.
   *
   * @return The first circle property value.
   */
  public String getCircle();
  
  /**
   * Get a single elevation property value for this GeoShape object.
   *
   * @return The first elevation property value.
   */
  public Thing getElevation();
  
  /**
   * Get a single line property value for this GeoShape object.
   *
   * @return The first line property value.
   */
  public String getLine();
  
  /**
   * Get a single polygon property value for this GeoShape object.
   *
   * @return The first polygon property value.
   */
  public String getPolygon();
  
  /**
   * Get all the box property values for this GeoShape object.
   *
   * @return A list of box property values.
   */
  public List<String> getBoxes();
  
  /**
   * Get all the circle property values for this GeoShape object.
   *
   * @return A list of circle property values.
   */
  public List<String> getCircles();
  
  /**
   * Get all the elevation property values for this GeoShape object.
   *
   * @return A list of elevation property values.
   */
  public List<Thing> getElevations();
  
  /**
   * Get all the line property values for this GeoShape object.
   *
   * @return A list of line property values.
   */
  public List<String> getLines();
  
  /**
   * Get all the polygon property values for this GeoShape object.
   *
   * @return A list of polygon property values.
   */
  public List<String> getPolygons();
  
  /**
   * Set the box property value for this GeoShape object; overwriting any existing values.
   *
   * @param box The value to set.
   */
  public void setBox(String box);
  
  /**
   * Set the circle property value for this GeoShape object; overwriting any existing values.
   *
   * @param circle The value to set.
   */
  public void setCircle(String circle);
  
  /**
   * Set the elevation property value for this GeoShape object; overwriting any existing values.
   *
   * @param elevation The value to set.
   */
  public void setElevation(Thing elevation);
  
  /**
   * Set the line property value for this GeoShape object; overwriting any existing values.
   *
   * @param line The value to set.
   */
  public void setLine(String line);
  
  /**
   * Set the polygon property value for this GeoShape object; overwriting any existing values.
   *
   * @param polygon The value to set.
   */
  public void setPolygon(String polygon);
  
  /**
   * Set the box property values for this GeoShape object; overwriting any existing values.
   *
   * @param boxes The list of values to set.
   */
  public void setBoxes(List<String> boxes);
  
  /**
   * Set the circle property values for this GeoShape object; overwriting any existing values.
   *
   * @param circles The list of values to set.
   */
  public void setCircles(List<String> circles);
  
  /**
   * Set the elevation property values for this GeoShape object; overwriting any existing values.
   *
   * @param elevations The list of values to set.
   */
  public void setElevations(List<Thing> elevations);
  
  /**
   * Set the line property values for this GeoShape object; overwriting any existing values.
   *
   * @param lines The list of values to set.
   */
  public void setLines(List<String> lines);
  
  /**
   * Set the polygon property values for this GeoShape object; overwriting any existing values.
   *
   * @param polygons The list of values to set.
   */
  public void setPolygons(List<String> polygons);
  
  /**
   * Adds a box property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param box The value to add.
   */
  public void addBox(String box);
  
  /**
   * Adds a circle property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param circle The value to add.
   */
  public void addCircle(String circle);
  
  /**
   * Adds a elevation property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param elevation The value to add.
   */
  public void addElevation(Thing elevation);
  
  /**
   * Adds a line property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param line The value to add.
   */
  public void addLine(String line);
  
  /**
   * Adds a polygon property value for this GeoShape object; appending it to the list of existing values.
   *
   * @param polygon The value to add.
   */
  public void addPolygon(String polygon);
  
}