package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TransferAction;

/**
 * The act of transferring ownership of an object to a destination. Reciprocal of TakeAction.<p>Related actions:</p><ul><li><a href="http://schema.org/TakeAction">TakeAction</a>: Reciprocal of GiveAction.</li><li><a href="http://schema.org/SendAction">SendAction</a>: Unlike SendAction, GiveAction implies that ownership is being transferred (e.g. I may send my laptop to you, but that doesn't mean I'm giving it to you).</li></ul>
 */
public interface GiveAction extends TransferAction, SchemaObject {

  /**
   * Get a single recipient property value for this GiveAction object.
   *
   * @return The first recipient property value.
   */
  public Thing getRecipient();
  
  /**
   * Get all the recipient property values for this GiveAction object.
   *
   * @return A list of recipient property values.
   */
  public List<Thing> getRecipients();
  
  /**
   * Set the recipient property value for this GiveAction object; overwriting any existing values.
   *
   * @param recipient The value to set.
   */
  public void setRecipient(Thing recipient);
  
  /**
   * Set the recipient property values for this GiveAction object; overwriting any existing values.
   *
   * @param recipients The list of values to set.
   */
  public void setRecipients(List<Thing> recipients);
  
  /**
   * Adds a recipient property value for this GiveAction object; appending it to the list of existing values.
   *
   * @param recipient The value to add.
   */
  public void addRecipient(Thing recipient);
  
}