package org.schema;

import java.lang.Boolean;
import java.lang.String;
import java.util.List;
import org.schema.ImageObject;
import org.schema.MediaObject;
import org.schema.SchemaObject;

/**
 * An image file.
 */
public interface ImageObject extends MediaObject, SchemaObject {

  /**
   * Get a single caption property value for this ImageObject object.
   *
   * @return The first caption property value.
   */
  public String getCaption();
  
  /**
   * Get a single exifData property value for this ImageObject object.
   *
   * @return The first exifData property value.
   */
  public String getExifData();
  
  /**
   * Get a single representativeOfPage property value for this ImageObject object.
   *
   * @return The first representativeOfPage property value.
   */
  public Boolean getRepresentativeOfPage();
  
  /**
   * Get a single thumbnail property value for this ImageObject object.
   *
   * @return The first thumbnail property value.
   */
  public ImageObject getThumbnail();
  
  /**
   * Get all the caption property values for this ImageObject object.
   *
   * @return A list of caption property values.
   */
  public List<String> getCaptions();
  
  /**
   * Get all the exifData property values for this ImageObject object.
   *
   * @return A list of exifData property values.
   */
  public List<String> getExifDatas();
  
  /**
   * Get all the representativeOfPage property values for this ImageObject object.
   *
   * @return A list of representativeOfPage property values.
   */
  public List<Boolean> getRepresentativeOfPages();
  
  /**
   * Get all the thumbnail property values for this ImageObject object.
   *
   * @return A list of thumbnail property values.
   */
  public List<ImageObject> getThumbnails();
  
  /**
   * Set the caption property value for this ImageObject object; overwriting any existing values.
   *
   * @param caption The value to set.
   */
  public void setCaption(String caption);
  
  /**
   * Set the exifData property value for this ImageObject object; overwriting any existing values.
   *
   * @param exifData The value to set.
   */
  public void setExifData(String exifData);
  
  /**
   * Set the representativeOfPage property value for this ImageObject object; overwriting any existing values.
   *
   * @param representativeOfPage The value to set.
   */
  public void setRepresentativeOfPage(Boolean representativeOfPage);
  
  /**
   * Set the thumbnail property value for this ImageObject object; overwriting any existing values.
   *
   * @param thumbnail The value to set.
   */
  public void setThumbnail(ImageObject thumbnail);
  
  /**
   * Set the caption property values for this ImageObject object; overwriting any existing values.
   *
   * @param captions The list of values to set.
   */
  public void setCaptions(List<String> captions);
  
  /**
   * Set the exifData property values for this ImageObject object; overwriting any existing values.
   *
   * @param exifDatas The list of values to set.
   */
  public void setExifDatas(List<String> exifDatas);
  
  /**
   * Set the representativeOfPage property values for this ImageObject object; overwriting any existing values.
   *
   * @param representativeOfPages The list of values to set.
   */
  public void setRepresentativeOfPages(List<Boolean> representativeOfPages);
  
  /**
   * Set the thumbnail property values for this ImageObject object; overwriting any existing values.
   *
   * @param thumbnails The list of values to set.
   */
  public void setThumbnails(List<ImageObject> thumbnails);
  
  /**
   * Adds a caption property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param caption The value to add.
   */
  public void addCaption(String caption);
  
  /**
   * Adds a exifData property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param exifData The value to add.
   */
  public void addExifData(String exifData);
  
  /**
   * Adds a representativeOfPage property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param representativeOfPage The value to add.
   */
  public void addRepresentativeOfPage(Boolean representativeOfPage);
  
  /**
   * Adds a thumbnail property value for this ImageObject object; appending it to the list of existing values.
   *
   * @param thumbnail The value to add.
   */
  public void addThumbnail(ImageObject thumbnail);
  
}