package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.InfectiousAgentClass;
import org.schema.MedicalCondition;
import org.schema.SchemaObject;

/**
 * An infectious disease is a clinically evident human disease resulting from the presence of pathogenic microbial agents, like pathogenic viruses, pathogenic bacteria, fungi, protozoa, multicellular parasites, and prions. To be considered an infectious disease, such pathogens are known to be able to cause this disease.
 */
public interface InfectiousDisease extends MedicalCondition, SchemaObject {

  /**
   * Get a single infectiousAgent property value for this InfectiousDisease object.
   *
   * @return The first infectiousAgent property value.
   */
  public String getInfectiousAgent();
  
  /**
   * Get a single infectiousAgentClass property value for this InfectiousDisease object.
   *
   * @return The first infectiousAgentClass property value.
   */
  public InfectiousAgentClass getInfectiousAgentClass();
  
  /**
   * Get a single transmissionMethod property value for this InfectiousDisease object.
   *
   * @return The first transmissionMethod property value.
   */
  public String getTransmissionMethod();
  
  /**
   * Get all the infectiousAgent property values for this InfectiousDisease object.
   *
   * @return A list of infectiousAgent property values.
   */
  public List<String> getInfectiousAgents();
  
  /**
   * Get all the infectiousAgentClass property values for this InfectiousDisease object.
   *
   * @return A list of infectiousAgentClass property values.
   */
  public List<InfectiousAgentClass> getInfectiousAgentClasses();
  
  /**
   * Get all the transmissionMethod property values for this InfectiousDisease object.
   *
   * @return A list of transmissionMethod property values.
   */
  public List<String> getTransmissionMethods();
  
  /**
   * Set the infectiousAgent property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgent The value to set.
   */
  public void setInfectiousAgent(String infectiousAgent);
  
  /**
   * Set the infectiousAgentClass property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgentClass The value to set.
   */
  public void setInfectiousAgentClass(InfectiousAgentClass infectiousAgentClass);
  
  /**
   * Set the transmissionMethod property value for this InfectiousDisease object; overwriting any existing values.
   *
   * @param transmissionMethod The value to set.
   */
  public void setTransmissionMethod(String transmissionMethod);
  
  /**
   * Set the infectiousAgent property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgents The list of values to set.
   */
  public void setInfectiousAgents(List<String> infectiousAgents);
  
  /**
   * Set the infectiousAgentClass property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param infectiousAgentClasses The list of values to set.
   */
  public void setInfectiousAgentClasses(List<InfectiousAgentClass> infectiousAgentClasses);
  
  /**
   * Set the transmissionMethod property values for this InfectiousDisease object; overwriting any existing values.
   *
   * @param transmissionMethods The list of values to set.
   */
  public void setTransmissionMethods(List<String> transmissionMethods);
  
  /**
   * Adds a infectiousAgent property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param infectiousAgent The value to add.
   */
  public void addInfectiousAgent(String infectiousAgent);
  
  /**
   * Adds a infectiousAgentClass property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param infectiousAgentClass The value to add.
   */
  public void addInfectiousAgentClass(InfectiousAgentClass infectiousAgentClass);
  
  /**
   * Adds a transmissionMethod property value for this InfectiousDisease object; appending it to the list of existing values.
   *
   * @param transmissionMethod The value to add.
   */
  public void addTransmissionMethod(String transmissionMethod);
  
}