package org.schema;

import java.util.List;
import org.schema.CommunicateAction;
import org.schema.Event;
import org.schema.SchemaObject;

/**
 * The act of notifying someone of information pertinent to them, with no expectation of a response.
 */
public interface InformAction extends CommunicateAction, SchemaObject {

  /**
   * Get a single event property value for this InformAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get all the event property values for this InformAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Set the event property value for this InformAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the event property values for this InformAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Adds a event property value for this InformAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
}