package org.schema;

import java.util.List;
import org.schema.CommunicateAction;
import org.schema.Event;
import org.schema.SchemaObject;

/**
 * The act of asking someone to attend an event. Reciprocal of RsvpAction.
 */
public interface InviteAction extends CommunicateAction, SchemaObject {

  /**
   * Get a single event property value for this InviteAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get all the event property values for this InviteAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Set the event property value for this InviteAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the event property values for this InviteAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Adds a event property value for this InviteAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
}