package org.schema;

import java.util.List;
import org.schema.Event;
import org.schema.InteractAction;
import org.schema.SchemaObject;

/**
 * An agent joins an event/group with participants/friends at a location.<p>Related actions:</p><ul><li><a href="http://schema.org/RegisterAction">RegisterAction</a>: Unlike RegisterAction, JoinAction refers to joining a group/team of people.</li><li><a href="http://schema.org/SubscribeAction">SubscribeAction</a>: Unlike SubscribeAction, JoinAction does not imply that you'll be receiving updates.</li><li><a href="http://schema.org/FollowAction">FollowAction</a>: Unlike FollowAction, JoinAction does not imply that you'll be polling for updates.</li></ul>
 */
public interface JoinAction extends InteractAction, SchemaObject {

  /**
   * Get a single event property value for this JoinAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get all the event property values for this JoinAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Set the event property value for this JoinAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the event property values for this JoinAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Adds a event property value for this JoinAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
}