package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.SchemaObject;

/**
 * The anatomical location at which two or more bones make contact.
 */
public interface Joint extends AnatomicalStructure, SchemaObject {

  /**
   * Get a single biomechnicalClass property value for this Joint object.
   *
   * @return The first biomechnicalClass property value.
   */
  public String getBiomechnicalClass();
  
  /**
   * Get a single functionalClass property value for this Joint object.
   *
   * @return The first functionalClass property value.
   */
  public String getFunctionalClass();
  
  /**
   * Get a single structuralClass property value for this Joint object.
   *
   * @return The first structuralClass property value.
   */
  public String getStructuralClass();
  
  /**
   * Get all the biomechnicalClass property values for this Joint object.
   *
   * @return A list of biomechnicalClass property values.
   */
  public List<String> getBiomechnicalClasses();
  
  /**
   * Get all the functionalClass property values for this Joint object.
   *
   * @return A list of functionalClass property values.
   */
  public List<String> getFunctionalClasses();
  
  /**
   * Get all the structuralClass property values for this Joint object.
   *
   * @return A list of structuralClass property values.
   */
  public List<String> getStructuralClasses();
  
  /**
   * Set the biomechnicalClass property value for this Joint object; overwriting any existing values.
   *
   * @param biomechnicalClass The value to set.
   */
  public void setBiomechnicalClass(String biomechnicalClass);
  
  /**
   * Set the functionalClass property value for this Joint object; overwriting any existing values.
   *
   * @param functionalClass The value to set.
   */
  public void setFunctionalClass(String functionalClass);
  
  /**
   * Set the structuralClass property value for this Joint object; overwriting any existing values.
   *
   * @param structuralClass The value to set.
   */
  public void setStructuralClass(String structuralClass);
  
  /**
   * Set the biomechnicalClass property values for this Joint object; overwriting any existing values.
   *
   * @param biomechnicalClasses The list of values to set.
   */
  public void setBiomechnicalClasses(List<String> biomechnicalClasses);
  
  /**
   * Set the functionalClass property values for this Joint object; overwriting any existing values.
   *
   * @param functionalClasses The list of values to set.
   */
  public void setFunctionalClasses(List<String> functionalClasses);
  
  /**
   * Set the structuralClass property values for this Joint object; overwriting any existing values.
   *
   * @param structuralClasses The list of values to set.
   */
  public void setStructuralClasses(List<String> structuralClasses);
  
  /**
   * Adds a biomechnicalClass property value for this Joint object; appending it to the list of existing values.
   *
   * @param biomechnicalClass The value to add.
   */
  public void addBiomechnicalClass(String biomechnicalClass);
  
  /**
   * Adds a functionalClass property value for this Joint object; appending it to the list of existing values.
   *
   * @param functionalClass The value to add.
   */
  public void addFunctionalClass(String functionalClass);
  
  /**
   * Adds a structuralClass property value for this Joint object; appending it to the list of existing values.
   *
   * @param structuralClass The value to add.
   */
  public void addStructuralClass(String structuralClass);
  
}