package org.schema;

import java.util.List;
import org.schema.Event;
import org.schema.InteractAction;
import org.schema.SchemaObject;

/**
 * An agent leaves an event / group with participants/friends at a location.<p>Related actions:</p><ul><li><a href="http://schema.org/JoinAction">JoinAction</a>: The antagonym of LeaveAction.</li><li><a href="http://schema.org/UnRegisterAction">UnRegisterAction</a>: Unlike UnRegisterAction, LeaveAction implies leaving a group/team of people rather than a service.</li></ul>
 */
public interface LeaveAction extends InteractAction, SchemaObject {

  /**
   * Get a single event property value for this LeaveAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get all the event property values for this LeaveAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Set the event property value for this LeaveAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the event property values for this LeaveAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Adds a event property value for this LeaveAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
}