package org.schema;

import java.util.List;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.TransferAction;

/**
 * The act of providing an object under an agreement that it will be returned at a later date. Reciprocal of BorrowAction.<p>Related actions:</p><ul><li><a href="http://schema.org/BorrowAction">BorrowAction</a>: Reciprocal of LendAction.</li></ul>
 */
public interface LendAction extends TransferAction, SchemaObject {

  /**
   * Get a single borrower property value for this LendAction object.
   *
   * @return The first borrower property value.
   */
  public Person getBorrower();
  
  /**
   * Get all the borrower property values for this LendAction object.
   *
   * @return A list of borrower property values.
   */
  public List<Person> getBorrowers();
  
  /**
   * Set the borrower property value for this LendAction object; overwriting any existing values.
   *
   * @param borrower The value to set.
   */
  public void setBorrower(Person borrower);
  
  /**
   * Set the borrower property values for this LendAction object; overwriting any existing values.
   *
   * @param borrowers The list of values to set.
   */
  public void setBorrowers(List<Person> borrowers);
  
  /**
   * Adds a borrower property value for this LendAction object; appending it to the list of existing values.
   *
   * @param borrower The value to add.
   */
  public void addBorrower(Person borrower);
  
}