package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Duration;
import org.schema.Organization;
import org.schema.Place;
import org.schema.SchemaObject;

/**
 * A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc.
 */
public interface LocalBusiness extends Organization, Place, SchemaObject {

  /**
   * Get a single branchOf property value for this LocalBusiness object.
   *
   * @return The first branchOf property value.
   */
  public Organization getBranchOf();
  
  /**
   * Get a single currenciesAccepted property value for this LocalBusiness object.
   *
   * @return The first currenciesAccepted property value.
   */
  public String getCurrenciesAccepted();
  
  /**
   * Get a single openingHours property value for this LocalBusiness object.
   *
   * @return The first openingHours property value.
   */
  public Duration getOpeningHours();
  
  /**
   * Get a single paymentAccepted property value for this LocalBusiness object.
   *
   * @return The first paymentAccepted property value.
   */
  public String getPaymentAccepted();
  
  /**
   * Get a single priceRange property value for this LocalBusiness object.
   *
   * @return The first priceRange property value.
   */
  public String getPriceRange();
  
  /**
   * Get all the branchOf property values for this LocalBusiness object.
   *
   * @return A list of branchOf property values.
   */
  public List<Organization> getBranchesOf();
  
  /**
   * Get all the currenciesAccepted property values for this LocalBusiness object.
   *
   * @return A list of currenciesAccepted property values.
   */
  public List<String> getCurrenciesAccepteds();
  
  /**
   * Get all the openingHours property values for this LocalBusiness object.
   *
   * @return A list of openingHours property values.
   */
  public List<Duration> getOpeningHourss();
  
  /**
   * Get all the paymentAccepted property values for this LocalBusiness object.
   *
   * @return A list of paymentAccepted property values.
   */
  public List<String> getPaymentAccepteds();
  
  /**
   * Get all the priceRange property values for this LocalBusiness object.
   *
   * @return A list of priceRange property values.
   */
  public List<String> getPriceRanges();
  
  /**
   * Set the branchOf property value for this LocalBusiness object; overwriting any existing values.
   *
   * @param branchOf The value to set.
   */
  public void setBranchOf(Organization branchOf);
  
  /**
   * Set the currenciesAccepted property value for this LocalBusiness object; overwriting any existing values.
   *
   * @param currenciesAccepted The value to set.
   */
  public void setCurrenciesAccepted(String currenciesAccepted);
  
  /**
   * Set the openingHours property value for this LocalBusiness object; overwriting any existing values.
   *
   * @param openingHours The value to set.
   */
  public void setOpeningHours(Duration openingHours);
  
  /**
   * Set the paymentAccepted property value for this LocalBusiness object; overwriting any existing values.
   *
   * @param paymentAccepted The value to set.
   */
  public void setPaymentAccepted(String paymentAccepted);
  
  /**
   * Set the priceRange property value for this LocalBusiness object; overwriting any existing values.
   *
   * @param priceRange The value to set.
   */
  public void setPriceRange(String priceRange);
  
  /**
   * Set the branchOf property values for this LocalBusiness object; overwriting any existing values.
   *
   * @param branchesOf The list of values to set.
   */
  public void setBranchesOf(List<Organization> branchesOf);
  
  /**
   * Set the currenciesAccepted property values for this LocalBusiness object; overwriting any existing values.
   *
   * @param currenciesAccepteds The list of values to set.
   */
  public void setCurrenciesAccepteds(List<String> currenciesAccepteds);
  
  /**
   * Set the openingHours property values for this LocalBusiness object; overwriting any existing values.
   *
   * @param openingHourss The list of values to set.
   */
  public void setOpeningHourss(List<Duration> openingHourss);
  
  /**
   * Set the paymentAccepted property values for this LocalBusiness object; overwriting any existing values.
   *
   * @param paymentAccepteds The list of values to set.
   */
  public void setPaymentAccepteds(List<String> paymentAccepteds);
  
  /**
   * Set the priceRange property values for this LocalBusiness object; overwriting any existing values.
   *
   * @param priceRanges The list of values to set.
   */
  public void setPriceRanges(List<String> priceRanges);
  
  /**
   * Adds a branchOf property value for this LocalBusiness object; appending it to the list of existing values.
   *
   * @param branchOf The value to add.
   */
  public void addBranchOf(Organization branchOf);
  
  /**
   * Adds a currenciesAccepted property value for this LocalBusiness object; appending it to the list of existing values.
   *
   * @param currenciesAccepted The value to add.
   */
  public void addCurrenciesAccepted(String currenciesAccepted);
  
  /**
   * Adds a openingHours property value for this LocalBusiness object; appending it to the list of existing values.
   *
   * @param openingHours The value to add.
   */
  public void addOpeningHours(Duration openingHours);
  
  /**
   * Adds a paymentAccepted property value for this LocalBusiness object; appending it to the list of existing values.
   *
   * @param paymentAccepted The value to add.
   */
  public void addPaymentAccepted(String paymentAccepted);
  
  /**
   * Adds a priceRange property value for this LocalBusiness object; appending it to the list of existing values.
   *
   * @param priceRange The value to add.
   */
  public void addPriceRange(String priceRange);
  
}