package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Reservation;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A reservation for lodging at a hotel, motel, inn, etc.Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations.
 */
public interface LodgingReservation extends Reservation, SchemaObject {

  /**
   * Get a single checkinTime property value for this LodgingReservation object.
   *
   * @return The first checkinTime property value.
   */
  public Date getCheckinTime();
  
  /**
   * Get a single checkoutTime property value for this LodgingReservation object.
   *
   * @return The first checkoutTime property value.
   */
  public Date getCheckoutTime();
  
  /**
   * Get a single lodgingUnitDescription property value for this LodgingReservation object.
   *
   * @return The first lodgingUnitDescription property value.
   */
  public String getLodgingUnitDescription();
  
  /**
   * Get a single lodgingUnitType property value for this LodgingReservation object.
   *
   * @return The first lodgingUnitType property value.
   */
  public Thing getLodgingUnitType();
  
  /**
   * Get a single numAdults property value for this LodgingReservation object.
   *
   * @return The first numAdults property value.
   */
  public Thing getNumAdults();
  
  /**
   * Get a single numChildren property value for this LodgingReservation object.
   *
   * @return The first numChildren property value.
   */
  public Thing getNumChildren();
  
  /**
   * Get all the checkinTime property values for this LodgingReservation object.
   *
   * @return A list of checkinTime property values.
   */
  public List<Date> getCheckinTimes();
  
  /**
   * Get all the checkoutTime property values for this LodgingReservation object.
   *
   * @return A list of checkoutTime property values.
   */
  public List<Date> getCheckoutTimes();
  
  /**
   * Get all the lodgingUnitDescription property values for this LodgingReservation object.
   *
   * @return A list of lodgingUnitDescription property values.
   */
  public List<String> getLodgingUnitDescriptions();
  
  /**
   * Get all the lodgingUnitType property values for this LodgingReservation object.
   *
   * @return A list of lodgingUnitType property values.
   */
  public List<Thing> getLodgingUnitTypes();
  
  /**
   * Get all the numAdults property values for this LodgingReservation object.
   *
   * @return A list of numAdults property values.
   */
  public List<Thing> getNumAdultss();
  
  /**
   * Get all the numChildren property values for this LodgingReservation object.
   *
   * @return A list of numChildren property values.
   */
  public List<Thing> getNumChildrens();
  
  /**
   * Set the checkinTime property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkinTime The value to set.
   */
  public void setCheckinTime(Date checkinTime);
  
  /**
   * Set the checkoutTime property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkoutTime The value to set.
   */
  public void setCheckoutTime(Date checkoutTime);
  
  /**
   * Set the lodgingUnitDescription property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitDescription The value to set.
   */
  public void setLodgingUnitDescription(String lodgingUnitDescription);
  
  /**
   * Set the lodgingUnitType property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitType The value to set.
   */
  public void setLodgingUnitType(Thing lodgingUnitType);
  
  /**
   * Set the numAdults property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param numAdults The value to set.
   */
  public void setNumAdults(Thing numAdults);
  
  /**
   * Set the numChildren property value for this LodgingReservation object; overwriting any existing values.
   *
   * @param numChildren The value to set.
   */
  public void setNumChildren(Thing numChildren);
  
  /**
   * Set the checkinTime property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkinTimes The list of values to set.
   */
  public void setCheckinTimes(List<Date> checkinTimes);
  
  /**
   * Set the checkoutTime property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param checkoutTimes The list of values to set.
   */
  public void setCheckoutTimes(List<Date> checkoutTimes);
  
  /**
   * Set the lodgingUnitDescription property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitDescriptions The list of values to set.
   */
  public void setLodgingUnitDescriptions(List<String> lodgingUnitDescriptions);
  
  /**
   * Set the lodgingUnitType property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param lodgingUnitTypes The list of values to set.
   */
  public void setLodgingUnitTypes(List<Thing> lodgingUnitTypes);
  
  /**
   * Set the numAdults property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param numAdultss The list of values to set.
   */
  public void setNumAdultss(List<Thing> numAdultss);
  
  /**
   * Set the numChildren property values for this LodgingReservation object; overwriting any existing values.
   *
   * @param numChildrens The list of values to set.
   */
  public void setNumChildrens(List<Thing> numChildrens);
  
  /**
   * Adds a checkinTime property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param checkinTime The value to add.
   */
  public void addCheckinTime(Date checkinTime);
  
  /**
   * Adds a checkoutTime property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param checkoutTime The value to add.
   */
  public void addCheckoutTime(Date checkoutTime);
  
  /**
   * Adds a lodgingUnitDescription property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param lodgingUnitDescription The value to add.
   */
  public void addLodgingUnitDescription(String lodgingUnitDescription);
  
  /**
   * Adds a lodgingUnitType property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param lodgingUnitType The value to add.
   */
  public void addLodgingUnitType(Thing lodgingUnitType);
  
  /**
   * Adds a numAdults property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param numAdults The value to add.
   */
  public void addNumAdults(Thing numAdults);
  
  /**
   * Adds a numChildren property value for this LodgingReservation object; appending it to the list of existing values.
   *
   * @param numChildren The value to add.
   */
  public void addNumChildren(Thing numChildren);
  
}