package org.schema;

import java.util.List;
import org.schema.AchieveAction;
import org.schema.Person;
import org.schema.SchemaObject;

/**
 * The act of being defeated in a competitive activity.
 */
public interface LoseAction extends AchieveAction, SchemaObject {

  /**
   * Get a single winner property value for this LoseAction object.
   *
   * @return The first winner property value.
   */
  public Person getWinner();
  
  /**
   * Get all the winner property values for this LoseAction object.
   *
   * @return A list of winner property values.
   */
  public List<Person> getWinners();
  
  /**
   * Set the winner property value for this LoseAction object; overwriting any existing values.
   *
   * @param winner The value to set.
   */
  public void setWinner(Person winner);
  
  /**
   * Set the winner property values for this LoseAction object; overwriting any existing values.
   *
   * @param winners The list of values to set.
   */
  public void setWinners(List<Person> winners);
  
  /**
   * Adds a winner property value for this LoseAction object; appending it to the list of existing values.
   *
   * @param winner The value to add.
   */
  public void addWinner(Person winner);
  
}