package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.Vessel;

/**
 * A type of blood vessel that specifically carries lymph fluid unidirectionally toward the heart.
 */
public interface LymphaticVessel extends Vessel, SchemaObject {

  /**
   * Get a single originatesFrom property value for this LymphaticVessel object.
   *
   * @return The first originatesFrom property value.
   */
  public Vessel getOriginatesFrom();
  
  /**
   * Get a single regionDrained property value for this LymphaticVessel object.
   *
   * @return The first regionDrained property value.
   */
  public Thing getRegionDrained();
  
  /**
   * Get a single runsTo property value for this LymphaticVessel object.
   *
   * @return The first runsTo property value.
   */
  public Vessel getRunsTo();
  
  /**
   * Get all the originatesFrom property values for this LymphaticVessel object.
   *
   * @return A list of originatesFrom property values.
   */
  public List<Vessel> getOriginatesFroms();
  
  /**
   * Get all the regionDrained property values for this LymphaticVessel object.
   *
   * @return A list of regionDrained property values.
   */
  public List<Thing> getRegionDraineds();
  
  /**
   * Get all the runsTo property values for this LymphaticVessel object.
   *
   * @return A list of runsTo property values.
   */
  public List<Vessel> getRunsToes();
  
  /**
   * Set the originatesFrom property value for this LymphaticVessel object; overwriting any existing values.
   *
   * @param originatesFrom The value to set.
   */
  public void setOriginatesFrom(Vessel originatesFrom);
  
  /**
   * Set the regionDrained property value for this LymphaticVessel object; overwriting any existing values.
   *
   * @param regionDrained The value to set.
   */
  public void setRegionDrained(Thing regionDrained);
  
  /**
   * Set the runsTo property value for this LymphaticVessel object; overwriting any existing values.
   *
   * @param runsTo The value to set.
   */
  public void setRunsTo(Vessel runsTo);
  
  /**
   * Set the originatesFrom property values for this LymphaticVessel object; overwriting any existing values.
   *
   * @param originatesFroms The list of values to set.
   */
  public void setOriginatesFroms(List<Vessel> originatesFroms);
  
  /**
   * Set the regionDrained property values for this LymphaticVessel object; overwriting any existing values.
   *
   * @param regionDraineds The list of values to set.
   */
  public void setRegionDraineds(List<Thing> regionDraineds);
  
  /**
   * Set the runsTo property values for this LymphaticVessel object; overwriting any existing values.
   *
   * @param runsToes The list of values to set.
   */
  public void setRunsToes(List<Vessel> runsToes);
  
  /**
   * Adds a originatesFrom property value for this LymphaticVessel object; appending it to the list of existing values.
   *
   * @param originatesFrom The value to add.
   */
  public void addOriginatesFrom(Vessel originatesFrom);
  
  /**
   * Adds a regionDrained property value for this LymphaticVessel object; appending it to the list of existing values.
   *
   * @param regionDrained The value to add.
   */
  public void addRegionDrained(Thing regionDrained);
  
  /**
   * Adds a runsTo property value for this LymphaticVessel object; appending it to the list of existing values.
   *
   * @param runsTo The value to add.
   */
  public void addRunsTo(Vessel runsTo);
  
}