package org.schema;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.NewsArticle;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Place;
import org.schema.PublicationEvent;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An image, video, or audio object embedded in a web page. Note that a creative work may have many media objects associated with it on the same web page. For example, a page about a single song (MusicRecording) may have a music video (VideoObject), and a high and low bandwidth audio stream (2 AudioObject's).
 */
public interface MediaObject extends CreativeWork, SchemaObject {

  /**
   * Get a single associatedArticle property value for this MediaObject object.
   *
   * @return The first associatedArticle property value.
   */
  public NewsArticle getAssociatedArticle();
  
  /**
   * Get a single bitrate property value for this MediaObject object.
   *
   * @return The first bitrate property value.
   */
  public String getBitrate();
  
  /**
   * Get a single contentSize property value for this MediaObject object.
   *
   * @return The first contentSize property value.
   */
  public String getContentSize();
  
  /**
   * Get a single contentUrl property value for this MediaObject object.
   *
   * @return The first contentUrl property value.
   */
  public URL getContentUrl();
  
  /**
   * Get a single duration property value for this MediaObject object.
   *
   * @return The first duration property value.
   */
  public Duration getDuration();
  
  /**
   * Get a single embedUrl property value for this MediaObject object.
   *
   * @return The first embedUrl property value.
   */
  public URL getEmbedUrl();
  
  /**
   * Get a single encodesCreativeWork property value for this MediaObject object.
   *
   * @return The first encodesCreativeWork property value.
   */
  public CreativeWork getEncodesCreativeWork();
  
  /**
   * Get a single encodingFormat property value for this MediaObject object.
   *
   * @return The first encodingFormat property value.
   */
  public String getEncodingFormat();
  
  /**
   * Get a single expires property value for this MediaObject object.
   *
   * @return The first expires property value.
   */
  public Date getExpires();
  
  /**
   * Get a single height property value for this MediaObject object.
   *
   * @return The first height property value.
   */
  public Thing getHeight();
  
  /**
   * Get a single interactionCount property value for this MediaObject object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount();
  
  /**
   * Get a single offers property value for this MediaObject object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers();
  
  /**
   * Get a single playerType property value for this MediaObject object.
   *
   * @return The first playerType property value.
   */
  public String getPlayerType();
  
  /**
   * Get a single productionCompany property value for this MediaObject object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany();
  
  /**
   * Get a single publication property value for this MediaObject object.
   *
   * @return The first publication property value.
   */
  public PublicationEvent getPublication();
  
  /**
   * Get a single regionsAllowed property value for this MediaObject object.
   *
   * @return The first regionsAllowed property value.
   */
  public Place getRegionsAllowed();
  
  /**
   * Get a single requiresSubscription property value for this MediaObject object.
   *
   * @return The first requiresSubscription property value.
   */
  public Boolean getRequiresSubscription();
  
  /**
   * Get a single uploadDate property value for this MediaObject object.
   *
   * @return The first uploadDate property value.
   */
  public Date getUploadDate();
  
  /**
   * Get a single width property value for this MediaObject object.
   *
   * @return The first width property value.
   */
  public Thing getWidth();
  
  /**
   * Get all the associatedArticle property values for this MediaObject object.
   *
   * @return A list of associatedArticle property values.
   */
  public List<NewsArticle> getAssociatedArticles();
  
  /**
   * Get all the bitrate property values for this MediaObject object.
   *
   * @return A list of bitrate property values.
   */
  public List<String> getBitrates();
  
  /**
   * Get all the contentSize property values for this MediaObject object.
   *
   * @return A list of contentSize property values.
   */
  public List<String> getContentSizes();
  
  /**
   * Get all the contentUrl property values for this MediaObject object.
   *
   * @return A list of contentUrl property values.
   */
  public List<URL> getContentUrls();
  
  /**
   * Get all the duration property values for this MediaObject object.
   *
   * @return A list of duration property values.
   */
  public List<Duration> getDurations();
  
  /**
   * Get all the embedUrl property values for this MediaObject object.
   *
   * @return A list of embedUrl property values.
   */
  public List<URL> getEmbedUrls();
  
  /**
   * Get all the encodesCreativeWork property values for this MediaObject object.
   *
   * @return A list of encodesCreativeWork property values.
   */
  public List<CreativeWork> getEncodesCreativeWorks();
  
  /**
   * Get all the encodingFormat property values for this MediaObject object.
   *
   * @return A list of encodingFormat property values.
   */
  public List<String> getEncodingFormats();
  
  /**
   * Get all the expires property values for this MediaObject object.
   *
   * @return A list of expires property values.
   */
  public List<Date> getExpiress();
  
  /**
   * Get all the height property values for this MediaObject object.
   *
   * @return A list of height property values.
   */
  public List<Thing> getHeights();
  
  /**
   * Get all the interactionCount property values for this MediaObject object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts();
  
  /**
   * Get all the offers property values for this MediaObject object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss();
  
  /**
   * Get all the playerType property values for this MediaObject object.
   *
   * @return A list of playerType property values.
   */
  public List<String> getPlayerTypes();
  
  /**
   * Get all the productionCompany property values for this MediaObject object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies();
  
  /**
   * Get all the publication property values for this MediaObject object.
   *
   * @return A list of publication property values.
   */
  public List<PublicationEvent> getPublications();
  
  /**
   * Get all the regionsAllowed property values for this MediaObject object.
   *
   * @return A list of regionsAllowed property values.
   */
  public List<Place> getRegionsAlloweds();
  
  /**
   * Get all the requiresSubscription property values for this MediaObject object.
   *
   * @return A list of requiresSubscription property values.
   */
  public List<Boolean> getRequiresSubscriptions();
  
  /**
   * Get all the uploadDate property values for this MediaObject object.
   *
   * @return A list of uploadDate property values.
   */
  public List<Date> getUploadDates();
  
  /**
   * Get all the width property values for this MediaObject object.
   *
   * @return A list of width property values.
   */
  public List<Thing> getWidths();
  
  /**
   * Set the associatedArticle property value for this MediaObject object; overwriting any existing values.
   *
   * @param associatedArticle The value to set.
   */
  public void setAssociatedArticle(NewsArticle associatedArticle);
  
  /**
   * Set the bitrate property value for this MediaObject object; overwriting any existing values.
   *
   * @param bitrate The value to set.
   */
  public void setBitrate(String bitrate);
  
  /**
   * Set the contentSize property value for this MediaObject object; overwriting any existing values.
   *
   * @param contentSize The value to set.
   */
  public void setContentSize(String contentSize);
  
  /**
   * Set the contentUrl property value for this MediaObject object; overwriting any existing values.
   *
   * @param contentUrl The value to set.
   */
  public void setContentUrl(URL contentUrl);
  
  /**
   * Set the duration property value for this MediaObject object; overwriting any existing values.
   *
   * @param duration The value to set.
   */
  public void setDuration(Duration duration);
  
  /**
   * Set the embedUrl property value for this MediaObject object; overwriting any existing values.
   *
   * @param embedUrl The value to set.
   */
  public void setEmbedUrl(URL embedUrl);
  
  /**
   * Set the encodesCreativeWork property value for this MediaObject object; overwriting any existing values.
   *
   * @param encodesCreativeWork The value to set.
   */
  public void setEncodesCreativeWork(CreativeWork encodesCreativeWork);
  
  /**
   * Set the encodingFormat property value for this MediaObject object; overwriting any existing values.
   *
   * @param encodingFormat The value to set.
   */
  public void setEncodingFormat(String encodingFormat);
  
  /**
   * Set the expires property value for this MediaObject object; overwriting any existing values.
   *
   * @param expires The value to set.
   */
  public void setExpires(Date expires);
  
  /**
   * Set the height property value for this MediaObject object; overwriting any existing values.
   *
   * @param height The value to set.
   */
  public void setHeight(Thing height);
  
  /**
   * Set the interactionCount property value for this MediaObject object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount);
  
  /**
   * Set the offers property value for this MediaObject object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers);
  
  /**
   * Set the playerType property value for this MediaObject object; overwriting any existing values.
   *
   * @param playerType The value to set.
   */
  public void setPlayerType(String playerType);
  
  /**
   * Set the productionCompany property value for this MediaObject object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany);
  
  /**
   * Set the publication property value for this MediaObject object; overwriting any existing values.
   *
   * @param publication The value to set.
   */
  public void setPublication(PublicationEvent publication);
  
  /**
   * Set the regionsAllowed property value for this MediaObject object; overwriting any existing values.
   *
   * @param regionsAllowed The value to set.
   */
  public void setRegionsAllowed(Place regionsAllowed);
  
  /**
   * Set the requiresSubscription property value for this MediaObject object; overwriting any existing values.
   *
   * @param requiresSubscription The value to set.
   */
  public void setRequiresSubscription(Boolean requiresSubscription);
  
  /**
   * Set the uploadDate property value for this MediaObject object; overwriting any existing values.
   *
   * @param uploadDate The value to set.
   */
  public void setUploadDate(Date uploadDate);
  
  /**
   * Set the width property value for this MediaObject object; overwriting any existing values.
   *
   * @param width The value to set.
   */
  public void setWidth(Thing width);
  
  /**
   * Set the associatedArticle property values for this MediaObject object; overwriting any existing values.
   *
   * @param associatedArticles The list of values to set.
   */
  public void setAssociatedArticles(List<NewsArticle> associatedArticles);
  
  /**
   * Set the bitrate property values for this MediaObject object; overwriting any existing values.
   *
   * @param bitrates The list of values to set.
   */
  public void setBitrates(List<String> bitrates);
  
  /**
   * Set the contentSize property values for this MediaObject object; overwriting any existing values.
   *
   * @param contentSizes The list of values to set.
   */
  public void setContentSizes(List<String> contentSizes);
  
  /**
   * Set the contentUrl property values for this MediaObject object; overwriting any existing values.
   *
   * @param contentUrls The list of values to set.
   */
  public void setContentUrls(List<URL> contentUrls);
  
  /**
   * Set the duration property values for this MediaObject object; overwriting any existing values.
   *
   * @param durations The list of values to set.
   */
  public void setDurations(List<Duration> durations);
  
  /**
   * Set the embedUrl property values for this MediaObject object; overwriting any existing values.
   *
   * @param embedUrls The list of values to set.
   */
  public void setEmbedUrls(List<URL> embedUrls);
  
  /**
   * Set the encodesCreativeWork property values for this MediaObject object; overwriting any existing values.
   *
   * @param encodesCreativeWorks The list of values to set.
   */
  public void setEncodesCreativeWorks(List<CreativeWork> encodesCreativeWorks);
  
  /**
   * Set the encodingFormat property values for this MediaObject object; overwriting any existing values.
   *
   * @param encodingFormats The list of values to set.
   */
  public void setEncodingFormats(List<String> encodingFormats);
  
  /**
   * Set the expires property values for this MediaObject object; overwriting any existing values.
   *
   * @param expiress The list of values to set.
   */
  public void setExpiress(List<Date> expiress);
  
  /**
   * Set the height property values for this MediaObject object; overwriting any existing values.
   *
   * @param heights The list of values to set.
   */
  public void setHeights(List<Thing> heights);
  
  /**
   * Set the interactionCount property values for this MediaObject object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts);
  
  /**
   * Set the offers property values for this MediaObject object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss);
  
  /**
   * Set the playerType property values for this MediaObject object; overwriting any existing values.
   *
   * @param playerTypes The list of values to set.
   */
  public void setPlayerTypes(List<String> playerTypes);
  
  /**
   * Set the productionCompany property values for this MediaObject object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies);
  
  /**
   * Set the publication property values for this MediaObject object; overwriting any existing values.
   *
   * @param publications The list of values to set.
   */
  public void setPublications(List<PublicationEvent> publications);
  
  /**
   * Set the regionsAllowed property values for this MediaObject object; overwriting any existing values.
   *
   * @param regionsAlloweds The list of values to set.
   */
  public void setRegionsAlloweds(List<Place> regionsAlloweds);
  
  /**
   * Set the requiresSubscription property values for this MediaObject object; overwriting any existing values.
   *
   * @param requiresSubscriptions The list of values to set.
   */
  public void setRequiresSubscriptions(List<Boolean> requiresSubscriptions);
  
  /**
   * Set the uploadDate property values for this MediaObject object; overwriting any existing values.
   *
   * @param uploadDates The list of values to set.
   */
  public void setUploadDates(List<Date> uploadDates);
  
  /**
   * Set the width property values for this MediaObject object; overwriting any existing values.
   *
   * @param widths The list of values to set.
   */
  public void setWidths(List<Thing> widths);
  
  /**
   * Adds a associatedArticle property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param associatedArticle The value to add.
   */
  public void addAssociatedArticle(NewsArticle associatedArticle);
  
  /**
   * Adds a bitrate property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param bitrate The value to add.
   */
  public void addBitrate(String bitrate);
  
  /**
   * Adds a contentSize property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param contentSize The value to add.
   */
  public void addContentSize(String contentSize);
  
  /**
   * Adds a contentUrl property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param contentUrl The value to add.
   */
  public void addContentUrl(URL contentUrl);
  
  /**
   * Adds a duration property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param duration The value to add.
   */
  public void addDuration(Duration duration);
  
  /**
   * Adds a embedUrl property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param embedUrl The value to add.
   */
  public void addEmbedUrl(URL embedUrl);
  
  /**
   * Adds a encodesCreativeWork property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param encodesCreativeWork The value to add.
   */
  public void addEncodesCreativeWork(CreativeWork encodesCreativeWork);
  
  /**
   * Adds a encodingFormat property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param encodingFormat The value to add.
   */
  public void addEncodingFormat(String encodingFormat);
  
  /**
   * Adds a expires property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param expires The value to add.
   */
  public void addExpires(Date expires);
  
  /**
   * Adds a height property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param height The value to add.
   */
  public void addHeight(Thing height);
  
  /**
   * Adds a interactionCount property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount);
  
  /**
   * Adds a offers property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers);
  
  /**
   * Adds a playerType property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param playerType The value to add.
   */
  public void addPlayerType(String playerType);
  
  /**
   * Adds a productionCompany property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany);
  
  /**
   * Adds a publication property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param publication The value to add.
   */
  public void addPublication(PublicationEvent publication);
  
  /**
   * Adds a regionsAllowed property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param regionsAllowed The value to add.
   */
  public void addRegionsAllowed(Place regionsAllowed);
  
  /**
   * Adds a requiresSubscription property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param requiresSubscription The value to add.
   */
  public void addRequiresSubscription(Boolean requiresSubscription);
  
  /**
   * Adds a uploadDate property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param uploadDate The value to add.
   */
  public void addUploadDate(Date uploadDate);
  
  /**
   * Adds a width property value for this MediaObject object; appending it to the list of existing values.
   *
   * @param width The value to add.
   */
  public void addWidth(Thing width);
  
}