package org.schema;

import java.util.List;
import org.schema.MedicalEntity;
import org.schema.SchemaObject;

/**
 * The causative agent(s) that are responsible for the pathophysiologic process that eventually results in a medical condition, symptom or sign. In this schema, unless otherwise specified this is meant to be the proximate cause of the medical condition, symptom or sign. The proximate cause is defined as the causative agent that most directly results in the medical condition, symptom or sign. For example, the HIV virus could be considered a cause of AIDS. Or in a diagnostic context, if a patient fell and sustained a hip fracture and two days later sustained a pulmonary embolism which eventuated in a cardiac arrest, the cause of the cardiac arrest (the proximate cause) would be the pulmonary embolism and not the fall. <p>Medical causes can include cardiovascular, chemical, dermatologic, endocrine, environmental, gastroenterologic, genetic, hematologic, gynecologic, iatrogenic, infectious, musculoskeletal, neurologic, nutritional, obstetric, oncologic, otolaryngologic, pharmacologic, psychiatric, pulmonary, renal, rheumatologic, toxic, traumatic, or urologic causes; medical conditions can be causes as well.
 */
public interface MedicalCause extends MedicalEntity, SchemaObject {

  /**
   * Get a single causeOf property value for this MedicalCause object.
   *
   * @return The first causeOf property value.
   */
  public MedicalEntity getCauseOf();
  
  /**
   * Get all the causeOf property values for this MedicalCause object.
   *
   * @return A list of causeOf property values.
   */
  public List<MedicalEntity> getCausesOf();
  
  /**
   * Set the causeOf property value for this MedicalCause object; overwriting any existing values.
   *
   * @param causeOf The value to set.
   */
  public void setCauseOf(MedicalEntity causeOf);
  
  /**
   * Set the causeOf property values for this MedicalCause object; overwriting any existing values.
   *
   * @param causesOf The list of values to set.
   */
  public void setCausesOf(List<MedicalEntity> causesOf);
  
  /**
   * Adds a causeOf property value for this MedicalCause object; appending it to the list of existing values.
   *
   * @param causeOf The value to add.
   */
  public void addCauseOf(MedicalEntity causeOf);
  
}