package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalIntangible;
import org.schema.SchemaObject;

/**
 * A code for a medical entity.
 */
public interface MedicalCode extends MedicalIntangible, SchemaObject {

  /**
   * Get a single codeValue property value for this MedicalCode object.
   *
   * @return The first codeValue property value.
   */
  public String getCodeValue();
  
  /**
   * Get a single codingSystem property value for this MedicalCode object.
   *
   * @return The first codingSystem property value.
   */
  public String getCodingSystem();
  
  /**
   * Get all the codeValue property values for this MedicalCode object.
   *
   * @return A list of codeValue property values.
   */
  public List<String> getCodeValues();
  
  /**
   * Get all the codingSystem property values for this MedicalCode object.
   *
   * @return A list of codingSystem property values.
   */
  public List<String> getCodingSystems();
  
  /**
   * Set the codeValue property value for this MedicalCode object; overwriting any existing values.
   *
   * @param codeValue The value to set.
   */
  public void setCodeValue(String codeValue);
  
  /**
   * Set the codingSystem property value for this MedicalCode object; overwriting any existing values.
   *
   * @param codingSystem The value to set.
   */
  public void setCodingSystem(String codingSystem);
  
  /**
   * Set the codeValue property values for this MedicalCode object; overwriting any existing values.
   *
   * @param codeValues The list of values to set.
   */
  public void setCodeValues(List<String> codeValues);
  
  /**
   * Set the codingSystem property values for this MedicalCode object; overwriting any existing values.
   *
   * @param codingSystems The list of values to set.
   */
  public void setCodingSystems(List<String> codingSystems);
  
  /**
   * Adds a codeValue property value for this MedicalCode object; appending it to the list of existing values.
   *
   * @param codeValue The value to add.
   */
  public void addCodeValue(String codeValue);
  
  /**
   * Adds a codingSystem property value for this MedicalCode object; appending it to the list of existing values.
   *
   * @param codingSystem The value to add.
   */
  public void addCodingSystem(String codingSystem);
  
}