package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.DDxElement;
import org.schema.MedicalCause;
import org.schema.MedicalConditionStage;
import org.schema.MedicalEntity;
import org.schema.MedicalRiskFactor;
import org.schema.MedicalSignOrSymptom;
import org.schema.MedicalTest;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Any condition of the human body that affects the normal functioning of a person, whether physically or mentally. Includes diseases, injuries, disabilities, disorders, syndromes, etc.
 */
public interface MedicalCondition extends MedicalEntity, SchemaObject {

  /**
   * Get a single associatedAnatomy property value for this MedicalCondition object.
   *
   * @return The first associatedAnatomy property value.
   */
  public Thing getAssociatedAnatomy();
  
  /**
   * Get a single cause property value for this MedicalCondition object.
   *
   * @return The first cause property value.
   */
  public MedicalCause getCause();
  
  /**
   * Get a single differentialDiagnosis property value for this MedicalCondition object.
   *
   * @return The first differentialDiagnosis property value.
   */
  public DDxElement getDifferentialDiagnosis();
  
  /**
   * Get a single epidemiology property value for this MedicalCondition object.
   *
   * @return The first epidemiology property value.
   */
  public String getEpidemiology();
  
  /**
   * Get a single expectedPrognosis property value for this MedicalCondition object.
   *
   * @return The first expectedPrognosis property value.
   */
  public String getExpectedPrognosis();
  
  /**
   * Get a single naturalProgression property value for this MedicalCondition object.
   *
   * @return The first naturalProgression property value.
   */
  public String getNaturalProgression();
  
  /**
   * Get a single pathophysiology property value for this MedicalCondition object.
   *
   * @return The first pathophysiology property value.
   */
  public String getPathophysiology();
  
  /**
   * Get a single possibleComplication property value for this MedicalCondition object.
   *
   * @return The first possibleComplication property value.
   */
  public String getPossibleComplication();
  
  /**
   * Get a single possibleTreatment property value for this MedicalCondition object.
   *
   * @return The first possibleTreatment property value.
   */
  public MedicalTherapy getPossibleTreatment();
  
  /**
   * Get a single primaryPrevention property value for this MedicalCondition object.
   *
   * @return The first primaryPrevention property value.
   */
  public MedicalTherapy getPrimaryPrevention();
  
  /**
   * Get a single riskFactor property value for this MedicalCondition object.
   *
   * @return The first riskFactor property value.
   */
  public MedicalRiskFactor getRiskFactor();
  
  /**
   * Get a single secondaryPrevention property value for this MedicalCondition object.
   *
   * @return The first secondaryPrevention property value.
   */
  public MedicalTherapy getSecondaryPrevention();
  
  /**
   * Get a single signOrSymptom property value for this MedicalCondition object.
   *
   * @return The first signOrSymptom property value.
   */
  public MedicalSignOrSymptom getSignOrSymptom();
  
  /**
   * Get a single stage property value for this MedicalCondition object.
   *
   * @return The first stage property value.
   */
  public MedicalConditionStage getStage();
  
  /**
   * Get a single subtype property value for this MedicalCondition object.
   *
   * @return The first subtype property value.
   */
  public String getSubtype();
  
  /**
   * Get a single typicalTest property value for this MedicalCondition object.
   *
   * @return The first typicalTest property value.
   */
  public MedicalTest getTypicalTest();
  
  /**
   * Get all the associatedAnatomy property values for this MedicalCondition object.
   *
   * @return A list of associatedAnatomy property values.
   */
  public List<Thing> getAssociatedAnatomies();
  
  /**
   * Get all the cause property values for this MedicalCondition object.
   *
   * @return A list of cause property values.
   */
  public List<MedicalCause> getCauses();
  
  /**
   * Get all the differentialDiagnosis property values for this MedicalCondition object.
   *
   * @return A list of differentialDiagnosis property values.
   */
  public List<DDxElement> getDifferentialDiagnoses();
  
  /**
   * Get all the epidemiology property values for this MedicalCondition object.
   *
   * @return A list of epidemiology property values.
   */
  public List<String> getEpidemiologies();
  
  /**
   * Get all the expectedPrognosis property values for this MedicalCondition object.
   *
   * @return A list of expectedPrognosis property values.
   */
  public List<String> getExpectedPrognoses();
  
  /**
   * Get all the naturalProgression property values for this MedicalCondition object.
   *
   * @return A list of naturalProgression property values.
   */
  public List<String> getNaturalProgressions();
  
  /**
   * Get all the pathophysiology property values for this MedicalCondition object.
   *
   * @return A list of pathophysiology property values.
   */
  public List<String> getPathophysiologies();
  
  /**
   * Get all the possibleComplication property values for this MedicalCondition object.
   *
   * @return A list of possibleComplication property values.
   */
  public List<String> getPossibleComplications();
  
  /**
   * Get all the possibleTreatment property values for this MedicalCondition object.
   *
   * @return A list of possibleTreatment property values.
   */
  public List<MedicalTherapy> getPossibleTreatments();
  
  /**
   * Get all the primaryPrevention property values for this MedicalCondition object.
   *
   * @return A list of primaryPrevention property values.
   */
  public List<MedicalTherapy> getPrimaryPreventions();
  
  /**
   * Get all the riskFactor property values for this MedicalCondition object.
   *
   * @return A list of riskFactor property values.
   */
  public List<MedicalRiskFactor> getRiskFactors();
  
  /**
   * Get all the secondaryPrevention property values for this MedicalCondition object.
   *
   * @return A list of secondaryPrevention property values.
   */
  public List<MedicalTherapy> getSecondaryPreventions();
  
  /**
   * Get all the signOrSymptom property values for this MedicalCondition object.
   *
   * @return A list of signOrSymptom property values.
   */
  public List<MedicalSignOrSymptom> getSignOrSymptoms();
  
  /**
   * Get all the stage property values for this MedicalCondition object.
   *
   * @return A list of stage property values.
   */
  public List<MedicalConditionStage> getStages();
  
  /**
   * Get all the subtype property values for this MedicalCondition object.
   *
   * @return A list of subtype property values.
   */
  public List<String> getSubtypes();
  
  /**
   * Get all the typicalTest property values for this MedicalCondition object.
   *
   * @return A list of typicalTest property values.
   */
  public List<MedicalTest> getTypicalTests();
  
  /**
   * Set the associatedAnatomy property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param associatedAnatomy The value to set.
   */
  public void setAssociatedAnatomy(Thing associatedAnatomy);
  
  /**
   * Set the cause property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param cause The value to set.
   */
  public void setCause(MedicalCause cause);
  
  /**
   * Set the differentialDiagnosis property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param differentialDiagnosis The value to set.
   */
  public void setDifferentialDiagnosis(DDxElement differentialDiagnosis);
  
  /**
   * Set the epidemiology property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param epidemiology The value to set.
   */
  public void setEpidemiology(String epidemiology);
  
  /**
   * Set the expectedPrognosis property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param expectedPrognosis The value to set.
   */
  public void setExpectedPrognosis(String expectedPrognosis);
  
  /**
   * Set the naturalProgression property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param naturalProgression The value to set.
   */
  public void setNaturalProgression(String naturalProgression);
  
  /**
   * Set the pathophysiology property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param pathophysiology The value to set.
   */
  public void setPathophysiology(String pathophysiology);
  
  /**
   * Set the possibleComplication property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleComplication The value to set.
   */
  public void setPossibleComplication(String possibleComplication);
  
  /**
   * Set the possibleTreatment property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleTreatment The value to set.
   */
  public void setPossibleTreatment(MedicalTherapy possibleTreatment);
  
  /**
   * Set the primaryPrevention property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param primaryPrevention The value to set.
   */
  public void setPrimaryPrevention(MedicalTherapy primaryPrevention);
  
  /**
   * Set the riskFactor property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param riskFactor The value to set.
   */
  public void setRiskFactor(MedicalRiskFactor riskFactor);
  
  /**
   * Set the secondaryPrevention property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param secondaryPrevention The value to set.
   */
  public void setSecondaryPrevention(MedicalTherapy secondaryPrevention);
  
  /**
   * Set the signOrSymptom property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param signOrSymptom The value to set.
   */
  public void setSignOrSymptom(MedicalSignOrSymptom signOrSymptom);
  
  /**
   * Set the stage property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param stage The value to set.
   */
  public void setStage(MedicalConditionStage stage);
  
  /**
   * Set the subtype property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param subtype The value to set.
   */
  public void setSubtype(String subtype);
  
  /**
   * Set the typicalTest property value for this MedicalCondition object; overwriting any existing values.
   *
   * @param typicalTest The value to set.
   */
  public void setTypicalTest(MedicalTest typicalTest);
  
  /**
   * Set the associatedAnatomy property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param associatedAnatomies The list of values to set.
   */
  public void setAssociatedAnatomies(List<Thing> associatedAnatomies);
  
  /**
   * Set the cause property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param causes The list of values to set.
   */
  public void setCauses(List<MedicalCause> causes);
  
  /**
   * Set the differentialDiagnosis property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param differentialDiagnoses The list of values to set.
   */
  public void setDifferentialDiagnoses(List<DDxElement> differentialDiagnoses);
  
  /**
   * Set the epidemiology property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param epidemiologies The list of values to set.
   */
  public void setEpidemiologies(List<String> epidemiologies);
  
  /**
   * Set the expectedPrognosis property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param expectedPrognoses The list of values to set.
   */
  public void setExpectedPrognoses(List<String> expectedPrognoses);
  
  /**
   * Set the naturalProgression property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param naturalProgressions The list of values to set.
   */
  public void setNaturalProgressions(List<String> naturalProgressions);
  
  /**
   * Set the pathophysiology property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param pathophysiologies The list of values to set.
   */
  public void setPathophysiologies(List<String> pathophysiologies);
  
  /**
   * Set the possibleComplication property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleComplications The list of values to set.
   */
  public void setPossibleComplications(List<String> possibleComplications);
  
  /**
   * Set the possibleTreatment property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param possibleTreatments The list of values to set.
   */
  public void setPossibleTreatments(List<MedicalTherapy> possibleTreatments);
  
  /**
   * Set the primaryPrevention property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param primaryPreventions The list of values to set.
   */
  public void setPrimaryPreventions(List<MedicalTherapy> primaryPreventions);
  
  /**
   * Set the riskFactor property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param riskFactors The list of values to set.
   */
  public void setRiskFactors(List<MedicalRiskFactor> riskFactors);
  
  /**
   * Set the secondaryPrevention property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param secondaryPreventions The list of values to set.
   */
  public void setSecondaryPreventions(List<MedicalTherapy> secondaryPreventions);
  
  /**
   * Set the signOrSymptom property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param signOrSymptoms The list of values to set.
   */
  public void setSignOrSymptoms(List<MedicalSignOrSymptom> signOrSymptoms);
  
  /**
   * Set the stage property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param stages The list of values to set.
   */
  public void setStages(List<MedicalConditionStage> stages);
  
  /**
   * Set the subtype property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param subtypes The list of values to set.
   */
  public void setSubtypes(List<String> subtypes);
  
  /**
   * Set the typicalTest property values for this MedicalCondition object; overwriting any existing values.
   *
   * @param typicalTests The list of values to set.
   */
  public void setTypicalTests(List<MedicalTest> typicalTests);
  
  /**
   * Adds a associatedAnatomy property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param associatedAnatomy The value to add.
   */
  public void addAssociatedAnatomy(Thing associatedAnatomy);
  
  /**
   * Adds a cause property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param cause The value to add.
   */
  public void addCause(MedicalCause cause);
  
  /**
   * Adds a differentialDiagnosis property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param differentialDiagnosis The value to add.
   */
  public void addDifferentialDiagnosis(DDxElement differentialDiagnosis);
  
  /**
   * Adds a epidemiology property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param epidemiology The value to add.
   */
  public void addEpidemiology(String epidemiology);
  
  /**
   * Adds a expectedPrognosis property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param expectedPrognosis The value to add.
   */
  public void addExpectedPrognosis(String expectedPrognosis);
  
  /**
   * Adds a naturalProgression property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param naturalProgression The value to add.
   */
  public void addNaturalProgression(String naturalProgression);
  
  /**
   * Adds a pathophysiology property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param pathophysiology The value to add.
   */
  public void addPathophysiology(String pathophysiology);
  
  /**
   * Adds a possibleComplication property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param possibleComplication The value to add.
   */
  public void addPossibleComplication(String possibleComplication);
  
  /**
   * Adds a possibleTreatment property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param possibleTreatment The value to add.
   */
  public void addPossibleTreatment(MedicalTherapy possibleTreatment);
  
  /**
   * Adds a primaryPrevention property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param primaryPrevention The value to add.
   */
  public void addPrimaryPrevention(MedicalTherapy primaryPrevention);
  
  /**
   * Adds a riskFactor property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param riskFactor The value to add.
   */
  public void addRiskFactor(MedicalRiskFactor riskFactor);
  
  /**
   * Adds a secondaryPrevention property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param secondaryPrevention The value to add.
   */
  public void addSecondaryPrevention(MedicalTherapy secondaryPrevention);
  
  /**
   * Adds a signOrSymptom property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param signOrSymptom The value to add.
   */
  public void addSignOrSymptom(MedicalSignOrSymptom signOrSymptom);
  
  /**
   * Adds a stage property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param stage The value to add.
   */
  public void addStage(MedicalConditionStage stage);
  
  /**
   * Adds a subtype property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param subtype The value to add.
   */
  public void addSubtype(String subtype);
  
  /**
   * Adds a typicalTest property value for this MedicalCondition object; appending it to the list of existing values.
   *
   * @param typicalTest The value to add.
   */
  public void addTypicalTest(MedicalTest typicalTest);
  
}