package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalContraindication;
import org.schema.MedicalEntity;
import org.schema.MedicalIndication;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Any object used in a medical capacity, such as to diagnose or treat a patient.
 */
public interface MedicalDevice extends MedicalEntity, SchemaObject {

  /**
   * Get a single adverseOutcome property value for this MedicalDevice object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome();
  
  /**
   * Get a single contraindication property value for this MedicalDevice object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication();
  
  /**
   * Get a single indication property value for this MedicalDevice object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication();
  
  /**
   * Get a single postOp property value for this MedicalDevice object.
   *
   * @return The first postOp property value.
   */
  public String getPostOp();
  
  /**
   * Get a single preOp property value for this MedicalDevice object.
   *
   * @return The first preOp property value.
   */
  public String getPreOp();
  
  /**
   * Get a single procedure property value for this MedicalDevice object.
   *
   * @return The first procedure property value.
   */
  public String getProcedure();
  
  /**
   * Get a single purpose property value for this MedicalDevice object.
   *
   * @return The first purpose property value.
   */
  public Thing getPurpose();
  
  /**
   * Get a single seriousAdverseOutcome property value for this MedicalDevice object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome();
  
  /**
   * Get all the adverseOutcome property values for this MedicalDevice object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes();
  
  /**
   * Get all the contraindication property values for this MedicalDevice object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications();
  
  /**
   * Get all the indication property values for this MedicalDevice object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications();
  
  /**
   * Get all the postOp property values for this MedicalDevice object.
   *
   * @return A list of postOp property values.
   */
  public List<String> getPostOps();
  
  /**
   * Get all the preOp property values for this MedicalDevice object.
   *
   * @return A list of preOp property values.
   */
  public List<String> getPreOps();
  
  /**
   * Get all the procedure property values for this MedicalDevice object.
   *
   * @return A list of procedure property values.
   */
  public List<String> getProcedures();
  
  /**
   * Get all the purpose property values for this MedicalDevice object.
   *
   * @return A list of purpose property values.
   */
  public List<Thing> getPurposes();
  
  /**
   * Get all the seriousAdverseOutcome property values for this MedicalDevice object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes();
  
  /**
   * Set the adverseOutcome property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome);
  
  /**
   * Set the contraindication property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication);
  
  /**
   * Set the indication property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication);
  
  /**
   * Set the postOp property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param postOp The value to set.
   */
  public void setPostOp(String postOp);
  
  /**
   * Set the preOp property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param preOp The value to set.
   */
  public void setPreOp(String preOp);
  
  /**
   * Set the procedure property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param procedure The value to set.
   */
  public void setProcedure(String procedure);
  
  /**
   * Set the purpose property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param purpose The value to set.
   */
  public void setPurpose(Thing purpose);
  
  /**
   * Set the seriousAdverseOutcome property value for this MedicalDevice object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome);
  
  /**
   * Set the adverseOutcome property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes);
  
  /**
   * Set the contraindication property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications);
  
  /**
   * Set the indication property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications);
  
  /**
   * Set the postOp property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param postOps The list of values to set.
   */
  public void setPostOps(List<String> postOps);
  
  /**
   * Set the preOp property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param preOps The list of values to set.
   */
  public void setPreOps(List<String> preOps);
  
  /**
   * Set the procedure property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param procedures The list of values to set.
   */
  public void setProcedures(List<String> procedures);
  
  /**
   * Set the purpose property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param purposes The list of values to set.
   */
  public void setPurposes(List<Thing> purposes);
  
  /**
   * Set the seriousAdverseOutcome property values for this MedicalDevice object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes);
  
  /**
   * Adds a adverseOutcome property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome);
  
  /**
   * Adds a contraindication property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication);
  
  /**
   * Adds a indication property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication);
  
  /**
   * Adds a postOp property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param postOp The value to add.
   */
  public void addPostOp(String postOp);
  
  /**
   * Adds a preOp property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param preOp The value to add.
   */
  public void addPreOp(String preOp);
  
  /**
   * Adds a procedure property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param procedure The value to add.
   */
  public void addProcedure(String procedure);
  
  /**
   * Adds a purpose property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param purpose The value to add.
   */
  public void addPurpose(Thing purpose);
  
  /**
   * Adds a seriousAdverseOutcome property value for this MedicalDevice object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome);
  
}