package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalCode;
import org.schema.MedicalGuideline;
import org.schema.MedicalSpecialty;
import org.schema.MedicalStudy;
import org.schema.MedicineSystem;
import org.schema.Organization;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The most generic type of entity related to health and the practice of medicine.
 */
public interface MedicalEntity extends Thing, SchemaObject {

  /**
   * Get a single alternateName property value for this MedicalEntity object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName();
  
  /**
   * Get a single code property value for this MedicalEntity object.
   *
   * @return The first code property value.
   */
  public MedicalCode getCode();
  
  /**
   * Get a single guideline property value for this MedicalEntity object.
   *
   * @return The first guideline property value.
   */
  public MedicalGuideline getGuideline();
  
  /**
   * Get a single medicineSystem property value for this MedicalEntity object.
   *
   * @return The first medicineSystem property value.
   */
  public MedicineSystem getMedicineSystem();
  
  /**
   * Get a single recognizingAuthority property value for this MedicalEntity object.
   *
   * @return The first recognizingAuthority property value.
   */
  public Organization getRecognizingAuthority();
  
  /**
   * Get a single relevantSpecialty property value for this MedicalEntity object.
   *
   * @return The first relevantSpecialty property value.
   */
  public MedicalSpecialty getRelevantSpecialty();
  
  /**
   * Get a single study property value for this MedicalEntity object.
   *
   * @return The first study property value.
   */
  public MedicalStudy getStudy();
  
  /**
   * Get all the alternateName property values for this MedicalEntity object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames();
  
  /**
   * Get all the code property values for this MedicalEntity object.
   *
   * @return A list of code property values.
   */
  public List<MedicalCode> getCodes();
  
  /**
   * Get all the guideline property values for this MedicalEntity object.
   *
   * @return A list of guideline property values.
   */
  public List<MedicalGuideline> getGuidelines();
  
  /**
   * Get all the medicineSystem property values for this MedicalEntity object.
   *
   * @return A list of medicineSystem property values.
   */
  public List<MedicineSystem> getMedicineSystems();
  
  /**
   * Get all the recognizingAuthority property values for this MedicalEntity object.
   *
   * @return A list of recognizingAuthority property values.
   */
  public List<Organization> getRecognizingAuthorities();
  
  /**
   * Get all the relevantSpecialty property values for this MedicalEntity object.
   *
   * @return A list of relevantSpecialty property values.
   */
  public List<MedicalSpecialty> getRelevantSpecialties();
  
  /**
   * Get all the study property values for this MedicalEntity object.
   *
   * @return A list of study property values.
   */
  public List<MedicalStudy> getStudies();
  
  /**
   * Set the alternateName property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName);
  
  /**
   * Set the code property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param code The value to set.
   */
  public void setCode(MedicalCode code);
  
  /**
   * Set the guideline property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param guideline The value to set.
   */
  public void setGuideline(MedicalGuideline guideline);
  
  /**
   * Set the medicineSystem property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param medicineSystem The value to set.
   */
  public void setMedicineSystem(MedicineSystem medicineSystem);
  
  /**
   * Set the recognizingAuthority property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param recognizingAuthority The value to set.
   */
  public void setRecognizingAuthority(Organization recognizingAuthority);
  
  /**
   * Set the relevantSpecialty property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param relevantSpecialty The value to set.
   */
  public void setRelevantSpecialty(MedicalSpecialty relevantSpecialty);
  
  /**
   * Set the study property value for this MedicalEntity object; overwriting any existing values.
   *
   * @param study The value to set.
   */
  public void setStudy(MedicalStudy study);
  
  /**
   * Set the alternateName property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames);
  
  /**
   * Set the code property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param codes The list of values to set.
   */
  public void setCodes(List<MedicalCode> codes);
  
  /**
   * Set the guideline property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param guidelines The list of values to set.
   */
  public void setGuidelines(List<MedicalGuideline> guidelines);
  
  /**
   * Set the medicineSystem property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param medicineSystems The list of values to set.
   */
  public void setMedicineSystems(List<MedicineSystem> medicineSystems);
  
  /**
   * Set the recognizingAuthority property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param recognizingAuthorities The list of values to set.
   */
  public void setRecognizingAuthorities(List<Organization> recognizingAuthorities);
  
  /**
   * Set the relevantSpecialty property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param relevantSpecialties The list of values to set.
   */
  public void setRelevantSpecialties(List<MedicalSpecialty> relevantSpecialties);
  
  /**
   * Set the study property values for this MedicalEntity object; overwriting any existing values.
   *
   * @param studies The list of values to set.
   */
  public void setStudies(List<MedicalStudy> studies);
  
  /**
   * Adds a alternateName property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName);
  
  /**
   * Adds a code property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param code The value to add.
   */
  public void addCode(MedicalCode code);
  
  /**
   * Adds a guideline property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param guideline The value to add.
   */
  public void addGuideline(MedicalGuideline guideline);
  
  /**
   * Adds a medicineSystem property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param medicineSystem The value to add.
   */
  public void addMedicineSystem(MedicineSystem medicineSystem);
  
  /**
   * Adds a recognizingAuthority property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param recognizingAuthority The value to add.
   */
  public void addRecognizingAuthority(Organization recognizingAuthority);
  
  /**
   * Adds a relevantSpecialty property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param relevantSpecialty The value to add.
   */
  public void addRelevantSpecialty(MedicalSpecialty relevantSpecialty);
  
  /**
   * Adds a study property value for this MedicalEntity object; appending it to the list of existing values.
   *
   * @param study The value to add.
   */
  public void addStudy(MedicalStudy study);
  
}