package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.MedicalEntity;
import org.schema.MedicalEvidenceLevel;
import org.schema.SchemaObject;

/**
 * Any recommendation made by a standard society (e.g. ACC/AHA) or consensus statement that denotes how to diagnose and treat a particular condition. Note: this type should be used to tag the actual guideline recommendation; if the guideline recommendation occurs in a larger scholarly article, use MedicalScholarlyArticle to tag the overall article, not this type. Note also: the organization making the recommendation should be captured in the recognizingAuthority base property of MedicalEntity.
 */
public interface MedicalGuideline extends MedicalEntity, SchemaObject {

  /**
   * Get a single evidenceLevel property value for this MedicalGuideline object.
   *
   * @return The first evidenceLevel property value.
   */
  public MedicalEvidenceLevel getEvidenceLevel();
  
  /**
   * Get a single evidenceOrigin property value for this MedicalGuideline object.
   *
   * @return The first evidenceOrigin property value.
   */
  public String getEvidenceOrigin();
  
  /**
   * Get a single guidelineDate property value for this MedicalGuideline object.
   *
   * @return The first guidelineDate property value.
   */
  public Date getGuidelineDate();
  
  /**
   * Get a single guidelineSubject property value for this MedicalGuideline object.
   *
   * @return The first guidelineSubject property value.
   */
  public MedicalEntity getGuidelineSubject();
  
  /**
   * Get all the evidenceLevel property values for this MedicalGuideline object.
   *
   * @return A list of evidenceLevel property values.
   */
  public List<MedicalEvidenceLevel> getEvidenceLevels();
  
  /**
   * Get all the evidenceOrigin property values for this MedicalGuideline object.
   *
   * @return A list of evidenceOrigin property values.
   */
  public List<String> getEvidenceOrigins();
  
  /**
   * Get all the guidelineDate property values for this MedicalGuideline object.
   *
   * @return A list of guidelineDate property values.
   */
  public List<Date> getGuidelineDates();
  
  /**
   * Get all the guidelineSubject property values for this MedicalGuideline object.
   *
   * @return A list of guidelineSubject property values.
   */
  public List<MedicalEntity> getGuidelineSubjects();
  
  /**
   * Set the evidenceLevel property value for this MedicalGuideline object; overwriting any existing values.
   *
   * @param evidenceLevel The value to set.
   */
  public void setEvidenceLevel(MedicalEvidenceLevel evidenceLevel);
  
  /**
   * Set the evidenceOrigin property value for this MedicalGuideline object; overwriting any existing values.
   *
   * @param evidenceOrigin The value to set.
   */
  public void setEvidenceOrigin(String evidenceOrigin);
  
  /**
   * Set the guidelineDate property value for this MedicalGuideline object; overwriting any existing values.
   *
   * @param guidelineDate The value to set.
   */
  public void setGuidelineDate(Date guidelineDate);
  
  /**
   * Set the guidelineSubject property value for this MedicalGuideline object; overwriting any existing values.
   *
   * @param guidelineSubject The value to set.
   */
  public void setGuidelineSubject(MedicalEntity guidelineSubject);
  
  /**
   * Set the evidenceLevel property values for this MedicalGuideline object; overwriting any existing values.
   *
   * @param evidenceLevels The list of values to set.
   */
  public void setEvidenceLevels(List<MedicalEvidenceLevel> evidenceLevels);
  
  /**
   * Set the evidenceOrigin property values for this MedicalGuideline object; overwriting any existing values.
   *
   * @param evidenceOrigins The list of values to set.
   */
  public void setEvidenceOrigins(List<String> evidenceOrigins);
  
  /**
   * Set the guidelineDate property values for this MedicalGuideline object; overwriting any existing values.
   *
   * @param guidelineDates The list of values to set.
   */
  public void setGuidelineDates(List<Date> guidelineDates);
  
  /**
   * Set the guidelineSubject property values for this MedicalGuideline object; overwriting any existing values.
   *
   * @param guidelineSubjects The list of values to set.
   */
  public void setGuidelineSubjects(List<MedicalEntity> guidelineSubjects);
  
  /**
   * Adds a evidenceLevel property value for this MedicalGuideline object; appending it to the list of existing values.
   *
   * @param evidenceLevel The value to add.
   */
  public void addEvidenceLevel(MedicalEvidenceLevel evidenceLevel);
  
  /**
   * Adds a evidenceOrigin property value for this MedicalGuideline object; appending it to the list of existing values.
   *
   * @param evidenceOrigin The value to add.
   */
  public void addEvidenceOrigin(String evidenceOrigin);
  
  /**
   * Adds a guidelineDate property value for this MedicalGuideline object; appending it to the list of existing values.
   *
   * @param guidelineDate The value to add.
   */
  public void addGuidelineDate(Date guidelineDate);
  
  /**
   * Adds a guidelineSubject property value for this MedicalGuideline object; appending it to the list of existing values.
   *
   * @param guidelineSubject The value to add.
   */
  public void addGuidelineSubject(MedicalEntity guidelineSubject);
  
}