package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalEntity;
import org.schema.MedicalProcedureType;
import org.schema.SchemaObject;

/**
 * A process of care used in either a diagnostic, therapeutic, or palliative capacity that relies on invasive (surgical), non-invasive, or percutaneous techniques.
 */
public interface MedicalProcedure extends MedicalEntity, SchemaObject {

  /**
   * Get a single followup property value for this MedicalProcedure object.
   *
   * @return The first followup property value.
   */
  public String getFollowup();
  
  /**
   * Get a single howPerformed property value for this MedicalProcedure object.
   *
   * @return The first howPerformed property value.
   */
  public String getHowPerformed();
  
  /**
   * Get a single preparation property value for this MedicalProcedure object.
   *
   * @return The first preparation property value.
   */
  public String getPreparation();
  
  /**
   * Get a single procedureType property value for this MedicalProcedure object.
   *
   * @return The first procedureType property value.
   */
  public MedicalProcedureType getProcedureType();
  
  /**
   * Get all the followup property values for this MedicalProcedure object.
   *
   * @return A list of followup property values.
   */
  public List<String> getFollowups();
  
  /**
   * Get all the howPerformed property values for this MedicalProcedure object.
   *
   * @return A list of howPerformed property values.
   */
  public List<String> getHowPerformeds();
  
  /**
   * Get all the preparation property values for this MedicalProcedure object.
   *
   * @return A list of preparation property values.
   */
  public List<String> getPreparations();
  
  /**
   * Get all the procedureType property values for this MedicalProcedure object.
   *
   * @return A list of procedureType property values.
   */
  public List<MedicalProcedureType> getProcedureTypes();
  
  /**
   * Set the followup property value for this MedicalProcedure object; overwriting any existing values.
   *
   * @param followup The value to set.
   */
  public void setFollowup(String followup);
  
  /**
   * Set the howPerformed property value for this MedicalProcedure object; overwriting any existing values.
   *
   * @param howPerformed The value to set.
   */
  public void setHowPerformed(String howPerformed);
  
  /**
   * Set the preparation property value for this MedicalProcedure object; overwriting any existing values.
   *
   * @param preparation The value to set.
   */
  public void setPreparation(String preparation);
  
  /**
   * Set the procedureType property value for this MedicalProcedure object; overwriting any existing values.
   *
   * @param procedureType The value to set.
   */
  public void setProcedureType(MedicalProcedureType procedureType);
  
  /**
   * Set the followup property values for this MedicalProcedure object; overwriting any existing values.
   *
   * @param followups The list of values to set.
   */
  public void setFollowups(List<String> followups);
  
  /**
   * Set the howPerformed property values for this MedicalProcedure object; overwriting any existing values.
   *
   * @param howPerformeds The list of values to set.
   */
  public void setHowPerformeds(List<String> howPerformeds);
  
  /**
   * Set the preparation property values for this MedicalProcedure object; overwriting any existing values.
   *
   * @param preparations The list of values to set.
   */
  public void setPreparations(List<String> preparations);
  
  /**
   * Set the procedureType property values for this MedicalProcedure object; overwriting any existing values.
   *
   * @param procedureTypes The list of values to set.
   */
  public void setProcedureTypes(List<MedicalProcedureType> procedureTypes);
  
  /**
   * Adds a followup property value for this MedicalProcedure object; appending it to the list of existing values.
   *
   * @param followup The value to add.
   */
  public void addFollowup(String followup);
  
  /**
   * Adds a howPerformed property value for this MedicalProcedure object; appending it to the list of existing values.
   *
   * @param howPerformed The value to add.
   */
  public void addHowPerformed(String howPerformed);
  
  /**
   * Adds a preparation property value for this MedicalProcedure object; appending it to the list of existing values.
   *
   * @param preparation The value to add.
   */
  public void addPreparation(String preparation);
  
  /**
   * Adds a procedureType property value for this MedicalProcedure object; appending it to the list of existing values.
   *
   * @param procedureType The value to add.
   */
  public void addProcedureType(MedicalProcedureType procedureType);
  
}