package org.schema;

import java.util.List;
import org.schema.MedicalEntity;
import org.schema.MedicalRiskFactor;
import org.schema.SchemaObject;

/**
 * Any rule set or interactive tool for estimating the risk of developing a complication or condition.
 */
public interface MedicalRiskEstimator extends MedicalEntity, SchemaObject {

  /**
   * Get a single estimatesRiskOf property value for this MedicalRiskEstimator object.
   *
   * @return The first estimatesRiskOf property value.
   */
  public MedicalEntity getEstimatesRiskOf();
  
  /**
   * Get a single includedRiskFactor property value for this MedicalRiskEstimator object.
   *
   * @return The first includedRiskFactor property value.
   */
  public MedicalRiskFactor getIncludedRiskFactor();
  
  /**
   * Get all the estimatesRiskOf property values for this MedicalRiskEstimator object.
   *
   * @return A list of estimatesRiskOf property values.
   */
  public List<MedicalEntity> getEstimatesRisksOf();
  
  /**
   * Get all the includedRiskFactor property values for this MedicalRiskEstimator object.
   *
   * @return A list of includedRiskFactor property values.
   */
  public List<MedicalRiskFactor> getIncludedRiskFactors();
  
  /**
   * Set the estimatesRiskOf property value for this MedicalRiskEstimator object; overwriting any existing values.
   *
   * @param estimatesRiskOf The value to set.
   */
  public void setEstimatesRiskOf(MedicalEntity estimatesRiskOf);
  
  /**
   * Set the includedRiskFactor property value for this MedicalRiskEstimator object; overwriting any existing values.
   *
   * @param includedRiskFactor The value to set.
   */
  public void setIncludedRiskFactor(MedicalRiskFactor includedRiskFactor);
  
  /**
   * Set the estimatesRiskOf property values for this MedicalRiskEstimator object; overwriting any existing values.
   *
   * @param estimatesRisksOf The list of values to set.
   */
  public void setEstimatesRisksOf(List<MedicalEntity> estimatesRisksOf);
  
  /**
   * Set the includedRiskFactor property values for this MedicalRiskEstimator object; overwriting any existing values.
   *
   * @param includedRiskFactors The list of values to set.
   */
  public void setIncludedRiskFactors(List<MedicalRiskFactor> includedRiskFactors);
  
  /**
   * Adds a estimatesRiskOf property value for this MedicalRiskEstimator object; appending it to the list of existing values.
   *
   * @param estimatesRiskOf The value to add.
   */
  public void addEstimatesRiskOf(MedicalEntity estimatesRiskOf);
  
  /**
   * Adds a includedRiskFactor property value for this MedicalRiskEstimator object; appending it to the list of existing values.
   *
   * @param includedRiskFactor The value to add.
   */
  public void addIncludedRiskFactor(MedicalRiskFactor includedRiskFactor);
  
}