package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalRiskEstimator;
import org.schema.SchemaObject;

/**
 * A simple system that adds up the number of risk factors to yield a score that is associated with prognosis, e.g. CHAD score, TIMI risk score.
 */
public interface MedicalRiskScore extends MedicalRiskEstimator, SchemaObject {

  /**
   * Get a single algorithm property value for this MedicalRiskScore object.
   *
   * @return The first algorithm property value.
   */
  public String getAlgorithm();
  
  /**
   * Get all the algorithm property values for this MedicalRiskScore object.
   *
   * @return A list of algorithm property values.
   */
  public List<String> getAlgorithms();
  
  /**
   * Set the algorithm property value for this MedicalRiskScore object; overwriting any existing values.
   *
   * @param algorithm The value to set.
   */
  public void setAlgorithm(String algorithm);
  
  /**
   * Set the algorithm property values for this MedicalRiskScore object; overwriting any existing values.
   *
   * @param algorithms The list of values to set.
   */
  public void setAlgorithms(List<String> algorithms);
  
  /**
   * Adds a algorithm property value for this MedicalRiskScore object; appending it to the list of existing values.
   *
   * @param algorithm The value to add.
   */
  public void addAlgorithm(String algorithm);
  
}