package org.schema;

import java.util.List;
import org.schema.MedicalCause;
import org.schema.MedicalEntity;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;

/**
 * Any indication of the existence of a medical condition or disease.
 */
public interface MedicalSignOrSymptom extends MedicalEntity, SchemaObject {

  /**
   * Get a single cause property value for this MedicalSignOrSymptom object.
   *
   * @return The first cause property value.
   */
  public MedicalCause getCause();
  
  /**
   * Get a single possibleTreatment property value for this MedicalSignOrSymptom object.
   *
   * @return The first possibleTreatment property value.
   */
  public MedicalTherapy getPossibleTreatment();
  
  /**
   * Get all the cause property values for this MedicalSignOrSymptom object.
   *
   * @return A list of cause property values.
   */
  public List<MedicalCause> getCauses();
  
  /**
   * Get all the possibleTreatment property values for this MedicalSignOrSymptom object.
   *
   * @return A list of possibleTreatment property values.
   */
  public List<MedicalTherapy> getPossibleTreatments();
  
  /**
   * Set the cause property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param cause The value to set.
   */
  public void setCause(MedicalCause cause);
  
  /**
   * Set the possibleTreatment property value for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param possibleTreatment The value to set.
   */
  public void setPossibleTreatment(MedicalTherapy possibleTreatment);
  
  /**
   * Set the cause property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param causes The list of values to set.
   */
  public void setCauses(List<MedicalCause> causes);
  
  /**
   * Set the possibleTreatment property values for this MedicalSignOrSymptom object; overwriting any existing values.
   *
   * @param possibleTreatments The list of values to set.
   */
  public void setPossibleTreatments(List<MedicalTherapy> possibleTreatments);
  
  /**
   * Adds a cause property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param cause The value to add.
   */
  public void addCause(MedicalCause cause);
  
  /**
   * Adds a possibleTreatment property value for this MedicalSignOrSymptom object; appending it to the list of existing values.
   *
   * @param possibleTreatment The value to add.
   */
  public void addPossibleTreatment(MedicalTherapy possibleTreatment);
  
}