package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.MedicalEntity;
import org.schema.MedicalStudyStatus;
import org.schema.Organization;
import org.schema.SchemaObject;

/**
 * A medical study is an umbrella type covering all kinds of research studies relating to human medicine or health, including observational studies and interventional trials and registries, randomized, controlled or not. When the specific type of study is known, use one of the extensions of this type, such as MedicalTrial or MedicalObservationalStudy. Also, note that this type should be used to mark up data that describes the study itself; to tag an article that publishes the results of a study, use MedicalScholarlyArticle. Note: use the code property of MedicalEntity to store study IDs, e.g. clinicaltrials.gov ID.
 */
public interface MedicalStudy extends MedicalEntity, SchemaObject {

  /**
   * Get a single outcome property value for this MedicalStudy object.
   *
   * @return The first outcome property value.
   */
  public String getOutcome();
  
  /**
   * Get a single population property value for this MedicalStudy object.
   *
   * @return The first population property value.
   */
  public String getPopulation();
  
  /**
   * Get a single sponsor property value for this MedicalStudy object.
   *
   * @return The first sponsor property value.
   */
  public Organization getSponsor();
  
  /**
   * Get a single status property value for this MedicalStudy object.
   *
   * @return The first status property value.
   */
  public MedicalStudyStatus getStatus();
  
  /**
   * Get a single studyLocation property value for this MedicalStudy object.
   *
   * @return The first studyLocation property value.
   */
  public AdministrativeArea getStudyLocation();
  
  /**
   * Get a single studySubject property value for this MedicalStudy object.
   *
   * @return The first studySubject property value.
   */
  public MedicalEntity getStudySubject();
  
  /**
   * Get all the outcome property values for this MedicalStudy object.
   *
   * @return A list of outcome property values.
   */
  public List<String> getOutcomes();
  
  /**
   * Get all the population property values for this MedicalStudy object.
   *
   * @return A list of population property values.
   */
  public List<String> getPopulations();
  
  /**
   * Get all the sponsor property values for this MedicalStudy object.
   *
   * @return A list of sponsor property values.
   */
  public List<Organization> getSponsors();
  
  /**
   * Get all the status property values for this MedicalStudy object.
   *
   * @return A list of status property values.
   */
  public List<MedicalStudyStatus> getStatuses();
  
  /**
   * Get all the studyLocation property values for this MedicalStudy object.
   *
   * @return A list of studyLocation property values.
   */
  public List<AdministrativeArea> getStudyLocations();
  
  /**
   * Get all the studySubject property values for this MedicalStudy object.
   *
   * @return A list of studySubject property values.
   */
  public List<MedicalEntity> getStudySubjects();
  
  /**
   * Set the outcome property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param outcome The value to set.
   */
  public void setOutcome(String outcome);
  
  /**
   * Set the population property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param population The value to set.
   */
  public void setPopulation(String population);
  
  /**
   * Set the sponsor property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param sponsor The value to set.
   */
  public void setSponsor(Organization sponsor);
  
  /**
   * Set the status property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param status The value to set.
   */
  public void setStatus(MedicalStudyStatus status);
  
  /**
   * Set the studyLocation property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param studyLocation The value to set.
   */
  public void setStudyLocation(AdministrativeArea studyLocation);
  
  /**
   * Set the studySubject property value for this MedicalStudy object; overwriting any existing values.
   *
   * @param studySubject The value to set.
   */
  public void setStudySubject(MedicalEntity studySubject);
  
  /**
   * Set the outcome property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param outcomes The list of values to set.
   */
  public void setOutcomes(List<String> outcomes);
  
  /**
   * Set the population property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param populations The list of values to set.
   */
  public void setPopulations(List<String> populations);
  
  /**
   * Set the sponsor property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param sponsors The list of values to set.
   */
  public void setSponsors(List<Organization> sponsors);
  
  /**
   * Set the status property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param statuses The list of values to set.
   */
  public void setStatuses(List<MedicalStudyStatus> statuses);
  
  /**
   * Set the studyLocation property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param studyLocations The list of values to set.
   */
  public void setStudyLocations(List<AdministrativeArea> studyLocations);
  
  /**
   * Set the studySubject property values for this MedicalStudy object; overwriting any existing values.
   *
   * @param studySubjects The list of values to set.
   */
  public void setStudySubjects(List<MedicalEntity> studySubjects);
  
  /**
   * Adds a outcome property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param outcome The value to add.
   */
  public void addOutcome(String outcome);
  
  /**
   * Adds a population property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param population The value to add.
   */
  public void addPopulation(String population);
  
  /**
   * Adds a sponsor property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param sponsor The value to add.
   */
  public void addSponsor(Organization sponsor);
  
  /**
   * Adds a status property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param status The value to add.
   */
  public void addStatus(MedicalStudyStatus status);
  
  /**
   * Adds a studyLocation property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param studyLocation The value to add.
   */
  public void addStudyLocation(AdministrativeArea studyLocation);
  
  /**
   * Adds a studySubject property value for this MedicalStudy object; appending it to the list of existing values.
   *
   * @param studySubject The value to add.
   */
  public void addStudySubject(MedicalEntity studySubject);
  
}