package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Drug;
import org.schema.MedicalCondition;
import org.schema.MedicalDevice;
import org.schema.MedicalEntity;
import org.schema.MedicalSign;
import org.schema.SchemaObject;

/**
 * Any medical test, typically performed for diagnostic purposes.
 */
public interface MedicalTest extends MedicalEntity, SchemaObject {

  /**
   * Get a single affectedBy property value for this MedicalTest object.
   *
   * @return The first affectedBy property value.
   */
  public Drug getAffectedBy();
  
  /**
   * Get a single normalRange property value for this MedicalTest object.
   *
   * @return The first normalRange property value.
   */
  public String getNormalRange();
  
  /**
   * Get a single signDetected property value for this MedicalTest object.
   *
   * @return The first signDetected property value.
   */
  public MedicalSign getSignDetected();
  
  /**
   * Get a single usedToDiagnose property value for this MedicalTest object.
   *
   * @return The first usedToDiagnose property value.
   */
  public MedicalCondition getUsedToDiagnose();
  
  /**
   * Get a single usesDevice property value for this MedicalTest object.
   *
   * @return The first usesDevice property value.
   */
  public MedicalDevice getUsesDevice();
  
  /**
   * Get all the affectedBy property values for this MedicalTest object.
   *
   * @return A list of affectedBy property values.
   */
  public List<Drug> getAffectedBies();
  
  /**
   * Get all the normalRange property values for this MedicalTest object.
   *
   * @return A list of normalRange property values.
   */
  public List<String> getNormalRanges();
  
  /**
   * Get all the signDetected property values for this MedicalTest object.
   *
   * @return A list of signDetected property values.
   */
  public List<MedicalSign> getSignDetecteds();
  
  /**
   * Get all the usedToDiagnose property values for this MedicalTest object.
   *
   * @return A list of usedToDiagnose property values.
   */
  public List<MedicalCondition> getUsedToDiagnoses();
  
  /**
   * Get all the usesDevice property values for this MedicalTest object.
   *
   * @return A list of usesDevice property values.
   */
  public List<MedicalDevice> getUsesDevices();
  
  /**
   * Set the affectedBy property value for this MedicalTest object; overwriting any existing values.
   *
   * @param affectedBy The value to set.
   */
  public void setAffectedBy(Drug affectedBy);
  
  /**
   * Set the normalRange property value for this MedicalTest object; overwriting any existing values.
   *
   * @param normalRange The value to set.
   */
  public void setNormalRange(String normalRange);
  
  /**
   * Set the signDetected property value for this MedicalTest object; overwriting any existing values.
   *
   * @param signDetected The value to set.
   */
  public void setSignDetected(MedicalSign signDetected);
  
  /**
   * Set the usedToDiagnose property value for this MedicalTest object; overwriting any existing values.
   *
   * @param usedToDiagnose The value to set.
   */
  public void setUsedToDiagnose(MedicalCondition usedToDiagnose);
  
  /**
   * Set the usesDevice property value for this MedicalTest object; overwriting any existing values.
   *
   * @param usesDevice The value to set.
   */
  public void setUsesDevice(MedicalDevice usesDevice);
  
  /**
   * Set the affectedBy property values for this MedicalTest object; overwriting any existing values.
   *
   * @param affectedBies The list of values to set.
   */
  public void setAffectedBies(List<Drug> affectedBies);
  
  /**
   * Set the normalRange property values for this MedicalTest object; overwriting any existing values.
   *
   * @param normalRanges The list of values to set.
   */
  public void setNormalRanges(List<String> normalRanges);
  
  /**
   * Set the signDetected property values for this MedicalTest object; overwriting any existing values.
   *
   * @param signDetecteds The list of values to set.
   */
  public void setSignDetecteds(List<MedicalSign> signDetecteds);
  
  /**
   * Set the usedToDiagnose property values for this MedicalTest object; overwriting any existing values.
   *
   * @param usedToDiagnoses The list of values to set.
   */
  public void setUsedToDiagnoses(List<MedicalCondition> usedToDiagnoses);
  
  /**
   * Set the usesDevice property values for this MedicalTest object; overwriting any existing values.
   *
   * @param usesDevices The list of values to set.
   */
  public void setUsesDevices(List<MedicalDevice> usesDevices);
  
  /**
   * Adds a affectedBy property value for this MedicalTest object; appending it to the list of existing values.
   *
   * @param affectedBy The value to add.
   */
  public void addAffectedBy(Drug affectedBy);
  
  /**
   * Adds a normalRange property value for this MedicalTest object; appending it to the list of existing values.
   *
   * @param normalRange The value to add.
   */
  public void addNormalRange(String normalRange);
  
  /**
   * Adds a signDetected property value for this MedicalTest object; appending it to the list of existing values.
   *
   * @param signDetected The value to add.
   */
  public void addSignDetected(MedicalSign signDetected);
  
  /**
   * Adds a usedToDiagnose property value for this MedicalTest object; appending it to the list of existing values.
   *
   * @param usedToDiagnose The value to add.
   */
  public void addUsedToDiagnose(MedicalCondition usedToDiagnose);
  
  /**
   * Adds a usesDevice property value for this MedicalTest object; appending it to the list of existing values.
   *
   * @param usesDevice The value to add.
   */
  public void addUsesDevice(MedicalDevice usesDevice);
  
}