package org.schema;

import java.util.List;
import org.schema.MedicalContraindication;
import org.schema.MedicalEntity;
import org.schema.MedicalIndication;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;

/**
 * Any medical intervention designed to prevent, treat, and cure human diseases and medical conditions, including both curative and palliative therapies. Medical therapies are typically processes of care relying upon pharmacotherapy, behavioral therapy, supportive therapy (with fluid or nutrition for example), or detoxification (e.g. hemodialysis) aimed at improving or preventing a health condition.
 */
public interface MedicalTherapy extends MedicalEntity, SchemaObject {

  /**
   * Get a single adverseOutcome property value for this MedicalTherapy object.
   *
   * @return The first adverseOutcome property value.
   */
  public MedicalEntity getAdverseOutcome();
  
  /**
   * Get a single contraindication property value for this MedicalTherapy object.
   *
   * @return The first contraindication property value.
   */
  public MedicalContraindication getContraindication();
  
  /**
   * Get a single duplicateTherapy property value for this MedicalTherapy object.
   *
   * @return The first duplicateTherapy property value.
   */
  public MedicalTherapy getDuplicateTherapy();
  
  /**
   * Get a single indication property value for this MedicalTherapy object.
   *
   * @return The first indication property value.
   */
  public MedicalIndication getIndication();
  
  /**
   * Get a single seriousAdverseOutcome property value for this MedicalTherapy object.
   *
   * @return The first seriousAdverseOutcome property value.
   */
  public MedicalEntity getSeriousAdverseOutcome();
  
  /**
   * Get all the adverseOutcome property values for this MedicalTherapy object.
   *
   * @return A list of adverseOutcome property values.
   */
  public List<MedicalEntity> getAdverseOutcomes();
  
  /**
   * Get all the contraindication property values for this MedicalTherapy object.
   *
   * @return A list of contraindication property values.
   */
  public List<MedicalContraindication> getContraindications();
  
  /**
   * Get all the duplicateTherapy property values for this MedicalTherapy object.
   *
   * @return A list of duplicateTherapy property values.
   */
  public List<MedicalTherapy> getDuplicateTherapies();
  
  /**
   * Get all the indication property values for this MedicalTherapy object.
   *
   * @return A list of indication property values.
   */
  public List<MedicalIndication> getIndications();
  
  /**
   * Get all the seriousAdverseOutcome property values for this MedicalTherapy object.
   *
   * @return A list of seriousAdverseOutcome property values.
   */
  public List<MedicalEntity> getSeriousAdverseOutcomes();
  
  /**
   * Set the adverseOutcome property value for this MedicalTherapy object; overwriting any existing values.
   *
   * @param adverseOutcome The value to set.
   */
  public void setAdverseOutcome(MedicalEntity adverseOutcome);
  
  /**
   * Set the contraindication property value for this MedicalTherapy object; overwriting any existing values.
   *
   * @param contraindication The value to set.
   */
  public void setContraindication(MedicalContraindication contraindication);
  
  /**
   * Set the duplicateTherapy property value for this MedicalTherapy object; overwriting any existing values.
   *
   * @param duplicateTherapy The value to set.
   */
  public void setDuplicateTherapy(MedicalTherapy duplicateTherapy);
  
  /**
   * Set the indication property value for this MedicalTherapy object; overwriting any existing values.
   *
   * @param indication The value to set.
   */
  public void setIndication(MedicalIndication indication);
  
  /**
   * Set the seriousAdverseOutcome property value for this MedicalTherapy object; overwriting any existing values.
   *
   * @param seriousAdverseOutcome The value to set.
   */
  public void setSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome);
  
  /**
   * Set the adverseOutcome property values for this MedicalTherapy object; overwriting any existing values.
   *
   * @param adverseOutcomes The list of values to set.
   */
  public void setAdverseOutcomes(List<MedicalEntity> adverseOutcomes);
  
  /**
   * Set the contraindication property values for this MedicalTherapy object; overwriting any existing values.
   *
   * @param contraindications The list of values to set.
   */
  public void setContraindications(List<MedicalContraindication> contraindications);
  
  /**
   * Set the duplicateTherapy property values for this MedicalTherapy object; overwriting any existing values.
   *
   * @param duplicateTherapies The list of values to set.
   */
  public void setDuplicateTherapies(List<MedicalTherapy> duplicateTherapies);
  
  /**
   * Set the indication property values for this MedicalTherapy object; overwriting any existing values.
   *
   * @param indications The list of values to set.
   */
  public void setIndications(List<MedicalIndication> indications);
  
  /**
   * Set the seriousAdverseOutcome property values for this MedicalTherapy object; overwriting any existing values.
   *
   * @param seriousAdverseOutcomes The list of values to set.
   */
  public void setSeriousAdverseOutcomes(List<MedicalEntity> seriousAdverseOutcomes);
  
  /**
   * Adds a adverseOutcome property value for this MedicalTherapy object; appending it to the list of existing values.
   *
   * @param adverseOutcome The value to add.
   */
  public void addAdverseOutcome(MedicalEntity adverseOutcome);
  
  /**
   * Adds a contraindication property value for this MedicalTherapy object; appending it to the list of existing values.
   *
   * @param contraindication The value to add.
   */
  public void addContraindication(MedicalContraindication contraindication);
  
  /**
   * Adds a duplicateTherapy property value for this MedicalTherapy object; appending it to the list of existing values.
   *
   * @param duplicateTherapy The value to add.
   */
  public void addDuplicateTherapy(MedicalTherapy duplicateTherapy);
  
  /**
   * Adds a indication property value for this MedicalTherapy object; appending it to the list of existing values.
   *
   * @param indication The value to add.
   */
  public void addIndication(MedicalIndication indication);
  
  /**
   * Adds a seriousAdverseOutcome property value for this MedicalTherapy object; appending it to the list of existing values.
   *
   * @param seriousAdverseOutcome The value to add.
   */
  public void addSeriousAdverseOutcome(MedicalEntity seriousAdverseOutcome);
  
}