package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalStudy;
import org.schema.MedicalTrialDesign;
import org.schema.SchemaObject;

/**
 * A medical trial is a type of medical study that uses scientific process used to compare the safety and efficacy of medical therapies or medical procedures. In general, medical trials are controlled and subjects are allocated at random to the different treatment and/or control groups.
 */
public interface MedicalTrial extends MedicalStudy, SchemaObject {

  /**
   * Get a single phase property value for this MedicalTrial object.
   *
   * @return The first phase property value.
   */
  public String getPhase();
  
  /**
   * Get a single trialDesign property value for this MedicalTrial object.
   *
   * @return The first trialDesign property value.
   */
  public MedicalTrialDesign getTrialDesign();
  
  /**
   * Get all the phase property values for this MedicalTrial object.
   *
   * @return A list of phase property values.
   */
  public List<String> getPhases();
  
  /**
   * Get all the trialDesign property values for this MedicalTrial object.
   *
   * @return A list of trialDesign property values.
   */
  public List<MedicalTrialDesign> getTrialDesigns();
  
  /**
   * Set the phase property value for this MedicalTrial object; overwriting any existing values.
   *
   * @param phase The value to set.
   */
  public void setPhase(String phase);
  
  /**
   * Set the trialDesign property value for this MedicalTrial object; overwriting any existing values.
   *
   * @param trialDesign The value to set.
   */
  public void setTrialDesign(MedicalTrialDesign trialDesign);
  
  /**
   * Set the phase property values for this MedicalTrial object; overwriting any existing values.
   *
   * @param phases The list of values to set.
   */
  public void setPhases(List<String> phases);
  
  /**
   * Set the trialDesign property values for this MedicalTrial object; overwriting any existing values.
   *
   * @param trialDesigns The list of values to set.
   */
  public void setTrialDesigns(List<MedicalTrialDesign> trialDesigns);
  
  /**
   * Adds a phase property value for this MedicalTrial object; appending it to the list of existing values.
   *
   * @param phase The value to add.
   */
  public void addPhase(String phase);
  
  /**
   * Adds a trialDesign property value for this MedicalTrial object; appending it to the list of existing values.
   *
   * @param trialDesign The value to add.
   */
  public void addTrialDesign(MedicalTrialDesign trialDesign);
  
}