package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.SchemaObject;
import org.schema.WebPage;

/**
 * A web page that provides medical information.
 */
public interface MedicalWebPage extends WebPage, SchemaObject {

  /**
   * Get a single aspect property value for this MedicalWebPage object.
   *
   * @return The first aspect property value.
   */
  public String getAspect();
  
  /**
   * Get all the aspect property values for this MedicalWebPage object.
   *
   * @return A list of aspect property values.
   */
  public List<String> getAspects();
  
  /**
   * Set the aspect property value for this MedicalWebPage object; overwriting any existing values.
   *
   * @param aspect The value to set.
   */
  public void setAspect(String aspect);
  
  /**
   * Set the aspect property values for this MedicalWebPage object; overwriting any existing values.
   *
   * @param aspects The list of values to set.
   */
  public void setAspects(List<String> aspects);
  
  /**
   * Adds a aspect property value for this MedicalWebPage object; appending it to the list of existing values.
   *
   * @param aspect The value to add.
   */
  public void addAspect(String aspect);
  
}