package org.schema;

import java.util.List;
import org.schema.Action;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of an agent relocating to a place.<p>Related actions:</p><ul><li><a href="http://schema.org/TransferAction">TransferAction</a>: Unlike TransferAction, the subject of the move is a living Person or Organization rather than an inanimate object.</li></ul>
 */
public interface MoveAction extends Action, SchemaObject {

  /**
   * Get a single fromLocation property value for this MoveAction object.
   *
   * @return The first fromLocation property value.
   */
  public Thing getFromLocation();
  
  /**
   * Get a single toLocation property value for this MoveAction object.
   *
   * @return The first toLocation property value.
   */
  public Thing getToLocation();
  
  /**
   * Get all the fromLocation property values for this MoveAction object.
   *
   * @return A list of fromLocation property values.
   */
  public List<Thing> getFromLocations();
  
  /**
   * Get all the toLocation property values for this MoveAction object.
   *
   * @return A list of toLocation property values.
   */
  public List<Thing> getToLocations();
  
  /**
   * Set the fromLocation property value for this MoveAction object; overwriting any existing values.
   *
   * @param fromLocation The value to set.
   */
  public void setFromLocation(Thing fromLocation);
  
  /**
   * Set the toLocation property value for this MoveAction object; overwriting any existing values.
   *
   * @param toLocation The value to set.
   */
  public void setToLocation(Thing toLocation);
  
  /**
   * Set the fromLocation property values for this MoveAction object; overwriting any existing values.
   *
   * @param fromLocations The list of values to set.
   */
  public void setFromLocations(List<Thing> fromLocations);
  
  /**
   * Set the toLocation property values for this MoveAction object; overwriting any existing values.
   *
   * @param toLocations The list of values to set.
   */
  public void setToLocations(List<Thing> toLocations);
  
  /**
   * Adds a fromLocation property value for this MoveAction object; appending it to the list of existing values.
   *
   * @param fromLocation The value to add.
   */
  public void addFromLocation(Thing fromLocation);
  
  /**
   * Adds a toLocation property value for this MoveAction object; appending it to the list of existing values.
   *
   * @param toLocation The value to add.
   */
  public void addToLocation(Thing toLocation);
  
}