package org.schema;

import java.util.List;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.Organization;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.VideoObject;

/**
 * A movie.
 */
public interface Movie extends CreativeWork, SchemaObject {

  /**
   * Get a single actor property value for this Movie object.
   *
   * @return The first actor property value.
   */
  public Person getActor();
  
  /**
   * Get a single director property value for this Movie object.
   *
   * @return The first director property value.
   */
  public Person getDirector();
  
  /**
   * Get a single duration property value for this Movie object.
   *
   * @return The first duration property value.
   */
  public Duration getDuration();
  
  /**
   * Get a single musicBy property value for this Movie object.
   *
   * @return The first musicBy property value.
   */
  public Thing getMusicBy();
  
  /**
   * Get a single producer property value for this Movie object.
   *
   * @return The first producer property value.
   */
  public Person getProducer();
  
  /**
   * Get a single productionCompany property value for this Movie object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany();
  
  /**
   * Get a single trailer property value for this Movie object.
   *
   * @return The first trailer property value.
   */
  public VideoObject getTrailer();
  
  /**
   * Get all the actor property values for this Movie object.
   *
   * @return A list of actor property values.
   */
  public List<Person> getActors();
  
  /**
   * Get all the director property values for this Movie object.
   *
   * @return A list of director property values.
   */
  public List<Person> getDirectors();
  
  /**
   * Get all the duration property values for this Movie object.
   *
   * @return A list of duration property values.
   */
  public List<Duration> getDurations();
  
  /**
   * Get all the musicBy property values for this Movie object.
   *
   * @return A list of musicBy property values.
   */
  public List<Thing> getMusicBies();
  
  /**
   * Get all the producer property values for this Movie object.
   *
   * @return A list of producer property values.
   */
  public List<Person> getProducers();
  
  /**
   * Get all the productionCompany property values for this Movie object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies();
  
  /**
   * Get all the trailer property values for this Movie object.
   *
   * @return A list of trailer property values.
   */
  public List<VideoObject> getTrailers();
  
  /**
   * Set the actor property value for this Movie object; overwriting any existing values.
   *
   * @param actor The value to set.
   */
  public void setActor(Person actor);
  
  /**
   * Set the director property value for this Movie object; overwriting any existing values.
   *
   * @param director The value to set.
   */
  public void setDirector(Person director);
  
  /**
   * Set the duration property value for this Movie object; overwriting any existing values.
   *
   * @param duration The value to set.
   */
  public void setDuration(Duration duration);
  
  /**
   * Set the musicBy property value for this Movie object; overwriting any existing values.
   *
   * @param musicBy The value to set.
   */
  public void setMusicBy(Thing musicBy);
  
  /**
   * Set the producer property value for this Movie object; overwriting any existing values.
   *
   * @param producer The value to set.
   */
  public void setProducer(Person producer);
  
  /**
   * Set the productionCompany property value for this Movie object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany);
  
  /**
   * Set the trailer property value for this Movie object; overwriting any existing values.
   *
   * @param trailer The value to set.
   */
  public void setTrailer(VideoObject trailer);
  
  /**
   * Set the actor property values for this Movie object; overwriting any existing values.
   *
   * @param actors The list of values to set.
   */
  public void setActors(List<Person> actors);
  
  /**
   * Set the director property values for this Movie object; overwriting any existing values.
   *
   * @param directors The list of values to set.
   */
  public void setDirectors(List<Person> directors);
  
  /**
   * Set the duration property values for this Movie object; overwriting any existing values.
   *
   * @param durations The list of values to set.
   */
  public void setDurations(List<Duration> durations);
  
  /**
   * Set the musicBy property values for this Movie object; overwriting any existing values.
   *
   * @param musicBies The list of values to set.
   */
  public void setMusicBies(List<Thing> musicBies);
  
  /**
   * Set the producer property values for this Movie object; overwriting any existing values.
   *
   * @param producers The list of values to set.
   */
  public void setProducers(List<Person> producers);
  
  /**
   * Set the productionCompany property values for this Movie object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies);
  
  /**
   * Set the trailer property values for this Movie object; overwriting any existing values.
   *
   * @param trailers The list of values to set.
   */
  public void setTrailers(List<VideoObject> trailers);
  
  /**
   * Adds a actor property value for this Movie object; appending it to the list of existing values.
   *
   * @param actor The value to add.
   */
  public void addActor(Person actor);
  
  /**
   * Adds a director property value for this Movie object; appending it to the list of existing values.
   *
   * @param director The value to add.
   */
  public void addDirector(Person director);
  
  /**
   * Adds a duration property value for this Movie object; appending it to the list of existing values.
   *
   * @param duration The value to add.
   */
  public void addDuration(Duration duration);
  
  /**
   * Adds a musicBy property value for this Movie object; appending it to the list of existing values.
   *
   * @param musicBy The value to add.
   */
  public void addMusicBy(Thing musicBy);
  
  /**
   * Adds a producer property value for this Movie object; appending it to the list of existing values.
   *
   * @param producer The value to add.
   */
  public void addProducer(Person producer);
  
  /**
   * Adds a productionCompany property value for this Movie object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany);
  
  /**
   * Adds a trailer property value for this Movie object; appending it to the list of existing values.
   *
   * @param trailer The value to add.
   */
  public void addTrailer(VideoObject trailer);
  
}