package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.Muscle;
import org.schema.Nerve;
import org.schema.SchemaObject;
import org.schema.Vessel;

/**
 * A muscle is an anatomical structure consisting of a contractile form of tissue that animals use to effect movement.
 */
public interface Muscle extends AnatomicalStructure, SchemaObject {

  /**
   * Get a single action property value for this Muscle object.
   *
   * @return The first action property value.
   */
  public String getAction();
  
  /**
   * Get a single antagonist property value for this Muscle object.
   *
   * @return The first antagonist property value.
   */
  public Muscle getAntagonist();
  
  /**
   * Get a single bloodSupply property value for this Muscle object.
   *
   * @return The first bloodSupply property value.
   */
  public Vessel getBloodSupply();
  
  /**
   * Get a single insertion property value for this Muscle object.
   *
   * @return The first insertion property value.
   */
  public AnatomicalStructure getInsertion();
  
  /**
   * Get a single nerve property value for this Muscle object.
   *
   * @return The first nerve property value.
   */
  public Nerve getNerve();
  
  /**
   * Get a single origin property value for this Muscle object.
   *
   * @return The first origin property value.
   */
  public AnatomicalStructure getOrigin();
  
  /**
   * Get all the action property values for this Muscle object.
   *
   * @return A list of action property values.
   */
  public List<String> getActions();
  
  /**
   * Get all the antagonist property values for this Muscle object.
   *
   * @return A list of antagonist property values.
   */
  public List<Muscle> getAntagonists();
  
  /**
   * Get all the bloodSupply property values for this Muscle object.
   *
   * @return A list of bloodSupply property values.
   */
  public List<Vessel> getBloodSupplies();
  
  /**
   * Get all the insertion property values for this Muscle object.
   *
   * @return A list of insertion property values.
   */
  public List<AnatomicalStructure> getInsertions();
  
  /**
   * Get all the nerve property values for this Muscle object.
   *
   * @return A list of nerve property values.
   */
  public List<Nerve> getNerves();
  
  /**
   * Get all the origin property values for this Muscle object.
   *
   * @return A list of origin property values.
   */
  public List<AnatomicalStructure> getOrigins();
  
  /**
   * Set the action property value for this Muscle object; overwriting any existing values.
   *
   * @param action The value to set.
   */
  public void setAction(String action);
  
  /**
   * Set the antagonist property value for this Muscle object; overwriting any existing values.
   *
   * @param antagonist The value to set.
   */
  public void setAntagonist(Muscle antagonist);
  
  /**
   * Set the bloodSupply property value for this Muscle object; overwriting any existing values.
   *
   * @param bloodSupply The value to set.
   */
  public void setBloodSupply(Vessel bloodSupply);
  
  /**
   * Set the insertion property value for this Muscle object; overwriting any existing values.
   *
   * @param insertion The value to set.
   */
  public void setInsertion(AnatomicalStructure insertion);
  
  /**
   * Set the nerve property value for this Muscle object; overwriting any existing values.
   *
   * @param nerve The value to set.
   */
  public void setNerve(Nerve nerve);
  
  /**
   * Set the origin property value for this Muscle object; overwriting any existing values.
   *
   * @param origin The value to set.
   */
  public void setOrigin(AnatomicalStructure origin);
  
  /**
   * Set the action property values for this Muscle object; overwriting any existing values.
   *
   * @param actions The list of values to set.
   */
  public void setActions(List<String> actions);
  
  /**
   * Set the antagonist property values for this Muscle object; overwriting any existing values.
   *
   * @param antagonists The list of values to set.
   */
  public void setAntagonists(List<Muscle> antagonists);
  
  /**
   * Set the bloodSupply property values for this Muscle object; overwriting any existing values.
   *
   * @param bloodSupplies The list of values to set.
   */
  public void setBloodSupplies(List<Vessel> bloodSupplies);
  
  /**
   * Set the insertion property values for this Muscle object; overwriting any existing values.
   *
   * @param insertions The list of values to set.
   */
  public void setInsertions(List<AnatomicalStructure> insertions);
  
  /**
   * Set the nerve property values for this Muscle object; overwriting any existing values.
   *
   * @param nerves The list of values to set.
   */
  public void setNerves(List<Nerve> nerves);
  
  /**
   * Set the origin property values for this Muscle object; overwriting any existing values.
   *
   * @param origins The list of values to set.
   */
  public void setOrigins(List<AnatomicalStructure> origins);
  
  /**
   * Adds a action property value for this Muscle object; appending it to the list of existing values.
   *
   * @param action The value to add.
   */
  public void addAction(String action);
  
  /**
   * Adds a antagonist property value for this Muscle object; appending it to the list of existing values.
   *
   * @param antagonist The value to add.
   */
  public void addAntagonist(Muscle antagonist);
  
  /**
   * Adds a bloodSupply property value for this Muscle object; appending it to the list of existing values.
   *
   * @param bloodSupply The value to add.
   */
  public void addBloodSupply(Vessel bloodSupply);
  
  /**
   * Adds a insertion property value for this Muscle object; appending it to the list of existing values.
   *
   * @param insertion The value to add.
   */
  public void addInsertion(AnatomicalStructure insertion);
  
  /**
   * Adds a nerve property value for this Muscle object; appending it to the list of existing values.
   *
   * @param nerve The value to add.
   */
  public void addNerve(Nerve nerve);
  
  /**
   * Adds a origin property value for this Muscle object; appending it to the list of existing values.
   *
   * @param origin The value to add.
   */
  public void addOrigin(AnatomicalStructure origin);
  
}