package org.schema;

import java.util.List;
import org.schema.MusicAlbum;
import org.schema.MusicRecording;
import org.schema.PerformingGroup;
import org.schema.Person;
import org.schema.SchemaObject;

/**
 * A musical group, such as a band, an orchestra, or a choir. Can also be a solo musician.
 */
public interface MusicGroup extends PerformingGroup, SchemaObject {

  /**
   * Get a single album property value for this MusicGroup object.
   *
   * @return The first album property value.
   */
  public MusicAlbum getAlbum();
  
  /**
   * Get a single musicGroupMember property value for this MusicGroup object.
   *
   * @return The first musicGroupMember property value.
   */
  public Person getMusicGroupMember();
  
  /**
   * Get a single track property value for this MusicGroup object.
   *
   * @return The first track property value.
   */
  public MusicRecording getTrack();
  
  /**
   * Get all the album property values for this MusicGroup object.
   *
   * @return A list of album property values.
   */
  public List<MusicAlbum> getAlbums();
  
  /**
   * Get all the musicGroupMember property values for this MusicGroup object.
   *
   * @return A list of musicGroupMember property values.
   */
  public List<Person> getMusicGroupMembers();
  
  /**
   * Get all the track property values for this MusicGroup object.
   *
   * @return A list of track property values.
   */
  public List<MusicRecording> getTracks();
  
  /**
   * Set the album property value for this MusicGroup object; overwriting any existing values.
   *
   * @param album The value to set.
   */
  public void setAlbum(MusicAlbum album);
  
  /**
   * Set the musicGroupMember property value for this MusicGroup object; overwriting any existing values.
   *
   * @param musicGroupMember The value to set.
   */
  public void setMusicGroupMember(Person musicGroupMember);
  
  /**
   * Set the track property value for this MusicGroup object; overwriting any existing values.
   *
   * @param track The value to set.
   */
  public void setTrack(MusicRecording track);
  
  /**
   * Set the album property values for this MusicGroup object; overwriting any existing values.
   *
   * @param albums The list of values to set.
   */
  public void setAlbums(List<MusicAlbum> albums);
  
  /**
   * Set the musicGroupMember property values for this MusicGroup object; overwriting any existing values.
   *
   * @param musicGroupMembers The list of values to set.
   */
  public void setMusicGroupMembers(List<Person> musicGroupMembers);
  
  /**
   * Set the track property values for this MusicGroup object; overwriting any existing values.
   *
   * @param tracks The list of values to set.
   */
  public void setTracks(List<MusicRecording> tracks);
  
  /**
   * Adds a album property value for this MusicGroup object; appending it to the list of existing values.
   *
   * @param album The value to add.
   */
  public void addAlbum(MusicAlbum album);
  
  /**
   * Adds a musicGroupMember property value for this MusicGroup object; appending it to the list of existing values.
   *
   * @param musicGroupMember The value to add.
   */
  public void addMusicGroupMember(Person musicGroupMember);
  
  /**
   * Adds a track property value for this MusicGroup object; appending it to the list of existing values.
   *
   * @param track The value to add.
   */
  public void addTrack(MusicRecording track);
  
}