package org.schema;

import java.util.List;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.MusicAlbum;
import org.schema.MusicGroup;
import org.schema.MusicPlaylist;
import org.schema.SchemaObject;

/**
 * A music recording (track), usually a single song.
 */
public interface MusicRecording extends CreativeWork, SchemaObject {

  /**
   * Get a single byArtist property value for this MusicRecording object.
   *
   * @return The first byArtist property value.
   */
  public MusicGroup getByArtist();
  
  /**
   * Get a single duration property value for this MusicRecording object.
   *
   * @return The first duration property value.
   */
  public Duration getDuration();
  
  /**
   * Get a single inAlbum property value for this MusicRecording object.
   *
   * @return The first inAlbum property value.
   */
  public MusicAlbum getInAlbum();
  
  /**
   * Get a single inPlaylist property value for this MusicRecording object.
   *
   * @return The first inPlaylist property value.
   */
  public MusicPlaylist getInPlaylist();
  
  /**
   * Get all the byArtist property values for this MusicRecording object.
   *
   * @return A list of byArtist property values.
   */
  public List<MusicGroup> getByArtists();
  
  /**
   * Get all the duration property values for this MusicRecording object.
   *
   * @return A list of duration property values.
   */
  public List<Duration> getDurations();
  
  /**
   * Get all the inAlbum property values for this MusicRecording object.
   *
   * @return A list of inAlbum property values.
   */
  public List<MusicAlbum> getInAlbums();
  
  /**
   * Get all the inPlaylist property values for this MusicRecording object.
   *
   * @return A list of inPlaylist property values.
   */
  public List<MusicPlaylist> getInPlaylists();
  
  /**
   * Set the byArtist property value for this MusicRecording object; overwriting any existing values.
   *
   * @param byArtist The value to set.
   */
  public void setByArtist(MusicGroup byArtist);
  
  /**
   * Set the duration property value for this MusicRecording object; overwriting any existing values.
   *
   * @param duration The value to set.
   */
  public void setDuration(Duration duration);
  
  /**
   * Set the inAlbum property value for this MusicRecording object; overwriting any existing values.
   *
   * @param inAlbum The value to set.
   */
  public void setInAlbum(MusicAlbum inAlbum);
  
  /**
   * Set the inPlaylist property value for this MusicRecording object; overwriting any existing values.
   *
   * @param inPlaylist The value to set.
   */
  public void setInPlaylist(MusicPlaylist inPlaylist);
  
  /**
   * Set the byArtist property values for this MusicRecording object; overwriting any existing values.
   *
   * @param byArtists The list of values to set.
   */
  public void setByArtists(List<MusicGroup> byArtists);
  
  /**
   * Set the duration property values for this MusicRecording object; overwriting any existing values.
   *
   * @param durations The list of values to set.
   */
  public void setDurations(List<Duration> durations);
  
  /**
   * Set the inAlbum property values for this MusicRecording object; overwriting any existing values.
   *
   * @param inAlbums The list of values to set.
   */
  public void setInAlbums(List<MusicAlbum> inAlbums);
  
  /**
   * Set the inPlaylist property values for this MusicRecording object; overwriting any existing values.
   *
   * @param inPlaylists The list of values to set.
   */
  public void setInPlaylists(List<MusicPlaylist> inPlaylists);
  
  /**
   * Adds a byArtist property value for this MusicRecording object; appending it to the list of existing values.
   *
   * @param byArtist The value to add.
   */
  public void addByArtist(MusicGroup byArtist);
  
  /**
   * Adds a duration property value for this MusicRecording object; appending it to the list of existing values.
   *
   * @param duration The value to add.
   */
  public void addDuration(Duration duration);
  
  /**
   * Adds a inAlbum property value for this MusicRecording object; appending it to the list of existing values.
   *
   * @param inAlbum The value to add.
   */
  public void addInAlbum(MusicAlbum inAlbum);
  
  /**
   * Adds a inPlaylist property value for this MusicRecording object; appending it to the list of existing values.
   *
   * @param inPlaylist The value to add.
   */
  public void addInPlaylist(MusicPlaylist inPlaylist);
  
}