package org.schema;

import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.BrainStructure;
import org.schema.Muscle;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A common pathway for the electrochemical nerve impulses that are transmitted along each of the axons.
 */
public interface Nerve extends AnatomicalStructure, SchemaObject {

  /**
   * Get a single branch property value for this Nerve object.
   *
   * @return The first branch property value.
   */
  public Thing getBranch();
  
  /**
   * Get a single nerveMotor property value for this Nerve object.
   *
   * @return The first nerveMotor property value.
   */
  public Muscle getNerveMotor();
  
  /**
   * Get a single sensoryUnit property value for this Nerve object.
   *
   * @return The first sensoryUnit property value.
   */
  public Thing getSensoryUnit();
  
  /**
   * Get a single sourcedFrom property value for this Nerve object.
   *
   * @return The first sourcedFrom property value.
   */
  public BrainStructure getSourcedFrom();
  
  /**
   * Get all the branch property values for this Nerve object.
   *
   * @return A list of branch property values.
   */
  public List<Thing> getBranches();
  
  /**
   * Get all the nerveMotor property values for this Nerve object.
   *
   * @return A list of nerveMotor property values.
   */
  public List<Muscle> getNerveMotors();
  
  /**
   * Get all the sensoryUnit property values for this Nerve object.
   *
   * @return A list of sensoryUnit property values.
   */
  public List<Thing> getSensoryUnits();
  
  /**
   * Get all the sourcedFrom property values for this Nerve object.
   *
   * @return A list of sourcedFrom property values.
   */
  public List<BrainStructure> getSourcedFroms();
  
  /**
   * Set the branch property value for this Nerve object; overwriting any existing values.
   *
   * @param branch The value to set.
   */
  public void setBranch(Thing branch);
  
  /**
   * Set the nerveMotor property value for this Nerve object; overwriting any existing values.
   *
   * @param nerveMotor The value to set.
   */
  public void setNerveMotor(Muscle nerveMotor);
  
  /**
   * Set the sensoryUnit property value for this Nerve object; overwriting any existing values.
   *
   * @param sensoryUnit The value to set.
   */
  public void setSensoryUnit(Thing sensoryUnit);
  
  /**
   * Set the sourcedFrom property value for this Nerve object; overwriting any existing values.
   *
   * @param sourcedFrom The value to set.
   */
  public void setSourcedFrom(BrainStructure sourcedFrom);
  
  /**
   * Set the branch property values for this Nerve object; overwriting any existing values.
   *
   * @param branches The list of values to set.
   */
  public void setBranches(List<Thing> branches);
  
  /**
   * Set the nerveMotor property values for this Nerve object; overwriting any existing values.
   *
   * @param nerveMotors The list of values to set.
   */
  public void setNerveMotors(List<Muscle> nerveMotors);
  
  /**
   * Set the sensoryUnit property values for this Nerve object; overwriting any existing values.
   *
   * @param sensoryUnits The list of values to set.
   */
  public void setSensoryUnits(List<Thing> sensoryUnits);
  
  /**
   * Set the sourcedFrom property values for this Nerve object; overwriting any existing values.
   *
   * @param sourcedFroms The list of values to set.
   */
  public void setSourcedFroms(List<BrainStructure> sourcedFroms);
  
  /**
   * Adds a branch property value for this Nerve object; appending it to the list of existing values.
   *
   * @param branch The value to add.
   */
  public void addBranch(Thing branch);
  
  /**
   * Adds a nerveMotor property value for this Nerve object; appending it to the list of existing values.
   *
   * @param nerveMotor The value to add.
   */
  public void addNerveMotor(Muscle nerveMotor);
  
  /**
   * Adds a sensoryUnit property value for this Nerve object; appending it to the list of existing values.
   *
   * @param sensoryUnit The value to add.
   */
  public void addSensoryUnit(Thing sensoryUnit);
  
  /**
   * Adds a sourcedFrom property value for this Nerve object; appending it to the list of existing values.
   *
   * @param sourcedFrom The value to add.
   */
  public void addSourcedFrom(BrainStructure sourcedFrom);
  
}