package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Article;
import org.schema.SchemaObject;

/**
 * A news article
 */
public interface NewsArticle extends Article, SchemaObject {

  /**
   * Get a single dateline property value for this NewsArticle object.
   *
   * @return The first dateline property value.
   */
  public String getDateline();
  
  /**
   * Get a single printColumn property value for this NewsArticle object.
   *
   * @return The first printColumn property value.
   */
  public String getPrintColumn();
  
  /**
   * Get a single printEdition property value for this NewsArticle object.
   *
   * @return The first printEdition property value.
   */
  public String getPrintEdition();
  
  /**
   * Get a single printPage property value for this NewsArticle object.
   *
   * @return The first printPage property value.
   */
  public String getPrintPage();
  
  /**
   * Get a single printSection property value for this NewsArticle object.
   *
   * @return The first printSection property value.
   */
  public String getPrintSection();
  
  /**
   * Get all the dateline property values for this NewsArticle object.
   *
   * @return A list of dateline property values.
   */
  public List<String> getDatelines();
  
  /**
   * Get all the printColumn property values for this NewsArticle object.
   *
   * @return A list of printColumn property values.
   */
  public List<String> getPrintColumns();
  
  /**
   * Get all the printEdition property values for this NewsArticle object.
   *
   * @return A list of printEdition property values.
   */
  public List<String> getPrintEditions();
  
  /**
   * Get all the printPage property values for this NewsArticle object.
   *
   * @return A list of printPage property values.
   */
  public List<String> getPrintPages();
  
  /**
   * Get all the printSection property values for this NewsArticle object.
   *
   * @return A list of printSection property values.
   */
  public List<String> getPrintSections();
  
  /**
   * Set the dateline property value for this NewsArticle object; overwriting any existing values.
   *
   * @param dateline The value to set.
   */
  public void setDateline(String dateline);
  
  /**
   * Set the printColumn property value for this NewsArticle object; overwriting any existing values.
   *
   * @param printColumn The value to set.
   */
  public void setPrintColumn(String printColumn);
  
  /**
   * Set the printEdition property value for this NewsArticle object; overwriting any existing values.
   *
   * @param printEdition The value to set.
   */
  public void setPrintEdition(String printEdition);
  
  /**
   * Set the printPage property value for this NewsArticle object; overwriting any existing values.
   *
   * @param printPage The value to set.
   */
  public void setPrintPage(String printPage);
  
  /**
   * Set the printSection property value for this NewsArticle object; overwriting any existing values.
   *
   * @param printSection The value to set.
   */
  public void setPrintSection(String printSection);
  
  /**
   * Set the dateline property values for this NewsArticle object; overwriting any existing values.
   *
   * @param datelines The list of values to set.
   */
  public void setDatelines(List<String> datelines);
  
  /**
   * Set the printColumn property values for this NewsArticle object; overwriting any existing values.
   *
   * @param printColumns The list of values to set.
   */
  public void setPrintColumns(List<String> printColumns);
  
  /**
   * Set the printEdition property values for this NewsArticle object; overwriting any existing values.
   *
   * @param printEditions The list of values to set.
   */
  public void setPrintEditions(List<String> printEditions);
  
  /**
   * Set the printPage property values for this NewsArticle object; overwriting any existing values.
   *
   * @param printPages The list of values to set.
   */
  public void setPrintPages(List<String> printPages);
  
  /**
   * Set the printSection property values for this NewsArticle object; overwriting any existing values.
   *
   * @param printSections The list of values to set.
   */
  public void setPrintSections(List<String> printSections);
  
  /**
   * Adds a dateline property value for this NewsArticle object; appending it to the list of existing values.
   *
   * @param dateline The value to add.
   */
  public void addDateline(String dateline);
  
  /**
   * Adds a printColumn property value for this NewsArticle object; appending it to the list of existing values.
   *
   * @param printColumn The value to add.
   */
  public void addPrintColumn(String printColumn);
  
  /**
   * Adds a printEdition property value for this NewsArticle object; appending it to the list of existing values.
   *
   * @param printEdition The value to add.
   */
  public void addPrintEdition(String printEdition);
  
  /**
   * Adds a printPage property value for this NewsArticle object; appending it to the list of existing values.
   *
   * @param printPage The value to add.
   */
  public void addPrintPage(String printPage);
  
  /**
   * Adds a printSection property value for this NewsArticle object; appending it to the list of existing values.
   *
   * @param printSection The value to add.
   */
  public void addPrintSection(String printSection);
  
}