package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Energy;
import org.schema.Mass;
import org.schema.SchemaObject;
import org.schema.StructuredValue;

/**
 * Nutritional information about the recipe.
 */
public interface NutritionInformation extends StructuredValue, SchemaObject {

  /**
   * Get a single calories property value for this NutritionInformation object.
   *
   * @return The first calories property value.
   */
  public Energy getCalories();
  
  /**
   * Get a single carbohydrateContent property value for this NutritionInformation object.
   *
   * @return The first carbohydrateContent property value.
   */
  public Mass getCarbohydrateContent();
  
  /**
   * Get a single cholesterolContent property value for this NutritionInformation object.
   *
   * @return The first cholesterolContent property value.
   */
  public Mass getCholesterolContent();
  
  /**
   * Get a single fatContent property value for this NutritionInformation object.
   *
   * @return The first fatContent property value.
   */
  public Mass getFatContent();
  
  /**
   * Get a single fiberContent property value for this NutritionInformation object.
   *
   * @return The first fiberContent property value.
   */
  public Mass getFiberContent();
  
  /**
   * Get a single proteinContent property value for this NutritionInformation object.
   *
   * @return The first proteinContent property value.
   */
  public Mass getProteinContent();
  
  /**
   * Get a single saturatedFatContent property value for this NutritionInformation object.
   *
   * @return The first saturatedFatContent property value.
   */
  public Mass getSaturatedFatContent();
  
  /**
   * Get a single servingSize property value for this NutritionInformation object.
   *
   * @return The first servingSize property value.
   */
  public String getServingSize();
  
  /**
   * Get a single sodiumContent property value for this NutritionInformation object.
   *
   * @return The first sodiumContent property value.
   */
  public Mass getSodiumContent();
  
  /**
   * Get a single sugarContent property value for this NutritionInformation object.
   *
   * @return The first sugarContent property value.
   */
  public Mass getSugarContent();
  
  /**
   * Get a single transFatContent property value for this NutritionInformation object.
   *
   * @return The first transFatContent property value.
   */
  public Mass getTransFatContent();
  
  /**
   * Get a single unsaturatedFatContent property value for this NutritionInformation object.
   *
   * @return The first unsaturatedFatContent property value.
   */
  public Mass getUnsaturatedFatContent();
  
  /**
   * Get all the calories property values for this NutritionInformation object.
   *
   * @return A list of calories property values.
   */
  public List<Energy> getCaloriess();
  
  /**
   * Get all the carbohydrateContent property values for this NutritionInformation object.
   *
   * @return A list of carbohydrateContent property values.
   */
  public List<Mass> getCarbohydrateContents();
  
  /**
   * Get all the cholesterolContent property values for this NutritionInformation object.
   *
   * @return A list of cholesterolContent property values.
   */
  public List<Mass> getCholesterolContents();
  
  /**
   * Get all the fatContent property values for this NutritionInformation object.
   *
   * @return A list of fatContent property values.
   */
  public List<Mass> getFatContents();
  
  /**
   * Get all the fiberContent property values for this NutritionInformation object.
   *
   * @return A list of fiberContent property values.
   */
  public List<Mass> getFiberContents();
  
  /**
   * Get all the proteinContent property values for this NutritionInformation object.
   *
   * @return A list of proteinContent property values.
   */
  public List<Mass> getProteinContents();
  
  /**
   * Get all the saturatedFatContent property values for this NutritionInformation object.
   *
   * @return A list of saturatedFatContent property values.
   */
  public List<Mass> getSaturatedFatContents();
  
  /**
   * Get all the servingSize property values for this NutritionInformation object.
   *
   * @return A list of servingSize property values.
   */
  public List<String> getServingSizes();
  
  /**
   * Get all the sodiumContent property values for this NutritionInformation object.
   *
   * @return A list of sodiumContent property values.
   */
  public List<Mass> getSodiumContents();
  
  /**
   * Get all the sugarContent property values for this NutritionInformation object.
   *
   * @return A list of sugarContent property values.
   */
  public List<Mass> getSugarContents();
  
  /**
   * Get all the transFatContent property values for this NutritionInformation object.
   *
   * @return A list of transFatContent property values.
   */
  public List<Mass> getTransFatContents();
  
  /**
   * Get all the unsaturatedFatContent property values for this NutritionInformation object.
   *
   * @return A list of unsaturatedFatContent property values.
   */
  public List<Mass> getUnsaturatedFatContents();
  
  /**
   * Set the calories property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param calories The value to set.
   */
  public void setCalories(Energy calories);
  
  /**
   * Set the carbohydrateContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param carbohydrateContent The value to set.
   */
  public void setCarbohydrateContent(Mass carbohydrateContent);
  
  /**
   * Set the cholesterolContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param cholesterolContent The value to set.
   */
  public void setCholesterolContent(Mass cholesterolContent);
  
  /**
   * Set the fatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param fatContent The value to set.
   */
  public void setFatContent(Mass fatContent);
  
  /**
   * Set the fiberContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param fiberContent The value to set.
   */
  public void setFiberContent(Mass fiberContent);
  
  /**
   * Set the proteinContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param proteinContent The value to set.
   */
  public void setProteinContent(Mass proteinContent);
  
  /**
   * Set the saturatedFatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param saturatedFatContent The value to set.
   */
  public void setSaturatedFatContent(Mass saturatedFatContent);
  
  /**
   * Set the servingSize property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param servingSize The value to set.
   */
  public void setServingSize(String servingSize);
  
  /**
   * Set the sodiumContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param sodiumContent The value to set.
   */
  public void setSodiumContent(Mass sodiumContent);
  
  /**
   * Set the sugarContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param sugarContent The value to set.
   */
  public void setSugarContent(Mass sugarContent);
  
  /**
   * Set the transFatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param transFatContent The value to set.
   */
  public void setTransFatContent(Mass transFatContent);
  
  /**
   * Set the unsaturatedFatContent property value for this NutritionInformation object; overwriting any existing values.
   *
   * @param unsaturatedFatContent The value to set.
   */
  public void setUnsaturatedFatContent(Mass unsaturatedFatContent);
  
  /**
   * Set the calories property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param caloriess The list of values to set.
   */
  public void setCaloriess(List<Energy> caloriess);
  
  /**
   * Set the carbohydrateContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param carbohydrateContents The list of values to set.
   */
  public void setCarbohydrateContents(List<Mass> carbohydrateContents);
  
  /**
   * Set the cholesterolContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param cholesterolContents The list of values to set.
   */
  public void setCholesterolContents(List<Mass> cholesterolContents);
  
  /**
   * Set the fatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param fatContents The list of values to set.
   */
  public void setFatContents(List<Mass> fatContents);
  
  /**
   * Set the fiberContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param fiberContents The list of values to set.
   */
  public void setFiberContents(List<Mass> fiberContents);
  
  /**
   * Set the proteinContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param proteinContents The list of values to set.
   */
  public void setProteinContents(List<Mass> proteinContents);
  
  /**
   * Set the saturatedFatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param saturatedFatContents The list of values to set.
   */
  public void setSaturatedFatContents(List<Mass> saturatedFatContents);
  
  /**
   * Set the servingSize property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param servingSizes The list of values to set.
   */
  public void setServingSizes(List<String> servingSizes);
  
  /**
   * Set the sodiumContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param sodiumContents The list of values to set.
   */
  public void setSodiumContents(List<Mass> sodiumContents);
  
  /**
   * Set the sugarContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param sugarContents The list of values to set.
   */
  public void setSugarContents(List<Mass> sugarContents);
  
  /**
   * Set the transFatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param transFatContents The list of values to set.
   */
  public void setTransFatContents(List<Mass> transFatContents);
  
  /**
   * Set the unsaturatedFatContent property values for this NutritionInformation object; overwriting any existing values.
   *
   * @param unsaturatedFatContents The list of values to set.
   */
  public void setUnsaturatedFatContents(List<Mass> unsaturatedFatContents);
  
  /**
   * Adds a calories property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param calories The value to add.
   */
  public void addCalories(Energy calories);
  
  /**
   * Adds a carbohydrateContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param carbohydrateContent The value to add.
   */
  public void addCarbohydrateContent(Mass carbohydrateContent);
  
  /**
   * Adds a cholesterolContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param cholesterolContent The value to add.
   */
  public void addCholesterolContent(Mass cholesterolContent);
  
  /**
   * Adds a fatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param fatContent The value to add.
   */
  public void addFatContent(Mass fatContent);
  
  /**
   * Adds a fiberContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param fiberContent The value to add.
   */
  public void addFiberContent(Mass fiberContent);
  
  /**
   * Adds a proteinContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param proteinContent The value to add.
   */
  public void addProteinContent(Mass proteinContent);
  
  /**
   * Adds a saturatedFatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param saturatedFatContent The value to add.
   */
  public void addSaturatedFatContent(Mass saturatedFatContent);
  
  /**
   * Adds a servingSize property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param servingSize The value to add.
   */
  public void addServingSize(String servingSize);
  
  /**
   * Adds a sodiumContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param sodiumContent The value to add.
   */
  public void addSodiumContent(Mass sodiumContent);
  
  /**
   * Adds a sugarContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param sugarContent The value to add.
   */
  public void addSugarContent(Mass sugarContent);
  
  /**
   * Adds a transFatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param transFatContent The value to add.
   */
  public void addTransFatContent(Mass transFatContent);
  
  /**
   * Adds a unsaturatedFatContent property value for this NutritionInformation object; appending it to the list of existing values.
   *
   * @param unsaturatedFatContent The value to add.
   */
  public void addUnsaturatedFatContent(Mass unsaturatedFatContent);
  
}