package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.DayOfWeek;
import org.schema.SchemaObject;
import org.schema.StructuredValue;

/**
 * A structured value providing information about the opening hours of a place or a certain service inside a place.
 */
public interface OpeningHoursSpecification extends StructuredValue, SchemaObject {

  /**
   * Get a single closes property value for this OpeningHoursSpecification object.
   *
   * @return The first closes property value.
   */
  public Date getCloses();
  
  /**
   * Get a single dayOfWeek property value for this OpeningHoursSpecification object.
   *
   * @return The first dayOfWeek property value.
   */
  public DayOfWeek getDayOfWeek();
  
  /**
   * Get a single opens property value for this OpeningHoursSpecification object.
   *
   * @return The first opens property value.
   */
  public Date getOpens();
  
  /**
   * Get a single validFrom property value for this OpeningHoursSpecification object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom();
  
  /**
   * Get a single validThrough property value for this OpeningHoursSpecification object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough();
  
  /**
   * Get all the closes property values for this OpeningHoursSpecification object.
   *
   * @return A list of closes property values.
   */
  public List<Date> getClosess();
  
  /**
   * Get all the dayOfWeek property values for this OpeningHoursSpecification object.
   *
   * @return A list of dayOfWeek property values.
   */
  public List<DayOfWeek> getDayOfWeeks();
  
  /**
   * Get all the opens property values for this OpeningHoursSpecification object.
   *
   * @return A list of opens property values.
   */
  public List<Date> getOpenss();
  
  /**
   * Get all the validFrom property values for this OpeningHoursSpecification object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms();
  
  /**
   * Get all the validThrough property values for this OpeningHoursSpecification object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs();
  
  /**
   * Set the closes property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param closes The value to set.
   */
  public void setCloses(Date closes);
  
  /**
   * Set the dayOfWeek property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param dayOfWeek The value to set.
   */
  public void setDayOfWeek(DayOfWeek dayOfWeek);
  
  /**
   * Set the opens property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param opens The value to set.
   */
  public void setOpens(Date opens);
  
  /**
   * Set the validFrom property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom);
  
  /**
   * Set the validThrough property value for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough);
  
  /**
   * Set the closes property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param closess The list of values to set.
   */
  public void setClosess(List<Date> closess);
  
  /**
   * Set the dayOfWeek property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param dayOfWeeks The list of values to set.
   */
  public void setDayOfWeeks(List<DayOfWeek> dayOfWeeks);
  
  /**
   * Set the opens property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param openss The list of values to set.
   */
  public void setOpenss(List<Date> openss);
  
  /**
   * Set the validFrom property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms);
  
  /**
   * Set the validThrough property values for this OpeningHoursSpecification object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs);
  
  /**
   * Adds a closes property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param closes The value to add.
   */
  public void addCloses(Date closes);
  
  /**
   * Adds a dayOfWeek property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param dayOfWeek The value to add.
   */
  public void addDayOfWeek(DayOfWeek dayOfWeek);
  
  /**
   * Adds a opens property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param opens The value to add.
   */
  public void addOpens(Date opens);
  
  /**
   * Adds a validFrom property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom);
  
  /**
   * Adds a validThrough property value for this OpeningHoursSpecification object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough);
  
}