package org.schema;

import java.lang.Boolean;
import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.Intangible;
import org.schema.Offer;
import org.schema.OrderStatus;
import org.schema.PaymentMethod;
import org.schema.PostalAddress;
import org.schema.Product;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An order is a confirmation of a transaction (a receipt), which can contain multiple line items, each represented by an Offer that has been accepted by the customer.
 */
public interface Order extends Intangible, SchemaObject {

  /**
   * Get a single acceptedOffer property value for this Order object.
   *
   * @return The first acceptedOffer property value.
   */
  public Offer getAcceptedOffer();
  
  /**
   * Get a single billingAddress property value for this Order object.
   *
   * @return The first billingAddress property value.
   */
  public PostalAddress getBillingAddress();
  
  /**
   * Get a single confirmationNumber property value for this Order object.
   *
   * @return The first confirmationNumber property value.
   */
  public String getConfirmationNumber();
  
  /**
   * Get a single customer property value for this Order object.
   *
   * @return The first customer property value.
   */
  public Thing getCustomer();
  
  /**
   * Get a single discount property value for this Order object.
   *
   * @return The first discount property value.
   */
  public Thing getDiscount();
  
  /**
   * Get a single discountCode property value for this Order object.
   *
   * @return The first discountCode property value.
   */
  public String getDiscountCode();
  
  /**
   * Get a single discountCurrency property value for this Order object.
   *
   * @return The first discountCurrency property value.
   */
  public String getDiscountCurrency();
  
  /**
   * Get a single isGift property value for this Order object.
   *
   * @return The first isGift property value.
   */
  public Boolean getIsGift();
  
  /**
   * Get a single merchant property value for this Order object.
   *
   * @return The first merchant property value.
   */
  public Thing getMerchant();
  
  /**
   * Get a single orderDate property value for this Order object.
   *
   * @return The first orderDate property value.
   */
  public Date getOrderDate();
  
  /**
   * Get a single orderNumber property value for this Order object.
   *
   * @return The first orderNumber property value.
   */
  public String getOrderNumber();
  
  /**
   * Get a single orderStatus property value for this Order object.
   *
   * @return The first orderStatus property value.
   */
  public OrderStatus getOrderStatus();
  
  /**
   * Get a single orderedItem property value for this Order object.
   *
   * @return The first orderedItem property value.
   */
  public Product getOrderedItem();
  
  /**
   * Get a single paymentDue property value for this Order object.
   *
   * @return The first paymentDue property value.
   */
  public Date getPaymentDue();
  
  /**
   * Get a single paymentMethod property value for this Order object.
   *
   * @return The first paymentMethod property value.
   */
  public PaymentMethod getPaymentMethod();
  
  /**
   * Get a single paymentMethodId property value for this Order object.
   *
   * @return The first paymentMethodId property value.
   */
  public String getPaymentMethodId();
  
  /**
   * Get a single paymentUrl property value for this Order object.
   *
   * @return The first paymentUrl property value.
   */
  public URL getPaymentUrl();
  
  /**
   * Get all the acceptedOffer property values for this Order object.
   *
   * @return A list of acceptedOffer property values.
   */
  public List<Offer> getAcceptedOffers();
  
  /**
   * Get all the billingAddress property values for this Order object.
   *
   * @return A list of billingAddress property values.
   */
  public List<PostalAddress> getBillingAddresses();
  
  /**
   * Get all the confirmationNumber property values for this Order object.
   *
   * @return A list of confirmationNumber property values.
   */
  public List<String> getConfirmationNumbers();
  
  /**
   * Get all the customer property values for this Order object.
   *
   * @return A list of customer property values.
   */
  public List<Thing> getCustomers();
  
  /**
   * Get all the discount property values for this Order object.
   *
   * @return A list of discount property values.
   */
  public List<Thing> getDiscounts();
  
  /**
   * Get all the discountCode property values for this Order object.
   *
   * @return A list of discountCode property values.
   */
  public List<String> getDiscountCodes();
  
  /**
   * Get all the discountCurrency property values for this Order object.
   *
   * @return A list of discountCurrency property values.
   */
  public List<String> getDiscountCurrencies();
  
  /**
   * Get all the isGift property values for this Order object.
   *
   * @return A list of isGift property values.
   */
  public List<Boolean> getIsGifts();
  
  /**
   * Get all the merchant property values for this Order object.
   *
   * @return A list of merchant property values.
   */
  public List<Thing> getMerchants();
  
  /**
   * Get all the orderDate property values for this Order object.
   *
   * @return A list of orderDate property values.
   */
  public List<Date> getOrderDates();
  
  /**
   * Get all the orderNumber property values for this Order object.
   *
   * @return A list of orderNumber property values.
   */
  public List<String> getOrderNumbers();
  
  /**
   * Get all the orderStatus property values for this Order object.
   *
   * @return A list of orderStatus property values.
   */
  public List<OrderStatus> getOrderStatuses();
  
  /**
   * Get all the orderedItem property values for this Order object.
   *
   * @return A list of orderedItem property values.
   */
  public List<Product> getOrderedItems();
  
  /**
   * Get all the paymentDue property values for this Order object.
   *
   * @return A list of paymentDue property values.
   */
  public List<Date> getPaymentDues();
  
  /**
   * Get all the paymentMethod property values for this Order object.
   *
   * @return A list of paymentMethod property values.
   */
  public List<PaymentMethod> getPaymentMethods();
  
  /**
   * Get all the paymentMethodId property values for this Order object.
   *
   * @return A list of paymentMethodId property values.
   */
  public List<String> getPaymentMethodIds();
  
  /**
   * Get all the paymentUrl property values for this Order object.
   *
   * @return A list of paymentUrl property values.
   */
  public List<URL> getPaymentUrls();
  
  /**
   * Set the acceptedOffer property value for this Order object; overwriting any existing values.
   *
   * @param acceptedOffer The value to set.
   */
  public void setAcceptedOffer(Offer acceptedOffer);
  
  /**
   * Set the billingAddress property value for this Order object; overwriting any existing values.
   *
   * @param billingAddress The value to set.
   */
  public void setBillingAddress(PostalAddress billingAddress);
  
  /**
   * Set the confirmationNumber property value for this Order object; overwriting any existing values.
   *
   * @param confirmationNumber The value to set.
   */
  public void setConfirmationNumber(String confirmationNumber);
  
  /**
   * Set the customer property value for this Order object; overwriting any existing values.
   *
   * @param customer The value to set.
   */
  public void setCustomer(Thing customer);
  
  /**
   * Set the discount property value for this Order object; overwriting any existing values.
   *
   * @param discount The value to set.
   */
  public void setDiscount(Thing discount);
  
  /**
   * Set the discountCode property value for this Order object; overwriting any existing values.
   *
   * @param discountCode The value to set.
   */
  public void setDiscountCode(String discountCode);
  
  /**
   * Set the discountCurrency property value for this Order object; overwriting any existing values.
   *
   * @param discountCurrency The value to set.
   */
  public void setDiscountCurrency(String discountCurrency);
  
  /**
   * Set the isGift property value for this Order object; overwriting any existing values.
   *
   * @param isGift The value to set.
   */
  public void setIsGift(Boolean isGift);
  
  /**
   * Set the merchant property value for this Order object; overwriting any existing values.
   *
   * @param merchant The value to set.
   */
  public void setMerchant(Thing merchant);
  
  /**
   * Set the orderDate property value for this Order object; overwriting any existing values.
   *
   * @param orderDate The value to set.
   */
  public void setOrderDate(Date orderDate);
  
  /**
   * Set the orderNumber property value for this Order object; overwriting any existing values.
   *
   * @param orderNumber The value to set.
   */
  public void setOrderNumber(String orderNumber);
  
  /**
   * Set the orderStatus property value for this Order object; overwriting any existing values.
   *
   * @param orderStatus The value to set.
   */
  public void setOrderStatus(OrderStatus orderStatus);
  
  /**
   * Set the orderedItem property value for this Order object; overwriting any existing values.
   *
   * @param orderedItem The value to set.
   */
  public void setOrderedItem(Product orderedItem);
  
  /**
   * Set the paymentDue property value for this Order object; overwriting any existing values.
   *
   * @param paymentDue The value to set.
   */
  public void setPaymentDue(Date paymentDue);
  
  /**
   * Set the paymentMethod property value for this Order object; overwriting any existing values.
   *
   * @param paymentMethod The value to set.
   */
  public void setPaymentMethod(PaymentMethod paymentMethod);
  
  /**
   * Set the paymentMethodId property value for this Order object; overwriting any existing values.
   *
   * @param paymentMethodId The value to set.
   */
  public void setPaymentMethodId(String paymentMethodId);
  
  /**
   * Set the paymentUrl property value for this Order object; overwriting any existing values.
   *
   * @param paymentUrl The value to set.
   */
  public void setPaymentUrl(URL paymentUrl);
  
  /**
   * Set the acceptedOffer property values for this Order object; overwriting any existing values.
   *
   * @param acceptedOffers The list of values to set.
   */
  public void setAcceptedOffers(List<Offer> acceptedOffers);
  
  /**
   * Set the billingAddress property values for this Order object; overwriting any existing values.
   *
   * @param billingAddresses The list of values to set.
   */
  public void setBillingAddresses(List<PostalAddress> billingAddresses);
  
  /**
   * Set the confirmationNumber property values for this Order object; overwriting any existing values.
   *
   * @param confirmationNumbers The list of values to set.
   */
  public void setConfirmationNumbers(List<String> confirmationNumbers);
  
  /**
   * Set the customer property values for this Order object; overwriting any existing values.
   *
   * @param customers The list of values to set.
   */
  public void setCustomers(List<Thing> customers);
  
  /**
   * Set the discount property values for this Order object; overwriting any existing values.
   *
   * @param discounts The list of values to set.
   */
  public void setDiscounts(List<Thing> discounts);
  
  /**
   * Set the discountCode property values for this Order object; overwriting any existing values.
   *
   * @param discountCodes The list of values to set.
   */
  public void setDiscountCodes(List<String> discountCodes);
  
  /**
   * Set the discountCurrency property values for this Order object; overwriting any existing values.
   *
   * @param discountCurrencies The list of values to set.
   */
  public void setDiscountCurrencies(List<String> discountCurrencies);
  
  /**
   * Set the isGift property values for this Order object; overwriting any existing values.
   *
   * @param isGifts The list of values to set.
   */
  public void setIsGifts(List<Boolean> isGifts);
  
  /**
   * Set the merchant property values for this Order object; overwriting any existing values.
   *
   * @param merchants The list of values to set.
   */
  public void setMerchants(List<Thing> merchants);
  
  /**
   * Set the orderDate property values for this Order object; overwriting any existing values.
   *
   * @param orderDates The list of values to set.
   */
  public void setOrderDates(List<Date> orderDates);
  
  /**
   * Set the orderNumber property values for this Order object; overwriting any existing values.
   *
   * @param orderNumbers The list of values to set.
   */
  public void setOrderNumbers(List<String> orderNumbers);
  
  /**
   * Set the orderStatus property values for this Order object; overwriting any existing values.
   *
   * @param orderStatuses The list of values to set.
   */
  public void setOrderStatuses(List<OrderStatus> orderStatuses);
  
  /**
   * Set the orderedItem property values for this Order object; overwriting any existing values.
   *
   * @param orderedItems The list of values to set.
   */
  public void setOrderedItems(List<Product> orderedItems);
  
  /**
   * Set the paymentDue property values for this Order object; overwriting any existing values.
   *
   * @param paymentDues The list of values to set.
   */
  public void setPaymentDues(List<Date> paymentDues);
  
  /**
   * Set the paymentMethod property values for this Order object; overwriting any existing values.
   *
   * @param paymentMethods The list of values to set.
   */
  public void setPaymentMethods(List<PaymentMethod> paymentMethods);
  
  /**
   * Set the paymentMethodId property values for this Order object; overwriting any existing values.
   *
   * @param paymentMethodIds The list of values to set.
   */
  public void setPaymentMethodIds(List<String> paymentMethodIds);
  
  /**
   * Set the paymentUrl property values for this Order object; overwriting any existing values.
   *
   * @param paymentUrls The list of values to set.
   */
  public void setPaymentUrls(List<URL> paymentUrls);
  
  /**
   * Adds a acceptedOffer property value for this Order object; appending it to the list of existing values.
   *
   * @param acceptedOffer The value to add.
   */
  public void addAcceptedOffer(Offer acceptedOffer);
  
  /**
   * Adds a billingAddress property value for this Order object; appending it to the list of existing values.
   *
   * @param billingAddress The value to add.
   */
  public void addBillingAddress(PostalAddress billingAddress);
  
  /**
   * Adds a confirmationNumber property value for this Order object; appending it to the list of existing values.
   *
   * @param confirmationNumber The value to add.
   */
  public void addConfirmationNumber(String confirmationNumber);
  
  /**
   * Adds a customer property value for this Order object; appending it to the list of existing values.
   *
   * @param customer The value to add.
   */
  public void addCustomer(Thing customer);
  
  /**
   * Adds a discount property value for this Order object; appending it to the list of existing values.
   *
   * @param discount The value to add.
   */
  public void addDiscount(Thing discount);
  
  /**
   * Adds a discountCode property value for this Order object; appending it to the list of existing values.
   *
   * @param discountCode The value to add.
   */
  public void addDiscountCode(String discountCode);
  
  /**
   * Adds a discountCurrency property value for this Order object; appending it to the list of existing values.
   *
   * @param discountCurrency The value to add.
   */
  public void addDiscountCurrency(String discountCurrency);
  
  /**
   * Adds a isGift property value for this Order object; appending it to the list of existing values.
   *
   * @param isGift The value to add.
   */
  public void addIsGift(Boolean isGift);
  
  /**
   * Adds a merchant property value for this Order object; appending it to the list of existing values.
   *
   * @param merchant The value to add.
   */
  public void addMerchant(Thing merchant);
  
  /**
   * Adds a orderDate property value for this Order object; appending it to the list of existing values.
   *
   * @param orderDate The value to add.
   */
  public void addOrderDate(Date orderDate);
  
  /**
   * Adds a orderNumber property value for this Order object; appending it to the list of existing values.
   *
   * @param orderNumber The value to add.
   */
  public void addOrderNumber(String orderNumber);
  
  /**
   * Adds a orderStatus property value for this Order object; appending it to the list of existing values.
   *
   * @param orderStatus The value to add.
   */
  public void addOrderStatus(OrderStatus orderStatus);
  
  /**
   * Adds a orderedItem property value for this Order object; appending it to the list of existing values.
   *
   * @param orderedItem The value to add.
   */
  public void addOrderedItem(Product orderedItem);
  
  /**
   * Adds a paymentDue property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentDue The value to add.
   */
  public void addPaymentDue(Date paymentDue);
  
  /**
   * Adds a paymentMethod property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentMethod The value to add.
   */
  public void addPaymentMethod(PaymentMethod paymentMethod);
  
  /**
   * Adds a paymentMethodId property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentMethodId The value to add.
   */
  public void addPaymentMethodId(String paymentMethodId);
  
  /**
   * Adds a paymentUrl property value for this Order object; appending it to the list of existing values.
   *
   * @param paymentUrl The value to add.
   */
  public void addPaymentUrl(URL paymentUrl);
  
}