package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.ContactPoint;
import org.schema.Demand;
import org.schema.Event;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Review;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * An organization such as a school, NGO, corporation, club, etc.
 */
public interface Organization extends Thing, SchemaObject {

  /**
   * Get a single address property value for this Organization object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress();
  
  /**
   * Get a single aggregateRating property value for this Organization object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating();
  
  /**
   * Get a single brand property value for this Organization object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand();
  
  /**
   * Get a single contactPoint property value for this Organization object.
   *
   * @return The first contactPoint property value.
   */
  public ContactPoint getContactPoint();
  
  /**
   * Get a single department property value for this Organization object.
   *
   * @return The first department property value.
   */
  public Organization getDepartment();
  
  /**
   * Get a single duns property value for this Organization object.
   *
   * @return The first duns property value.
   */
  public String getDuns();
  
  /**
   * Get a single email property value for this Organization object.
   *
   * @return The first email property value.
   */
  public String getEmail();
  
  /**
   * Get a single employee property value for this Organization object.
   *
   * @return The first employee property value.
   */
  public Person getEmployee();
  
  /**
   * Get a single event property value for this Organization object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get a single faxNumber property value for this Organization object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber();
  
  /**
   * Get a single founder property value for this Organization object.
   *
   * @return The first founder property value.
   */
  public Person getFounder();
  
  /**
   * Get a single foundingDate property value for this Organization object.
   *
   * @return The first foundingDate property value.
   */
  public Date getFoundingDate();
  
  /**
   * Get a single globalLocationNumber property value for this Organization object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber();
  
  /**
   * Get a single hasPOS property value for this Organization object.
   *
   * @return The first hasPOS property value.
   */
  public Place getHasPOS();
  
  /**
   * Get a single interactionCount property value for this Organization object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount();
  
  /**
   * Get a single isicV4 property value for this Organization object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4();
  
  /**
   * Get a single legalName property value for this Organization object.
   *
   * @return The first legalName property value.
   */
  public String getLegalName();
  
  /**
   * Get a single location property value for this Organization object.
   *
   * @return The first location property value.
   */
  public Thing getLocation();
  
  /**
   * Get a single logo property value for this Organization object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo();
  
  /**
   * Get a single makesOffer property value for this Organization object.
   *
   * @return The first makesOffer property value.
   */
  public Offer getMakesOffer();
  
  /**
   * Get a single member property value for this Organization object.
   *
   * @return The first member property value.
   */
  public Thing getMember();
  
  /**
   * Get a single naics property value for this Organization object.
   *
   * @return The first naics property value.
   */
  public String getNaics();
  
  /**
   * Get a single owns property value for this Organization object.
   *
   * @return The first owns property value.
   */
  public Thing getOwns();
  
  /**
   * Get a single review property value for this Organization object.
   *
   * @return The first review property value.
   */
  public Review getReview();
  
  /**
   * Get a single seeks property value for this Organization object.
   *
   * @return The first seeks property value.
   */
  public Demand getSeeks();
  
  /**
   * Get a single subOrganization property value for this Organization object.
   *
   * @return The first subOrganization property value.
   */
  public Organization getSubOrganization();
  
  /**
   * Get a single taxID property value for this Organization object.
   *
   * @return The first taxID property value.
   */
  public String getTaxID();
  
  /**
   * Get a single telephone property value for this Organization object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone();
  
  /**
   * Get a single vatID property value for this Organization object.
   *
   * @return The first vatID property value.
   */
  public String getVatID();
  
  /**
   * Get all the address property values for this Organization object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses();
  
  /**
   * Get all the aggregateRating property values for this Organization object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings();
  
  /**
   * Get all the brand property values for this Organization object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands();
  
  /**
   * Get all the contactPoint property values for this Organization object.
   *
   * @return A list of contactPoint property values.
   */
  public List<ContactPoint> getContactPoints();
  
  /**
   * Get all the department property values for this Organization object.
   *
   * @return A list of department property values.
   */
  public List<Organization> getDepartments();
  
  /**
   * Get all the duns property values for this Organization object.
   *
   * @return A list of duns property values.
   */
  public List<String> getDunss();
  
  /**
   * Get all the email property values for this Organization object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails();
  
  /**
   * Get all the employee property values for this Organization object.
   *
   * @return A list of employee property values.
   */
  public List<Person> getEmployees();
  
  /**
   * Get all the event property values for this Organization object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Get all the faxNumber property values for this Organization object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers();
  
  /**
   * Get all the founder property values for this Organization object.
   *
   * @return A list of founder property values.
   */
  public List<Person> getFounders();
  
  /**
   * Get all the foundingDate property values for this Organization object.
   *
   * @return A list of foundingDate property values.
   */
  public List<Date> getFoundingDates();
  
  /**
   * Get all the globalLocationNumber property values for this Organization object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers();
  
  /**
   * Get all the hasPOS property values for this Organization object.
   *
   * @return A list of hasPOS property values.
   */
  public List<Place> getHasPOSs();
  
  /**
   * Get all the interactionCount property values for this Organization object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts();
  
  /**
   * Get all the isicV4 property values for this Organization object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s();
  
  /**
   * Get all the legalName property values for this Organization object.
   *
   * @return A list of legalName property values.
   */
  public List<String> getLegalNames();
  
  /**
   * Get all the location property values for this Organization object.
   *
   * @return A list of location property values.
   */
  public List<Thing> getLocations();
  
  /**
   * Get all the logo property values for this Organization object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes();
  
  /**
   * Get all the makesOffer property values for this Organization object.
   *
   * @return A list of makesOffer property values.
   */
  public List<Offer> getMakesOffers();
  
  /**
   * Get all the member property values for this Organization object.
   *
   * @return A list of member property values.
   */
  public List<Thing> getMembers();
  
  /**
   * Get all the naics property values for this Organization object.
   *
   * @return A list of naics property values.
   */
  public List<String> getNaicss();
  
  /**
   * Get all the owns property values for this Organization object.
   *
   * @return A list of owns property values.
   */
  public List<Thing> getOwnss();
  
  /**
   * Get all the review property values for this Organization object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews();
  
  /**
   * Get all the seeks property values for this Organization object.
   *
   * @return A list of seeks property values.
   */
  public List<Demand> getSeekss();
  
  /**
   * Get all the subOrganization property values for this Organization object.
   *
   * @return A list of subOrganization property values.
   */
  public List<Organization> getSubOrganizations();
  
  /**
   * Get all the taxID property values for this Organization object.
   *
   * @return A list of taxID property values.
   */
  public List<String> getTaxIDs();
  
  /**
   * Get all the telephone property values for this Organization object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones();
  
  /**
   * Get all the vatID property values for this Organization object.
   *
   * @return A list of vatID property values.
   */
  public List<String> getVatIDs();
  
  /**
   * Set the address property value for this Organization object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address);
  
  /**
   * Set the aggregateRating property value for this Organization object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Set the brand property value for this Organization object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand);
  
  /**
   * Set the contactPoint property value for this Organization object; overwriting any existing values.
   *
   * @param contactPoint The value to set.
   */
  public void setContactPoint(ContactPoint contactPoint);
  
  /**
   * Set the department property value for this Organization object; overwriting any existing values.
   *
   * @param department The value to set.
   */
  public void setDepartment(Organization department);
  
  /**
   * Set the duns property value for this Organization object; overwriting any existing values.
   *
   * @param duns The value to set.
   */
  public void setDuns(String duns);
  
  /**
   * Set the email property value for this Organization object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email);
  
  /**
   * Set the employee property value for this Organization object; overwriting any existing values.
   *
   * @param employee The value to set.
   */
  public void setEmployee(Person employee);
  
  /**
   * Set the event property value for this Organization object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the faxNumber property value for this Organization object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber);
  
  /**
   * Set the founder property value for this Organization object; overwriting any existing values.
   *
   * @param founder The value to set.
   */
  public void setFounder(Person founder);
  
  /**
   * Set the foundingDate property value for this Organization object; overwriting any existing values.
   *
   * @param foundingDate The value to set.
   */
  public void setFoundingDate(Date foundingDate);
  
  /**
   * Set the globalLocationNumber property value for this Organization object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber);
  
  /**
   * Set the hasPOS property value for this Organization object; overwriting any existing values.
   *
   * @param hasPOS The value to set.
   */
  public void setHasPOS(Place hasPOS);
  
  /**
   * Set the interactionCount property value for this Organization object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount);
  
  /**
   * Set the isicV4 property value for this Organization object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4);
  
  /**
   * Set the legalName property value for this Organization object; overwriting any existing values.
   *
   * @param legalName The value to set.
   */
  public void setLegalName(String legalName);
  
  /**
   * Set the location property value for this Organization object; overwriting any existing values.
   *
   * @param location The value to set.
   */
  public void setLocation(Thing location);
  
  /**
   * Set the logo property value for this Organization object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo);
  
  /**
   * Set the makesOffer property value for this Organization object; overwriting any existing values.
   *
   * @param makesOffer The value to set.
   */
  public void setMakesOffer(Offer makesOffer);
  
  /**
   * Set the member property value for this Organization object; overwriting any existing values.
   *
   * @param member The value to set.
   */
  public void setMember(Thing member);
  
  /**
   * Set the naics property value for this Organization object; overwriting any existing values.
   *
   * @param naics The value to set.
   */
  public void setNaics(String naics);
  
  /**
   * Set the owns property value for this Organization object; overwriting any existing values.
   *
   * @param owns The value to set.
   */
  public void setOwns(Thing owns);
  
  /**
   * Set the review property value for this Organization object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review);
  
  /**
   * Set the seeks property value for this Organization object; overwriting any existing values.
   *
   * @param seeks The value to set.
   */
  public void setSeeks(Demand seeks);
  
  /**
   * Set the subOrganization property value for this Organization object; overwriting any existing values.
   *
   * @param subOrganization The value to set.
   */
  public void setSubOrganization(Organization subOrganization);
  
  /**
   * Set the taxID property value for this Organization object; overwriting any existing values.
   *
   * @param taxID The value to set.
   */
  public void setTaxID(String taxID);
  
  /**
   * Set the telephone property value for this Organization object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone);
  
  /**
   * Set the vatID property value for this Organization object; overwriting any existing values.
   *
   * @param vatID The value to set.
   */
  public void setVatID(String vatID);
  
  /**
   * Set the address property values for this Organization object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses);
  
  /**
   * Set the aggregateRating property values for this Organization object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings);
  
  /**
   * Set the brand property values for this Organization object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands);
  
  /**
   * Set the contactPoint property values for this Organization object; overwriting any existing values.
   *
   * @param contactPoints The list of values to set.
   */
  public void setContactPoints(List<ContactPoint> contactPoints);
  
  /**
   * Set the department property values for this Organization object; overwriting any existing values.
   *
   * @param departments The list of values to set.
   */
  public void setDepartments(List<Organization> departments);
  
  /**
   * Set the duns property values for this Organization object; overwriting any existing values.
   *
   * @param dunss The list of values to set.
   */
  public void setDunss(List<String> dunss);
  
  /**
   * Set the email property values for this Organization object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails);
  
  /**
   * Set the employee property values for this Organization object; overwriting any existing values.
   *
   * @param employees The list of values to set.
   */
  public void setEmployees(List<Person> employees);
  
  /**
   * Set the event property values for this Organization object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Set the faxNumber property values for this Organization object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers);
  
  /**
   * Set the founder property values for this Organization object; overwriting any existing values.
   *
   * @param founders The list of values to set.
   */
  public void setFounders(List<Person> founders);
  
  /**
   * Set the foundingDate property values for this Organization object; overwriting any existing values.
   *
   * @param foundingDates The list of values to set.
   */
  public void setFoundingDates(List<Date> foundingDates);
  
  /**
   * Set the globalLocationNumber property values for this Organization object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers);
  
  /**
   * Set the hasPOS property values for this Organization object; overwriting any existing values.
   *
   * @param hasPOSs The list of values to set.
   */
  public void setHasPOSs(List<Place> hasPOSs);
  
  /**
   * Set the interactionCount property values for this Organization object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts);
  
  /**
   * Set the isicV4 property values for this Organization object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s);
  
  /**
   * Set the legalName property values for this Organization object; overwriting any existing values.
   *
   * @param legalNames The list of values to set.
   */
  public void setLegalNames(List<String> legalNames);
  
  /**
   * Set the location property values for this Organization object; overwriting any existing values.
   *
   * @param locations The list of values to set.
   */
  public void setLocations(List<Thing> locations);
  
  /**
   * Set the logo property values for this Organization object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes);
  
  /**
   * Set the makesOffer property values for this Organization object; overwriting any existing values.
   *
   * @param makesOffers The list of values to set.
   */
  public void setMakesOffers(List<Offer> makesOffers);
  
  /**
   * Set the member property values for this Organization object; overwriting any existing values.
   *
   * @param members The list of values to set.
   */
  public void setMembers(List<Thing> members);
  
  /**
   * Set the naics property values for this Organization object; overwriting any existing values.
   *
   * @param naicss The list of values to set.
   */
  public void setNaicss(List<String> naicss);
  
  /**
   * Set the owns property values for this Organization object; overwriting any existing values.
   *
   * @param ownss The list of values to set.
   */
  public void setOwnss(List<Thing> ownss);
  
  /**
   * Set the review property values for this Organization object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews);
  
  /**
   * Set the seeks property values for this Organization object; overwriting any existing values.
   *
   * @param seekss The list of values to set.
   */
  public void setSeekss(List<Demand> seekss);
  
  /**
   * Set the subOrganization property values for this Organization object; overwriting any existing values.
   *
   * @param subOrganizations The list of values to set.
   */
  public void setSubOrganizations(List<Organization> subOrganizations);
  
  /**
   * Set the taxID property values for this Organization object; overwriting any existing values.
   *
   * @param taxIDs The list of values to set.
   */
  public void setTaxIDs(List<String> taxIDs);
  
  /**
   * Set the telephone property values for this Organization object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones);
  
  /**
   * Set the vatID property values for this Organization object; overwriting any existing values.
   *
   * @param vatIDs The list of values to set.
   */
  public void setVatIDs(List<String> vatIDs);
  
  /**
   * Adds a address property value for this Organization object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address);
  
  /**
   * Adds a aggregateRating property value for this Organization object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Adds a brand property value for this Organization object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand);
  
  /**
   * Adds a contactPoint property value for this Organization object; appending it to the list of existing values.
   *
   * @param contactPoint The value to add.
   */
  public void addContactPoint(ContactPoint contactPoint);
  
  /**
   * Adds a department property value for this Organization object; appending it to the list of existing values.
   *
   * @param department The value to add.
   */
  public void addDepartment(Organization department);
  
  /**
   * Adds a duns property value for this Organization object; appending it to the list of existing values.
   *
   * @param duns The value to add.
   */
  public void addDuns(String duns);
  
  /**
   * Adds a email property value for this Organization object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email);
  
  /**
   * Adds a employee property value for this Organization object; appending it to the list of existing values.
   *
   * @param employee The value to add.
   */
  public void addEmployee(Person employee);
  
  /**
   * Adds a event property value for this Organization object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
  /**
   * Adds a faxNumber property value for this Organization object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber);
  
  /**
   * Adds a founder property value for this Organization object; appending it to the list of existing values.
   *
   * @param founder The value to add.
   */
  public void addFounder(Person founder);
  
  /**
   * Adds a foundingDate property value for this Organization object; appending it to the list of existing values.
   *
   * @param foundingDate The value to add.
   */
  public void addFoundingDate(Date foundingDate);
  
  /**
   * Adds a globalLocationNumber property value for this Organization object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber);
  
  /**
   * Adds a hasPOS property value for this Organization object; appending it to the list of existing values.
   *
   * @param hasPOS The value to add.
   */
  public void addHasPOS(Place hasPOS);
  
  /**
   * Adds a interactionCount property value for this Organization object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount);
  
  /**
   * Adds a isicV4 property value for this Organization object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4);
  
  /**
   * Adds a legalName property value for this Organization object; appending it to the list of existing values.
   *
   * @param legalName The value to add.
   */
  public void addLegalName(String legalName);
  
  /**
   * Adds a location property value for this Organization object; appending it to the list of existing values.
   *
   * @param location The value to add.
   */
  public void addLocation(Thing location);
  
  /**
   * Adds a logo property value for this Organization object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo);
  
  /**
   * Adds a makesOffer property value for this Organization object; appending it to the list of existing values.
   *
   * @param makesOffer The value to add.
   */
  public void addMakesOffer(Offer makesOffer);
  
  /**
   * Adds a member property value for this Organization object; appending it to the list of existing values.
   *
   * @param member The value to add.
   */
  public void addMember(Thing member);
  
  /**
   * Adds a naics property value for this Organization object; appending it to the list of existing values.
   *
   * @param naics The value to add.
   */
  public void addNaics(String naics);
  
  /**
   * Adds a owns property value for this Organization object; appending it to the list of existing values.
   *
   * @param owns The value to add.
   */
  public void addOwns(Thing owns);
  
  /**
   * Adds a review property value for this Organization object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review);
  
  /**
   * Adds a seeks property value for this Organization object; appending it to the list of existing values.
   *
   * @param seeks The value to add.
   */
  public void addSeeks(Demand seeks);
  
  /**
   * Adds a subOrganization property value for this Organization object; appending it to the list of existing values.
   *
   * @param subOrganization The value to add.
   */
  public void addSubOrganization(Organization subOrganization);
  
  /**
   * Adds a taxID property value for this Organization object; appending it to the list of existing values.
   *
   * @param taxID The value to add.
   */
  public void addTaxID(String taxID);
  
  /**
   * Adds a telephone property value for this Organization object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone);
  
  /**
   * Adds a vatID property value for this Organization object; appending it to the list of existing values.
   *
   * @param vatID The value to add.
   */
  public void addVatID(String vatID);
  
}