package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.Product;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.Thing;

/**
 * A structured value providing information about when a certain organization or person owned a certain product.
 */
public interface OwnershipInfo extends StructuredValue, SchemaObject {

  /**
   * Get a single acquiredFrom property value for this OwnershipInfo object.
   *
   * @return The first acquiredFrom property value.
   */
  public Thing getAcquiredFrom();
  
  /**
   * Get a single ownedFrom property value for this OwnershipInfo object.
   *
   * @return The first ownedFrom property value.
   */
  public Date getOwnedFrom();
  
  /**
   * Get a single ownedThrough property value for this OwnershipInfo object.
   *
   * @return The first ownedThrough property value.
   */
  public Date getOwnedThrough();
  
  /**
   * Get a single typeOfGood property value for this OwnershipInfo object.
   *
   * @return The first typeOfGood property value.
   */
  public Product getTypeOfGood();
  
  /**
   * Get all the acquiredFrom property values for this OwnershipInfo object.
   *
   * @return A list of acquiredFrom property values.
   */
  public List<Thing> getAcquiredFroms();
  
  /**
   * Get all the ownedFrom property values for this OwnershipInfo object.
   *
   * @return A list of ownedFrom property values.
   */
  public List<Date> getOwnedFroms();
  
  /**
   * Get all the ownedThrough property values for this OwnershipInfo object.
   *
   * @return A list of ownedThrough property values.
   */
  public List<Date> getOwnedThroughs();
  
  /**
   * Get all the typeOfGood property values for this OwnershipInfo object.
   *
   * @return A list of typeOfGood property values.
   */
  public List<Product> getTypeOfGoods();
  
  /**
   * Set the acquiredFrom property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param acquiredFrom The value to set.
   */
  public void setAcquiredFrom(Thing acquiredFrom);
  
  /**
   * Set the ownedFrom property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedFrom The value to set.
   */
  public void setOwnedFrom(Date ownedFrom);
  
  /**
   * Set the ownedThrough property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedThrough The value to set.
   */
  public void setOwnedThrough(Date ownedThrough);
  
  /**
   * Set the typeOfGood property value for this OwnershipInfo object; overwriting any existing values.
   *
   * @param typeOfGood The value to set.
   */
  public void setTypeOfGood(Product typeOfGood);
  
  /**
   * Set the acquiredFrom property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param acquiredFroms The list of values to set.
   */
  public void setAcquiredFroms(List<Thing> acquiredFroms);
  
  /**
   * Set the ownedFrom property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedFroms The list of values to set.
   */
  public void setOwnedFroms(List<Date> ownedFroms);
  
  /**
   * Set the ownedThrough property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param ownedThroughs The list of values to set.
   */
  public void setOwnedThroughs(List<Date> ownedThroughs);
  
  /**
   * Set the typeOfGood property values for this OwnershipInfo object; overwriting any existing values.
   *
   * @param typeOfGoods The list of values to set.
   */
  public void setTypeOfGoods(List<Product> typeOfGoods);
  
  /**
   * Adds a acquiredFrom property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param acquiredFrom The value to add.
   */
  public void addAcquiredFrom(Thing acquiredFrom);
  
  /**
   * Adds a ownedFrom property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param ownedFrom The value to add.
   */
  public void addOwnedFrom(Date ownedFrom);
  
  /**
   * Adds a ownedThrough property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param ownedThrough The value to add.
   */
  public void addOwnedThrough(Date ownedThrough);
  
  /**
   * Adds a typeOfGood property value for this OwnershipInfo object; appending it to the list of existing values.
   *
   * @param typeOfGood The value to add.
   */
  public void addTypeOfGood(Product typeOfGood);
  
}