package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.DeliveryEvent;
import org.schema.DeliveryMethod;
import org.schema.Intangible;
import org.schema.Order;
import org.schema.PostalAddress;
import org.schema.Product;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The delivery of a parcel either via the postal service or a commercial service.
 */
public interface ParcelDelivery extends Intangible, SchemaObject {

  /**
   * Get a single carrier property value for this ParcelDelivery object.
   *
   * @return The first carrier property value.
   */
  public Thing getCarrier();
  
  /**
   * Get a single deliveryAddress property value for this ParcelDelivery object.
   *
   * @return The first deliveryAddress property value.
   */
  public PostalAddress getDeliveryAddress();
  
  /**
   * Get a single deliveryStatus property value for this ParcelDelivery object.
   *
   * @return The first deliveryStatus property value.
   */
  public DeliveryEvent getDeliveryStatus();
  
  /**
   * Get a single expectedArrivalFrom property value for this ParcelDelivery object.
   *
   * @return The first expectedArrivalFrom property value.
   */
  public Date getExpectedArrivalFrom();
  
  /**
   * Get a single expectedArrivalUntil property value for this ParcelDelivery object.
   *
   * @return The first expectedArrivalUntil property value.
   */
  public Date getExpectedArrivalUntil();
  
  /**
   * Get a single hasDeliveryMethod property value for this ParcelDelivery object.
   *
   * @return The first hasDeliveryMethod property value.
   */
  public DeliveryMethod getHasDeliveryMethod();
  
  /**
   * Get a single itemShipped property value for this ParcelDelivery object.
   *
   * @return The first itemShipped property value.
   */
  public Product getItemShipped();
  
  /**
   * Get a single originAddress property value for this ParcelDelivery object.
   *
   * @return The first originAddress property value.
   */
  public PostalAddress getOriginAddress();
  
  /**
   * Get a single partOfOrder property value for this ParcelDelivery object.
   *
   * @return The first partOfOrder property value.
   */
  public Order getPartOfOrder();
  
  /**
   * Get a single trackingNumber property value for this ParcelDelivery object.
   *
   * @return The first trackingNumber property value.
   */
  public String getTrackingNumber();
  
  /**
   * Get a single trackingUrl property value for this ParcelDelivery object.
   *
   * @return The first trackingUrl property value.
   */
  public URL getTrackingUrl();
  
  /**
   * Get all the carrier property values for this ParcelDelivery object.
   *
   * @return A list of carrier property values.
   */
  public List<Thing> getCarriers();
  
  /**
   * Get all the deliveryAddress property values for this ParcelDelivery object.
   *
   * @return A list of deliveryAddress property values.
   */
  public List<PostalAddress> getDeliveryAddresses();
  
  /**
   * Get all the deliveryStatus property values for this ParcelDelivery object.
   *
   * @return A list of deliveryStatus property values.
   */
  public List<DeliveryEvent> getDeliveryStatuses();
  
  /**
   * Get all the expectedArrivalFrom property values for this ParcelDelivery object.
   *
   * @return A list of expectedArrivalFrom property values.
   */
  public List<Date> getExpectedArrivalFroms();
  
  /**
   * Get all the expectedArrivalUntil property values for this ParcelDelivery object.
   *
   * @return A list of expectedArrivalUntil property values.
   */
  public List<Date> getExpectedArrivalUntils();
  
  /**
   * Get all the hasDeliveryMethod property values for this ParcelDelivery object.
   *
   * @return A list of hasDeliveryMethod property values.
   */
  public List<DeliveryMethod> getHasDeliveryMethods();
  
  /**
   * Get all the itemShipped property values for this ParcelDelivery object.
   *
   * @return A list of itemShipped property values.
   */
  public List<Product> getItemShippeds();
  
  /**
   * Get all the originAddress property values for this ParcelDelivery object.
   *
   * @return A list of originAddress property values.
   */
  public List<PostalAddress> getOriginAddresses();
  
  /**
   * Get all the partOfOrder property values for this ParcelDelivery object.
   *
   * @return A list of partOfOrder property values.
   */
  public List<Order> getPartOfOrders();
  
  /**
   * Get all the trackingNumber property values for this ParcelDelivery object.
   *
   * @return A list of trackingNumber property values.
   */
  public List<String> getTrackingNumbers();
  
  /**
   * Get all the trackingUrl property values for this ParcelDelivery object.
   *
   * @return A list of trackingUrl property values.
   */
  public List<URL> getTrackingUrls();
  
  /**
   * Set the carrier property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param carrier The value to set.
   */
  public void setCarrier(Thing carrier);
  
  /**
   * Set the deliveryAddress property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryAddress The value to set.
   */
  public void setDeliveryAddress(PostalAddress deliveryAddress);
  
  /**
   * Set the deliveryStatus property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryStatus The value to set.
   */
  public void setDeliveryStatus(DeliveryEvent deliveryStatus);
  
  /**
   * Set the expectedArrivalFrom property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalFrom The value to set.
   */
  public void setExpectedArrivalFrom(Date expectedArrivalFrom);
  
  /**
   * Set the expectedArrivalUntil property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalUntil The value to set.
   */
  public void setExpectedArrivalUntil(Date expectedArrivalUntil);
  
  /**
   * Set the hasDeliveryMethod property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param hasDeliveryMethod The value to set.
   */
  public void setHasDeliveryMethod(DeliveryMethod hasDeliveryMethod);
  
  /**
   * Set the itemShipped property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param itemShipped The value to set.
   */
  public void setItemShipped(Product itemShipped);
  
  /**
   * Set the originAddress property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param originAddress The value to set.
   */
  public void setOriginAddress(PostalAddress originAddress);
  
  /**
   * Set the partOfOrder property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param partOfOrder The value to set.
   */
  public void setPartOfOrder(Order partOfOrder);
  
  /**
   * Set the trackingNumber property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingNumber The value to set.
   */
  public void setTrackingNumber(String trackingNumber);
  
  /**
   * Set the trackingUrl property value for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingUrl The value to set.
   */
  public void setTrackingUrl(URL trackingUrl);
  
  /**
   * Set the carrier property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param carriers The list of values to set.
   */
  public void setCarriers(List<Thing> carriers);
  
  /**
   * Set the deliveryAddress property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryAddresses The list of values to set.
   */
  public void setDeliveryAddresses(List<PostalAddress> deliveryAddresses);
  
  /**
   * Set the deliveryStatus property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param deliveryStatuses The list of values to set.
   */
  public void setDeliveryStatuses(List<DeliveryEvent> deliveryStatuses);
  
  /**
   * Set the expectedArrivalFrom property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalFroms The list of values to set.
   */
  public void setExpectedArrivalFroms(List<Date> expectedArrivalFroms);
  
  /**
   * Set the expectedArrivalUntil property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param expectedArrivalUntils The list of values to set.
   */
  public void setExpectedArrivalUntils(List<Date> expectedArrivalUntils);
  
  /**
   * Set the hasDeliveryMethod property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param hasDeliveryMethods The list of values to set.
   */
  public void setHasDeliveryMethods(List<DeliveryMethod> hasDeliveryMethods);
  
  /**
   * Set the itemShipped property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param itemShippeds The list of values to set.
   */
  public void setItemShippeds(List<Product> itemShippeds);
  
  /**
   * Set the originAddress property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param originAddresses The list of values to set.
   */
  public void setOriginAddresses(List<PostalAddress> originAddresses);
  
  /**
   * Set the partOfOrder property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param partOfOrders The list of values to set.
   */
  public void setPartOfOrders(List<Order> partOfOrders);
  
  /**
   * Set the trackingNumber property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingNumbers The list of values to set.
   */
  public void setTrackingNumbers(List<String> trackingNumbers);
  
  /**
   * Set the trackingUrl property values for this ParcelDelivery object; overwriting any existing values.
   *
   * @param trackingUrls The list of values to set.
   */
  public void setTrackingUrls(List<URL> trackingUrls);
  
  /**
   * Adds a carrier property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param carrier The value to add.
   */
  public void addCarrier(Thing carrier);
  
  /**
   * Adds a deliveryAddress property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param deliveryAddress The value to add.
   */
  public void addDeliveryAddress(PostalAddress deliveryAddress);
  
  /**
   * Adds a deliveryStatus property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param deliveryStatus The value to add.
   */
  public void addDeliveryStatus(DeliveryEvent deliveryStatus);
  
  /**
   * Adds a expectedArrivalFrom property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param expectedArrivalFrom The value to add.
   */
  public void addExpectedArrivalFrom(Date expectedArrivalFrom);
  
  /**
   * Adds a expectedArrivalUntil property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param expectedArrivalUntil The value to add.
   */
  public void addExpectedArrivalUntil(Date expectedArrivalUntil);
  
  /**
   * Adds a hasDeliveryMethod property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param hasDeliveryMethod The value to add.
   */
  public void addHasDeliveryMethod(DeliveryMethod hasDeliveryMethod);
  
  /**
   * Adds a itemShipped property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param itemShipped The value to add.
   */
  public void addItemShipped(Product itemShipped);
  
  /**
   * Adds a originAddress property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param originAddress The value to add.
   */
  public void addOriginAddress(PostalAddress originAddress);
  
  /**
   * Adds a partOfOrder property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param partOfOrder The value to add.
   */
  public void addPartOfOrder(Order partOfOrder);
  
  /**
   * Adds a trackingNumber property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param trackingNumber The value to add.
   */
  public void addTrackingNumber(String trackingNumber);
  
  /**
   * Adds a trackingUrl property value for this ParcelDelivery object; appending it to the list of existing values.
   *
   * @param trackingUrl The value to add.
   */
  public void addTrackingUrl(URL trackingUrl);
  
}