package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TradeAction;

/**
 * An agent pays a price to a participant.
 */
public interface PayAction extends TradeAction, SchemaObject {

  /**
   * Get a single purpose property value for this PayAction object.
   *
   * @return The first purpose property value.
   */
  public Thing getPurpose();
  
  /**
   * Get a single recipient property value for this PayAction object.
   *
   * @return The first recipient property value.
   */
  public Thing getRecipient();
  
  /**
   * Get all the purpose property values for this PayAction object.
   *
   * @return A list of purpose property values.
   */
  public List<Thing> getPurposes();
  
  /**
   * Get all the recipient property values for this PayAction object.
   *
   * @return A list of recipient property values.
   */
  public List<Thing> getRecipients();
  
  /**
   * Set the purpose property value for this PayAction object; overwriting any existing values.
   *
   * @param purpose The value to set.
   */
  public void setPurpose(Thing purpose);
  
  /**
   * Set the recipient property value for this PayAction object; overwriting any existing values.
   *
   * @param recipient The value to set.
   */
  public void setRecipient(Thing recipient);
  
  /**
   * Set the purpose property values for this PayAction object; overwriting any existing values.
   *
   * @param purposes The list of values to set.
   */
  public void setPurposes(List<Thing> purposes);
  
  /**
   * Set the recipient property values for this PayAction object; overwriting any existing values.
   *
   * @param recipients The list of values to set.
   */
  public void setRecipients(List<Thing> recipients);
  
  /**
   * Adds a purpose property value for this PayAction object; appending it to the list of existing values.
   *
   * @param purpose The value to add.
   */
  public void addPurpose(Thing purpose);
  
  /**
   * Adds a recipient property value for this PayAction object; appending it to the list of existing values.
   *
   * @param recipient The value to add.
   */
  public void addRecipient(Thing recipient);
  
}