package org.schema;

import java.lang.Long;
import java.lang.String;
import java.util.List;
import org.schema.Audience;
import org.schema.MedicalCondition;
import org.schema.Number;
import org.schema.SchemaObject;

/**
 * A set of characteristics belonging to people, e.g. who compose an item's target audience.
 */
public interface PeopleAudience extends Audience, SchemaObject {

  /**
   * Get a single healthCondition property value for this PeopleAudience object.
   *
   * @return The first healthCondition property value.
   */
  public MedicalCondition getHealthCondition();
  
  /**
   * Get a single requiredGender property value for this PeopleAudience object.
   *
   * @return The first requiredGender property value.
   */
  public String getRequiredGender();
  
  /**
   * Get a single requiredMaxAge property value for this PeopleAudience object.
   *
   * @return The first requiredMaxAge property value.
   */
  public Long getRequiredMaxAge();
  
  /**
   * Get a single requiredMinAge property value for this PeopleAudience object.
   *
   * @return The first requiredMinAge property value.
   */
  public Long getRequiredMinAge();
  
  /**
   * Get a single suggestedGender property value for this PeopleAudience object.
   *
   * @return The first suggestedGender property value.
   */
  public String getSuggestedGender();
  
  /**
   * Get a single suggestedMaxAge property value for this PeopleAudience object.
   *
   * @return The first suggestedMaxAge property value.
   */
  public Number getSuggestedMaxAge();
  
  /**
   * Get a single suggestedMinAge property value for this PeopleAudience object.
   *
   * @return The first suggestedMinAge property value.
   */
  public Number getSuggestedMinAge();
  
  /**
   * Get all the healthCondition property values for this PeopleAudience object.
   *
   * @return A list of healthCondition property values.
   */
  public List<MedicalCondition> getHealthConditions();
  
  /**
   * Get all the requiredGender property values for this PeopleAudience object.
   *
   * @return A list of requiredGender property values.
   */
  public List<String> getRequiredGenders();
  
  /**
   * Get all the requiredMaxAge property values for this PeopleAudience object.
   *
   * @return A list of requiredMaxAge property values.
   */
  public List<Long> getRequiredMaxAges();
  
  /**
   * Get all the requiredMinAge property values for this PeopleAudience object.
   *
   * @return A list of requiredMinAge property values.
   */
  public List<Long> getRequiredMinAges();
  
  /**
   * Get all the suggestedGender property values for this PeopleAudience object.
   *
   * @return A list of suggestedGender property values.
   */
  public List<String> getSuggestedGenders();
  
  /**
   * Get all the suggestedMaxAge property values for this PeopleAudience object.
   *
   * @return A list of suggestedMaxAge property values.
   */
  public List<Number> getSuggestedMaxAges();
  
  /**
   * Get all the suggestedMinAge property values for this PeopleAudience object.
   *
   * @return A list of suggestedMinAge property values.
   */
  public List<Number> getSuggestedMinAges();
  
  /**
   * Set the healthCondition property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param healthCondition The value to set.
   */
  public void setHealthCondition(MedicalCondition healthCondition);
  
  /**
   * Set the requiredGender property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredGender The value to set.
   */
  public void setRequiredGender(String requiredGender);
  
  /**
   * Set the requiredMaxAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMaxAge The value to set.
   */
  public void setRequiredMaxAge(Long requiredMaxAge);
  
  /**
   * Set the requiredMinAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMinAge The value to set.
   */
  public void setRequiredMinAge(Long requiredMinAge);
  
  /**
   * Set the suggestedGender property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedGender The value to set.
   */
  public void setSuggestedGender(String suggestedGender);
  
  /**
   * Set the suggestedMaxAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMaxAge The value to set.
   */
  public void setSuggestedMaxAge(Number suggestedMaxAge);
  
  /**
   * Set the suggestedMinAge property value for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMinAge The value to set.
   */
  public void setSuggestedMinAge(Number suggestedMinAge);
  
  /**
   * Set the healthCondition property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param healthConditions The list of values to set.
   */
  public void setHealthConditions(List<MedicalCondition> healthConditions);
  
  /**
   * Set the requiredGender property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredGenders The list of values to set.
   */
  public void setRequiredGenders(List<String> requiredGenders);
  
  /**
   * Set the requiredMaxAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMaxAges The list of values to set.
   */
  public void setRequiredMaxAges(List<Long> requiredMaxAges);
  
  /**
   * Set the requiredMinAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param requiredMinAges The list of values to set.
   */
  public void setRequiredMinAges(List<Long> requiredMinAges);
  
  /**
   * Set the suggestedGender property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedGenders The list of values to set.
   */
  public void setSuggestedGenders(List<String> suggestedGenders);
  
  /**
   * Set the suggestedMaxAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMaxAges The list of values to set.
   */
  public void setSuggestedMaxAges(List<Number> suggestedMaxAges);
  
  /**
   * Set the suggestedMinAge property values for this PeopleAudience object; overwriting any existing values.
   *
   * @param suggestedMinAges The list of values to set.
   */
  public void setSuggestedMinAges(List<Number> suggestedMinAges);
  
  /**
   * Adds a healthCondition property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param healthCondition The value to add.
   */
  public void addHealthCondition(MedicalCondition healthCondition);
  
  /**
   * Adds a requiredGender property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param requiredGender The value to add.
   */
  public void addRequiredGender(String requiredGender);
  
  /**
   * Adds a requiredMaxAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param requiredMaxAge The value to add.
   */
  public void addRequiredMaxAge(Long requiredMaxAge);
  
  /**
   * Adds a requiredMinAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param requiredMinAge The value to add.
   */
  public void addRequiredMinAge(Long requiredMinAge);
  
  /**
   * Adds a suggestedGender property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param suggestedGender The value to add.
   */
  public void addSuggestedGender(String suggestedGender);
  
  /**
   * Adds a suggestedMaxAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param suggestedMaxAge The value to add.
   */
  public void addSuggestedMaxAge(Number suggestedMaxAge);
  
  /**
   * Adds a suggestedMinAge property value for this PeopleAudience object; appending it to the list of existing values.
   *
   * @param suggestedMinAge The value to add.
   */
  public void addSuggestedMinAge(Number suggestedMinAge);
  
}