package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.Audience;
import org.schema.Duration;
import org.schema.Intangible;
import org.schema.Organization;
import org.schema.SchemaObject;
import org.schema.Service;

/**
 * A permit issued by an organization, e.g. a parking pass.
 */
public interface Permit extends Intangible, SchemaObject {

  /**
   * Get a single issuedBy property value for this Permit object.
   *
   * @return The first issuedBy property value.
   */
  public Organization getIssuedBy();
  
  /**
   * Get a single issuedThrough property value for this Permit object.
   *
   * @return The first issuedThrough property value.
   */
  public Service getIssuedThrough();
  
  /**
   * Get a single permitAudience property value for this Permit object.
   *
   * @return The first permitAudience property value.
   */
  public Audience getPermitAudience();
  
  /**
   * Get a single validFor property value for this Permit object.
   *
   * @return The first validFor property value.
   */
  public Duration getValidFor();
  
  /**
   * Get a single validFrom property value for this Permit object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom();
  
  /**
   * Get a single validIn property value for this Permit object.
   *
   * @return The first validIn property value.
   */
  public AdministrativeArea getValidIn();
  
  /**
   * Get a single validUntil property value for this Permit object.
   *
   * @return The first validUntil property value.
   */
  public Date getValidUntil();
  
  /**
   * Get all the issuedBy property values for this Permit object.
   *
   * @return A list of issuedBy property values.
   */
  public List<Organization> getIssuedBies();
  
  /**
   * Get all the issuedThrough property values for this Permit object.
   *
   * @return A list of issuedThrough property values.
   */
  public List<Service> getIssuedThroughs();
  
  /**
   * Get all the permitAudience property values for this Permit object.
   *
   * @return A list of permitAudience property values.
   */
  public List<Audience> getPermitAudiences();
  
  /**
   * Get all the validFor property values for this Permit object.
   *
   * @return A list of validFor property values.
   */
  public List<Duration> getValidFors();
  
  /**
   * Get all the validFrom property values for this Permit object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms();
  
  /**
   * Get all the validIn property values for this Permit object.
   *
   * @return A list of validIn property values.
   */
  public List<AdministrativeArea> getValidsIn();
  
  /**
   * Get all the validUntil property values for this Permit object.
   *
   * @return A list of validUntil property values.
   */
  public List<Date> getValidUntils();
  
  /**
   * Set the issuedBy property value for this Permit object; overwriting any existing values.
   *
   * @param issuedBy The value to set.
   */
  public void setIssuedBy(Organization issuedBy);
  
  /**
   * Set the issuedThrough property value for this Permit object; overwriting any existing values.
   *
   * @param issuedThrough The value to set.
   */
  public void setIssuedThrough(Service issuedThrough);
  
  /**
   * Set the permitAudience property value for this Permit object; overwriting any existing values.
   *
   * @param permitAudience The value to set.
   */
  public void setPermitAudience(Audience permitAudience);
  
  /**
   * Set the validFor property value for this Permit object; overwriting any existing values.
   *
   * @param validFor The value to set.
   */
  public void setValidFor(Duration validFor);
  
  /**
   * Set the validFrom property value for this Permit object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom);
  
  /**
   * Set the validIn property value for this Permit object; overwriting any existing values.
   *
   * @param validIn The value to set.
   */
  public void setValidIn(AdministrativeArea validIn);
  
  /**
   * Set the validUntil property value for this Permit object; overwriting any existing values.
   *
   * @param validUntil The value to set.
   */
  public void setValidUntil(Date validUntil);
  
  /**
   * Set the issuedBy property values for this Permit object; overwriting any existing values.
   *
   * @param issuedBies The list of values to set.
   */
  public void setIssuedBies(List<Organization> issuedBies);
  
  /**
   * Set the issuedThrough property values for this Permit object; overwriting any existing values.
   *
   * @param issuedThroughs The list of values to set.
   */
  public void setIssuedThroughs(List<Service> issuedThroughs);
  
  /**
   * Set the permitAudience property values for this Permit object; overwriting any existing values.
   *
   * @param permitAudiences The list of values to set.
   */
  public void setPermitAudiences(List<Audience> permitAudiences);
  
  /**
   * Set the validFor property values for this Permit object; overwriting any existing values.
   *
   * @param validFors The list of values to set.
   */
  public void setValidFors(List<Duration> validFors);
  
  /**
   * Set the validFrom property values for this Permit object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms);
  
  /**
   * Set the validIn property values for this Permit object; overwriting any existing values.
   *
   * @param validsIn The list of values to set.
   */
  public void setValidsIn(List<AdministrativeArea> validsIn);
  
  /**
   * Set the validUntil property values for this Permit object; overwriting any existing values.
   *
   * @param validUntils The list of values to set.
   */
  public void setValidUntils(List<Date> validUntils);
  
  /**
   * Adds a issuedBy property value for this Permit object; appending it to the list of existing values.
   *
   * @param issuedBy The value to add.
   */
  public void addIssuedBy(Organization issuedBy);
  
  /**
   * Adds a issuedThrough property value for this Permit object; appending it to the list of existing values.
   *
   * @param issuedThrough The value to add.
   */
  public void addIssuedThrough(Service issuedThrough);
  
  /**
   * Adds a permitAudience property value for this Permit object; appending it to the list of existing values.
   *
   * @param permitAudience The value to add.
   */
  public void addPermitAudience(Audience permitAudience);
  
  /**
   * Adds a validFor property value for this Permit object; appending it to the list of existing values.
   *
   * @param validFor The value to add.
   */
  public void addValidFor(Duration validFor);
  
  /**
   * Adds a validFrom property value for this Permit object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom);
  
  /**
   * Adds a validIn property value for this Permit object; appending it to the list of existing values.
   *
   * @param validIn The value to add.
   */
  public void addValidIn(AdministrativeArea validIn);
  
  /**
   * Adds a validUntil property value for this Permit object; appending it to the list of existing values.
   *
   * @param validUntil The value to add.
   */
  public void addValidUntil(Date validUntil);
  
}