package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.ContactPoint;
import org.schema.Country;
import org.schema.Demand;
import org.schema.EducationalOrganization;
import org.schema.Event;
import org.schema.Offer;
import org.schema.Organization;
import org.schema.Person;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A person (alive, dead, undead, or fictional).
 */
public interface Person extends Thing, SchemaObject {

  /**
   * Get a single additionalName property value for this Person object.
   *
   * @return The first additionalName property value.
   */
  public String getAdditionalName();
  
  /**
   * Get a single address property value for this Person object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress();
  
  /**
   * Get a single affiliation property value for this Person object.
   *
   * @return The first affiliation property value.
   */
  public Organization getAffiliation();
  
  /**
   * Get a single alumniOf property value for this Person object.
   *
   * @return The first alumniOf property value.
   */
  public EducationalOrganization getAlumniOf();
  
  /**
   * Get a single award property value for this Person object.
   *
   * @return The first award property value.
   */
  public String getAward();
  
  /**
   * Get a single birthDate property value for this Person object.
   *
   * @return The first birthDate property value.
   */
  public Date getBirthDate();
  
  /**
   * Get a single brand property value for this Person object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand();
  
  /**
   * Get a single children property value for this Person object.
   *
   * @return The first children property value.
   */
  public Person getChildren();
  
  /**
   * Get a single colleague property value for this Person object.
   *
   * @return The first colleague property value.
   */
  public Person getColleague();
  
  /**
   * Get a single contactPoint property value for this Person object.
   *
   * @return The first contactPoint property value.
   */
  public ContactPoint getContactPoint();
  
  /**
   * Get a single deathDate property value for this Person object.
   *
   * @return The first deathDate property value.
   */
  public Date getDeathDate();
  
  /**
   * Get a single duns property value for this Person object.
   *
   * @return The first duns property value.
   */
  public String getDuns();
  
  /**
   * Get a single email property value for this Person object.
   *
   * @return The first email property value.
   */
  public String getEmail();
  
  /**
   * Get a single familyName property value for this Person object.
   *
   * @return The first familyName property value.
   */
  public String getFamilyName();
  
  /**
   * Get a single faxNumber property value for this Person object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber();
  
  /**
   * Get a single follows property value for this Person object.
   *
   * @return The first follows property value.
   */
  public Person getFollows();
  
  /**
   * Get a single gender property value for this Person object.
   *
   * @return The first gender property value.
   */
  public String getGender();
  
  /**
   * Get a single givenName property value for this Person object.
   *
   * @return The first givenName property value.
   */
  public String getGivenName();
  
  /**
   * Get a single globalLocationNumber property value for this Person object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber();
  
  /**
   * Get a single hasPOS property value for this Person object.
   *
   * @return The first hasPOS property value.
   */
  public Place getHasPOS();
  
  /**
   * Get a single homeLocation property value for this Person object.
   *
   * @return The first homeLocation property value.
   */
  public Thing getHomeLocation();
  
  /**
   * Get a single honorificPrefix property value for this Person object.
   *
   * @return The first honorificPrefix property value.
   */
  public String getHonorificPrefix();
  
  /**
   * Get a single honorificSuffix property value for this Person object.
   *
   * @return The first honorificSuffix property value.
   */
  public String getHonorificSuffix();
  
  /**
   * Get a single interactionCount property value for this Person object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount();
  
  /**
   * Get a single isicV4 property value for this Person object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4();
  
  /**
   * Get a single jobTitle property value for this Person object.
   *
   * @return The first jobTitle property value.
   */
  public String getJobTitle();
  
  /**
   * Get a single knows property value for this Person object.
   *
   * @return The first knows property value.
   */
  public Person getKnows();
  
  /**
   * Get a single makesOffer property value for this Person object.
   *
   * @return The first makesOffer property value.
   */
  public Offer getMakesOffer();
  
  /**
   * Get a single memberOf property value for this Person object.
   *
   * @return The first memberOf property value.
   */
  public Organization getMemberOf();
  
  /**
   * Get a single naics property value for this Person object.
   *
   * @return The first naics property value.
   */
  public String getNaics();
  
  /**
   * Get a single nationality property value for this Person object.
   *
   * @return The first nationality property value.
   */
  public Country getNationality();
  
  /**
   * Get a single owns property value for this Person object.
   *
   * @return The first owns property value.
   */
  public Thing getOwns();
  
  /**
   * Get a single parent property value for this Person object.
   *
   * @return The first parent property value.
   */
  public Person getParent();
  
  /**
   * Get a single performerIn property value for this Person object.
   *
   * @return The first performerIn property value.
   */
  public Event getPerformerIn();
  
  /**
   * Get a single relatedTo property value for this Person object.
   *
   * @return The first relatedTo property value.
   */
  public Person getRelatedTo();
  
  /**
   * Get a single seeks property value for this Person object.
   *
   * @return The first seeks property value.
   */
  public Demand getSeeks();
  
  /**
   * Get a single sibling property value for this Person object.
   *
   * @return The first sibling property value.
   */
  public Person getSibling();
  
  /**
   * Get a single spouse property value for this Person object.
   *
   * @return The first spouse property value.
   */
  public Person getSpouse();
  
  /**
   * Get a single taxID property value for this Person object.
   *
   * @return The first taxID property value.
   */
  public String getTaxID();
  
  /**
   * Get a single telephone property value for this Person object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone();
  
  /**
   * Get a single vatID property value for this Person object.
   *
   * @return The first vatID property value.
   */
  public String getVatID();
  
  /**
   * Get a single workLocation property value for this Person object.
   *
   * @return The first workLocation property value.
   */
  public Thing getWorkLocation();
  
  /**
   * Get a single worksFor property value for this Person object.
   *
   * @return The first worksFor property value.
   */
  public Organization getWorksFor();
  
  /**
   * Get all the additionalName property values for this Person object.
   *
   * @return A list of additionalName property values.
   */
  public List<String> getAdditionalNames();
  
  /**
   * Get all the address property values for this Person object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses();
  
  /**
   * Get all the affiliation property values for this Person object.
   *
   * @return A list of affiliation property values.
   */
  public List<Organization> getAffiliations();
  
  /**
   * Get all the alumniOf property values for this Person object.
   *
   * @return A list of alumniOf property values.
   */
  public List<EducationalOrganization> getAlumnisOf();
  
  /**
   * Get all the award property values for this Person object.
   *
   * @return A list of award property values.
   */
  public List<String> getAwards();
  
  /**
   * Get all the birthDate property values for this Person object.
   *
   * @return A list of birthDate property values.
   */
  public List<Date> getBirthDates();
  
  /**
   * Get all the brand property values for this Person object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands();
  
  /**
   * Get all the children property values for this Person object.
   *
   * @return A list of children property values.
   */
  public List<Person> getChildrens();
  
  /**
   * Get all the colleague property values for this Person object.
   *
   * @return A list of colleague property values.
   */
  public List<Person> getColleagues();
  
  /**
   * Get all the contactPoint property values for this Person object.
   *
   * @return A list of contactPoint property values.
   */
  public List<ContactPoint> getContactPoints();
  
  /**
   * Get all the deathDate property values for this Person object.
   *
   * @return A list of deathDate property values.
   */
  public List<Date> getDeathDates();
  
  /**
   * Get all the duns property values for this Person object.
   *
   * @return A list of duns property values.
   */
  public List<String> getDunss();
  
  /**
   * Get all the email property values for this Person object.
   *
   * @return A list of email property values.
   */
  public List<String> getEmails();
  
  /**
   * Get all the familyName property values for this Person object.
   *
   * @return A list of familyName property values.
   */
  public List<String> getFamilyNames();
  
  /**
   * Get all the faxNumber property values for this Person object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers();
  
  /**
   * Get all the follows property values for this Person object.
   *
   * @return A list of follows property values.
   */
  public List<Person> getFollowss();
  
  /**
   * Get all the gender property values for this Person object.
   *
   * @return A list of gender property values.
   */
  public List<String> getGenders();
  
  /**
   * Get all the givenName property values for this Person object.
   *
   * @return A list of givenName property values.
   */
  public List<String> getGivenNames();
  
  /**
   * Get all the globalLocationNumber property values for this Person object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers();
  
  /**
   * Get all the hasPOS property values for this Person object.
   *
   * @return A list of hasPOS property values.
   */
  public List<Place> getHasPOSs();
  
  /**
   * Get all the homeLocation property values for this Person object.
   *
   * @return A list of homeLocation property values.
   */
  public List<Thing> getHomeLocations();
  
  /**
   * Get all the honorificPrefix property values for this Person object.
   *
   * @return A list of honorificPrefix property values.
   */
  public List<String> getHonorificPrefixes();
  
  /**
   * Get all the honorificSuffix property values for this Person object.
   *
   * @return A list of honorificSuffix property values.
   */
  public List<String> getHonorificSuffixes();
  
  /**
   * Get all the interactionCount property values for this Person object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts();
  
  /**
   * Get all the isicV4 property values for this Person object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s();
  
  /**
   * Get all the jobTitle property values for this Person object.
   *
   * @return A list of jobTitle property values.
   */
  public List<String> getJobTitles();
  
  /**
   * Get all the knows property values for this Person object.
   *
   * @return A list of knows property values.
   */
  public List<Person> getKnowss();
  
  /**
   * Get all the makesOffer property values for this Person object.
   *
   * @return A list of makesOffer property values.
   */
  public List<Offer> getMakesOffers();
  
  /**
   * Get all the memberOf property values for this Person object.
   *
   * @return A list of memberOf property values.
   */
  public List<Organization> getMembersOf();
  
  /**
   * Get all the naics property values for this Person object.
   *
   * @return A list of naics property values.
   */
  public List<String> getNaicss();
  
  /**
   * Get all the nationality property values for this Person object.
   *
   * @return A list of nationality property values.
   */
  public List<Country> getNationalities();
  
  /**
   * Get all the owns property values for this Person object.
   *
   * @return A list of owns property values.
   */
  public List<Thing> getOwnss();
  
  /**
   * Get all the parent property values for this Person object.
   *
   * @return A list of parent property values.
   */
  public List<Person> getParents();
  
  /**
   * Get all the performerIn property values for this Person object.
   *
   * @return A list of performerIn property values.
   */
  public List<Event> getPerformersIn();
  
  /**
   * Get all the relatedTo property values for this Person object.
   *
   * @return A list of relatedTo property values.
   */
  public List<Person> getRelatedToes();
  
  /**
   * Get all the seeks property values for this Person object.
   *
   * @return A list of seeks property values.
   */
  public List<Demand> getSeekss();
  
  /**
   * Get all the sibling property values for this Person object.
   *
   * @return A list of sibling property values.
   */
  public List<Person> getSiblings();
  
  /**
   * Get all the spouse property values for this Person object.
   *
   * @return A list of spouse property values.
   */
  public List<Person> getSpouses();
  
  /**
   * Get all the taxID property values for this Person object.
   *
   * @return A list of taxID property values.
   */
  public List<String> getTaxIDs();
  
  /**
   * Get all the telephone property values for this Person object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones();
  
  /**
   * Get all the vatID property values for this Person object.
   *
   * @return A list of vatID property values.
   */
  public List<String> getVatIDs();
  
  /**
   * Get all the workLocation property values for this Person object.
   *
   * @return A list of workLocation property values.
   */
  public List<Thing> getWorkLocations();
  
  /**
   * Get all the worksFor property values for this Person object.
   *
   * @return A list of worksFor property values.
   */
  public List<Organization> getWorksFors();
  
  /**
   * Set the additionalName property value for this Person object; overwriting any existing values.
   *
   * @param additionalName The value to set.
   */
  public void setAdditionalName(String additionalName);
  
  /**
   * Set the address property value for this Person object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address);
  
  /**
   * Set the affiliation property value for this Person object; overwriting any existing values.
   *
   * @param affiliation The value to set.
   */
  public void setAffiliation(Organization affiliation);
  
  /**
   * Set the alumniOf property value for this Person object; overwriting any existing values.
   *
   * @param alumniOf The value to set.
   */
  public void setAlumniOf(EducationalOrganization alumniOf);
  
  /**
   * Set the award property value for this Person object; overwriting any existing values.
   *
   * @param award The value to set.
   */
  public void setAward(String award);
  
  /**
   * Set the birthDate property value for this Person object; overwriting any existing values.
   *
   * @param birthDate The value to set.
   */
  public void setBirthDate(Date birthDate);
  
  /**
   * Set the brand property value for this Person object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand);
  
  /**
   * Set the children property value for this Person object; overwriting any existing values.
   *
   * @param children The value to set.
   */
  public void setChildren(Person children);
  
  /**
   * Set the colleague property value for this Person object; overwriting any existing values.
   *
   * @param colleague The value to set.
   */
  public void setColleague(Person colleague);
  
  /**
   * Set the contactPoint property value for this Person object; overwriting any existing values.
   *
   * @param contactPoint The value to set.
   */
  public void setContactPoint(ContactPoint contactPoint);
  
  /**
   * Set the deathDate property value for this Person object; overwriting any existing values.
   *
   * @param deathDate The value to set.
   */
  public void setDeathDate(Date deathDate);
  
  /**
   * Set the duns property value for this Person object; overwriting any existing values.
   *
   * @param duns The value to set.
   */
  public void setDuns(String duns);
  
  /**
   * Set the email property value for this Person object; overwriting any existing values.
   *
   * @param email The value to set.
   */
  public void setEmail(String email);
  
  /**
   * Set the familyName property value for this Person object; overwriting any existing values.
   *
   * @param familyName The value to set.
   */
  public void setFamilyName(String familyName);
  
  /**
   * Set the faxNumber property value for this Person object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber);
  
  /**
   * Set the follows property value for this Person object; overwriting any existing values.
   *
   * @param follows The value to set.
   */
  public void setFollows(Person follows);
  
  /**
   * Set the gender property value for this Person object; overwriting any existing values.
   *
   * @param gender The value to set.
   */
  public void setGender(String gender);
  
  /**
   * Set the givenName property value for this Person object; overwriting any existing values.
   *
   * @param givenName The value to set.
   */
  public void setGivenName(String givenName);
  
  /**
   * Set the globalLocationNumber property value for this Person object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber);
  
  /**
   * Set the hasPOS property value for this Person object; overwriting any existing values.
   *
   * @param hasPOS The value to set.
   */
  public void setHasPOS(Place hasPOS);
  
  /**
   * Set the homeLocation property value for this Person object; overwriting any existing values.
   *
   * @param homeLocation The value to set.
   */
  public void setHomeLocation(Thing homeLocation);
  
  /**
   * Set the honorificPrefix property value for this Person object; overwriting any existing values.
   *
   * @param honorificPrefix The value to set.
   */
  public void setHonorificPrefix(String honorificPrefix);
  
  /**
   * Set the honorificSuffix property value for this Person object; overwriting any existing values.
   *
   * @param honorificSuffix The value to set.
   */
  public void setHonorificSuffix(String honorificSuffix);
  
  /**
   * Set the interactionCount property value for this Person object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount);
  
  /**
   * Set the isicV4 property value for this Person object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4);
  
  /**
   * Set the jobTitle property value for this Person object; overwriting any existing values.
   *
   * @param jobTitle The value to set.
   */
  public void setJobTitle(String jobTitle);
  
  /**
   * Set the knows property value for this Person object; overwriting any existing values.
   *
   * @param knows The value to set.
   */
  public void setKnows(Person knows);
  
  /**
   * Set the makesOffer property value for this Person object; overwriting any existing values.
   *
   * @param makesOffer The value to set.
   */
  public void setMakesOffer(Offer makesOffer);
  
  /**
   * Set the memberOf property value for this Person object; overwriting any existing values.
   *
   * @param memberOf The value to set.
   */
  public void setMemberOf(Organization memberOf);
  
  /**
   * Set the naics property value for this Person object; overwriting any existing values.
   *
   * @param naics The value to set.
   */
  public void setNaics(String naics);
  
  /**
   * Set the nationality property value for this Person object; overwriting any existing values.
   *
   * @param nationality The value to set.
   */
  public void setNationality(Country nationality);
  
  /**
   * Set the owns property value for this Person object; overwriting any existing values.
   *
   * @param owns The value to set.
   */
  public void setOwns(Thing owns);
  
  /**
   * Set the parent property value for this Person object; overwriting any existing values.
   *
   * @param parent The value to set.
   */
  public void setParent(Person parent);
  
  /**
   * Set the performerIn property value for this Person object; overwriting any existing values.
   *
   * @param performerIn The value to set.
   */
  public void setPerformerIn(Event performerIn);
  
  /**
   * Set the relatedTo property value for this Person object; overwriting any existing values.
   *
   * @param relatedTo The value to set.
   */
  public void setRelatedTo(Person relatedTo);
  
  /**
   * Set the seeks property value for this Person object; overwriting any existing values.
   *
   * @param seeks The value to set.
   */
  public void setSeeks(Demand seeks);
  
  /**
   * Set the sibling property value for this Person object; overwriting any existing values.
   *
   * @param sibling The value to set.
   */
  public void setSibling(Person sibling);
  
  /**
   * Set the spouse property value for this Person object; overwriting any existing values.
   *
   * @param spouse The value to set.
   */
  public void setSpouse(Person spouse);
  
  /**
   * Set the taxID property value for this Person object; overwriting any existing values.
   *
   * @param taxID The value to set.
   */
  public void setTaxID(String taxID);
  
  /**
   * Set the telephone property value for this Person object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone);
  
  /**
   * Set the vatID property value for this Person object; overwriting any existing values.
   *
   * @param vatID The value to set.
   */
  public void setVatID(String vatID);
  
  /**
   * Set the workLocation property value for this Person object; overwriting any existing values.
   *
   * @param workLocation The value to set.
   */
  public void setWorkLocation(Thing workLocation);
  
  /**
   * Set the worksFor property value for this Person object; overwriting any existing values.
   *
   * @param worksFor The value to set.
   */
  public void setWorksFor(Organization worksFor);
  
  /**
   * Set the additionalName property values for this Person object; overwriting any existing values.
   *
   * @param additionalNames The list of values to set.
   */
  public void setAdditionalNames(List<String> additionalNames);
  
  /**
   * Set the address property values for this Person object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses);
  
  /**
   * Set the affiliation property values for this Person object; overwriting any existing values.
   *
   * @param affiliations The list of values to set.
   */
  public void setAffiliations(List<Organization> affiliations);
  
  /**
   * Set the alumniOf property values for this Person object; overwriting any existing values.
   *
   * @param alumnisOf The list of values to set.
   */
  public void setAlumnisOf(List<EducationalOrganization> alumnisOf);
  
  /**
   * Set the award property values for this Person object; overwriting any existing values.
   *
   * @param awards The list of values to set.
   */
  public void setAwards(List<String> awards);
  
  /**
   * Set the birthDate property values for this Person object; overwriting any existing values.
   *
   * @param birthDates The list of values to set.
   */
  public void setBirthDates(List<Date> birthDates);
  
  /**
   * Set the brand property values for this Person object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands);
  
  /**
   * Set the children property values for this Person object; overwriting any existing values.
   *
   * @param childrens The list of values to set.
   */
  public void setChildrens(List<Person> childrens);
  
  /**
   * Set the colleague property values for this Person object; overwriting any existing values.
   *
   * @param colleagues The list of values to set.
   */
  public void setColleagues(List<Person> colleagues);
  
  /**
   * Set the contactPoint property values for this Person object; overwriting any existing values.
   *
   * @param contactPoints The list of values to set.
   */
  public void setContactPoints(List<ContactPoint> contactPoints);
  
  /**
   * Set the deathDate property values for this Person object; overwriting any existing values.
   *
   * @param deathDates The list of values to set.
   */
  public void setDeathDates(List<Date> deathDates);
  
  /**
   * Set the duns property values for this Person object; overwriting any existing values.
   *
   * @param dunss The list of values to set.
   */
  public void setDunss(List<String> dunss);
  
  /**
   * Set the email property values for this Person object; overwriting any existing values.
   *
   * @param emails The list of values to set.
   */
  public void setEmails(List<String> emails);
  
  /**
   * Set the familyName property values for this Person object; overwriting any existing values.
   *
   * @param familyNames The list of values to set.
   */
  public void setFamilyNames(List<String> familyNames);
  
  /**
   * Set the faxNumber property values for this Person object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers);
  
  /**
   * Set the follows property values for this Person object; overwriting any existing values.
   *
   * @param followss The list of values to set.
   */
  public void setFollowss(List<Person> followss);
  
  /**
   * Set the gender property values for this Person object; overwriting any existing values.
   *
   * @param genders The list of values to set.
   */
  public void setGenders(List<String> genders);
  
  /**
   * Set the givenName property values for this Person object; overwriting any existing values.
   *
   * @param givenNames The list of values to set.
   */
  public void setGivenNames(List<String> givenNames);
  
  /**
   * Set the globalLocationNumber property values for this Person object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers);
  
  /**
   * Set the hasPOS property values for this Person object; overwriting any existing values.
   *
   * @param hasPOSs The list of values to set.
   */
  public void setHasPOSs(List<Place> hasPOSs);
  
  /**
   * Set the homeLocation property values for this Person object; overwriting any existing values.
   *
   * @param homeLocations The list of values to set.
   */
  public void setHomeLocations(List<Thing> homeLocations);
  
  /**
   * Set the honorificPrefix property values for this Person object; overwriting any existing values.
   *
   * @param honorificPrefixes The list of values to set.
   */
  public void setHonorificPrefixes(List<String> honorificPrefixes);
  
  /**
   * Set the honorificSuffix property values for this Person object; overwriting any existing values.
   *
   * @param honorificSuffixes The list of values to set.
   */
  public void setHonorificSuffixes(List<String> honorificSuffixes);
  
  /**
   * Set the interactionCount property values for this Person object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts);
  
  /**
   * Set the isicV4 property values for this Person object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s);
  
  /**
   * Set the jobTitle property values for this Person object; overwriting any existing values.
   *
   * @param jobTitles The list of values to set.
   */
  public void setJobTitles(List<String> jobTitles);
  
  /**
   * Set the knows property values for this Person object; overwriting any existing values.
   *
   * @param knowss The list of values to set.
   */
  public void setKnowss(List<Person> knowss);
  
  /**
   * Set the makesOffer property values for this Person object; overwriting any existing values.
   *
   * @param makesOffers The list of values to set.
   */
  public void setMakesOffers(List<Offer> makesOffers);
  
  /**
   * Set the memberOf property values for this Person object; overwriting any existing values.
   *
   * @param membersOf The list of values to set.
   */
  public void setMembersOf(List<Organization> membersOf);
  
  /**
   * Set the naics property values for this Person object; overwriting any existing values.
   *
   * @param naicss The list of values to set.
   */
  public void setNaicss(List<String> naicss);
  
  /**
   * Set the nationality property values for this Person object; overwriting any existing values.
   *
   * @param nationalities The list of values to set.
   */
  public void setNationalities(List<Country> nationalities);
  
  /**
   * Set the owns property values for this Person object; overwriting any existing values.
   *
   * @param ownss The list of values to set.
   */
  public void setOwnss(List<Thing> ownss);
  
  /**
   * Set the parent property values for this Person object; overwriting any existing values.
   *
   * @param parents The list of values to set.
   */
  public void setParents(List<Person> parents);
  
  /**
   * Set the performerIn property values for this Person object; overwriting any existing values.
   *
   * @param performersIn The list of values to set.
   */
  public void setPerformersIn(List<Event> performersIn);
  
  /**
   * Set the relatedTo property values for this Person object; overwriting any existing values.
   *
   * @param relatedToes The list of values to set.
   */
  public void setRelatedToes(List<Person> relatedToes);
  
  /**
   * Set the seeks property values for this Person object; overwriting any existing values.
   *
   * @param seekss The list of values to set.
   */
  public void setSeekss(List<Demand> seekss);
  
  /**
   * Set the sibling property values for this Person object; overwriting any existing values.
   *
   * @param siblings The list of values to set.
   */
  public void setSiblings(List<Person> siblings);
  
  /**
   * Set the spouse property values for this Person object; overwriting any existing values.
   *
   * @param spouses The list of values to set.
   */
  public void setSpouses(List<Person> spouses);
  
  /**
   * Set the taxID property values for this Person object; overwriting any existing values.
   *
   * @param taxIDs The list of values to set.
   */
  public void setTaxIDs(List<String> taxIDs);
  
  /**
   * Set the telephone property values for this Person object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones);
  
  /**
   * Set the vatID property values for this Person object; overwriting any existing values.
   *
   * @param vatIDs The list of values to set.
   */
  public void setVatIDs(List<String> vatIDs);
  
  /**
   * Set the workLocation property values for this Person object; overwriting any existing values.
   *
   * @param workLocations The list of values to set.
   */
  public void setWorkLocations(List<Thing> workLocations);
  
  /**
   * Set the worksFor property values for this Person object; overwriting any existing values.
   *
   * @param worksFors The list of values to set.
   */
  public void setWorksFors(List<Organization> worksFors);
  
  /**
   * Adds a additionalName property value for this Person object; appending it to the list of existing values.
   *
   * @param additionalName The value to add.
   */
  public void addAdditionalName(String additionalName);
  
  /**
   * Adds a address property value for this Person object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address);
  
  /**
   * Adds a affiliation property value for this Person object; appending it to the list of existing values.
   *
   * @param affiliation The value to add.
   */
  public void addAffiliation(Organization affiliation);
  
  /**
   * Adds a alumniOf property value for this Person object; appending it to the list of existing values.
   *
   * @param alumniOf The value to add.
   */
  public void addAlumniOf(EducationalOrganization alumniOf);
  
  /**
   * Adds a award property value for this Person object; appending it to the list of existing values.
   *
   * @param award The value to add.
   */
  public void addAward(String award);
  
  /**
   * Adds a birthDate property value for this Person object; appending it to the list of existing values.
   *
   * @param birthDate The value to add.
   */
  public void addBirthDate(Date birthDate);
  
  /**
   * Adds a brand property value for this Person object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand);
  
  /**
   * Adds a children property value for this Person object; appending it to the list of existing values.
   *
   * @param children The value to add.
   */
  public void addChildren(Person children);
  
  /**
   * Adds a colleague property value for this Person object; appending it to the list of existing values.
   *
   * @param colleague The value to add.
   */
  public void addColleague(Person colleague);
  
  /**
   * Adds a contactPoint property value for this Person object; appending it to the list of existing values.
   *
   * @param contactPoint The value to add.
   */
  public void addContactPoint(ContactPoint contactPoint);
  
  /**
   * Adds a deathDate property value for this Person object; appending it to the list of existing values.
   *
   * @param deathDate The value to add.
   */
  public void addDeathDate(Date deathDate);
  
  /**
   * Adds a duns property value for this Person object; appending it to the list of existing values.
   *
   * @param duns The value to add.
   */
  public void addDuns(String duns);
  
  /**
   * Adds a email property value for this Person object; appending it to the list of existing values.
   *
   * @param email The value to add.
   */
  public void addEmail(String email);
  
  /**
   * Adds a familyName property value for this Person object; appending it to the list of existing values.
   *
   * @param familyName The value to add.
   */
  public void addFamilyName(String familyName);
  
  /**
   * Adds a faxNumber property value for this Person object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber);
  
  /**
   * Adds a follows property value for this Person object; appending it to the list of existing values.
   *
   * @param follows The value to add.
   */
  public void addFollows(Person follows);
  
  /**
   * Adds a gender property value for this Person object; appending it to the list of existing values.
   *
   * @param gender The value to add.
   */
  public void addGender(String gender);
  
  /**
   * Adds a givenName property value for this Person object; appending it to the list of existing values.
   *
   * @param givenName The value to add.
   */
  public void addGivenName(String givenName);
  
  /**
   * Adds a globalLocationNumber property value for this Person object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber);
  
  /**
   * Adds a hasPOS property value for this Person object; appending it to the list of existing values.
   *
   * @param hasPOS The value to add.
   */
  public void addHasPOS(Place hasPOS);
  
  /**
   * Adds a homeLocation property value for this Person object; appending it to the list of existing values.
   *
   * @param homeLocation The value to add.
   */
  public void addHomeLocation(Thing homeLocation);
  
  /**
   * Adds a honorificPrefix property value for this Person object; appending it to the list of existing values.
   *
   * @param honorificPrefix The value to add.
   */
  public void addHonorificPrefix(String honorificPrefix);
  
  /**
   * Adds a honorificSuffix property value for this Person object; appending it to the list of existing values.
   *
   * @param honorificSuffix The value to add.
   */
  public void addHonorificSuffix(String honorificSuffix);
  
  /**
   * Adds a interactionCount property value for this Person object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount);
  
  /**
   * Adds a isicV4 property value for this Person object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4);
  
  /**
   * Adds a jobTitle property value for this Person object; appending it to the list of existing values.
   *
   * @param jobTitle The value to add.
   */
  public void addJobTitle(String jobTitle);
  
  /**
   * Adds a knows property value for this Person object; appending it to the list of existing values.
   *
   * @param knows The value to add.
   */
  public void addKnows(Person knows);
  
  /**
   * Adds a makesOffer property value for this Person object; appending it to the list of existing values.
   *
   * @param makesOffer The value to add.
   */
  public void addMakesOffer(Offer makesOffer);
  
  /**
   * Adds a memberOf property value for this Person object; appending it to the list of existing values.
   *
   * @param memberOf The value to add.
   */
  public void addMemberOf(Organization memberOf);
  
  /**
   * Adds a naics property value for this Person object; appending it to the list of existing values.
   *
   * @param naics The value to add.
   */
  public void addNaics(String naics);
  
  /**
   * Adds a nationality property value for this Person object; appending it to the list of existing values.
   *
   * @param nationality The value to add.
   */
  public void addNationality(Country nationality);
  
  /**
   * Adds a owns property value for this Person object; appending it to the list of existing values.
   *
   * @param owns The value to add.
   */
  public void addOwns(Thing owns);
  
  /**
   * Adds a parent property value for this Person object; appending it to the list of existing values.
   *
   * @param parent The value to add.
   */
  public void addParent(Person parent);
  
  /**
   * Adds a performerIn property value for this Person object; appending it to the list of existing values.
   *
   * @param performerIn The value to add.
   */
  public void addPerformerIn(Event performerIn);
  
  /**
   * Adds a relatedTo property value for this Person object; appending it to the list of existing values.
   *
   * @param relatedTo The value to add.
   */
  public void addRelatedTo(Person relatedTo);
  
  /**
   * Adds a seeks property value for this Person object; appending it to the list of existing values.
   *
   * @param seeks The value to add.
   */
  public void addSeeks(Demand seeks);
  
  /**
   * Adds a sibling property value for this Person object; appending it to the list of existing values.
   *
   * @param sibling The value to add.
   */
  public void addSibling(Person sibling);
  
  /**
   * Adds a spouse property value for this Person object; appending it to the list of existing values.
   *
   * @param spouse The value to add.
   */
  public void addSpouse(Person spouse);
  
  /**
   * Adds a taxID property value for this Person object; appending it to the list of existing values.
   *
   * @param taxID The value to add.
   */
  public void addTaxID(String taxID);
  
  /**
   * Adds a telephone property value for this Person object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone);
  
  /**
   * Adds a vatID property value for this Person object; appending it to the list of existing values.
   *
   * @param vatID The value to add.
   */
  public void addVatID(String vatID);
  
  /**
   * Adds a workLocation property value for this Person object; appending it to the list of existing values.
   *
   * @param workLocation The value to add.
   */
  public void addWorkLocation(Thing workLocation);
  
  /**
   * Adds a worksFor property value for this Person object; appending it to the list of existing values.
   *
   * @param worksFor The value to add.
   */
  public void addWorksFor(Organization worksFor);
  
}