package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.LifestyleModification;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Any bodily activity that enhances or maintains physical fitness and overall health and wellness. Includes activity that is part of daily living and routine, structured exercise, and exercise prescribed as part of a medical treatment or recovery plan.
 */
public interface PhysicalActivity extends LifestyleModification, SchemaObject {

  /**
   * Get a single associatedAnatomy property value for this PhysicalActivity object.
   *
   * @return The first associatedAnatomy property value.
   */
  public Thing getAssociatedAnatomy();
  
  /**
   * Get a single category property value for this PhysicalActivity object.
   *
   * @return The first category property value.
   */
  public Thing getCategory();
  
  /**
   * Get a single epidemiology property value for this PhysicalActivity object.
   *
   * @return The first epidemiology property value.
   */
  public String getEpidemiology();
  
  /**
   * Get a single pathophysiology property value for this PhysicalActivity object.
   *
   * @return The first pathophysiology property value.
   */
  public String getPathophysiology();
  
  /**
   * Get all the associatedAnatomy property values for this PhysicalActivity object.
   *
   * @return A list of associatedAnatomy property values.
   */
  public List<Thing> getAssociatedAnatomies();
  
  /**
   * Get all the category property values for this PhysicalActivity object.
   *
   * @return A list of category property values.
   */
  public List<Thing> getCategories();
  
  /**
   * Get all the epidemiology property values for this PhysicalActivity object.
   *
   * @return A list of epidemiology property values.
   */
  public List<String> getEpidemiologies();
  
  /**
   * Get all the pathophysiology property values for this PhysicalActivity object.
   *
   * @return A list of pathophysiology property values.
   */
  public List<String> getPathophysiologies();
  
  /**
   * Set the associatedAnatomy property value for this PhysicalActivity object; overwriting any existing values.
   *
   * @param associatedAnatomy The value to set.
   */
  public void setAssociatedAnatomy(Thing associatedAnatomy);
  
  /**
   * Set the category property value for this PhysicalActivity object; overwriting any existing values.
   *
   * @param category The value to set.
   */
  public void setCategory(Thing category);
  
  /**
   * Set the epidemiology property value for this PhysicalActivity object; overwriting any existing values.
   *
   * @param epidemiology The value to set.
   */
  public void setEpidemiology(String epidemiology);
  
  /**
   * Set the pathophysiology property value for this PhysicalActivity object; overwriting any existing values.
   *
   * @param pathophysiology The value to set.
   */
  public void setPathophysiology(String pathophysiology);
  
  /**
   * Set the associatedAnatomy property values for this PhysicalActivity object; overwriting any existing values.
   *
   * @param associatedAnatomies The list of values to set.
   */
  public void setAssociatedAnatomies(List<Thing> associatedAnatomies);
  
  /**
   * Set the category property values for this PhysicalActivity object; overwriting any existing values.
   *
   * @param categories The list of values to set.
   */
  public void setCategories(List<Thing> categories);
  
  /**
   * Set the epidemiology property values for this PhysicalActivity object; overwriting any existing values.
   *
   * @param epidemiologies The list of values to set.
   */
  public void setEpidemiologies(List<String> epidemiologies);
  
  /**
   * Set the pathophysiology property values for this PhysicalActivity object; overwriting any existing values.
   *
   * @param pathophysiologies The list of values to set.
   */
  public void setPathophysiologies(List<String> pathophysiologies);
  
  /**
   * Adds a associatedAnatomy property value for this PhysicalActivity object; appending it to the list of existing values.
   *
   * @param associatedAnatomy The value to add.
   */
  public void addAssociatedAnatomy(Thing associatedAnatomy);
  
  /**
   * Adds a category property value for this PhysicalActivity object; appending it to the list of existing values.
   *
   * @param category The value to add.
   */
  public void addCategory(Thing category);
  
  /**
   * Adds a epidemiology property value for this PhysicalActivity object; appending it to the list of existing values.
   *
   * @param epidemiology The value to add.
   */
  public void addEpidemiology(String epidemiology);
  
  /**
   * Adds a pathophysiology property value for this PhysicalActivity object; appending it to the list of existing values.
   *
   * @param pathophysiology The value to add.
   */
  public void addPathophysiology(String pathophysiology);
  
}