package org.schema;

import java.util.List;
import org.schema.Hospital;
import org.schema.MedicalOrganization;
import org.schema.MedicalSpecialty;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A doctor's office.
 */
public interface Physician extends MedicalOrganization, SchemaObject {

  /**
   * Get a single availableService property value for this Physician object.
   *
   * @return The first availableService property value.
   */
  public Thing getAvailableService();
  
  /**
   * Get a single hospitalAffiliation property value for this Physician object.
   *
   * @return The first hospitalAffiliation property value.
   */
  public Hospital getHospitalAffiliation();
  
  /**
   * Get a single medicalSpecialty property value for this Physician object.
   *
   * @return The first medicalSpecialty property value.
   */
  public MedicalSpecialty getMedicalSpecialty();
  
  /**
   * Get all the availableService property values for this Physician object.
   *
   * @return A list of availableService property values.
   */
  public List<Thing> getAvailableServices();
  
  /**
   * Get all the hospitalAffiliation property values for this Physician object.
   *
   * @return A list of hospitalAffiliation property values.
   */
  public List<Hospital> getHospitalAffiliations();
  
  /**
   * Get all the medicalSpecialty property values for this Physician object.
   *
   * @return A list of medicalSpecialty property values.
   */
  public List<MedicalSpecialty> getMedicalSpecialties();
  
  /**
   * Set the availableService property value for this Physician object; overwriting any existing values.
   *
   * @param availableService The value to set.
   */
  public void setAvailableService(Thing availableService);
  
  /**
   * Set the hospitalAffiliation property value for this Physician object; overwriting any existing values.
   *
   * @param hospitalAffiliation The value to set.
   */
  public void setHospitalAffiliation(Hospital hospitalAffiliation);
  
  /**
   * Set the medicalSpecialty property value for this Physician object; overwriting any existing values.
   *
   * @param medicalSpecialty The value to set.
   */
  public void setMedicalSpecialty(MedicalSpecialty medicalSpecialty);
  
  /**
   * Set the availableService property values for this Physician object; overwriting any existing values.
   *
   * @param availableServices The list of values to set.
   */
  public void setAvailableServices(List<Thing> availableServices);
  
  /**
   * Set the hospitalAffiliation property values for this Physician object; overwriting any existing values.
   *
   * @param hospitalAffiliations The list of values to set.
   */
  public void setHospitalAffiliations(List<Hospital> hospitalAffiliations);
  
  /**
   * Set the medicalSpecialty property values for this Physician object; overwriting any existing values.
   *
   * @param medicalSpecialties The list of values to set.
   */
  public void setMedicalSpecialties(List<MedicalSpecialty> medicalSpecialties);
  
  /**
   * Adds a availableService property value for this Physician object; appending it to the list of existing values.
   *
   * @param availableService The value to add.
   */
  public void addAvailableService(Thing availableService);
  
  /**
   * Adds a hospitalAffiliation property value for this Physician object; appending it to the list of existing values.
   *
   * @param hospitalAffiliation The value to add.
   */
  public void addHospitalAffiliation(Hospital hospitalAffiliation);
  
  /**
   * Adds a medicalSpecialty property value for this Physician object; appending it to the list of existing values.
   *
   * @param medicalSpecialty The value to add.
   */
  public void addMedicalSpecialty(MedicalSpecialty medicalSpecialty);
  
}