package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.Event;
import org.schema.OpeningHoursSpecification;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.Review;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Entities that have a somewhat fixed, physical extension.
 */
public interface Place extends Thing, SchemaObject {

  /**
   * Get a single address property value for this Place object.
   *
   * @return The first address property value.
   */
  public PostalAddress getAddress();
  
  /**
   * Get a single aggregateRating property value for this Place object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating();
  
  /**
   * Get a single containedIn property value for this Place object.
   *
   * @return The first containedIn property value.
   */
  public Place getContainedIn();
  
  /**
   * Get a single event property value for this Place object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get a single faxNumber property value for this Place object.
   *
   * @return The first faxNumber property value.
   */
  public String getFaxNumber();
  
  /**
   * Get a single geo property value for this Place object.
   *
   * @return The first geo property value.
   */
  public Thing getGeo();
  
  /**
   * Get a single globalLocationNumber property value for this Place object.
   *
   * @return The first globalLocationNumber property value.
   */
  public String getGlobalLocationNumber();
  
  /**
   * Get a single interactionCount property value for this Place object.
   *
   * @return The first interactionCount property value.
   */
  public String getInteractionCount();
  
  /**
   * Get a single isicV4 property value for this Place object.
   *
   * @return The first isicV4 property value.
   */
  public String getIsicV4();
  
  /**
   * Get a single logo property value for this Place object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo();
  
  /**
   * Get a single map property value for this Place object.
   *
   * @return The first map property value.
   */
  public URL getMap();
  
  /**
   * Get a single openingHoursSpecification property value for this Place object.
   *
   * @return The first openingHoursSpecification property value.
   */
  public OpeningHoursSpecification getOpeningHoursSpecification();
  
  /**
   * Get a single photo property value for this Place object.
   *
   * @return The first photo property value.
   */
  public Thing getPhoto();
  
  /**
   * Get a single review property value for this Place object.
   *
   * @return The first review property value.
   */
  public Review getReview();
  
  /**
   * Get a single telephone property value for this Place object.
   *
   * @return The first telephone property value.
   */
  public String getTelephone();
  
  /**
   * Get all the address property values for this Place object.
   *
   * @return A list of address property values.
   */
  public List<PostalAddress> getAddresses();
  
  /**
   * Get all the aggregateRating property values for this Place object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings();
  
  /**
   * Get all the containedIn property values for this Place object.
   *
   * @return A list of containedIn property values.
   */
  public List<Place> getContainedsIn();
  
  /**
   * Get all the event property values for this Place object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Get all the faxNumber property values for this Place object.
   *
   * @return A list of faxNumber property values.
   */
  public List<String> getFaxNumbers();
  
  /**
   * Get all the geo property values for this Place object.
   *
   * @return A list of geo property values.
   */
  public List<Thing> getGeos();
  
  /**
   * Get all the globalLocationNumber property values for this Place object.
   *
   * @return A list of globalLocationNumber property values.
   */
  public List<String> getGlobalLocationNumbers();
  
  /**
   * Get all the interactionCount property values for this Place object.
   *
   * @return A list of interactionCount property values.
   */
  public List<String> getInteractionCounts();
  
  /**
   * Get all the isicV4 property values for this Place object.
   *
   * @return A list of isicV4 property values.
   */
  public List<String> getIsicV4s();
  
  /**
   * Get all the logo property values for this Place object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes();
  
  /**
   * Get all the map property values for this Place object.
   *
   * @return A list of map property values.
   */
  public List<URL> getMaps();
  
  /**
   * Get all the openingHoursSpecification property values for this Place object.
   *
   * @return A list of openingHoursSpecification property values.
   */
  public List<OpeningHoursSpecification> getOpeningHoursSpecifications();
  
  /**
   * Get all the photo property values for this Place object.
   *
   * @return A list of photo property values.
   */
  public List<Thing> getPhotos();
  
  /**
   * Get all the review property values for this Place object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews();
  
  /**
   * Get all the telephone property values for this Place object.
   *
   * @return A list of telephone property values.
   */
  public List<String> getTelephones();
  
  /**
   * Set the address property value for this Place object; overwriting any existing values.
   *
   * @param address The value to set.
   */
  public void setAddress(PostalAddress address);
  
  /**
   * Set the aggregateRating property value for this Place object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Set the containedIn property value for this Place object; overwriting any existing values.
   *
   * @param containedIn The value to set.
   */
  public void setContainedIn(Place containedIn);
  
  /**
   * Set the event property value for this Place object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the faxNumber property value for this Place object; overwriting any existing values.
   *
   * @param faxNumber The value to set.
   */
  public void setFaxNumber(String faxNumber);
  
  /**
   * Set the geo property value for this Place object; overwriting any existing values.
   *
   * @param geo The value to set.
   */
  public void setGeo(Thing geo);
  
  /**
   * Set the globalLocationNumber property value for this Place object; overwriting any existing values.
   *
   * @param globalLocationNumber The value to set.
   */
  public void setGlobalLocationNumber(String globalLocationNumber);
  
  /**
   * Set the interactionCount property value for this Place object; overwriting any existing values.
   *
   * @param interactionCount The value to set.
   */
  public void setInteractionCount(String interactionCount);
  
  /**
   * Set the isicV4 property value for this Place object; overwriting any existing values.
   *
   * @param isicV4 The value to set.
   */
  public void setIsicV4(String isicV4);
  
  /**
   * Set the logo property value for this Place object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo);
  
  /**
   * Set the map property value for this Place object; overwriting any existing values.
   *
   * @param map The value to set.
   */
  public void setMap(URL map);
  
  /**
   * Set the openingHoursSpecification property value for this Place object; overwriting any existing values.
   *
   * @param openingHoursSpecification The value to set.
   */
  public void setOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification);
  
  /**
   * Set the photo property value for this Place object; overwriting any existing values.
   *
   * @param photo The value to set.
   */
  public void setPhoto(Thing photo);
  
  /**
   * Set the review property value for this Place object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review);
  
  /**
   * Set the telephone property value for this Place object; overwriting any existing values.
   *
   * @param telephone The value to set.
   */
  public void setTelephone(String telephone);
  
  /**
   * Set the address property values for this Place object; overwriting any existing values.
   *
   * @param addresses The list of values to set.
   */
  public void setAddresses(List<PostalAddress> addresses);
  
  /**
   * Set the aggregateRating property values for this Place object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings);
  
  /**
   * Set the containedIn property values for this Place object; overwriting any existing values.
   *
   * @param containedsIn The list of values to set.
   */
  public void setContainedsIn(List<Place> containedsIn);
  
  /**
   * Set the event property values for this Place object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Set the faxNumber property values for this Place object; overwriting any existing values.
   *
   * @param faxNumbers The list of values to set.
   */
  public void setFaxNumbers(List<String> faxNumbers);
  
  /**
   * Set the geo property values for this Place object; overwriting any existing values.
   *
   * @param geos The list of values to set.
   */
  public void setGeos(List<Thing> geos);
  
  /**
   * Set the globalLocationNumber property values for this Place object; overwriting any existing values.
   *
   * @param globalLocationNumbers The list of values to set.
   */
  public void setGlobalLocationNumbers(List<String> globalLocationNumbers);
  
  /**
   * Set the interactionCount property values for this Place object; overwriting any existing values.
   *
   * @param interactionCounts The list of values to set.
   */
  public void setInteractionCounts(List<String> interactionCounts);
  
  /**
   * Set the isicV4 property values for this Place object; overwriting any existing values.
   *
   * @param isicV4s The list of values to set.
   */
  public void setIsicV4s(List<String> isicV4s);
  
  /**
   * Set the logo property values for this Place object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes);
  
  /**
   * Set the map property values for this Place object; overwriting any existing values.
   *
   * @param maps The list of values to set.
   */
  public void setMaps(List<URL> maps);
  
  /**
   * Set the openingHoursSpecification property values for this Place object; overwriting any existing values.
   *
   * @param openingHoursSpecifications The list of values to set.
   */
  public void setOpeningHoursSpecifications(List<OpeningHoursSpecification> openingHoursSpecifications);
  
  /**
   * Set the photo property values for this Place object; overwriting any existing values.
   *
   * @param photos The list of values to set.
   */
  public void setPhotos(List<Thing> photos);
  
  /**
   * Set the review property values for this Place object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews);
  
  /**
   * Set the telephone property values for this Place object; overwriting any existing values.
   *
   * @param telephones The list of values to set.
   */
  public void setTelephones(List<String> telephones);
  
  /**
   * Adds a address property value for this Place object; appending it to the list of existing values.
   *
   * @param address The value to add.
   */
  public void addAddress(PostalAddress address);
  
  /**
   * Adds a aggregateRating property value for this Place object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Adds a containedIn property value for this Place object; appending it to the list of existing values.
   *
   * @param containedIn The value to add.
   */
  public void addContainedIn(Place containedIn);
  
  /**
   * Adds a event property value for this Place object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
  /**
   * Adds a faxNumber property value for this Place object; appending it to the list of existing values.
   *
   * @param faxNumber The value to add.
   */
  public void addFaxNumber(String faxNumber);
  
  /**
   * Adds a geo property value for this Place object; appending it to the list of existing values.
   *
   * @param geo The value to add.
   */
  public void addGeo(Thing geo);
  
  /**
   * Adds a globalLocationNumber property value for this Place object; appending it to the list of existing values.
   *
   * @param globalLocationNumber The value to add.
   */
  public void addGlobalLocationNumber(String globalLocationNumber);
  
  /**
   * Adds a interactionCount property value for this Place object; appending it to the list of existing values.
   *
   * @param interactionCount The value to add.
   */
  public void addInteractionCount(String interactionCount);
  
  /**
   * Adds a isicV4 property value for this Place object; appending it to the list of existing values.
   *
   * @param isicV4 The value to add.
   */
  public void addIsicV4(String isicV4);
  
  /**
   * Adds a logo property value for this Place object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo);
  
  /**
   * Adds a map property value for this Place object; appending it to the list of existing values.
   *
   * @param map The value to add.
   */
  public void addMap(URL map);
  
  /**
   * Adds a openingHoursSpecification property value for this Place object; appending it to the list of existing values.
   *
   * @param openingHoursSpecification The value to add.
   */
  public void addOpeningHoursSpecification(OpeningHoursSpecification openingHoursSpecification);
  
  /**
   * Adds a photo property value for this Place object; appending it to the list of existing values.
   *
   * @param photo The value to add.
   */
  public void addPhoto(Thing photo);
  
  /**
   * Adds a review property value for this Place object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review);
  
  /**
   * Adds a telephone property value for this Place object; appending it to the list of existing values.
   *
   * @param telephone The value to add.
   */
  public void addTelephone(String telephone);
  
}