package org.schema;

import java.util.List;
import org.schema.Action;
import org.schema.Audience;
import org.schema.Event;
import org.schema.SchemaObject;

/**
 * The act of playing/exercising/training/performing for enjoyment, leisure, recreation, competion or exercise.<p>Related actions:</p><ul><li><a href="http://schema.org/ListenAction">ListenAction</a>: Unlike ListenAction (which is under ConsumeAction), PlayAction refers to performing for an audience or at an event, rather than consuming music.</li><li><a href="http://schema.org/WatchAction">WatchAction</a>: Unlike WatchAction (which is under ConsumeAction), PlayAction refers to showing/displaying for an audience or at an event, rather than consuming visual content.</li></ul>
 */
public interface PlayAction extends Action, SchemaObject {

  /**
   * Get a single audience property value for this PlayAction object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience();
  
  /**
   * Get a single event property value for this PlayAction object.
   *
   * @return The first event property value.
   */
  public Event getEvent();
  
  /**
   * Get all the audience property values for this PlayAction object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences();
  
  /**
   * Get all the event property values for this PlayAction object.
   *
   * @return A list of event property values.
   */
  public List<Event> getEvents();
  
  /**
   * Set the audience property value for this PlayAction object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience);
  
  /**
   * Set the event property value for this PlayAction object; overwriting any existing values.
   *
   * @param event The value to set.
   */
  public void setEvent(Event event);
  
  /**
   * Set the audience property values for this PlayAction object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences);
  
  /**
   * Set the event property values for this PlayAction object; overwriting any existing values.
   *
   * @param events The list of values to set.
   */
  public void setEvents(List<Event> events);
  
  /**
   * Adds a audience property value for this PlayAction object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience);
  
  /**
   * Adds a event property value for this PlayAction object; appending it to the list of existing values.
   *
   * @param event The value to add.
   */
  public void addEvent(Event event);
  
}