package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.ContactPoint;
import org.schema.Country;
import org.schema.SchemaObject;

/**
 * The mailing address.
 */
public interface PostalAddress extends ContactPoint, SchemaObject {

  /**
   * Get a single addressCountry property value for this PostalAddress object.
   *
   * @return The first addressCountry property value.
   */
  public Country getAddressCountry();
  
  /**
   * Get a single addressLocality property value for this PostalAddress object.
   *
   * @return The first addressLocality property value.
   */
  public String getAddressLocality();
  
  /**
   * Get a single addressRegion property value for this PostalAddress object.
   *
   * @return The first addressRegion property value.
   */
  public String getAddressRegion();
  
  /**
   * Get a single postOfficeBoxNumber property value for this PostalAddress object.
   *
   * @return The first postOfficeBoxNumber property value.
   */
  public String getPostOfficeBoxNumber();
  
  /**
   * Get a single postalCode property value for this PostalAddress object.
   *
   * @return The first postalCode property value.
   */
  public String getPostalCode();
  
  /**
   * Get a single streetAddress property value for this PostalAddress object.
   *
   * @return The first streetAddress property value.
   */
  public String getStreetAddress();
  
  /**
   * Get all the addressCountry property values for this PostalAddress object.
   *
   * @return A list of addressCountry property values.
   */
  public List<Country> getAddressCountries();
  
  /**
   * Get all the addressLocality property values for this PostalAddress object.
   *
   * @return A list of addressLocality property values.
   */
  public List<String> getAddressLocalities();
  
  /**
   * Get all the addressRegion property values for this PostalAddress object.
   *
   * @return A list of addressRegion property values.
   */
  public List<String> getAddressRegions();
  
  /**
   * Get all the postOfficeBoxNumber property values for this PostalAddress object.
   *
   * @return A list of postOfficeBoxNumber property values.
   */
  public List<String> getPostOfficeBoxNumbers();
  
  /**
   * Get all the postalCode property values for this PostalAddress object.
   *
   * @return A list of postalCode property values.
   */
  public List<String> getPostalCodes();
  
  /**
   * Get all the streetAddress property values for this PostalAddress object.
   *
   * @return A list of streetAddress property values.
   */
  public List<String> getStreetAddresses();
  
  /**
   * Set the addressCountry property value for this PostalAddress object; overwriting any existing values.
   *
   * @param addressCountry The value to set.
   */
  public void setAddressCountry(Country addressCountry);
  
  /**
   * Set the addressLocality property value for this PostalAddress object; overwriting any existing values.
   *
   * @param addressLocality The value to set.
   */
  public void setAddressLocality(String addressLocality);
  
  /**
   * Set the addressRegion property value for this PostalAddress object; overwriting any existing values.
   *
   * @param addressRegion The value to set.
   */
  public void setAddressRegion(String addressRegion);
  
  /**
   * Set the postOfficeBoxNumber property value for this PostalAddress object; overwriting any existing values.
   *
   * @param postOfficeBoxNumber The value to set.
   */
  public void setPostOfficeBoxNumber(String postOfficeBoxNumber);
  
  /**
   * Set the postalCode property value for this PostalAddress object; overwriting any existing values.
   *
   * @param postalCode The value to set.
   */
  public void setPostalCode(String postalCode);
  
  /**
   * Set the streetAddress property value for this PostalAddress object; overwriting any existing values.
   *
   * @param streetAddress The value to set.
   */
  public void setStreetAddress(String streetAddress);
  
  /**
   * Set the addressCountry property values for this PostalAddress object; overwriting any existing values.
   *
   * @param addressCountries The list of values to set.
   */
  public void setAddressCountries(List<Country> addressCountries);
  
  /**
   * Set the addressLocality property values for this PostalAddress object; overwriting any existing values.
   *
   * @param addressLocalities The list of values to set.
   */
  public void setAddressLocalities(List<String> addressLocalities);
  
  /**
   * Set the addressRegion property values for this PostalAddress object; overwriting any existing values.
   *
   * @param addressRegions The list of values to set.
   */
  public void setAddressRegions(List<String> addressRegions);
  
  /**
   * Set the postOfficeBoxNumber property values for this PostalAddress object; overwriting any existing values.
   *
   * @param postOfficeBoxNumbers The list of values to set.
   */
  public void setPostOfficeBoxNumbers(List<String> postOfficeBoxNumbers);
  
  /**
   * Set the postalCode property values for this PostalAddress object; overwriting any existing values.
   *
   * @param postalCodes The list of values to set.
   */
  public void setPostalCodes(List<String> postalCodes);
  
  /**
   * Set the streetAddress property values for this PostalAddress object; overwriting any existing values.
   *
   * @param streetAddresses The list of values to set.
   */
  public void setStreetAddresses(List<String> streetAddresses);
  
  /**
   * Adds a addressCountry property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param addressCountry The value to add.
   */
  public void addAddressCountry(Country addressCountry);
  
  /**
   * Adds a addressLocality property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param addressLocality The value to add.
   */
  public void addAddressLocality(String addressLocality);
  
  /**
   * Adds a addressRegion property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param addressRegion The value to add.
   */
  public void addAddressRegion(String addressRegion);
  
  /**
   * Adds a postOfficeBoxNumber property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param postOfficeBoxNumber The value to add.
   */
  public void addPostOfficeBoxNumber(String postOfficeBoxNumber);
  
  /**
   * Adds a postalCode property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param postalCode The value to add.
   */
  public void addPostalCode(String postalCode);
  
  /**
   * Adds a streetAddress property value for this PostalAddress object; appending it to the list of existing values.
   *
   * @param streetAddress The value to add.
   */
  public void addStreetAddress(String streetAddress);
  
}