package org.schema;

import java.lang.Boolean;
import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Number;
import org.schema.PriceSpecification;
import org.schema.QuantitativeValue;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.Thing;

/**
 * A structured value representing a monetary amount. Typically, only the subclasses of this type are used for markup.
 */
public interface PriceSpecification extends StructuredValue, SchemaObject {

  /**
   * Get a single eligibleQuantity property value for this PriceSpecification object.
   *
   * @return The first eligibleQuantity property value.
   */
  public QuantitativeValue getEligibleQuantity();
  
  /**
   * Get a single eligibleTransactionVolume property value for this PriceSpecification object.
   *
   * @return The first eligibleTransactionVolume property value.
   */
  public PriceSpecification getEligibleTransactionVolume();
  
  /**
   * Get a single maxPrice property value for this PriceSpecification object.
   *
   * @return The first maxPrice property value.
   */
  public Number getMaxPrice();
  
  /**
   * Get a single minPrice property value for this PriceSpecification object.
   *
   * @return The first minPrice property value.
   */
  public Number getMinPrice();
  
  /**
   * Get a single price property value for this PriceSpecification object.
   *
   * @return The first price property value.
   */
  public Thing getPrice();
  
  /**
   * Get a single priceCurrency property value for this PriceSpecification object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency();
  
  /**
   * Get a single validFrom property value for this PriceSpecification object.
   *
   * @return The first validFrom property value.
   */
  public Date getValidFrom();
  
  /**
   * Get a single validThrough property value for this PriceSpecification object.
   *
   * @return The first validThrough property value.
   */
  public Date getValidThrough();
  
  /**
   * Get a single valueAddedTaxIncluded property value for this PriceSpecification object.
   *
   * @return The first valueAddedTaxIncluded property value.
   */
  public Boolean getValueAddedTaxIncluded();
  
  /**
   * Get all the eligibleQuantity property values for this PriceSpecification object.
   *
   * @return A list of eligibleQuantity property values.
   */
  public List<QuantitativeValue> getEligibleQuantities();
  
  /**
   * Get all the eligibleTransactionVolume property values for this PriceSpecification object.
   *
   * @return A list of eligibleTransactionVolume property values.
   */
  public List<PriceSpecification> getEligibleTransactionVolumes();
  
  /**
   * Get all the maxPrice property values for this PriceSpecification object.
   *
   * @return A list of maxPrice property values.
   */
  public List<Number> getMaxPrices();
  
  /**
   * Get all the minPrice property values for this PriceSpecification object.
   *
   * @return A list of minPrice property values.
   */
  public List<Number> getMinPrices();
  
  /**
   * Get all the price property values for this PriceSpecification object.
   *
   * @return A list of price property values.
   */
  public List<Thing> getPrices();
  
  /**
   * Get all the priceCurrency property values for this PriceSpecification object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies();
  
  /**
   * Get all the validFrom property values for this PriceSpecification object.
   *
   * @return A list of validFrom property values.
   */
  public List<Date> getValidFroms();
  
  /**
   * Get all the validThrough property values for this PriceSpecification object.
   *
   * @return A list of validThrough property values.
   */
  public List<Date> getValidThroughs();
  
  /**
   * Get all the valueAddedTaxIncluded property values for this PriceSpecification object.
   *
   * @return A list of valueAddedTaxIncluded property values.
   */
  public List<Boolean> getValueAddedTaxIncludeds();
  
  /**
   * Set the eligibleQuantity property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleQuantity The value to set.
   */
  public void setEligibleQuantity(QuantitativeValue eligibleQuantity);
  
  /**
   * Set the eligibleTransactionVolume property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleTransactionVolume The value to set.
   */
  public void setEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume);
  
  /**
   * Set the maxPrice property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param maxPrice The value to set.
   */
  public void setMaxPrice(Number maxPrice);
  
  /**
   * Set the minPrice property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param minPrice The value to set.
   */
  public void setMinPrice(Number minPrice);
  
  /**
   * Set the price property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param price The value to set.
   */
  public void setPrice(Thing price);
  
  /**
   * Set the priceCurrency property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency);
  
  /**
   * Set the validFrom property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param validFrom The value to set.
   */
  public void setValidFrom(Date validFrom);
  
  /**
   * Set the validThrough property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param validThrough The value to set.
   */
  public void setValidThrough(Date validThrough);
  
  /**
   * Set the valueAddedTaxIncluded property value for this PriceSpecification object; overwriting any existing values.
   *
   * @param valueAddedTaxIncluded The value to set.
   */
  public void setValueAddedTaxIncluded(Boolean valueAddedTaxIncluded);
  
  /**
   * Set the eligibleQuantity property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleQuantities The list of values to set.
   */
  public void setEligibleQuantities(List<QuantitativeValue> eligibleQuantities);
  
  /**
   * Set the eligibleTransactionVolume property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param eligibleTransactionVolumes The list of values to set.
   */
  public void setEligibleTransactionVolumes(List<PriceSpecification> eligibleTransactionVolumes);
  
  /**
   * Set the maxPrice property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param maxPrices The list of values to set.
   */
  public void setMaxPrices(List<Number> maxPrices);
  
  /**
   * Set the minPrice property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param minPrices The list of values to set.
   */
  public void setMinPrices(List<Number> minPrices);
  
  /**
   * Set the price property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param prices The list of values to set.
   */
  public void setPrices(List<Thing> prices);
  
  /**
   * Set the priceCurrency property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies);
  
  /**
   * Set the validFrom property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param validFroms The list of values to set.
   */
  public void setValidFroms(List<Date> validFroms);
  
  /**
   * Set the validThrough property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param validThroughs The list of values to set.
   */
  public void setValidThroughs(List<Date> validThroughs);
  
  /**
   * Set the valueAddedTaxIncluded property values for this PriceSpecification object; overwriting any existing values.
   *
   * @param valueAddedTaxIncludeds The list of values to set.
   */
  public void setValueAddedTaxIncludeds(List<Boolean> valueAddedTaxIncludeds);
  
  /**
   * Adds a eligibleQuantity property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param eligibleQuantity The value to add.
   */
  public void addEligibleQuantity(QuantitativeValue eligibleQuantity);
  
  /**
   * Adds a eligibleTransactionVolume property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param eligibleTransactionVolume The value to add.
   */
  public void addEligibleTransactionVolume(PriceSpecification eligibleTransactionVolume);
  
  /**
   * Adds a maxPrice property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param maxPrice The value to add.
   */
  public void addMaxPrice(Number maxPrice);
  
  /**
   * Adds a minPrice property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param minPrice The value to add.
   */
  public void addMinPrice(Number minPrice);
  
  /**
   * Adds a price property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param price The value to add.
   */
  public void addPrice(Thing price);
  
  /**
   * Adds a priceCurrency property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency);
  
  /**
   * Adds a validFrom property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param validFrom The value to add.
   */
  public void addValidFrom(Date validFrom);
  
  /**
   * Adds a validThrough property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param validThrough The value to add.
   */
  public void addValidThrough(Date validThrough);
  
  /**
   * Adds a valueAddedTaxIncluded property value for this PriceSpecification object; appending it to the list of existing values.
   *
   * @param valueAddedTaxIncluded The value to add.
   */
  public void addValueAddedTaxIncluded(Boolean valueAddedTaxIncluded);
  
}