package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.AggregateRating;
import org.schema.Audience;
import org.schema.Offer;
import org.schema.OfferItemCondition;
import org.schema.Organization;
import org.schema.Product;
import org.schema.QuantitativeValue;
import org.schema.Review;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A product is anything that is made available for sale???for example, a pair of shoes, a concert ticket, or a car. Commodity services, like haircuts, can also be represented using this type.
 */
public interface Product extends Thing, SchemaObject {

  /**
   * Get a single aggregateRating property value for this Product object.
   *
   * @return The first aggregateRating property value.
   */
  public AggregateRating getAggregateRating();
  
  /**
   * Get a single audience property value for this Product object.
   *
   * @return The first audience property value.
   */
  public Audience getAudience();
  
  /**
   * Get a single brand property value for this Product object.
   *
   * @return The first brand property value.
   */
  public Thing getBrand();
  
  /**
   * Get a single color property value for this Product object.
   *
   * @return The first color property value.
   */
  public String getColor();
  
  /**
   * Get a single depth property value for this Product object.
   *
   * @return The first depth property value.
   */
  public Thing getDepth();
  
  /**
   * Get a single gtin13 property value for this Product object.
   *
   * @return The first gtin13 property value.
   */
  public String getGtin13();
  
  /**
   * Get a single gtin14 property value for this Product object.
   *
   * @return The first gtin14 property value.
   */
  public String getGtin14();
  
  /**
   * Get a single gtin8 property value for this Product object.
   *
   * @return The first gtin8 property value.
   */
  public String getGtin8();
  
  /**
   * Get a single height property value for this Product object.
   *
   * @return The first height property value.
   */
  public Thing getHeight();
  
  /**
   * Get a single isAccessoryOrSparePartFor property value for this Product object.
   *
   * @return The first isAccessoryOrSparePartFor property value.
   */
  public Product getIsAccessoryOrSparePartFor();
  
  /**
   * Get a single isConsumableFor property value for this Product object.
   *
   * @return The first isConsumableFor property value.
   */
  public Product getIsConsumableFor();
  
  /**
   * Get a single isRelatedTo property value for this Product object.
   *
   * @return The first isRelatedTo property value.
   */
  public Product getIsRelatedTo();
  
  /**
   * Get a single isSimilarTo property value for this Product object.
   *
   * @return The first isSimilarTo property value.
   */
  public Product getIsSimilarTo();
  
  /**
   * Get a single itemCondition property value for this Product object.
   *
   * @return The first itemCondition property value.
   */
  public OfferItemCondition getItemCondition();
  
  /**
   * Get a single logo property value for this Product object.
   *
   * @return The first logo property value.
   */
  public Thing getLogo();
  
  /**
   * Get a single manufacturer property value for this Product object.
   *
   * @return The first manufacturer property value.
   */
  public Organization getManufacturer();
  
  /**
   * Get a single model property value for this Product object.
   *
   * @return The first model property value.
   */
  public Thing getModel();
  
  /**
   * Get a single mpn property value for this Product object.
   *
   * @return The first mpn property value.
   */
  public String getMpn();
  
  /**
   * Get a single offers property value for this Product object.
   *
   * @return The first offers property value.
   */
  public Offer getOffers();
  
  /**
   * Get a single productID property value for this Product object.
   *
   * @return The first productID property value.
   */
  public String getProductID();
  
  /**
   * Get a single releaseDate property value for this Product object.
   *
   * @return The first releaseDate property value.
   */
  public Date getReleaseDate();
  
  /**
   * Get a single review property value for this Product object.
   *
   * @return The first review property value.
   */
  public Review getReview();
  
  /**
   * Get a single sku property value for this Product object.
   *
   * @return The first sku property value.
   */
  public String getSku();
  
  /**
   * Get a single weight property value for this Product object.
   *
   * @return The first weight property value.
   */
  public QuantitativeValue getWeight();
  
  /**
   * Get a single width property value for this Product object.
   *
   * @return The first width property value.
   */
  public Thing getWidth();
  
  /**
   * Get all the aggregateRating property values for this Product object.
   *
   * @return A list of aggregateRating property values.
   */
  public List<AggregateRating> getAggregateRatings();
  
  /**
   * Get all the audience property values for this Product object.
   *
   * @return A list of audience property values.
   */
  public List<Audience> getAudiences();
  
  /**
   * Get all the brand property values for this Product object.
   *
   * @return A list of brand property values.
   */
  public List<Thing> getBrands();
  
  /**
   * Get all the color property values for this Product object.
   *
   * @return A list of color property values.
   */
  public List<String> getColors();
  
  /**
   * Get all the depth property values for this Product object.
   *
   * @return A list of depth property values.
   */
  public List<Thing> getDepths();
  
  /**
   * Get all the gtin13 property values for this Product object.
   *
   * @return A list of gtin13 property values.
   */
  public List<String> getGtin13s();
  
  /**
   * Get all the gtin14 property values for this Product object.
   *
   * @return A list of gtin14 property values.
   */
  public List<String> getGtin14s();
  
  /**
   * Get all the gtin8 property values for this Product object.
   *
   * @return A list of gtin8 property values.
   */
  public List<String> getGtin8s();
  
  /**
   * Get all the height property values for this Product object.
   *
   * @return A list of height property values.
   */
  public List<Thing> getHeights();
  
  /**
   * Get all the isAccessoryOrSparePartFor property values for this Product object.
   *
   * @return A list of isAccessoryOrSparePartFor property values.
   */
  public List<Product> getIsAccessoryOrSparePartFors();
  
  /**
   * Get all the isConsumableFor property values for this Product object.
   *
   * @return A list of isConsumableFor property values.
   */
  public List<Product> getIsConsumableFors();
  
  /**
   * Get all the isRelatedTo property values for this Product object.
   *
   * @return A list of isRelatedTo property values.
   */
  public List<Product> getIsRelatedToes();
  
  /**
   * Get all the isSimilarTo property values for this Product object.
   *
   * @return A list of isSimilarTo property values.
   */
  public List<Product> getIsSimilarToes();
  
  /**
   * Get all the itemCondition property values for this Product object.
   *
   * @return A list of itemCondition property values.
   */
  public List<OfferItemCondition> getItemConditions();
  
  /**
   * Get all the logo property values for this Product object.
   *
   * @return A list of logo property values.
   */
  public List<Thing> getLogoes();
  
  /**
   * Get all the manufacturer property values for this Product object.
   *
   * @return A list of manufacturer property values.
   */
  public List<Organization> getManufacturers();
  
  /**
   * Get all the model property values for this Product object.
   *
   * @return A list of model property values.
   */
  public List<Thing> getModels();
  
  /**
   * Get all the mpn property values for this Product object.
   *
   * @return A list of mpn property values.
   */
  public List<String> getMpns();
  
  /**
   * Get all the offers property values for this Product object.
   *
   * @return A list of offers property values.
   */
  public List<Offer> getOfferss();
  
  /**
   * Get all the productID property values for this Product object.
   *
   * @return A list of productID property values.
   */
  public List<String> getProductIDs();
  
  /**
   * Get all the releaseDate property values for this Product object.
   *
   * @return A list of releaseDate property values.
   */
  public List<Date> getReleaseDates();
  
  /**
   * Get all the review property values for this Product object.
   *
   * @return A list of review property values.
   */
  public List<Review> getReviews();
  
  /**
   * Get all the sku property values for this Product object.
   *
   * @return A list of sku property values.
   */
  public List<String> getSkus();
  
  /**
   * Get all the weight property values for this Product object.
   *
   * @return A list of weight property values.
   */
  public List<QuantitativeValue> getWeights();
  
  /**
   * Get all the width property values for this Product object.
   *
   * @return A list of width property values.
   */
  public List<Thing> getWidths();
  
  /**
   * Set the aggregateRating property value for this Product object; overwriting any existing values.
   *
   * @param aggregateRating The value to set.
   */
  public void setAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Set the audience property value for this Product object; overwriting any existing values.
   *
   * @param audience The value to set.
   */
  public void setAudience(Audience audience);
  
  /**
   * Set the brand property value for this Product object; overwriting any existing values.
   *
   * @param brand The value to set.
   */
  public void setBrand(Thing brand);
  
  /**
   * Set the color property value for this Product object; overwriting any existing values.
   *
   * @param color The value to set.
   */
  public void setColor(String color);
  
  /**
   * Set the depth property value for this Product object; overwriting any existing values.
   *
   * @param depth The value to set.
   */
  public void setDepth(Thing depth);
  
  /**
   * Set the gtin13 property value for this Product object; overwriting any existing values.
   *
   * @param gtin13 The value to set.
   */
  public void setGtin13(String gtin13);
  
  /**
   * Set the gtin14 property value for this Product object; overwriting any existing values.
   *
   * @param gtin14 The value to set.
   */
  public void setGtin14(String gtin14);
  
  /**
   * Set the gtin8 property value for this Product object; overwriting any existing values.
   *
   * @param gtin8 The value to set.
   */
  public void setGtin8(String gtin8);
  
  /**
   * Set the height property value for this Product object; overwriting any existing values.
   *
   * @param height The value to set.
   */
  public void setHeight(Thing height);
  
  /**
   * Set the isAccessoryOrSparePartFor property value for this Product object; overwriting any existing values.
   *
   * @param isAccessoryOrSparePartFor The value to set.
   */
  public void setIsAccessoryOrSparePartFor(Product isAccessoryOrSparePartFor);
  
  /**
   * Set the isConsumableFor property value for this Product object; overwriting any existing values.
   *
   * @param isConsumableFor The value to set.
   */
  public void setIsConsumableFor(Product isConsumableFor);
  
  /**
   * Set the isRelatedTo property value for this Product object; overwriting any existing values.
   *
   * @param isRelatedTo The value to set.
   */
  public void setIsRelatedTo(Product isRelatedTo);
  
  /**
   * Set the isSimilarTo property value for this Product object; overwriting any existing values.
   *
   * @param isSimilarTo The value to set.
   */
  public void setIsSimilarTo(Product isSimilarTo);
  
  /**
   * Set the itemCondition property value for this Product object; overwriting any existing values.
   *
   * @param itemCondition The value to set.
   */
  public void setItemCondition(OfferItemCondition itemCondition);
  
  /**
   * Set the logo property value for this Product object; overwriting any existing values.
   *
   * @param logo The value to set.
   */
  public void setLogo(Thing logo);
  
  /**
   * Set the manufacturer property value for this Product object; overwriting any existing values.
   *
   * @param manufacturer The value to set.
   */
  public void setManufacturer(Organization manufacturer);
  
  /**
   * Set the model property value for this Product object; overwriting any existing values.
   *
   * @param model The value to set.
   */
  public void setModel(Thing model);
  
  /**
   * Set the mpn property value for this Product object; overwriting any existing values.
   *
   * @param mpn The value to set.
   */
  public void setMpn(String mpn);
  
  /**
   * Set the offers property value for this Product object; overwriting any existing values.
   *
   * @param offers The value to set.
   */
  public void setOffers(Offer offers);
  
  /**
   * Set the productID property value for this Product object; overwriting any existing values.
   *
   * @param productID The value to set.
   */
  public void setProductID(String productID);
  
  /**
   * Set the releaseDate property value for this Product object; overwriting any existing values.
   *
   * @param releaseDate The value to set.
   */
  public void setReleaseDate(Date releaseDate);
  
  /**
   * Set the review property value for this Product object; overwriting any existing values.
   *
   * @param review The value to set.
   */
  public void setReview(Review review);
  
  /**
   * Set the sku property value for this Product object; overwriting any existing values.
   *
   * @param sku The value to set.
   */
  public void setSku(String sku);
  
  /**
   * Set the weight property value for this Product object; overwriting any existing values.
   *
   * @param weight The value to set.
   */
  public void setWeight(QuantitativeValue weight);
  
  /**
   * Set the width property value for this Product object; overwriting any existing values.
   *
   * @param width The value to set.
   */
  public void setWidth(Thing width);
  
  /**
   * Set the aggregateRating property values for this Product object; overwriting any existing values.
   *
   * @param aggregateRatings The list of values to set.
   */
  public void setAggregateRatings(List<AggregateRating> aggregateRatings);
  
  /**
   * Set the audience property values for this Product object; overwriting any existing values.
   *
   * @param audiences The list of values to set.
   */
  public void setAudiences(List<Audience> audiences);
  
  /**
   * Set the brand property values for this Product object; overwriting any existing values.
   *
   * @param brands The list of values to set.
   */
  public void setBrands(List<Thing> brands);
  
  /**
   * Set the color property values for this Product object; overwriting any existing values.
   *
   * @param colors The list of values to set.
   */
  public void setColors(List<String> colors);
  
  /**
   * Set the depth property values for this Product object; overwriting any existing values.
   *
   * @param depths The list of values to set.
   */
  public void setDepths(List<Thing> depths);
  
  /**
   * Set the gtin13 property values for this Product object; overwriting any existing values.
   *
   * @param gtin13s The list of values to set.
   */
  public void setGtin13s(List<String> gtin13s);
  
  /**
   * Set the gtin14 property values for this Product object; overwriting any existing values.
   *
   * @param gtin14s The list of values to set.
   */
  public void setGtin14s(List<String> gtin14s);
  
  /**
   * Set the gtin8 property values for this Product object; overwriting any existing values.
   *
   * @param gtin8s The list of values to set.
   */
  public void setGtin8s(List<String> gtin8s);
  
  /**
   * Set the height property values for this Product object; overwriting any existing values.
   *
   * @param heights The list of values to set.
   */
  public void setHeights(List<Thing> heights);
  
  /**
   * Set the isAccessoryOrSparePartFor property values for this Product object; overwriting any existing values.
   *
   * @param isAccessoryOrSparePartFors The list of values to set.
   */
  public void setIsAccessoryOrSparePartFors(List<Product> isAccessoryOrSparePartFors);
  
  /**
   * Set the isConsumableFor property values for this Product object; overwriting any existing values.
   *
   * @param isConsumableFors The list of values to set.
   */
  public void setIsConsumableFors(List<Product> isConsumableFors);
  
  /**
   * Set the isRelatedTo property values for this Product object; overwriting any existing values.
   *
   * @param isRelatedToes The list of values to set.
   */
  public void setIsRelatedToes(List<Product> isRelatedToes);
  
  /**
   * Set the isSimilarTo property values for this Product object; overwriting any existing values.
   *
   * @param isSimilarToes The list of values to set.
   */
  public void setIsSimilarToes(List<Product> isSimilarToes);
  
  /**
   * Set the itemCondition property values for this Product object; overwriting any existing values.
   *
   * @param itemConditions The list of values to set.
   */
  public void setItemConditions(List<OfferItemCondition> itemConditions);
  
  /**
   * Set the logo property values for this Product object; overwriting any existing values.
   *
   * @param logoes The list of values to set.
   */
  public void setLogoes(List<Thing> logoes);
  
  /**
   * Set the manufacturer property values for this Product object; overwriting any existing values.
   *
   * @param manufacturers The list of values to set.
   */
  public void setManufacturers(List<Organization> manufacturers);
  
  /**
   * Set the model property values for this Product object; overwriting any existing values.
   *
   * @param models The list of values to set.
   */
  public void setModels(List<Thing> models);
  
  /**
   * Set the mpn property values for this Product object; overwriting any existing values.
   *
   * @param mpns The list of values to set.
   */
  public void setMpns(List<String> mpns);
  
  /**
   * Set the offers property values for this Product object; overwriting any existing values.
   *
   * @param offerss The list of values to set.
   */
  public void setOfferss(List<Offer> offerss);
  
  /**
   * Set the productID property values for this Product object; overwriting any existing values.
   *
   * @param productIDs The list of values to set.
   */
  public void setProductIDs(List<String> productIDs);
  
  /**
   * Set the releaseDate property values for this Product object; overwriting any existing values.
   *
   * @param releaseDates The list of values to set.
   */
  public void setReleaseDates(List<Date> releaseDates);
  
  /**
   * Set the review property values for this Product object; overwriting any existing values.
   *
   * @param reviews The list of values to set.
   */
  public void setReviews(List<Review> reviews);
  
  /**
   * Set the sku property values for this Product object; overwriting any existing values.
   *
   * @param skus The list of values to set.
   */
  public void setSkus(List<String> skus);
  
  /**
   * Set the weight property values for this Product object; overwriting any existing values.
   *
   * @param weights The list of values to set.
   */
  public void setWeights(List<QuantitativeValue> weights);
  
  /**
   * Set the width property values for this Product object; overwriting any existing values.
   *
   * @param widths The list of values to set.
   */
  public void setWidths(List<Thing> widths);
  
  /**
   * Adds a aggregateRating property value for this Product object; appending it to the list of existing values.
   *
   * @param aggregateRating The value to add.
   */
  public void addAggregateRating(AggregateRating aggregateRating);
  
  /**
   * Adds a audience property value for this Product object; appending it to the list of existing values.
   *
   * @param audience The value to add.
   */
  public void addAudience(Audience audience);
  
  /**
   * Adds a brand property value for this Product object; appending it to the list of existing values.
   *
   * @param brand The value to add.
   */
  public void addBrand(Thing brand);
  
  /**
   * Adds a color property value for this Product object; appending it to the list of existing values.
   *
   * @param color The value to add.
   */
  public void addColor(String color);
  
  /**
   * Adds a depth property value for this Product object; appending it to the list of existing values.
   *
   * @param depth The value to add.
   */
  public void addDepth(Thing depth);
  
  /**
   * Adds a gtin13 property value for this Product object; appending it to the list of existing values.
   *
   * @param gtin13 The value to add.
   */
  public void addGtin13(String gtin13);
  
  /**
   * Adds a gtin14 property value for this Product object; appending it to the list of existing values.
   *
   * @param gtin14 The value to add.
   */
  public void addGtin14(String gtin14);
  
  /**
   * Adds a gtin8 property value for this Product object; appending it to the list of existing values.
   *
   * @param gtin8 The value to add.
   */
  public void addGtin8(String gtin8);
  
  /**
   * Adds a height property value for this Product object; appending it to the list of existing values.
   *
   * @param height The value to add.
   */
  public void addHeight(Thing height);
  
  /**
   * Adds a isAccessoryOrSparePartFor property value for this Product object; appending it to the list of existing values.
   *
   * @param isAccessoryOrSparePartFor The value to add.
   */
  public void addIsAccessoryOrSparePartFor(Product isAccessoryOrSparePartFor);
  
  /**
   * Adds a isConsumableFor property value for this Product object; appending it to the list of existing values.
   *
   * @param isConsumableFor The value to add.
   */
  public void addIsConsumableFor(Product isConsumableFor);
  
  /**
   * Adds a isRelatedTo property value for this Product object; appending it to the list of existing values.
   *
   * @param isRelatedTo The value to add.
   */
  public void addIsRelatedTo(Product isRelatedTo);
  
  /**
   * Adds a isSimilarTo property value for this Product object; appending it to the list of existing values.
   *
   * @param isSimilarTo The value to add.
   */
  public void addIsSimilarTo(Product isSimilarTo);
  
  /**
   * Adds a itemCondition property value for this Product object; appending it to the list of existing values.
   *
   * @param itemCondition The value to add.
   */
  public void addItemCondition(OfferItemCondition itemCondition);
  
  /**
   * Adds a logo property value for this Product object; appending it to the list of existing values.
   *
   * @param logo The value to add.
   */
  public void addLogo(Thing logo);
  
  /**
   * Adds a manufacturer property value for this Product object; appending it to the list of existing values.
   *
   * @param manufacturer The value to add.
   */
  public void addManufacturer(Organization manufacturer);
  
  /**
   * Adds a model property value for this Product object; appending it to the list of existing values.
   *
   * @param model The value to add.
   */
  public void addModel(Thing model);
  
  /**
   * Adds a mpn property value for this Product object; appending it to the list of existing values.
   *
   * @param mpn The value to add.
   */
  public void addMpn(String mpn);
  
  /**
   * Adds a offers property value for this Product object; appending it to the list of existing values.
   *
   * @param offers The value to add.
   */
  public void addOffers(Offer offers);
  
  /**
   * Adds a productID property value for this Product object; appending it to the list of existing values.
   *
   * @param productID The value to add.
   */
  public void addProductID(String productID);
  
  /**
   * Adds a releaseDate property value for this Product object; appending it to the list of existing values.
   *
   * @param releaseDate The value to add.
   */
  public void addReleaseDate(Date releaseDate);
  
  /**
   * Adds a review property value for this Product object; appending it to the list of existing values.
   *
   * @param review The value to add.
   */
  public void addReview(Review review);
  
  /**
   * Adds a sku property value for this Product object; appending it to the list of existing values.
   *
   * @param sku The value to add.
   */
  public void addSku(String sku);
  
  /**
   * Adds a weight property value for this Product object; appending it to the list of existing values.
   *
   * @param weight The value to add.
   */
  public void addWeight(QuantitativeValue weight);
  
  /**
   * Adds a width property value for this Product object; appending it to the list of existing values.
   *
   * @param width The value to add.
   */
  public void addWidth(Thing width);
  
}