package org.schema;

import java.util.List;
import org.schema.Product;
import org.schema.ProductModel;
import org.schema.SchemaObject;

/**
 * A datasheet or vendor specification of a product (in the sense of a prototypical description).
 */
public interface ProductModel extends Product, SchemaObject {

  /**
   * Get a single isVariantOf property value for this ProductModel object.
   *
   * @return The first isVariantOf property value.
   */
  public ProductModel getIsVariantOf();
  
  /**
   * Get a single predecessorOf property value for this ProductModel object.
   *
   * @return The first predecessorOf property value.
   */
  public ProductModel getPredecessorOf();
  
  /**
   * Get a single successorOf property value for this ProductModel object.
   *
   * @return The first successorOf property value.
   */
  public ProductModel getSuccessorOf();
  
  /**
   * Get all the isVariantOf property values for this ProductModel object.
   *
   * @return A list of isVariantOf property values.
   */
  public List<ProductModel> getIsVariantsOf();
  
  /**
   * Get all the predecessorOf property values for this ProductModel object.
   *
   * @return A list of predecessorOf property values.
   */
  public List<ProductModel> getPredecessorsOf();
  
  /**
   * Get all the successorOf property values for this ProductModel object.
   *
   * @return A list of successorOf property values.
   */
  public List<ProductModel> getSuccessorsOf();
  
  /**
   * Set the isVariantOf property value for this ProductModel object; overwriting any existing values.
   *
   * @param isVariantOf The value to set.
   */
  public void setIsVariantOf(ProductModel isVariantOf);
  
  /**
   * Set the predecessorOf property value for this ProductModel object; overwriting any existing values.
   *
   * @param predecessorOf The value to set.
   */
  public void setPredecessorOf(ProductModel predecessorOf);
  
  /**
   * Set the successorOf property value for this ProductModel object; overwriting any existing values.
   *
   * @param successorOf The value to set.
   */
  public void setSuccessorOf(ProductModel successorOf);
  
  /**
   * Set the isVariantOf property values for this ProductModel object; overwriting any existing values.
   *
   * @param isVariantsOf The list of values to set.
   */
  public void setIsVariantsOf(List<ProductModel> isVariantsOf);
  
  /**
   * Set the predecessorOf property values for this ProductModel object; overwriting any existing values.
   *
   * @param predecessorsOf The list of values to set.
   */
  public void setPredecessorsOf(List<ProductModel> predecessorsOf);
  
  /**
   * Set the successorOf property values for this ProductModel object; overwriting any existing values.
   *
   * @param successorsOf The list of values to set.
   */
  public void setSuccessorsOf(List<ProductModel> successorsOf);
  
  /**
   * Adds a isVariantOf property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param isVariantOf The value to add.
   */
  public void addIsVariantOf(ProductModel isVariantOf);
  
  /**
   * Adds a predecessorOf property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param predecessorOf The value to add.
   */
  public void addPredecessorOf(ProductModel predecessorOf);
  
  /**
   * Adds a successorOf property value for this ProductModel object; appending it to the list of existing values.
   *
   * @param successorOf The value to add.
   */
  public void addSuccessorOf(ProductModel successorOf);
  
}