package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Intangible;
import org.schema.Organization;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Used to describe membership in a loyalty programs (e.g. "StarAliance"), traveler clubs (e.g. "AAA"), purchase clubs ("Safeway Club"), etc.
 */
public interface ProgramMembership extends Intangible, SchemaObject {

  /**
   * Get a single hostingOrganization property value for this ProgramMembership object.
   *
   * @return The first hostingOrganization property value.
   */
  public Organization getHostingOrganization();
  
  /**
   * Get a single member property value for this ProgramMembership object.
   *
   * @return The first member property value.
   */
  public Thing getMember();
  
  /**
   * Get a single membershipNumber property value for this ProgramMembership object.
   *
   * @return The first membershipNumber property value.
   */
  public String getMembershipNumber();
  
  /**
   * Get a single programName property value for this ProgramMembership object.
   *
   * @return The first programName property value.
   */
  public String getProgramName();
  
  /**
   * Get all the hostingOrganization property values for this ProgramMembership object.
   *
   * @return A list of hostingOrganization property values.
   */
  public List<Organization> getHostingOrganizations();
  
  /**
   * Get all the member property values for this ProgramMembership object.
   *
   * @return A list of member property values.
   */
  public List<Thing> getMembers();
  
  /**
   * Get all the membershipNumber property values for this ProgramMembership object.
   *
   * @return A list of membershipNumber property values.
   */
  public List<String> getMembershipNumbers();
  
  /**
   * Get all the programName property values for this ProgramMembership object.
   *
   * @return A list of programName property values.
   */
  public List<String> getProgramNames();
  
  /**
   * Set the hostingOrganization property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param hostingOrganization The value to set.
   */
  public void setHostingOrganization(Organization hostingOrganization);
  
  /**
   * Set the member property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param member The value to set.
   */
  public void setMember(Thing member);
  
  /**
   * Set the membershipNumber property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param membershipNumber The value to set.
   */
  public void setMembershipNumber(String membershipNumber);
  
  /**
   * Set the programName property value for this ProgramMembership object; overwriting any existing values.
   *
   * @param programName The value to set.
   */
  public void setProgramName(String programName);
  
  /**
   * Set the hostingOrganization property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param hostingOrganizations The list of values to set.
   */
  public void setHostingOrganizations(List<Organization> hostingOrganizations);
  
  /**
   * Set the member property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param members The list of values to set.
   */
  public void setMembers(List<Thing> members);
  
  /**
   * Set the membershipNumber property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param membershipNumbers The list of values to set.
   */
  public void setMembershipNumbers(List<String> membershipNumbers);
  
  /**
   * Set the programName property values for this ProgramMembership object; overwriting any existing values.
   *
   * @param programNames The list of values to set.
   */
  public void setProgramNames(List<String> programNames);
  
  /**
   * Adds a hostingOrganization property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param hostingOrganization The value to add.
   */
  public void addHostingOrganization(Organization hostingOrganization);
  
  /**
   * Adds a member property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param member The value to add.
   */
  public void addMember(Thing member);
  
  /**
   * Adds a membershipNumber property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param membershipNumber The value to add.
   */
  public void addMembershipNumber(String membershipNumber);
  
  /**
   * Adds a programName property value for this ProgramMembership object; appending it to the list of existing values.
   *
   * @param programName The value to add.
   */
  public void addProgramName(String programName);
  
}