package org.schema;

import java.util.List;
import org.schema.Class;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A property, used to indicate attributes and relationships of some Thing; equivalent to rdf:Property.
 */
public interface Property extends Thing, SchemaObject {

  /**
   * Get a single domainIncludes property value for this Property object.
   *
   * @return The first domainIncludes property value.
   */
  public Class getDomainIncludes();
  
  /**
   * Get a single rangeIncludes property value for this Property object.
   *
   * @return The first rangeIncludes property value.
   */
  public Class getRangeIncludes();
  
  /**
   * Get all the domainIncludes property values for this Property object.
   *
   * @return A list of domainIncludes property values.
   */
  public List<Class> getDomainIncludess();
  
  /**
   * Get all the rangeIncludes property values for this Property object.
   *
   * @return A list of rangeIncludes property values.
   */
  public List<Class> getRangeIncludess();
  
  /**
   * Set the domainIncludes property value for this Property object; overwriting any existing values.
   *
   * @param domainIncludes The value to set.
   */
  public void setDomainIncludes(Class domainIncludes);
  
  /**
   * Set the rangeIncludes property value for this Property object; overwriting any existing values.
   *
   * @param rangeIncludes The value to set.
   */
  public void setRangeIncludes(Class rangeIncludes);
  
  /**
   * Set the domainIncludes property values for this Property object; overwriting any existing values.
   *
   * @param domainIncludess The list of values to set.
   */
  public void setDomainIncludess(List<Class> domainIncludess);
  
  /**
   * Set the rangeIncludes property values for this Property object; overwriting any existing values.
   *
   * @param rangeIncludess The list of values to set.
   */
  public void setRangeIncludess(List<Class> rangeIncludess);
  
  /**
   * Adds a domainIncludes property value for this Property object; appending it to the list of existing values.
   *
   * @param domainIncludes The value to add.
   */
  public void addDomainIncludes(Class domainIncludes);
  
  /**
   * Adds a rangeIncludes property value for this Property object; appending it to the list of existing values.
   *
   * @param rangeIncludes The value to add.
   */
  public void addRangeIncludes(Class rangeIncludes);
  
}