package org.schema;

import java.lang.Boolean;
import java.util.List;
import org.schema.BroadcastService;
import org.schema.Event;
import org.schema.SchemaObject;

/**
 * A PublicationEvent corresponds indifferently to the event of publication for a CreativeWork of any type e.g. a broadcast event, an on-demand event, a book/journal publication via a variety of delivery media.
 */
public interface PublicationEvent extends Event, SchemaObject {

  /**
   * Get a single free property value for this PublicationEvent object.
   *
   * @return The first free property value.
   */
  public Boolean getFree();
  
  /**
   * Get a single publishedOn property value for this PublicationEvent object.
   *
   * @return The first publishedOn property value.
   */
  public BroadcastService getPublishedOn();
  
  /**
   * Get all the free property values for this PublicationEvent object.
   *
   * @return A list of free property values.
   */
  public List<Boolean> getFrees();
  
  /**
   * Get all the publishedOn property values for this PublicationEvent object.
   *
   * @return A list of publishedOn property values.
   */
  public List<BroadcastService> getPublishedsOn();
  
  /**
   * Set the free property value for this PublicationEvent object; overwriting any existing values.
   *
   * @param free The value to set.
   */
  public void setFree(Boolean free);
  
  /**
   * Set the publishedOn property value for this PublicationEvent object; overwriting any existing values.
   *
   * @param publishedOn The value to set.
   */
  public void setPublishedOn(BroadcastService publishedOn);
  
  /**
   * Set the free property values for this PublicationEvent object; overwriting any existing values.
   *
   * @param frees The list of values to set.
   */
  public void setFrees(List<Boolean> frees);
  
  /**
   * Set the publishedOn property values for this PublicationEvent object; overwriting any existing values.
   *
   * @param publishedsOn The list of values to set.
   */
  public void setPublishedsOn(List<BroadcastService> publishedsOn);
  
  /**
   * Adds a free property value for this PublicationEvent object; appending it to the list of existing values.
   *
   * @param free The value to add.
   */
  public void addFree(Boolean free);
  
  /**
   * Adds a publishedOn property value for this PublicationEvent object; appending it to the list of existing values.
   *
   * @param publishedOn The value to add.
   */
  public void addPublishedOn(BroadcastService publishedOn);
  
}