package org.schema;

import java.util.List;
import org.schema.Enumeration;
import org.schema.QualitativeValue;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A predefined value for a product characteristic, e.g. the the power cord plug type "US" or the garment sizes "S", "M", "L", and "XL"
 */
public interface QualitativeValue extends Enumeration, SchemaObject {

  /**
   * Get a single equal property value for this QualitativeValue object.
   *
   * @return The first equal property value.
   */
  public QualitativeValue getEqual();
  
  /**
   * Get a single greater property value for this QualitativeValue object.
   *
   * @return The first greater property value.
   */
  public QualitativeValue getGreater();
  
  /**
   * Get a single greaterOrEqual property value for this QualitativeValue object.
   *
   * @return The first greaterOrEqual property value.
   */
  public QualitativeValue getGreaterOrEqual();
  
  /**
   * Get a single lesser property value for this QualitativeValue object.
   *
   * @return The first lesser property value.
   */
  public QualitativeValue getLesser();
  
  /**
   * Get a single lesserOrEqual property value for this QualitativeValue object.
   *
   * @return The first lesserOrEqual property value.
   */
  public QualitativeValue getLesserOrEqual();
  
  /**
   * Get a single nonEqual property value for this QualitativeValue object.
   *
   * @return The first nonEqual property value.
   */
  public QualitativeValue getNonEqual();
  
  /**
   * Get a single valueReference property value for this QualitativeValue object.
   *
   * @return The first valueReference property value.
   */
  public Thing getValueReference();
  
  /**
   * Get all the equal property values for this QualitativeValue object.
   *
   * @return A list of equal property values.
   */
  public List<QualitativeValue> getEquals();
  
  /**
   * Get all the greater property values for this QualitativeValue object.
   *
   * @return A list of greater property values.
   */
  public List<QualitativeValue> getGreaters();
  
  /**
   * Get all the greaterOrEqual property values for this QualitativeValue object.
   *
   * @return A list of greaterOrEqual property values.
   */
  public List<QualitativeValue> getGreaterOrEquals();
  
  /**
   * Get all the lesser property values for this QualitativeValue object.
   *
   * @return A list of lesser property values.
   */
  public List<QualitativeValue> getLessers();
  
  /**
   * Get all the lesserOrEqual property values for this QualitativeValue object.
   *
   * @return A list of lesserOrEqual property values.
   */
  public List<QualitativeValue> getLesserOrEquals();
  
  /**
   * Get all the nonEqual property values for this QualitativeValue object.
   *
   * @return A list of nonEqual property values.
   */
  public List<QualitativeValue> getNonEquals();
  
  /**
   * Get all the valueReference property values for this QualitativeValue object.
   *
   * @return A list of valueReference property values.
   */
  public List<Thing> getValueReferences();
  
  /**
   * Set the equal property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param equal The value to set.
   */
  public void setEqual(QualitativeValue equal);
  
  /**
   * Set the greater property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param greater The value to set.
   */
  public void setGreater(QualitativeValue greater);
  
  /**
   * Set the greaterOrEqual property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param greaterOrEqual The value to set.
   */
  public void setGreaterOrEqual(QualitativeValue greaterOrEqual);
  
  /**
   * Set the lesser property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param lesser The value to set.
   */
  public void setLesser(QualitativeValue lesser);
  
  /**
   * Set the lesserOrEqual property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param lesserOrEqual The value to set.
   */
  public void setLesserOrEqual(QualitativeValue lesserOrEqual);
  
  /**
   * Set the nonEqual property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param nonEqual The value to set.
   */
  public void setNonEqual(QualitativeValue nonEqual);
  
  /**
   * Set the valueReference property value for this QualitativeValue object; overwriting any existing values.
   *
   * @param valueReference The value to set.
   */
  public void setValueReference(Thing valueReference);
  
  /**
   * Set the equal property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param equals The list of values to set.
   */
  public void setEquals(List<QualitativeValue> equals);
  
  /**
   * Set the greater property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param greaters The list of values to set.
   */
  public void setGreaters(List<QualitativeValue> greaters);
  
  /**
   * Set the greaterOrEqual property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param greaterOrEquals The list of values to set.
   */
  public void setGreaterOrEquals(List<QualitativeValue> greaterOrEquals);
  
  /**
   * Set the lesser property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param lessers The list of values to set.
   */
  public void setLessers(List<QualitativeValue> lessers);
  
  /**
   * Set the lesserOrEqual property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param lesserOrEquals The list of values to set.
   */
  public void setLesserOrEquals(List<QualitativeValue> lesserOrEquals);
  
  /**
   * Set the nonEqual property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param nonEquals The list of values to set.
   */
  public void setNonEquals(List<QualitativeValue> nonEquals);
  
  /**
   * Set the valueReference property values for this QualitativeValue object; overwriting any existing values.
   *
   * @param valueReferences The list of values to set.
   */
  public void setValueReferences(List<Thing> valueReferences);
  
  /**
   * Adds a equal property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param equal The value to add.
   */
  public void addEqual(QualitativeValue equal);
  
  /**
   * Adds a greater property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param greater The value to add.
   */
  public void addGreater(QualitativeValue greater);
  
  /**
   * Adds a greaterOrEqual property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param greaterOrEqual The value to add.
   */
  public void addGreaterOrEqual(QualitativeValue greaterOrEqual);
  
  /**
   * Adds a lesser property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param lesser The value to add.
   */
  public void addLesser(QualitativeValue lesser);
  
  /**
   * Adds a lesserOrEqual property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param lesserOrEqual The value to add.
   */
  public void addLesserOrEqual(QualitativeValue lesserOrEqual);
  
  /**
   * Adds a nonEqual property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param nonEqual The value to add.
   */
  public void addNonEqual(QualitativeValue nonEqual);
  
  /**
   * Adds a valueReference property value for this QualitativeValue object; appending it to the list of existing values.
   *
   * @param valueReference The value to add.
   */
  public void addValueReference(Thing valueReference);
  
}