package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Number;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.Thing;

/**
 *  A point value or interval for product characteristics and other purposes.
 */
public interface QuantitativeValue extends StructuredValue, SchemaObject {

  /**
   * Get a single maxValue property value for this QuantitativeValue object.
   *
   * @return The first maxValue property value.
   */
  public Number getMaxValue();
  
  /**
   * Get a single minValue property value for this QuantitativeValue object.
   *
   * @return The first minValue property value.
   */
  public Number getMinValue();
  
  /**
   * Get a single unitCode property value for this QuantitativeValue object.
   *
   * @return The first unitCode property value.
   */
  public String getUnitCode();
  
  /**
   * Get a single value property value for this QuantitativeValue object.
   *
   * @return The first value property value.
   */
  public Number getValue();
  
  /**
   * Get a single valueReference property value for this QuantitativeValue object.
   *
   * @return The first valueReference property value.
   */
  public Thing getValueReference();
  
  /**
   * Get all the maxValue property values for this QuantitativeValue object.
   *
   * @return A list of maxValue property values.
   */
  public List<Number> getMaxValues();
  
  /**
   * Get all the minValue property values for this QuantitativeValue object.
   *
   * @return A list of minValue property values.
   */
  public List<Number> getMinValues();
  
  /**
   * Get all the unitCode property values for this QuantitativeValue object.
   *
   * @return A list of unitCode property values.
   */
  public List<String> getUnitCodes();
  
  /**
   * Get all the value property values for this QuantitativeValue object.
   *
   * @return A list of value property values.
   */
  public List<Number> getValues();
  
  /**
   * Get all the valueReference property values for this QuantitativeValue object.
   *
   * @return A list of valueReference property values.
   */
  public List<Thing> getValueReferences();
  
  /**
   * Set the maxValue property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param maxValue The value to set.
   */
  public void setMaxValue(Number maxValue);
  
  /**
   * Set the minValue property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param minValue The value to set.
   */
  public void setMinValue(Number minValue);
  
  /**
   * Set the unitCode property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param unitCode The value to set.
   */
  public void setUnitCode(String unitCode);
  
  /**
   * Set the value property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param value The value to set.
   */
  public void setValue(Number value);
  
  /**
   * Set the valueReference property value for this QuantitativeValue object; overwriting any existing values.
   *
   * @param valueReference The value to set.
   */
  public void setValueReference(Thing valueReference);
  
  /**
   * Set the maxValue property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param maxValues The list of values to set.
   */
  public void setMaxValues(List<Number> maxValues);
  
  /**
   * Set the minValue property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param minValues The list of values to set.
   */
  public void setMinValues(List<Number> minValues);
  
  /**
   * Set the unitCode property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param unitCodes The list of values to set.
   */
  public void setUnitCodes(List<String> unitCodes);
  
  /**
   * Set the value property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param values The list of values to set.
   */
  public void setValues(List<Number> values);
  
  /**
   * Set the valueReference property values for this QuantitativeValue object; overwriting any existing values.
   *
   * @param valueReferences The list of values to set.
   */
  public void setValueReferences(List<Thing> valueReferences);
  
  /**
   * Adds a maxValue property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param maxValue The value to add.
   */
  public void addMaxValue(Number maxValue);
  
  /**
   * Adds a minValue property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param minValue The value to add.
   */
  public void addMinValue(Number minValue);
  
  /**
   * Adds a unitCode property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param unitCode The value to add.
   */
  public void addUnitCode(String unitCode);
  
  /**
   * Adds a value property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param value The value to add.
   */
  public void addValue(Number value);
  
  /**
   * Adds a valueReference property value for this QuantitativeValue object; appending it to the list of existing values.
   *
   * @param valueReference The value to add.
   */
  public void addValueReference(Thing valueReference);
  
}