package org.schema;

import java.lang.Long;
import java.util.List;
import org.schema.Answer;
import org.schema.CreativeWork;
import org.schema.SchemaObject;

/**
 * A specific question - e.g. from a user seeking answers online, or collected in a Frequently Asked Questions (FAQ) document.
 */
public interface Question extends CreativeWork, SchemaObject {

  /**
   * Get a single acceptedAnswer property value for this Question object.
   *
   * @return The first acceptedAnswer property value.
   */
  public Answer getAcceptedAnswer();
  
  /**
   * Get a single answerCount property value for this Question object.
   *
   * @return The first answerCount property value.
   */
  public Long getAnswerCount();
  
  /**
   * Get a single downvoteCount property value for this Question object.
   *
   * @return The first downvoteCount property value.
   */
  public Long getDownvoteCount();
  
  /**
   * Get a single suggestedAnswer property value for this Question object.
   *
   * @return The first suggestedAnswer property value.
   */
  public Answer getSuggestedAnswer();
  
  /**
   * Get a single upvoteCount property value for this Question object.
   *
   * @return The first upvoteCount property value.
   */
  public Long getUpvoteCount();
  
  /**
   * Get all the acceptedAnswer property values for this Question object.
   *
   * @return A list of acceptedAnswer property values.
   */
  public List<Answer> getAcceptedAnswers();
  
  /**
   * Get all the answerCount property values for this Question object.
   *
   * @return A list of answerCount property values.
   */
  public List<Long> getAnswerCounts();
  
  /**
   * Get all the downvoteCount property values for this Question object.
   *
   * @return A list of downvoteCount property values.
   */
  public List<Long> getDownvoteCounts();
  
  /**
   * Get all the suggestedAnswer property values for this Question object.
   *
   * @return A list of suggestedAnswer property values.
   */
  public List<Answer> getSuggestedAnswers();
  
  /**
   * Get all the upvoteCount property values for this Question object.
   *
   * @return A list of upvoteCount property values.
   */
  public List<Long> getUpvoteCounts();
  
  /**
   * Set the acceptedAnswer property value for this Question object; overwriting any existing values.
   *
   * @param acceptedAnswer The value to set.
   */
  public void setAcceptedAnswer(Answer acceptedAnswer);
  
  /**
   * Set the answerCount property value for this Question object; overwriting any existing values.
   *
   * @param answerCount The value to set.
   */
  public void setAnswerCount(Long answerCount);
  
  /**
   * Set the downvoteCount property value for this Question object; overwriting any existing values.
   *
   * @param downvoteCount The value to set.
   */
  public void setDownvoteCount(Long downvoteCount);
  
  /**
   * Set the suggestedAnswer property value for this Question object; overwriting any existing values.
   *
   * @param suggestedAnswer The value to set.
   */
  public void setSuggestedAnswer(Answer suggestedAnswer);
  
  /**
   * Set the upvoteCount property value for this Question object; overwriting any existing values.
   *
   * @param upvoteCount The value to set.
   */
  public void setUpvoteCount(Long upvoteCount);
  
  /**
   * Set the acceptedAnswer property values for this Question object; overwriting any existing values.
   *
   * @param acceptedAnswers The list of values to set.
   */
  public void setAcceptedAnswers(List<Answer> acceptedAnswers);
  
  /**
   * Set the answerCount property values for this Question object; overwriting any existing values.
   *
   * @param answerCounts The list of values to set.
   */
  public void setAnswerCounts(List<Long> answerCounts);
  
  /**
   * Set the downvoteCount property values for this Question object; overwriting any existing values.
   *
   * @param downvoteCounts The list of values to set.
   */
  public void setDownvoteCounts(List<Long> downvoteCounts);
  
  /**
   * Set the suggestedAnswer property values for this Question object; overwriting any existing values.
   *
   * @param suggestedAnswers The list of values to set.
   */
  public void setSuggestedAnswers(List<Answer> suggestedAnswers);
  
  /**
   * Set the upvoteCount property values for this Question object; overwriting any existing values.
   *
   * @param upvoteCounts The list of values to set.
   */
  public void setUpvoteCounts(List<Long> upvoteCounts);
  
  /**
   * Adds a acceptedAnswer property value for this Question object; appending it to the list of existing values.
   *
   * @param acceptedAnswer The value to add.
   */
  public void addAcceptedAnswer(Answer acceptedAnswer);
  
  /**
   * Adds a answerCount property value for this Question object; appending it to the list of existing values.
   *
   * @param answerCount The value to add.
   */
  public void addAnswerCount(Long answerCount);
  
  /**
   * Adds a downvoteCount property value for this Question object; appending it to the list of existing values.
   *
   * @param downvoteCount The value to add.
   */
  public void addDownvoteCount(Long downvoteCount);
  
  /**
   * Adds a suggestedAnswer property value for this Question object; appending it to the list of existing values.
   *
   * @param suggestedAnswer The value to add.
   */
  public void addSuggestedAnswer(Answer suggestedAnswer);
  
  /**
   * Adds a upvoteCount property value for this Question object; appending it to the list of existing values.
   *
   * @param upvoteCount The value to add.
   */
  public void addUpvoteCount(Long upvoteCount);
  
}