package org.schema;

import java.util.List;
import org.schema.Episode;
import org.schema.Organization;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.Season;
import org.schema.Thing;
import org.schema.VideoObject;

/**
 * A radio episode which can be part of a series or season.
 */
public interface RadioEpisode extends Episode, SchemaObject {

  /**
   * Get a single actor property value for this RadioEpisode object.
   *
   * @return The first actor property value.
   */
  public Person getActor();
  
  /**
   * Get a single director property value for this RadioEpisode object.
   *
   * @return The first director property value.
   */
  public Person getDirector();
  
  /**
   * Get a single musicBy property value for this RadioEpisode object.
   *
   * @return The first musicBy property value.
   */
  public Thing getMusicBy();
  
  /**
   * Get a single partOfSeason property value for this RadioEpisode object.
   *
   * @return The first partOfSeason property value.
   */
  public Season getPartOfSeason();
  
  /**
   * Get a single producer property value for this RadioEpisode object.
   *
   * @return The first producer property value.
   */
  public Person getProducer();
  
  /**
   * Get a single productionCompany property value for this RadioEpisode object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany();
  
  /**
   * Get a single trailer property value for this RadioEpisode object.
   *
   * @return The first trailer property value.
   */
  public VideoObject getTrailer();
  
  /**
   * Get all the actor property values for this RadioEpisode object.
   *
   * @return A list of actor property values.
   */
  public List<Person> getActors();
  
  /**
   * Get all the director property values for this RadioEpisode object.
   *
   * @return A list of director property values.
   */
  public List<Person> getDirectors();
  
  /**
   * Get all the musicBy property values for this RadioEpisode object.
   *
   * @return A list of musicBy property values.
   */
  public List<Thing> getMusicBies();
  
  /**
   * Get all the partOfSeason property values for this RadioEpisode object.
   *
   * @return A list of partOfSeason property values.
   */
  public List<Season> getPartOfSeasons();
  
  /**
   * Get all the producer property values for this RadioEpisode object.
   *
   * @return A list of producer property values.
   */
  public List<Person> getProducers();
  
  /**
   * Get all the productionCompany property values for this RadioEpisode object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies();
  
  /**
   * Get all the trailer property values for this RadioEpisode object.
   *
   * @return A list of trailer property values.
   */
  public List<VideoObject> getTrailers();
  
  /**
   * Set the actor property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param actor The value to set.
   */
  public void setActor(Person actor);
  
  /**
   * Set the director property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param director The value to set.
   */
  public void setDirector(Person director);
  
  /**
   * Set the musicBy property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param musicBy The value to set.
   */
  public void setMusicBy(Thing musicBy);
  
  /**
   * Set the partOfSeason property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param partOfSeason The value to set.
   */
  public void setPartOfSeason(Season partOfSeason);
  
  /**
   * Set the producer property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param producer The value to set.
   */
  public void setProducer(Person producer);
  
  /**
   * Set the productionCompany property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany);
  
  /**
   * Set the trailer property value for this RadioEpisode object; overwriting any existing values.
   *
   * @param trailer The value to set.
   */
  public void setTrailer(VideoObject trailer);
  
  /**
   * Set the actor property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param actors The list of values to set.
   */
  public void setActors(List<Person> actors);
  
  /**
   * Set the director property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param directors The list of values to set.
   */
  public void setDirectors(List<Person> directors);
  
  /**
   * Set the musicBy property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param musicBies The list of values to set.
   */
  public void setMusicBies(List<Thing> musicBies);
  
  /**
   * Set the partOfSeason property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param partOfSeasons The list of values to set.
   */
  public void setPartOfSeasons(List<Season> partOfSeasons);
  
  /**
   * Set the producer property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param producers The list of values to set.
   */
  public void setProducers(List<Person> producers);
  
  /**
   * Set the productionCompany property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies);
  
  /**
   * Set the trailer property values for this RadioEpisode object; overwriting any existing values.
   *
   * @param trailers The list of values to set.
   */
  public void setTrailers(List<VideoObject> trailers);
  
  /**
   * Adds a actor property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param actor The value to add.
   */
  public void addActor(Person actor);
  
  /**
   * Adds a director property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param director The value to add.
   */
  public void addDirector(Person director);
  
  /**
   * Adds a musicBy property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param musicBy The value to add.
   */
  public void addMusicBy(Thing musicBy);
  
  /**
   * Adds a partOfSeason property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param partOfSeason The value to add.
   */
  public void addPartOfSeason(Season partOfSeason);
  
  /**
   * Adds a producer property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param producer The value to add.
   */
  public void addProducer(Person producer);
  
  /**
   * Adds a productionCompany property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany);
  
  /**
   * Adds a trailer property value for this RadioEpisode object; appending it to the list of existing values.
   *
   * @param trailer The value to add.
   */
  public void addTrailer(VideoObject trailer);
  
}