package org.schema;

import java.util.List;
import org.schema.Episode;
import org.schema.Number;
import org.schema.SchemaObject;
import org.schema.Season;
import org.schema.VideoObject;

/**
 * Season dedicated to radio broadcast and associated online delivery.
 */
public interface RadioSeason extends Season, SchemaObject {

  /**
   * Get a single episode property value for this RadioSeason object.
   *
   * @return The first episode property value.
   */
  public Episode getEpisode();
  
  /**
   * Get a single numberOfEpisodes property value for this RadioSeason object.
   *
   * @return The first numberOfEpisodes property value.
   */
  public Number getNumberOfEpisodes();
  
  /**
   * Get a single trailer property value for this RadioSeason object.
   *
   * @return The first trailer property value.
   */
  public VideoObject getTrailer();
  
  /**
   * Get all the episode property values for this RadioSeason object.
   *
   * @return A list of episode property values.
   */
  public List<Episode> getEpisodes();
  
  /**
   * Get all the numberOfEpisodes property values for this RadioSeason object.
   *
   * @return A list of numberOfEpisodes property values.
   */
  public List<Number> getNumberOfEpisodess();
  
  /**
   * Get all the trailer property values for this RadioSeason object.
   *
   * @return A list of trailer property values.
   */
  public List<VideoObject> getTrailers();
  
  /**
   * Set the episode property value for this RadioSeason object; overwriting any existing values.
   *
   * @param episode The value to set.
   */
  public void setEpisode(Episode episode);
  
  /**
   * Set the numberOfEpisodes property value for this RadioSeason object; overwriting any existing values.
   *
   * @param numberOfEpisodes The value to set.
   */
  public void setNumberOfEpisodes(Number numberOfEpisodes);
  
  /**
   * Set the trailer property value for this RadioSeason object; overwriting any existing values.
   *
   * @param trailer The value to set.
   */
  public void setTrailer(VideoObject trailer);
  
  /**
   * Set the episode property values for this RadioSeason object; overwriting any existing values.
   *
   * @param episodes The list of values to set.
   */
  public void setEpisodes(List<Episode> episodes);
  
  /**
   * Set the numberOfEpisodes property values for this RadioSeason object; overwriting any existing values.
   *
   * @param numberOfEpisodess The list of values to set.
   */
  public void setNumberOfEpisodess(List<Number> numberOfEpisodess);
  
  /**
   * Set the trailer property values for this RadioSeason object; overwriting any existing values.
   *
   * @param trailers The list of values to set.
   */
  public void setTrailers(List<VideoObject> trailers);
  
  /**
   * Adds a episode property value for this RadioSeason object; appending it to the list of existing values.
   *
   * @param episode The value to add.
   */
  public void addEpisode(Episode episode);
  
  /**
   * Adds a numberOfEpisodes property value for this RadioSeason object; appending it to the list of existing values.
   *
   * @param numberOfEpisodes The value to add.
   */
  public void addNumberOfEpisodes(Number numberOfEpisodes);
  
  /**
   * Adds a trailer property value for this RadioSeason object; appending it to the list of existing values.
   *
   * @param trailer The value to add.
   */
  public void addTrailer(VideoObject trailer);
  
}