package org.schema;

import java.util.List;
import org.schema.DeliveryMethod;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TransferAction;

/**
 * The act of physically/electronically taking delivery of an object thathas been transferred from an origin to a destination. Reciprocal of SendAction.<p>Related actions:</p><ul><li><a href="http://schema.org/SendAction">SendAction</a>: The reciprocal of ReceiveAction.</li><li><a href="http://schema.org/TakeAction">TakeAction</a>: Unlike TakeAction, ReceiveAction does not imply that the ownership has been transfered (e.g. I can receive a package, but it does not mean the package is now mine).</li></ul>
 */
public interface ReceiveAction extends TransferAction, SchemaObject {

  /**
   * Get a single deliveryMethod property value for this ReceiveAction object.
   *
   * @return The first deliveryMethod property value.
   */
  public DeliveryMethod getDeliveryMethod();
  
  /**
   * Get a single sender property value for this ReceiveAction object.
   *
   * @return The first sender property value.
   */
  public Thing getSender();
  
  /**
   * Get all the deliveryMethod property values for this ReceiveAction object.
   *
   * @return A list of deliveryMethod property values.
   */
  public List<DeliveryMethod> getDeliveryMethods();
  
  /**
   * Get all the sender property values for this ReceiveAction object.
   *
   * @return A list of sender property values.
   */
  public List<Thing> getSenders();
  
  /**
   * Set the deliveryMethod property value for this ReceiveAction object; overwriting any existing values.
   *
   * @param deliveryMethod The value to set.
   */
  public void setDeliveryMethod(DeliveryMethod deliveryMethod);
  
  /**
   * Set the sender property value for this ReceiveAction object; overwriting any existing values.
   *
   * @param sender The value to set.
   */
  public void setSender(Thing sender);
  
  /**
   * Set the deliveryMethod property values for this ReceiveAction object; overwriting any existing values.
   *
   * @param deliveryMethods The list of values to set.
   */
  public void setDeliveryMethods(List<DeliveryMethod> deliveryMethods);
  
  /**
   * Set the sender property values for this ReceiveAction object; overwriting any existing values.
   *
   * @param senders The list of values to set.
   */
  public void setSenders(List<Thing> senders);
  
  /**
   * Adds a deliveryMethod property value for this ReceiveAction object; appending it to the list of existing values.
   *
   * @param deliveryMethod The value to add.
   */
  public void addDeliveryMethod(DeliveryMethod deliveryMethod);
  
  /**
   * Adds a sender property value for this ReceiveAction object; appending it to the list of existing values.
   *
   * @param sender The value to add.
   */
  public void addSender(Thing sender);
  
}