package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Duration;
import org.schema.NutritionInformation;
import org.schema.SchemaObject;

/**
 * A recipe.
 */
public interface Recipe extends CreativeWork, SchemaObject {

  /**
   * Get a single cookTime property value for this Recipe object.
   *
   * @return The first cookTime property value.
   */
  public Duration getCookTime();
  
  /**
   * Get a single cookingMethod property value for this Recipe object.
   *
   * @return The first cookingMethod property value.
   */
  public String getCookingMethod();
  
  /**
   * Get a single ingredients property value for this Recipe object.
   *
   * @return The first ingredients property value.
   */
  public String getIngredients();
  
  /**
   * Get a single nutrition property value for this Recipe object.
   *
   * @return The first nutrition property value.
   */
  public NutritionInformation getNutrition();
  
  /**
   * Get a single prepTime property value for this Recipe object.
   *
   * @return The first prepTime property value.
   */
  public Duration getPrepTime();
  
  /**
   * Get a single recipeCategory property value for this Recipe object.
   *
   * @return The first recipeCategory property value.
   */
  public String getRecipeCategory();
  
  /**
   * Get a single recipeCuisine property value for this Recipe object.
   *
   * @return The first recipeCuisine property value.
   */
  public String getRecipeCuisine();
  
  /**
   * Get a single recipeInstructions property value for this Recipe object.
   *
   * @return The first recipeInstructions property value.
   */
  public String getRecipeInstructions();
  
  /**
   * Get a single recipeYield property value for this Recipe object.
   *
   * @return The first recipeYield property value.
   */
  public String getRecipeYield();
  
  /**
   * Get a single totalTime property value for this Recipe object.
   *
   * @return The first totalTime property value.
   */
  public Duration getTotalTime();
  
  /**
   * Get all the cookTime property values for this Recipe object.
   *
   * @return A list of cookTime property values.
   */
  public List<Duration> getCookTimes();
  
  /**
   * Get all the cookingMethod property values for this Recipe object.
   *
   * @return A list of cookingMethod property values.
   */
  public List<String> getCookingMethods();
  
  /**
   * Get all the ingredients property values for this Recipe object.
   *
   * @return A list of ingredients property values.
   */
  public List<String> getIngredientss();
  
  /**
   * Get all the nutrition property values for this Recipe object.
   *
   * @return A list of nutrition property values.
   */
  public List<NutritionInformation> getNutritions();
  
  /**
   * Get all the prepTime property values for this Recipe object.
   *
   * @return A list of prepTime property values.
   */
  public List<Duration> getPrepTimes();
  
  /**
   * Get all the recipeCategory property values for this Recipe object.
   *
   * @return A list of recipeCategory property values.
   */
  public List<String> getRecipeCategories();
  
  /**
   * Get all the recipeCuisine property values for this Recipe object.
   *
   * @return A list of recipeCuisine property values.
   */
  public List<String> getRecipeCuisines();
  
  /**
   * Get all the recipeInstructions property values for this Recipe object.
   *
   * @return A list of recipeInstructions property values.
   */
  public List<String> getRecipeInstructionss();
  
  /**
   * Get all the recipeYield property values for this Recipe object.
   *
   * @return A list of recipeYield property values.
   */
  public List<String> getRecipeYields();
  
  /**
   * Get all the totalTime property values for this Recipe object.
   *
   * @return A list of totalTime property values.
   */
  public List<Duration> getTotalTimes();
  
  /**
   * Set the cookTime property value for this Recipe object; overwriting any existing values.
   *
   * @param cookTime The value to set.
   */
  public void setCookTime(Duration cookTime);
  
  /**
   * Set the cookingMethod property value for this Recipe object; overwriting any existing values.
   *
   * @param cookingMethod The value to set.
   */
  public void setCookingMethod(String cookingMethod);
  
  /**
   * Set the ingredients property value for this Recipe object; overwriting any existing values.
   *
   * @param ingredients The value to set.
   */
  public void setIngredients(String ingredients);
  
  /**
   * Set the nutrition property value for this Recipe object; overwriting any existing values.
   *
   * @param nutrition The value to set.
   */
  public void setNutrition(NutritionInformation nutrition);
  
  /**
   * Set the prepTime property value for this Recipe object; overwriting any existing values.
   *
   * @param prepTime The value to set.
   */
  public void setPrepTime(Duration prepTime);
  
  /**
   * Set the recipeCategory property value for this Recipe object; overwriting any existing values.
   *
   * @param recipeCategory The value to set.
   */
  public void setRecipeCategory(String recipeCategory);
  
  /**
   * Set the recipeCuisine property value for this Recipe object; overwriting any existing values.
   *
   * @param recipeCuisine The value to set.
   */
  public void setRecipeCuisine(String recipeCuisine);
  
  /**
   * Set the recipeInstructions property value for this Recipe object; overwriting any existing values.
   *
   * @param recipeInstructions The value to set.
   */
  public void setRecipeInstructions(String recipeInstructions);
  
  /**
   * Set the recipeYield property value for this Recipe object; overwriting any existing values.
   *
   * @param recipeYield The value to set.
   */
  public void setRecipeYield(String recipeYield);
  
  /**
   * Set the totalTime property value for this Recipe object; overwriting any existing values.
   *
   * @param totalTime The value to set.
   */
  public void setTotalTime(Duration totalTime);
  
  /**
   * Set the cookTime property values for this Recipe object; overwriting any existing values.
   *
   * @param cookTimes The list of values to set.
   */
  public void setCookTimes(List<Duration> cookTimes);
  
  /**
   * Set the cookingMethod property values for this Recipe object; overwriting any existing values.
   *
   * @param cookingMethods The list of values to set.
   */
  public void setCookingMethods(List<String> cookingMethods);
  
  /**
   * Set the ingredients property values for this Recipe object; overwriting any existing values.
   *
   * @param ingredientss The list of values to set.
   */
  public void setIngredientss(List<String> ingredientss);
  
  /**
   * Set the nutrition property values for this Recipe object; overwriting any existing values.
   *
   * @param nutritions The list of values to set.
   */
  public void setNutritions(List<NutritionInformation> nutritions);
  
  /**
   * Set the prepTime property values for this Recipe object; overwriting any existing values.
   *
   * @param prepTimes The list of values to set.
   */
  public void setPrepTimes(List<Duration> prepTimes);
  
  /**
   * Set the recipeCategory property values for this Recipe object; overwriting any existing values.
   *
   * @param recipeCategories The list of values to set.
   */
  public void setRecipeCategories(List<String> recipeCategories);
  
  /**
   * Set the recipeCuisine property values for this Recipe object; overwriting any existing values.
   *
   * @param recipeCuisines The list of values to set.
   */
  public void setRecipeCuisines(List<String> recipeCuisines);
  
  /**
   * Set the recipeInstructions property values for this Recipe object; overwriting any existing values.
   *
   * @param recipeInstructionss The list of values to set.
   */
  public void setRecipeInstructionss(List<String> recipeInstructionss);
  
  /**
   * Set the recipeYield property values for this Recipe object; overwriting any existing values.
   *
   * @param recipeYields The list of values to set.
   */
  public void setRecipeYields(List<String> recipeYields);
  
  /**
   * Set the totalTime property values for this Recipe object; overwriting any existing values.
   *
   * @param totalTimes The list of values to set.
   */
  public void setTotalTimes(List<Duration> totalTimes);
  
  /**
   * Adds a cookTime property value for this Recipe object; appending it to the list of existing values.
   *
   * @param cookTime The value to add.
   */
  public void addCookTime(Duration cookTime);
  
  /**
   * Adds a cookingMethod property value for this Recipe object; appending it to the list of existing values.
   *
   * @param cookingMethod The value to add.
   */
  public void addCookingMethod(String cookingMethod);
  
  /**
   * Adds a ingredients property value for this Recipe object; appending it to the list of existing values.
   *
   * @param ingredients The value to add.
   */
  public void addIngredients(String ingredients);
  
  /**
   * Adds a nutrition property value for this Recipe object; appending it to the list of existing values.
   *
   * @param nutrition The value to add.
   */
  public void addNutrition(NutritionInformation nutrition);
  
  /**
   * Adds a prepTime property value for this Recipe object; appending it to the list of existing values.
   *
   * @param prepTime The value to add.
   */
  public void addPrepTime(Duration prepTime);
  
  /**
   * Adds a recipeCategory property value for this Recipe object; appending it to the list of existing values.
   *
   * @param recipeCategory The value to add.
   */
  public void addRecipeCategory(String recipeCategory);
  
  /**
   * Adds a recipeCuisine property value for this Recipe object; appending it to the list of existing values.
   *
   * @param recipeCuisine The value to add.
   */
  public void addRecipeCuisine(String recipeCuisine);
  
  /**
   * Adds a recipeInstructions property value for this Recipe object; appending it to the list of existing values.
   *
   * @param recipeInstructions The value to add.
   */
  public void addRecipeInstructions(String recipeInstructions);
  
  /**
   * Adds a recipeYield property value for this Recipe object; appending it to the list of existing values.
   *
   * @param recipeYield The value to add.
   */
  public void addRecipeYield(String recipeYield);
  
  /**
   * Adds a totalTime property value for this Recipe object; appending it to the list of existing values.
   *
   * @param totalTime The value to add.
   */
  public void addTotalTime(Duration totalTime);
  
}