package org.schema;

import java.util.List;
import org.schema.RealEstateAgent;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TradeAction;

/**
 * The act of giving money in return for temporary use, but not ownership, of an object such as a vehicle or property. For example, an agent rents a property from a landlord in exchange for a periodic payment.
 */
public interface RentAction extends TradeAction, SchemaObject {

  /**
   * Get a single landlord property value for this RentAction object.
   *
   * @return The first landlord property value.
   */
  public Thing getLandlord();
  
  /**
   * Get a single realEstateAgent property value for this RentAction object.
   *
   * @return The first realEstateAgent property value.
   */
  public RealEstateAgent getRealEstateAgent();
  
  /**
   * Get all the landlord property values for this RentAction object.
   *
   * @return A list of landlord property values.
   */
  public List<Thing> getLandlords();
  
  /**
   * Get all the realEstateAgent property values for this RentAction object.
   *
   * @return A list of realEstateAgent property values.
   */
  public List<RealEstateAgent> getRealEstateAgents();
  
  /**
   * Set the landlord property value for this RentAction object; overwriting any existing values.
   *
   * @param landlord The value to set.
   */
  public void setLandlord(Thing landlord);
  
  /**
   * Set the realEstateAgent property value for this RentAction object; overwriting any existing values.
   *
   * @param realEstateAgent The value to set.
   */
  public void setRealEstateAgent(RealEstateAgent realEstateAgent);
  
  /**
   * Set the landlord property values for this RentAction object; overwriting any existing values.
   *
   * @param landlords The list of values to set.
   */
  public void setLandlords(List<Thing> landlords);
  
  /**
   * Set the realEstateAgent property values for this RentAction object; overwriting any existing values.
   *
   * @param realEstateAgents The list of values to set.
   */
  public void setRealEstateAgents(List<RealEstateAgent> realEstateAgents);
  
  /**
   * Adds a landlord property value for this RentAction object; appending it to the list of existing values.
   *
   * @param landlord The value to add.
   */
  public void addLandlord(Thing landlord);
  
  /**
   * Adds a realEstateAgent property value for this RentAction object; appending it to the list of existing values.
   *
   * @param realEstateAgent The value to add.
   */
  public void addRealEstateAgent(RealEstateAgent realEstateAgent);
  
}