package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.UpdateAction;

/**
 * The act of editing a recipient by replacing an old object with a new object.
 */
public interface ReplaceAction extends UpdateAction, SchemaObject {

  /**
   * Get a single replacee property value for this ReplaceAction object.
   *
   * @return The first replacee property value.
   */
  public Thing getReplacee();
  
  /**
   * Get a single replacer property value for this ReplaceAction object.
   *
   * @return The first replacer property value.
   */
  public Thing getReplacer();
  
  /**
   * Get all the replacee property values for this ReplaceAction object.
   *
   * @return A list of replacee property values.
   */
  public List<Thing> getReplacees();
  
  /**
   * Get all the replacer property values for this ReplaceAction object.
   *
   * @return A list of replacer property values.
   */
  public List<Thing> getReplacers();
  
  /**
   * Set the replacee property value for this ReplaceAction object; overwriting any existing values.
   *
   * @param replacee The value to set.
   */
  public void setReplacee(Thing replacee);
  
  /**
   * Set the replacer property value for this ReplaceAction object; overwriting any existing values.
   *
   * @param replacer The value to set.
   */
  public void setReplacer(Thing replacer);
  
  /**
   * Set the replacee property values for this ReplaceAction object; overwriting any existing values.
   *
   * @param replacees The list of values to set.
   */
  public void setReplacees(List<Thing> replacees);
  
  /**
   * Set the replacer property values for this ReplaceAction object; overwriting any existing values.
   *
   * @param replacers The list of values to set.
   */
  public void setReplacers(List<Thing> replacers);
  
  /**
   * Adds a replacee property value for this ReplaceAction object; appending it to the list of existing values.
   *
   * @param replacee The value to add.
   */
  public void addReplacee(Thing replacee);
  
  /**
   * Adds a replacer property value for this ReplaceAction object; appending it to the list of existing values.
   *
   * @param replacer The value to add.
   */
  public void addReplacer(Thing replacer);
  
}