package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Intangible;
import org.schema.ProgramMembership;
import org.schema.ReservationStatusType;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.Ticket;

/**
 * Describes a reservation for travel, dining or an event. Some reservations require tickets.Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, restaurant reservations, flights, or rental cars, use http://schema.org/Offer.
 */
public interface Reservation extends Intangible, SchemaObject {

  /**
   * Get a single bookingAgent property value for this Reservation object.
   *
   * @return The first bookingAgent property value.
   */
  public Thing getBookingAgent();
  
  /**
   * Get a single bookingTime property value for this Reservation object.
   *
   * @return The first bookingTime property value.
   */
  public Date getBookingTime();
  
  /**
   * Get a single modifiedTime property value for this Reservation object.
   *
   * @return The first modifiedTime property value.
   */
  public Date getModifiedTime();
  
  /**
   * Get a single priceCurrency property value for this Reservation object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency();
  
  /**
   * Get a single programMembershipUsed property value for this Reservation object.
   *
   * @return The first programMembershipUsed property value.
   */
  public ProgramMembership getProgramMembershipUsed();
  
  /**
   * Get a single provider property value for this Reservation object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider();
  
  /**
   * Get a single reservationFor property value for this Reservation object.
   *
   * @return The first reservationFor property value.
   */
  public Thing getReservationFor();
  
  /**
   * Get a single reservationId property value for this Reservation object.
   *
   * @return The first reservationId property value.
   */
  public String getReservationId();
  
  /**
   * Get a single reservationStatus property value for this Reservation object.
   *
   * @return The first reservationStatus property value.
   */
  public ReservationStatusType getReservationStatus();
  
  /**
   * Get a single reservedTicket property value for this Reservation object.
   *
   * @return The first reservedTicket property value.
   */
  public Ticket getReservedTicket();
  
  /**
   * Get a single totalPrice property value for this Reservation object.
   *
   * @return The first totalPrice property value.
   */
  public Thing getTotalPrice();
  
  /**
   * Get a single underName property value for this Reservation object.
   *
   * @return The first underName property value.
   */
  public Thing getUnderName();
  
  /**
   * Get all the bookingAgent property values for this Reservation object.
   *
   * @return A list of bookingAgent property values.
   */
  public List<Thing> getBookingAgents();
  
  /**
   * Get all the bookingTime property values for this Reservation object.
   *
   * @return A list of bookingTime property values.
   */
  public List<Date> getBookingTimes();
  
  /**
   * Get all the modifiedTime property values for this Reservation object.
   *
   * @return A list of modifiedTime property values.
   */
  public List<Date> getModifiedTimes();
  
  /**
   * Get all the priceCurrency property values for this Reservation object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies();
  
  /**
   * Get all the programMembershipUsed property values for this Reservation object.
   *
   * @return A list of programMembershipUsed property values.
   */
  public List<ProgramMembership> getProgramMembershipUseds();
  
  /**
   * Get all the provider property values for this Reservation object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders();
  
  /**
   * Get all the reservationFor property values for this Reservation object.
   *
   * @return A list of reservationFor property values.
   */
  public List<Thing> getReservationFors();
  
  /**
   * Get all the reservationId property values for this Reservation object.
   *
   * @return A list of reservationId property values.
   */
  public List<String> getReservationIds();
  
  /**
   * Get all the reservationStatus property values for this Reservation object.
   *
   * @return A list of reservationStatus property values.
   */
  public List<ReservationStatusType> getReservationStatuses();
  
  /**
   * Get all the reservedTicket property values for this Reservation object.
   *
   * @return A list of reservedTicket property values.
   */
  public List<Ticket> getReservedTickets();
  
  /**
   * Get all the totalPrice property values for this Reservation object.
   *
   * @return A list of totalPrice property values.
   */
  public List<Thing> getTotalPrices();
  
  /**
   * Get all the underName property values for this Reservation object.
   *
   * @return A list of underName property values.
   */
  public List<Thing> getUnderNames();
  
  /**
   * Set the bookingAgent property value for this Reservation object; overwriting any existing values.
   *
   * @param bookingAgent The value to set.
   */
  public void setBookingAgent(Thing bookingAgent);
  
  /**
   * Set the bookingTime property value for this Reservation object; overwriting any existing values.
   *
   * @param bookingTime The value to set.
   */
  public void setBookingTime(Date bookingTime);
  
  /**
   * Set the modifiedTime property value for this Reservation object; overwriting any existing values.
   *
   * @param modifiedTime The value to set.
   */
  public void setModifiedTime(Date modifiedTime);
  
  /**
   * Set the priceCurrency property value for this Reservation object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency);
  
  /**
   * Set the programMembershipUsed property value for this Reservation object; overwriting any existing values.
   *
   * @param programMembershipUsed The value to set.
   */
  public void setProgramMembershipUsed(ProgramMembership programMembershipUsed);
  
  /**
   * Set the provider property value for this Reservation object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider);
  
  /**
   * Set the reservationFor property value for this Reservation object; overwriting any existing values.
   *
   * @param reservationFor The value to set.
   */
  public void setReservationFor(Thing reservationFor);
  
  /**
   * Set the reservationId property value for this Reservation object; overwriting any existing values.
   *
   * @param reservationId The value to set.
   */
  public void setReservationId(String reservationId);
  
  /**
   * Set the reservationStatus property value for this Reservation object; overwriting any existing values.
   *
   * @param reservationStatus The value to set.
   */
  public void setReservationStatus(ReservationStatusType reservationStatus);
  
  /**
   * Set the reservedTicket property value for this Reservation object; overwriting any existing values.
   *
   * @param reservedTicket The value to set.
   */
  public void setReservedTicket(Ticket reservedTicket);
  
  /**
   * Set the totalPrice property value for this Reservation object; overwriting any existing values.
   *
   * @param totalPrice The value to set.
   */
  public void setTotalPrice(Thing totalPrice);
  
  /**
   * Set the underName property value for this Reservation object; overwriting any existing values.
   *
   * @param underName The value to set.
   */
  public void setUnderName(Thing underName);
  
  /**
   * Set the bookingAgent property values for this Reservation object; overwriting any existing values.
   *
   * @param bookingAgents The list of values to set.
   */
  public void setBookingAgents(List<Thing> bookingAgents);
  
  /**
   * Set the bookingTime property values for this Reservation object; overwriting any existing values.
   *
   * @param bookingTimes The list of values to set.
   */
  public void setBookingTimes(List<Date> bookingTimes);
  
  /**
   * Set the modifiedTime property values for this Reservation object; overwriting any existing values.
   *
   * @param modifiedTimes The list of values to set.
   */
  public void setModifiedTimes(List<Date> modifiedTimes);
  
  /**
   * Set the priceCurrency property values for this Reservation object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies);
  
  /**
   * Set the programMembershipUsed property values for this Reservation object; overwriting any existing values.
   *
   * @param programMembershipUseds The list of values to set.
   */
  public void setProgramMembershipUseds(List<ProgramMembership> programMembershipUseds);
  
  /**
   * Set the provider property values for this Reservation object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers);
  
  /**
   * Set the reservationFor property values for this Reservation object; overwriting any existing values.
   *
   * @param reservationFors The list of values to set.
   */
  public void setReservationFors(List<Thing> reservationFors);
  
  /**
   * Set the reservationId property values for this Reservation object; overwriting any existing values.
   *
   * @param reservationIds The list of values to set.
   */
  public void setReservationIds(List<String> reservationIds);
  
  /**
   * Set the reservationStatus property values for this Reservation object; overwriting any existing values.
   *
   * @param reservationStatuses The list of values to set.
   */
  public void setReservationStatuses(List<ReservationStatusType> reservationStatuses);
  
  /**
   * Set the reservedTicket property values for this Reservation object; overwriting any existing values.
   *
   * @param reservedTickets The list of values to set.
   */
  public void setReservedTickets(List<Ticket> reservedTickets);
  
  /**
   * Set the totalPrice property values for this Reservation object; overwriting any existing values.
   *
   * @param totalPrices The list of values to set.
   */
  public void setTotalPrices(List<Thing> totalPrices);
  
  /**
   * Set the underName property values for this Reservation object; overwriting any existing values.
   *
   * @param underNames The list of values to set.
   */
  public void setUnderNames(List<Thing> underNames);
  
  /**
   * Adds a bookingAgent property value for this Reservation object; appending it to the list of existing values.
   *
   * @param bookingAgent The value to add.
   */
  public void addBookingAgent(Thing bookingAgent);
  
  /**
   * Adds a bookingTime property value for this Reservation object; appending it to the list of existing values.
   *
   * @param bookingTime The value to add.
   */
  public void addBookingTime(Date bookingTime);
  
  /**
   * Adds a modifiedTime property value for this Reservation object; appending it to the list of existing values.
   *
   * @param modifiedTime The value to add.
   */
  public void addModifiedTime(Date modifiedTime);
  
  /**
   * Adds a priceCurrency property value for this Reservation object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency);
  
  /**
   * Adds a programMembershipUsed property value for this Reservation object; appending it to the list of existing values.
   *
   * @param programMembershipUsed The value to add.
   */
  public void addProgramMembershipUsed(ProgramMembership programMembershipUsed);
  
  /**
   * Adds a provider property value for this Reservation object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider);
  
  /**
   * Adds a reservationFor property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservationFor The value to add.
   */
  public void addReservationFor(Thing reservationFor);
  
  /**
   * Adds a reservationId property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservationId The value to add.
   */
  public void addReservationId(String reservationId);
  
  /**
   * Adds a reservationStatus property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservationStatus The value to add.
   */
  public void addReservationStatus(ReservationStatusType reservationStatus);
  
  /**
   * Adds a reservedTicket property value for this Reservation object; appending it to the list of existing values.
   *
   * @param reservedTicket The value to add.
   */
  public void addReservedTicket(Ticket reservedTicket);
  
  /**
   * Adds a totalPrice property value for this Reservation object; appending it to the list of existing values.
   *
   * @param totalPrice The value to add.
   */
  public void addTotalPrice(Thing totalPrice);
  
  /**
   * Adds a underName property value for this Reservation object; appending it to the list of existing values.
   *
   * @param underName The value to add.
   */
  public void addUnderName(Thing underName);
  
}