package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.PlanAction;
import org.schema.SchemaObject;

/**
 * Reserving a concrete object.<p>Related actions:</p><ul><li><a href="http://schema.org/ScheduleAction">ScheduleAction</a>: Unlike ScheduleAction, ReserveAction reserves concrete objects (e.g. a table, a hotel) towards a time slot / spatial allocation.</li></ul>
 */
public interface ReserveAction extends PlanAction, SchemaObject {

  /**
   * Get a single scheduledTime property value for this ReserveAction object.
   *
   * @return The first scheduledTime property value.
   */
  public Date getScheduledTime();
  
  /**
   * Get all the scheduledTime property values for this ReserveAction object.
   *
   * @return A list of scheduledTime property values.
   */
  public List<Date> getScheduledTimes();
  
  /**
   * Set the scheduledTime property value for this ReserveAction object; overwriting any existing values.
   *
   * @param scheduledTime The value to set.
   */
  public void setScheduledTime(Date scheduledTime);
  
  /**
   * Set the scheduledTime property values for this ReserveAction object; overwriting any existing values.
   *
   * @param scheduledTimes The list of values to set.
   */
  public void setScheduledTimes(List<Date> scheduledTimes);
  
  /**
   * Adds a scheduledTime property value for this ReserveAction object; appending it to the list of existing values.
   *
   * @param scheduledTime The value to add.
   */
  public void addScheduledTime(Date scheduledTime);
  
}