package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TransferAction;

/**
 * The act of returning to the origin that which was previously received (concrete objects) or taken (ownership).
 */
public interface ReturnAction extends TransferAction, SchemaObject {

  /**
   * Get a single recipient property value for this ReturnAction object.
   *
   * @return The first recipient property value.
   */
  public Thing getRecipient();
  
  /**
   * Get all the recipient property values for this ReturnAction object.
   *
   * @return A list of recipient property values.
   */
  public List<Thing> getRecipients();
  
  /**
   * Set the recipient property value for this ReturnAction object; overwriting any existing values.
   *
   * @param recipient The value to set.
   */
  public void setRecipient(Thing recipient);
  
  /**
   * Set the recipient property values for this ReturnAction object; overwriting any existing values.
   *
   * @param recipients The list of values to set.
   */
  public void setRecipients(List<Thing> recipients);
  
  /**
   * Adds a recipient property value for this ReturnAction object; appending it to the list of existing values.
   *
   * @param recipient The value to add.
   */
  public void addRecipient(Thing recipient);
  
}