package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Rating;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A review of an item - for example, a restaurant, movie, or store.
 */
public interface Review extends CreativeWork, SchemaObject {

  /**
   * Get a single itemReviewed property value for this Review object.
   *
   * @return The first itemReviewed property value.
   */
  public Thing getItemReviewed();
  
  /**
   * Get a single reviewBody property value for this Review object.
   *
   * @return The first reviewBody property value.
   */
  public String getReviewBody();
  
  /**
   * Get a single reviewRating property value for this Review object.
   *
   * @return The first reviewRating property value.
   */
  public Rating getReviewRating();
  
  /**
   * Get all the itemReviewed property values for this Review object.
   *
   * @return A list of itemReviewed property values.
   */
  public List<Thing> getItemRevieweds();
  
  /**
   * Get all the reviewBody property values for this Review object.
   *
   * @return A list of reviewBody property values.
   */
  public List<String> getReviewBodies();
  
  /**
   * Get all the reviewRating property values for this Review object.
   *
   * @return A list of reviewRating property values.
   */
  public List<Rating> getReviewRatings();
  
  /**
   * Set the itemReviewed property value for this Review object; overwriting any existing values.
   *
   * @param itemReviewed The value to set.
   */
  public void setItemReviewed(Thing itemReviewed);
  
  /**
   * Set the reviewBody property value for this Review object; overwriting any existing values.
   *
   * @param reviewBody The value to set.
   */
  public void setReviewBody(String reviewBody);
  
  /**
   * Set the reviewRating property value for this Review object; overwriting any existing values.
   *
   * @param reviewRating The value to set.
   */
  public void setReviewRating(Rating reviewRating);
  
  /**
   * Set the itemReviewed property values for this Review object; overwriting any existing values.
   *
   * @param itemRevieweds The list of values to set.
   */
  public void setItemRevieweds(List<Thing> itemRevieweds);
  
  /**
   * Set the reviewBody property values for this Review object; overwriting any existing values.
   *
   * @param reviewBodies The list of values to set.
   */
  public void setReviewBodies(List<String> reviewBodies);
  
  /**
   * Set the reviewRating property values for this Review object; overwriting any existing values.
   *
   * @param reviewRatings The list of values to set.
   */
  public void setReviewRatings(List<Rating> reviewRatings);
  
  /**
   * Adds a itemReviewed property value for this Review object; appending it to the list of existing values.
   *
   * @param itemReviewed The value to add.
   */
  public void addItemReviewed(Thing itemReviewed);
  
  /**
   * Adds a reviewBody property value for this Review object; appending it to the list of existing values.
   *
   * @param reviewBody The value to add.
   */
  public void addReviewBody(String reviewBody);
  
  /**
   * Adds a reviewRating property value for this Review object; appending it to the list of existing values.
   *
   * @param reviewRating The value to add.
   */
  public void addReviewRating(Rating reviewRating);
  
}