package org.schema;

import java.util.List;
import org.schema.Action;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of searching for an object.<p>Related actions:</p><ul><li><a href="http://schema.org/FindAction">FindAction</a>: SearchAction generally leads to a FindAction, but not necessarily.</li></ul>
 */
public interface SearchAction extends Action, SchemaObject {

  /**
   * Get a single query property value for this SearchAction object.
   *
   * @return The first query property value.
   */
  public Thing getQuery();
  
  /**
   * Get all the query property values for this SearchAction object.
   *
   * @return A list of query property values.
   */
  public List<Thing> getQueries();
  
  /**
   * Set the query property value for this SearchAction object; overwriting any existing values.
   *
   * @param query The value to set.
   */
  public void setQuery(Thing query);
  
  /**
   * Set the query property values for this SearchAction object; overwriting any existing values.
   *
   * @param queries The list of values to set.
   */
  public void setQueries(List<Thing> queries);
  
  /**
   * Adds a query property value for this SearchAction object; appending it to the list of existing values.
   *
   * @param query The value to add.
   */
  public void addQuery(Thing query);
  
}