package org.schema;

import java.lang.Long;
import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Episode;
import org.schema.Number;
import org.schema.Organization;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.VideoObject;

/**
 * A TV or radio season.
 */
public interface Season extends CreativeWork, SchemaObject {

  /**
   * Get a single endDate property value for this Season object.
   *
   * @return The first endDate property value.
   */
  public Date getEndDate();
  
  /**
   * Get a single episode property value for this Season object.
   *
   * @return The first episode property value.
   */
  public Episode getEpisode();
  
  /**
   * Get a single numberOfEpisodes property value for this Season object.
   *
   * @return The first numberOfEpisodes property value.
   */
  public Number getNumberOfEpisodes();
  
  /**
   * Get a single position property value for this Season object.
   *
   * @return The first position property value.
   */
  public String getPosition();
  
  /**
   * Get a single producer property value for this Season object.
   *
   * @return The first producer property value.
   */
  public Person getProducer();
  
  /**
   * Get a single productionCompany property value for this Season object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany();
  
  /**
   * Get a single seasonNumber property value for this Season object.
   *
   * @return The first seasonNumber property value.
   */
  public Long getSeasonNumber();
  
  /**
   * Get a single startDate property value for this Season object.
   *
   * @return The first startDate property value.
   */
  public Date getStartDate();
  
  /**
   * Get a single trailer property value for this Season object.
   *
   * @return The first trailer property value.
   */
  public VideoObject getTrailer();
  
  /**
   * Get all the endDate property values for this Season object.
   *
   * @return A list of endDate property values.
   */
  public List<Date> getEndDates();
  
  /**
   * Get all the episode property values for this Season object.
   *
   * @return A list of episode property values.
   */
  public List<Episode> getEpisodes();
  
  /**
   * Get all the numberOfEpisodes property values for this Season object.
   *
   * @return A list of numberOfEpisodes property values.
   */
  public List<Number> getNumberOfEpisodess();
  
  /**
   * Get all the position property values for this Season object.
   *
   * @return A list of position property values.
   */
  public List<String> getPositions();
  
  /**
   * Get all the producer property values for this Season object.
   *
   * @return A list of producer property values.
   */
  public List<Person> getProducers();
  
  /**
   * Get all the productionCompany property values for this Season object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies();
  
  /**
   * Get all the seasonNumber property values for this Season object.
   *
   * @return A list of seasonNumber property values.
   */
  public List<Long> getSeasonNumbers();
  
  /**
   * Get all the startDate property values for this Season object.
   *
   * @return A list of startDate property values.
   */
  public List<Date> getStartDates();
  
  /**
   * Get all the trailer property values for this Season object.
   *
   * @return A list of trailer property values.
   */
  public List<VideoObject> getTrailers();
  
  /**
   * Set the endDate property value for this Season object; overwriting any existing values.
   *
   * @param endDate The value to set.
   */
  public void setEndDate(Date endDate);
  
  /**
   * Set the episode property value for this Season object; overwriting any existing values.
   *
   * @param episode The value to set.
   */
  public void setEpisode(Episode episode);
  
  /**
   * Set the numberOfEpisodes property value for this Season object; overwriting any existing values.
   *
   * @param numberOfEpisodes The value to set.
   */
  public void setNumberOfEpisodes(Number numberOfEpisodes);
  
  /**
   * Set the position property value for this Season object; overwriting any existing values.
   *
   * @param position The value to set.
   */
  public void setPosition(String position);
  
  /**
   * Set the producer property value for this Season object; overwriting any existing values.
   *
   * @param producer The value to set.
   */
  public void setProducer(Person producer);
  
  /**
   * Set the productionCompany property value for this Season object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany);
  
  /**
   * Set the seasonNumber property value for this Season object; overwriting any existing values.
   *
   * @param seasonNumber The value to set.
   */
  public void setSeasonNumber(Long seasonNumber);
  
  /**
   * Set the startDate property value for this Season object; overwriting any existing values.
   *
   * @param startDate The value to set.
   */
  public void setStartDate(Date startDate);
  
  /**
   * Set the trailer property value for this Season object; overwriting any existing values.
   *
   * @param trailer The value to set.
   */
  public void setTrailer(VideoObject trailer);
  
  /**
   * Set the endDate property values for this Season object; overwriting any existing values.
   *
   * @param endDates The list of values to set.
   */
  public void setEndDates(List<Date> endDates);
  
  /**
   * Set the episode property values for this Season object; overwriting any existing values.
   *
   * @param episodes The list of values to set.
   */
  public void setEpisodes(List<Episode> episodes);
  
  /**
   * Set the numberOfEpisodes property values for this Season object; overwriting any existing values.
   *
   * @param numberOfEpisodess The list of values to set.
   */
  public void setNumberOfEpisodess(List<Number> numberOfEpisodess);
  
  /**
   * Set the position property values for this Season object; overwriting any existing values.
   *
   * @param positions The list of values to set.
   */
  public void setPositions(List<String> positions);
  
  /**
   * Set the producer property values for this Season object; overwriting any existing values.
   *
   * @param producers The list of values to set.
   */
  public void setProducers(List<Person> producers);
  
  /**
   * Set the productionCompany property values for this Season object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies);
  
  /**
   * Set the seasonNumber property values for this Season object; overwriting any existing values.
   *
   * @param seasonNumbers The list of values to set.
   */
  public void setSeasonNumbers(List<Long> seasonNumbers);
  
  /**
   * Set the startDate property values for this Season object; overwriting any existing values.
   *
   * @param startDates The list of values to set.
   */
  public void setStartDates(List<Date> startDates);
  
  /**
   * Set the trailer property values for this Season object; overwriting any existing values.
   *
   * @param trailers The list of values to set.
   */
  public void setTrailers(List<VideoObject> trailers);
  
  /**
   * Adds a endDate property value for this Season object; appending it to the list of existing values.
   *
   * @param endDate The value to add.
   */
  public void addEndDate(Date endDate);
  
  /**
   * Adds a episode property value for this Season object; appending it to the list of existing values.
   *
   * @param episode The value to add.
   */
  public void addEpisode(Episode episode);
  
  /**
   * Adds a numberOfEpisodes property value for this Season object; appending it to the list of existing values.
   *
   * @param numberOfEpisodes The value to add.
   */
  public void addNumberOfEpisodes(Number numberOfEpisodes);
  
  /**
   * Adds a position property value for this Season object; appending it to the list of existing values.
   *
   * @param position The value to add.
   */
  public void addPosition(String position);
  
  /**
   * Adds a producer property value for this Season object; appending it to the list of existing values.
   *
   * @param producer The value to add.
   */
  public void addProducer(Person producer);
  
  /**
   * Adds a productionCompany property value for this Season object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany);
  
  /**
   * Adds a seasonNumber property value for this Season object; appending it to the list of existing values.
   *
   * @param seasonNumber The value to add.
   */
  public void addSeasonNumber(Long seasonNumber);
  
  /**
   * Adds a startDate property value for this Season object; appending it to the list of existing values.
   *
   * @param startDate The value to add.
   */
  public void addStartDate(Date startDate);
  
  /**
   * Adds a trailer property value for this Season object; appending it to the list of existing values.
   *
   * @param trailer The value to add.
   */
  public void addTrailer(VideoObject trailer);
  
}