package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Intangible;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Used to describe a seat, such as a reserved seat in an event reservation.
 */
public interface Seat extends Intangible, SchemaObject {

  /**
   * Get a single seatNumber property value for this Seat object.
   *
   * @return The first seatNumber property value.
   */
  public String getSeatNumber();
  
  /**
   * Get a single seatRow property value for this Seat object.
   *
   * @return The first seatRow property value.
   */
  public String getSeatRow();
  
  /**
   * Get a single seatSection property value for this Seat object.
   *
   * @return The first seatSection property value.
   */
  public String getSeatSection();
  
  /**
   * Get a single seatingType property value for this Seat object.
   *
   * @return The first seatingType property value.
   */
  public Thing getSeatingType();
  
  /**
   * Get all the seatNumber property values for this Seat object.
   *
   * @return A list of seatNumber property values.
   */
  public List<String> getSeatNumbers();
  
  /**
   * Get all the seatRow property values for this Seat object.
   *
   * @return A list of seatRow property values.
   */
  public List<String> getSeatRows();
  
  /**
   * Get all the seatSection property values for this Seat object.
   *
   * @return A list of seatSection property values.
   */
  public List<String> getSeatSections();
  
  /**
   * Get all the seatingType property values for this Seat object.
   *
   * @return A list of seatingType property values.
   */
  public List<Thing> getSeatingTypes();
  
  /**
   * Set the seatNumber property value for this Seat object; overwriting any existing values.
   *
   * @param seatNumber The value to set.
   */
  public void setSeatNumber(String seatNumber);
  
  /**
   * Set the seatRow property value for this Seat object; overwriting any existing values.
   *
   * @param seatRow The value to set.
   */
  public void setSeatRow(String seatRow);
  
  /**
   * Set the seatSection property value for this Seat object; overwriting any existing values.
   *
   * @param seatSection The value to set.
   */
  public void setSeatSection(String seatSection);
  
  /**
   * Set the seatingType property value for this Seat object; overwriting any existing values.
   *
   * @param seatingType The value to set.
   */
  public void setSeatingType(Thing seatingType);
  
  /**
   * Set the seatNumber property values for this Seat object; overwriting any existing values.
   *
   * @param seatNumbers The list of values to set.
   */
  public void setSeatNumbers(List<String> seatNumbers);
  
  /**
   * Set the seatRow property values for this Seat object; overwriting any existing values.
   *
   * @param seatRows The list of values to set.
   */
  public void setSeatRows(List<String> seatRows);
  
  /**
   * Set the seatSection property values for this Seat object; overwriting any existing values.
   *
   * @param seatSections The list of values to set.
   */
  public void setSeatSections(List<String> seatSections);
  
  /**
   * Set the seatingType property values for this Seat object; overwriting any existing values.
   *
   * @param seatingTypes The list of values to set.
   */
  public void setSeatingTypes(List<Thing> seatingTypes);
  
  /**
   * Adds a seatNumber property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatNumber The value to add.
   */
  public void addSeatNumber(String seatNumber);
  
  /**
   * Adds a seatRow property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatRow The value to add.
   */
  public void addSeatRow(String seatRow);
  
  /**
   * Adds a seatSection property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatSection The value to add.
   */
  public void addSeatSection(String seatSection);
  
  /**
   * Adds a seatingType property value for this Seat object; appending it to the list of existing values.
   *
   * @param seatingType The value to add.
   */
  public void addSeatingType(Thing seatingType);
  
}