package org.schema;

import java.util.List;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.TradeAction;
import org.schema.WarrantyPromise;

/**
 * The act of taking money from a buyer in exchange for goods or services rendered. An agent sells an object, product, or service to a buyer for a price. Reciprocal of BuyAction.
 */
public interface SellAction extends TradeAction, SchemaObject {

  /**
   * Get a single buyer property value for this SellAction object.
   *
   * @return The first buyer property value.
   */
  public Person getBuyer();
  
  /**
   * Get a single warrantyPromise property value for this SellAction object.
   *
   * @return The first warrantyPromise property value.
   */
  public WarrantyPromise getWarrantyPromise();
  
  /**
   * Get all the buyer property values for this SellAction object.
   *
   * @return A list of buyer property values.
   */
  public List<Person> getBuyers();
  
  /**
   * Get all the warrantyPromise property values for this SellAction object.
   *
   * @return A list of warrantyPromise property values.
   */
  public List<WarrantyPromise> getWarrantyPromises();
  
  /**
   * Set the buyer property value for this SellAction object; overwriting any existing values.
   *
   * @param buyer The value to set.
   */
  public void setBuyer(Person buyer);
  
  /**
   * Set the warrantyPromise property value for this SellAction object; overwriting any existing values.
   *
   * @param warrantyPromise The value to set.
   */
  public void setWarrantyPromise(WarrantyPromise warrantyPromise);
  
  /**
   * Set the buyer property values for this SellAction object; overwriting any existing values.
   *
   * @param buyers The list of values to set.
   */
  public void setBuyers(List<Person> buyers);
  
  /**
   * Set the warrantyPromise property values for this SellAction object; overwriting any existing values.
   *
   * @param warrantyPromises The list of values to set.
   */
  public void setWarrantyPromises(List<WarrantyPromise> warrantyPromises);
  
  /**
   * Adds a buyer property value for this SellAction object; appending it to the list of existing values.
   *
   * @param buyer The value to add.
   */
  public void addBuyer(Person buyer);
  
  /**
   * Adds a warrantyPromise property value for this SellAction object; appending it to the list of existing values.
   *
   * @param warrantyPromise The value to add.
   */
  public void addWarrantyPromise(WarrantyPromise warrantyPromise);
  
}