package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.Episode;
import org.schema.Number;
import org.schema.Organization;
import org.schema.Person;
import org.schema.SchemaObject;
import org.schema.Season;
import org.schema.Thing;
import org.schema.VideoObject;

/**
 * A TV or radio series.
 */
public interface Series extends CreativeWork, SchemaObject {

  /**
   * Get a single actor property value for this Series object.
   *
   * @return The first actor property value.
   */
  public Person getActor();
  
  /**
   * Get a single director property value for this Series object.
   *
   * @return The first director property value.
   */
  public Person getDirector();
  
  /**
   * Get a single endDate property value for this Series object.
   *
   * @return The first endDate property value.
   */
  public Date getEndDate();
  
  /**
   * Get a single episode property value for this Series object.
   *
   * @return The first episode property value.
   */
  public Episode getEpisode();
  
  /**
   * Get a single musicBy property value for this Series object.
   *
   * @return The first musicBy property value.
   */
  public Thing getMusicBy();
  
  /**
   * Get a single numberOfEpisodes property value for this Series object.
   *
   * @return The first numberOfEpisodes property value.
   */
  public Number getNumberOfEpisodes();
  
  /**
   * Get a single numberOfSeasons property value for this Series object.
   *
   * @return The first numberOfSeasons property value.
   */
  public Number getNumberOfSeasons();
  
  /**
   * Get a single producer property value for this Series object.
   *
   * @return The first producer property value.
   */
  public Person getProducer();
  
  /**
   * Get a single productionCompany property value for this Series object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany();
  
  /**
   * Get a single season property value for this Series object.
   *
   * @return The first season property value.
   */
  public Season getSeason();
  
  /**
   * Get a single startDate property value for this Series object.
   *
   * @return The first startDate property value.
   */
  public Date getStartDate();
  
  /**
   * Get a single trailer property value for this Series object.
   *
   * @return The first trailer property value.
   */
  public VideoObject getTrailer();
  
  /**
   * Get all the actor property values for this Series object.
   *
   * @return A list of actor property values.
   */
  public List<Person> getActors();
  
  /**
   * Get all the director property values for this Series object.
   *
   * @return A list of director property values.
   */
  public List<Person> getDirectors();
  
  /**
   * Get all the endDate property values for this Series object.
   *
   * @return A list of endDate property values.
   */
  public List<Date> getEndDates();
  
  /**
   * Get all the episode property values for this Series object.
   *
   * @return A list of episode property values.
   */
  public List<Episode> getEpisodes();
  
  /**
   * Get all the musicBy property values for this Series object.
   *
   * @return A list of musicBy property values.
   */
  public List<Thing> getMusicBies();
  
  /**
   * Get all the numberOfEpisodes property values for this Series object.
   *
   * @return A list of numberOfEpisodes property values.
   */
  public List<Number> getNumberOfEpisodess();
  
  /**
   * Get all the numberOfSeasons property values for this Series object.
   *
   * @return A list of numberOfSeasons property values.
   */
  public List<Number> getNumberOfSeasonss();
  
  /**
   * Get all the producer property values for this Series object.
   *
   * @return A list of producer property values.
   */
  public List<Person> getProducers();
  
  /**
   * Get all the productionCompany property values for this Series object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies();
  
  /**
   * Get all the season property values for this Series object.
   *
   * @return A list of season property values.
   */
  public List<Season> getSeasons();
  
  /**
   * Get all the startDate property values for this Series object.
   *
   * @return A list of startDate property values.
   */
  public List<Date> getStartDates();
  
  /**
   * Get all the trailer property values for this Series object.
   *
   * @return A list of trailer property values.
   */
  public List<VideoObject> getTrailers();
  
  /**
   * Set the actor property value for this Series object; overwriting any existing values.
   *
   * @param actor The value to set.
   */
  public void setActor(Person actor);
  
  /**
   * Set the director property value for this Series object; overwriting any existing values.
   *
   * @param director The value to set.
   */
  public void setDirector(Person director);
  
  /**
   * Set the endDate property value for this Series object; overwriting any existing values.
   *
   * @param endDate The value to set.
   */
  public void setEndDate(Date endDate);
  
  /**
   * Set the episode property value for this Series object; overwriting any existing values.
   *
   * @param episode The value to set.
   */
  public void setEpisode(Episode episode);
  
  /**
   * Set the musicBy property value for this Series object; overwriting any existing values.
   *
   * @param musicBy The value to set.
   */
  public void setMusicBy(Thing musicBy);
  
  /**
   * Set the numberOfEpisodes property value for this Series object; overwriting any existing values.
   *
   * @param numberOfEpisodes The value to set.
   */
  public void setNumberOfEpisodes(Number numberOfEpisodes);
  
  /**
   * Set the numberOfSeasons property value for this Series object; overwriting any existing values.
   *
   * @param numberOfSeasons The value to set.
   */
  public void setNumberOfSeasons(Number numberOfSeasons);
  
  /**
   * Set the producer property value for this Series object; overwriting any existing values.
   *
   * @param producer The value to set.
   */
  public void setProducer(Person producer);
  
  /**
   * Set the productionCompany property value for this Series object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany);
  
  /**
   * Set the season property value for this Series object; overwriting any existing values.
   *
   * @param season The value to set.
   */
  public void setSeason(Season season);
  
  /**
   * Set the startDate property value for this Series object; overwriting any existing values.
   *
   * @param startDate The value to set.
   */
  public void setStartDate(Date startDate);
  
  /**
   * Set the trailer property value for this Series object; overwriting any existing values.
   *
   * @param trailer The value to set.
   */
  public void setTrailer(VideoObject trailer);
  
  /**
   * Set the actor property values for this Series object; overwriting any existing values.
   *
   * @param actors The list of values to set.
   */
  public void setActors(List<Person> actors);
  
  /**
   * Set the director property values for this Series object; overwriting any existing values.
   *
   * @param directors The list of values to set.
   */
  public void setDirectors(List<Person> directors);
  
  /**
   * Set the endDate property values for this Series object; overwriting any existing values.
   *
   * @param endDates The list of values to set.
   */
  public void setEndDates(List<Date> endDates);
  
  /**
   * Set the episode property values for this Series object; overwriting any existing values.
   *
   * @param episodes The list of values to set.
   */
  public void setEpisodes(List<Episode> episodes);
  
  /**
   * Set the musicBy property values for this Series object; overwriting any existing values.
   *
   * @param musicBies The list of values to set.
   */
  public void setMusicBies(List<Thing> musicBies);
  
  /**
   * Set the numberOfEpisodes property values for this Series object; overwriting any existing values.
   *
   * @param numberOfEpisodess The list of values to set.
   */
  public void setNumberOfEpisodess(List<Number> numberOfEpisodess);
  
  /**
   * Set the numberOfSeasons property values for this Series object; overwriting any existing values.
   *
   * @param numberOfSeasonss The list of values to set.
   */
  public void setNumberOfSeasonss(List<Number> numberOfSeasonss);
  
  /**
   * Set the producer property values for this Series object; overwriting any existing values.
   *
   * @param producers The list of values to set.
   */
  public void setProducers(List<Person> producers);
  
  /**
   * Set the productionCompany property values for this Series object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies);
  
  /**
   * Set the season property values for this Series object; overwriting any existing values.
   *
   * @param seasons The list of values to set.
   */
  public void setSeasons(List<Season> seasons);
  
  /**
   * Set the startDate property values for this Series object; overwriting any existing values.
   *
   * @param startDates The list of values to set.
   */
  public void setStartDates(List<Date> startDates);
  
  /**
   * Set the trailer property values for this Series object; overwriting any existing values.
   *
   * @param trailers The list of values to set.
   */
  public void setTrailers(List<VideoObject> trailers);
  
  /**
   * Adds a actor property value for this Series object; appending it to the list of existing values.
   *
   * @param actor The value to add.
   */
  public void addActor(Person actor);
  
  /**
   * Adds a director property value for this Series object; appending it to the list of existing values.
   *
   * @param director The value to add.
   */
  public void addDirector(Person director);
  
  /**
   * Adds a endDate property value for this Series object; appending it to the list of existing values.
   *
   * @param endDate The value to add.
   */
  public void addEndDate(Date endDate);
  
  /**
   * Adds a episode property value for this Series object; appending it to the list of existing values.
   *
   * @param episode The value to add.
   */
  public void addEpisode(Episode episode);
  
  /**
   * Adds a musicBy property value for this Series object; appending it to the list of existing values.
   *
   * @param musicBy The value to add.
   */
  public void addMusicBy(Thing musicBy);
  
  /**
   * Adds a numberOfEpisodes property value for this Series object; appending it to the list of existing values.
   *
   * @param numberOfEpisodes The value to add.
   */
  public void addNumberOfEpisodes(Number numberOfEpisodes);
  
  /**
   * Adds a numberOfSeasons property value for this Series object; appending it to the list of existing values.
   *
   * @param numberOfSeasons The value to add.
   */
  public void addNumberOfSeasons(Number numberOfSeasons);
  
  /**
   * Adds a producer property value for this Series object; appending it to the list of existing values.
   *
   * @param producer The value to add.
   */
  public void addProducer(Person producer);
  
  /**
   * Adds a productionCompany property value for this Series object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany);
  
  /**
   * Adds a season property value for this Series object; appending it to the list of existing values.
   *
   * @param season The value to add.
   */
  public void addSeason(Season season);
  
  /**
   * Adds a startDate property value for this Series object; appending it to the list of existing values.
   *
   * @param startDate The value to add.
   */
  public void addStartDate(Date startDate);
  
  /**
   * Adds a trailer property value for this Series object; appending it to the list of existing values.
   *
   * @param trailer The value to add.
   */
  public void addTrailer(VideoObject trailer);
  
}