package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.AdministrativeArea;
import org.schema.Audience;
import org.schema.Intangible;
import org.schema.SchemaObject;
import org.schema.ServiceChannel;
import org.schema.Thing;

/**
 * A service provided by an organization, e.g. delivery service, print services, etc.
 */
public interface Service extends Intangible, SchemaObject {

  /**
   * Get a single availableChannel property value for this Service object.
   *
   * @return The first availableChannel property value.
   */
  public ServiceChannel getAvailableChannel();
  
  /**
   * Get a single produces property value for this Service object.
   *
   * @return The first produces property value.
   */
  public Thing getProduces();
  
  /**
   * Get a single provider property value for this Service object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider();
  
  /**
   * Get a single serviceArea property value for this Service object.
   *
   * @return The first serviceArea property value.
   */
  public AdministrativeArea getServiceArea();
  
  /**
   * Get a single serviceAudience property value for this Service object.
   *
   * @return The first serviceAudience property value.
   */
  public Audience getServiceAudience();
  
  /**
   * Get a single serviceType property value for this Service object.
   *
   * @return The first serviceType property value.
   */
  public String getServiceType();
  
  /**
   * Get all the availableChannel property values for this Service object.
   *
   * @return A list of availableChannel property values.
   */
  public List<ServiceChannel> getAvailableChannels();
  
  /**
   * Get all the produces property values for this Service object.
   *
   * @return A list of produces property values.
   */
  public List<Thing> getProducess();
  
  /**
   * Get all the provider property values for this Service object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders();
  
  /**
   * Get all the serviceArea property values for this Service object.
   *
   * @return A list of serviceArea property values.
   */
  public List<AdministrativeArea> getServiceAreas();
  
  /**
   * Get all the serviceAudience property values for this Service object.
   *
   * @return A list of serviceAudience property values.
   */
  public List<Audience> getServiceAudiences();
  
  /**
   * Get all the serviceType property values for this Service object.
   *
   * @return A list of serviceType property values.
   */
  public List<String> getServiceTypes();
  
  /**
   * Set the availableChannel property value for this Service object; overwriting any existing values.
   *
   * @param availableChannel The value to set.
   */
  public void setAvailableChannel(ServiceChannel availableChannel);
  
  /**
   * Set the produces property value for this Service object; overwriting any existing values.
   *
   * @param produces The value to set.
   */
  public void setProduces(Thing produces);
  
  /**
   * Set the provider property value for this Service object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider);
  
  /**
   * Set the serviceArea property value for this Service object; overwriting any existing values.
   *
   * @param serviceArea The value to set.
   */
  public void setServiceArea(AdministrativeArea serviceArea);
  
  /**
   * Set the serviceAudience property value for this Service object; overwriting any existing values.
   *
   * @param serviceAudience The value to set.
   */
  public void setServiceAudience(Audience serviceAudience);
  
  /**
   * Set the serviceType property value for this Service object; overwriting any existing values.
   *
   * @param serviceType The value to set.
   */
  public void setServiceType(String serviceType);
  
  /**
   * Set the availableChannel property values for this Service object; overwriting any existing values.
   *
   * @param availableChannels The list of values to set.
   */
  public void setAvailableChannels(List<ServiceChannel> availableChannels);
  
  /**
   * Set the produces property values for this Service object; overwriting any existing values.
   *
   * @param producess The list of values to set.
   */
  public void setProducess(List<Thing> producess);
  
  /**
   * Set the provider property values for this Service object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers);
  
  /**
   * Set the serviceArea property values for this Service object; overwriting any existing values.
   *
   * @param serviceAreas The list of values to set.
   */
  public void setServiceAreas(List<AdministrativeArea> serviceAreas);
  
  /**
   * Set the serviceAudience property values for this Service object; overwriting any existing values.
   *
   * @param serviceAudiences The list of values to set.
   */
  public void setServiceAudiences(List<Audience> serviceAudiences);
  
  /**
   * Set the serviceType property values for this Service object; overwriting any existing values.
   *
   * @param serviceTypes The list of values to set.
   */
  public void setServiceTypes(List<String> serviceTypes);
  
  /**
   * Adds a availableChannel property value for this Service object; appending it to the list of existing values.
   *
   * @param availableChannel The value to add.
   */
  public void addAvailableChannel(ServiceChannel availableChannel);
  
  /**
   * Adds a produces property value for this Service object; appending it to the list of existing values.
   *
   * @param produces The value to add.
   */
  public void addProduces(Thing produces);
  
  /**
   * Adds a provider property value for this Service object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider);
  
  /**
   * Adds a serviceArea property value for this Service object; appending it to the list of existing values.
   *
   * @param serviceArea The value to add.
   */
  public void addServiceArea(AdministrativeArea serviceArea);
  
  /**
   * Adds a serviceAudience property value for this Service object; appending it to the list of existing values.
   *
   * @param serviceAudience The value to add.
   */
  public void addServiceAudience(Audience serviceAudience);
  
  /**
   * Adds a serviceType property value for this Service object; appending it to the list of existing values.
   *
   * @param serviceType The value to add.
   */
  public void addServiceType(String serviceType);
  
}