package org.schema;

import java.net.URL;
import java.util.List;
import org.schema.ContactPoint;
import org.schema.Duration;
import org.schema.Intangible;
import org.schema.Language;
import org.schema.Place;
import org.schema.PostalAddress;
import org.schema.SchemaObject;
import org.schema.Service;

/**
 * A means for accessing a service, e.g. a government office location, web site, or phone number.
 */
public interface ServiceChannel extends Intangible, SchemaObject {

  /**
   * Get a single availableLanguage property value for this ServiceChannel object.
   *
   * @return The first availableLanguage property value.
   */
  public Language getAvailableLanguage();
  
  /**
   * Get a single processingTime property value for this ServiceChannel object.
   *
   * @return The first processingTime property value.
   */
  public Duration getProcessingTime();
  
  /**
   * Get a single providesService property value for this ServiceChannel object.
   *
   * @return The first providesService property value.
   */
  public Service getProvidesService();
  
  /**
   * Get a single serviceLocation property value for this ServiceChannel object.
   *
   * @return The first serviceLocation property value.
   */
  public Place getServiceLocation();
  
  /**
   * Get a single servicePhone property value for this ServiceChannel object.
   *
   * @return The first servicePhone property value.
   */
  public ContactPoint getServicePhone();
  
  /**
   * Get a single servicePostalAddress property value for this ServiceChannel object.
   *
   * @return The first servicePostalAddress property value.
   */
  public PostalAddress getServicePostalAddress();
  
  /**
   * Get a single serviceSmsNumber property value for this ServiceChannel object.
   *
   * @return The first serviceSmsNumber property value.
   */
  public ContactPoint getServiceSmsNumber();
  
  /**
   * Get a single serviceUrl property value for this ServiceChannel object.
   *
   * @return The first serviceUrl property value.
   */
  public URL getServiceUrl();
  
  /**
   * Get all the availableLanguage property values for this ServiceChannel object.
   *
   * @return A list of availableLanguage property values.
   */
  public List<Language> getAvailableLanguages();
  
  /**
   * Get all the processingTime property values for this ServiceChannel object.
   *
   * @return A list of processingTime property values.
   */
  public List<Duration> getProcessingTimes();
  
  /**
   * Get all the providesService property values for this ServiceChannel object.
   *
   * @return A list of providesService property values.
   */
  public List<Service> getProvidesServices();
  
  /**
   * Get all the serviceLocation property values for this ServiceChannel object.
   *
   * @return A list of serviceLocation property values.
   */
  public List<Place> getServiceLocations();
  
  /**
   * Get all the servicePhone property values for this ServiceChannel object.
   *
   * @return A list of servicePhone property values.
   */
  public List<ContactPoint> getServicePhones();
  
  /**
   * Get all the servicePostalAddress property values for this ServiceChannel object.
   *
   * @return A list of servicePostalAddress property values.
   */
  public List<PostalAddress> getServicePostalAddresses();
  
  /**
   * Get all the serviceSmsNumber property values for this ServiceChannel object.
   *
   * @return A list of serviceSmsNumber property values.
   */
  public List<ContactPoint> getServiceSmsNumbers();
  
  /**
   * Get all the serviceUrl property values for this ServiceChannel object.
   *
   * @return A list of serviceUrl property values.
   */
  public List<URL> getServiceUrls();
  
  /**
   * Set the availableLanguage property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param availableLanguage The value to set.
   */
  public void setAvailableLanguage(Language availableLanguage);
  
  /**
   * Set the processingTime property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param processingTime The value to set.
   */
  public void setProcessingTime(Duration processingTime);
  
  /**
   * Set the providesService property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param providesService The value to set.
   */
  public void setProvidesService(Service providesService);
  
  /**
   * Set the serviceLocation property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceLocation The value to set.
   */
  public void setServiceLocation(Place serviceLocation);
  
  /**
   * Set the servicePhone property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePhone The value to set.
   */
  public void setServicePhone(ContactPoint servicePhone);
  
  /**
   * Set the servicePostalAddress property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePostalAddress The value to set.
   */
  public void setServicePostalAddress(PostalAddress servicePostalAddress);
  
  /**
   * Set the serviceSmsNumber property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceSmsNumber The value to set.
   */
  public void setServiceSmsNumber(ContactPoint serviceSmsNumber);
  
  /**
   * Set the serviceUrl property value for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceUrl The value to set.
   */
  public void setServiceUrl(URL serviceUrl);
  
  /**
   * Set the availableLanguage property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param availableLanguages The list of values to set.
   */
  public void setAvailableLanguages(List<Language> availableLanguages);
  
  /**
   * Set the processingTime property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param processingTimes The list of values to set.
   */
  public void setProcessingTimes(List<Duration> processingTimes);
  
  /**
   * Set the providesService property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param providesServices The list of values to set.
   */
  public void setProvidesServices(List<Service> providesServices);
  
  /**
   * Set the serviceLocation property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceLocations The list of values to set.
   */
  public void setServiceLocations(List<Place> serviceLocations);
  
  /**
   * Set the servicePhone property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePhones The list of values to set.
   */
  public void setServicePhones(List<ContactPoint> servicePhones);
  
  /**
   * Set the servicePostalAddress property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param servicePostalAddresses The list of values to set.
   */
  public void setServicePostalAddresses(List<PostalAddress> servicePostalAddresses);
  
  /**
   * Set the serviceSmsNumber property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceSmsNumbers The list of values to set.
   */
  public void setServiceSmsNumbers(List<ContactPoint> serviceSmsNumbers);
  
  /**
   * Set the serviceUrl property values for this ServiceChannel object; overwriting any existing values.
   *
   * @param serviceUrls The list of values to set.
   */
  public void setServiceUrls(List<URL> serviceUrls);
  
  /**
   * Adds a availableLanguage property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param availableLanguage The value to add.
   */
  public void addAvailableLanguage(Language availableLanguage);
  
  /**
   * Adds a processingTime property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param processingTime The value to add.
   */
  public void addProcessingTime(Duration processingTime);
  
  /**
   * Adds a providesService property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param providesService The value to add.
   */
  public void addProvidesService(Service providesService);
  
  /**
   * Adds a serviceLocation property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param serviceLocation The value to add.
   */
  public void addServiceLocation(Place serviceLocation);
  
  /**
   * Adds a servicePhone property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param servicePhone The value to add.
   */
  public void addServicePhone(ContactPoint servicePhone);
  
  /**
   * Adds a servicePostalAddress property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param servicePostalAddress The value to add.
   */
  public void addServicePostalAddress(PostalAddress servicePostalAddress);
  
  /**
   * Adds a serviceSmsNumber property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param serviceSmsNumber The value to add.
   */
  public void addServiceSmsNumber(ContactPoint serviceSmsNumber);
  
  /**
   * Adds a serviceUrl property value for this ServiceChannel object; appending it to the list of existing values.
   *
   * @param serviceUrl The value to add.
   */
  public void addServiceUrl(URL serviceUrl);
  
}