package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.MedicalCondition;
import org.schema.MedicalEntity;
import org.schema.MedicalTherapy;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * Anatomical features that can be observed by sight (without dissection), including the form and proportions of the human body as well as surface landmarks that correspond to deeper subcutaneous structures. Superficial anatomy plays an important role in sports medicine, phlebotomy, and other medical specialties as underlying anatomical structures can be identified through surface palpation. For example, during back surgery, superficial anatomy can be used to palpate and count vertebrae to find the site of incision. Or in phlebotomy, superficial anatomy can be used to locate an underlying vein; for example, the median cubital vein can be located by palpating the borders of the cubital fossa (such as the epicondyles of the humerus) and then looking for the superficial signs of the vein, such as size, prominence, ability to refill after depression, and feel of surrounding tissue support. As another example, in a subluxation (dislocation) of the glenohumeral joint, the bony structure becomes pronounced with the deltoid muscle failing to cover the glenohumeral joint allowing the edges of the scapula to be superficially visible. Here, the superficial anatomy is the visible edges of the scapula, implying the underlying dislocation of the joint (the related anatomical structure).
 */
public interface SuperficialAnatomy extends MedicalEntity, SchemaObject {

  /**
   * Get a single associatedPathophysiology property value for this SuperficialAnatomy object.
   *
   * @return The first associatedPathophysiology property value.
   */
  public String getAssociatedPathophysiology();
  
  /**
   * Get a single relatedAnatomy property value for this SuperficialAnatomy object.
   *
   * @return The first relatedAnatomy property value.
   */
  public Thing getRelatedAnatomy();
  
  /**
   * Get a single relatedCondition property value for this SuperficialAnatomy object.
   *
   * @return The first relatedCondition property value.
   */
  public MedicalCondition getRelatedCondition();
  
  /**
   * Get a single relatedTherapy property value for this SuperficialAnatomy object.
   *
   * @return The first relatedTherapy property value.
   */
  public MedicalTherapy getRelatedTherapy();
  
  /**
   * Get a single significance property value for this SuperficialAnatomy object.
   *
   * @return The first significance property value.
   */
  public String getSignificance();
  
  /**
   * Get all the associatedPathophysiology property values for this SuperficialAnatomy object.
   *
   * @return A list of associatedPathophysiology property values.
   */
  public List<String> getAssociatedPathophysiologies();
  
  /**
   * Get all the relatedAnatomy property values for this SuperficialAnatomy object.
   *
   * @return A list of relatedAnatomy property values.
   */
  public List<Thing> getRelatedAnatomies();
  
  /**
   * Get all the relatedCondition property values for this SuperficialAnatomy object.
   *
   * @return A list of relatedCondition property values.
   */
  public List<MedicalCondition> getRelatedConditions();
  
  /**
   * Get all the relatedTherapy property values for this SuperficialAnatomy object.
   *
   * @return A list of relatedTherapy property values.
   */
  public List<MedicalTherapy> getRelatedTherapies();
  
  /**
   * Get all the significance property values for this SuperficialAnatomy object.
   *
   * @return A list of significance property values.
   */
  public List<String> getSignificances();
  
  /**
   * Set the associatedPathophysiology property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param associatedPathophysiology The value to set.
   */
  public void setAssociatedPathophysiology(String associatedPathophysiology);
  
  /**
   * Set the relatedAnatomy property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedAnatomy The value to set.
   */
  public void setRelatedAnatomy(Thing relatedAnatomy);
  
  /**
   * Set the relatedCondition property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedCondition The value to set.
   */
  public void setRelatedCondition(MedicalCondition relatedCondition);
  
  /**
   * Set the relatedTherapy property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedTherapy The value to set.
   */
  public void setRelatedTherapy(MedicalTherapy relatedTherapy);
  
  /**
   * Set the significance property value for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param significance The value to set.
   */
  public void setSignificance(String significance);
  
  /**
   * Set the associatedPathophysiology property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param associatedPathophysiologies The list of values to set.
   */
  public void setAssociatedPathophysiologies(List<String> associatedPathophysiologies);
  
  /**
   * Set the relatedAnatomy property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedAnatomies The list of values to set.
   */
  public void setRelatedAnatomies(List<Thing> relatedAnatomies);
  
  /**
   * Set the relatedCondition property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedConditions The list of values to set.
   */
  public void setRelatedConditions(List<MedicalCondition> relatedConditions);
  
  /**
   * Set the relatedTherapy property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param relatedTherapies The list of values to set.
   */
  public void setRelatedTherapies(List<MedicalTherapy> relatedTherapies);
  
  /**
   * Set the significance property values for this SuperficialAnatomy object; overwriting any existing values.
   *
   * @param significances The list of values to set.
   */
  public void setSignificances(List<String> significances);
  
  /**
   * Adds a associatedPathophysiology property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param associatedPathophysiology The value to add.
   */
  public void addAssociatedPathophysiology(String associatedPathophysiology);
  
  /**
   * Adds a relatedAnatomy property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relatedAnatomy The value to add.
   */
  public void addRelatedAnatomy(Thing relatedAnatomy);
  
  /**
   * Adds a relatedCondition property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relatedCondition The value to add.
   */
  public void addRelatedCondition(MedicalCondition relatedCondition);
  
  /**
   * Adds a relatedTherapy property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param relatedTherapy The value to add.
   */
  public void addRelatedTherapy(MedicalTherapy relatedTherapy);
  
  /**
   * Adds a significance property value for this SuperficialAnatomy object; appending it to the list of existing values.
   *
   * @param significance The value to add.
   */
  public void addSignificance(String significance);
  
}