package org.schema;

import java.util.Date;
import java.util.List;
import org.schema.Place;
import org.schema.Reservation;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * A reservation for a taxi.Note: This type is for information about actual reservations, e.g. in confirmation emails or HTML pages with individual confirmations of reservations. For offers of tickets, use http://schema.org/Offer.
 */
public interface TaxiReservation extends Reservation, SchemaObject {

  /**
   * Get a single partySize property value for this TaxiReservation object.
   *
   * @return The first partySize property value.
   */
  public Thing getPartySize();
  
  /**
   * Get a single pickupLocation property value for this TaxiReservation object.
   *
   * @return The first pickupLocation property value.
   */
  public Place getPickupLocation();
  
  /**
   * Get a single pickupTime property value for this TaxiReservation object.
   *
   * @return The first pickupTime property value.
   */
  public Date getPickupTime();
  
  /**
   * Get all the partySize property values for this TaxiReservation object.
   *
   * @return A list of partySize property values.
   */
  public List<Thing> getPartySizes();
  
  /**
   * Get all the pickupLocation property values for this TaxiReservation object.
   *
   * @return A list of pickupLocation property values.
   */
  public List<Place> getPickupLocations();
  
  /**
   * Get all the pickupTime property values for this TaxiReservation object.
   *
   * @return A list of pickupTime property values.
   */
  public List<Date> getPickupTimes();
  
  /**
   * Set the partySize property value for this TaxiReservation object; overwriting any existing values.
   *
   * @param partySize The value to set.
   */
  public void setPartySize(Thing partySize);
  
  /**
   * Set the pickupLocation property value for this TaxiReservation object; overwriting any existing values.
   *
   * @param pickupLocation The value to set.
   */
  public void setPickupLocation(Place pickupLocation);
  
  /**
   * Set the pickupTime property value for this TaxiReservation object; overwriting any existing values.
   *
   * @param pickupTime The value to set.
   */
  public void setPickupTime(Date pickupTime);
  
  /**
   * Set the partySize property values for this TaxiReservation object; overwriting any existing values.
   *
   * @param partySizes The list of values to set.
   */
  public void setPartySizes(List<Thing> partySizes);
  
  /**
   * Set the pickupLocation property values for this TaxiReservation object; overwriting any existing values.
   *
   * @param pickupLocations The list of values to set.
   */
  public void setPickupLocations(List<Place> pickupLocations);
  
  /**
   * Set the pickupTime property values for this TaxiReservation object; overwriting any existing values.
   *
   * @param pickupTimes The list of values to set.
   */
  public void setPickupTimes(List<Date> pickupTimes);
  
  /**
   * Adds a partySize property value for this TaxiReservation object; appending it to the list of existing values.
   *
   * @param partySize The value to add.
   */
  public void addPartySize(Thing partySize);
  
  /**
   * Adds a pickupLocation property value for this TaxiReservation object; appending it to the list of existing values.
   *
   * @param pickupLocation The value to add.
   */
  public void addPickupLocation(Place pickupLocation);
  
  /**
   * Adds a pickupTime property value for this TaxiReservation object; appending it to the list of existing values.
   *
   * @param pickupTime The value to add.
   */
  public void addPickupTime(Date pickupTime);
  
}