package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.Article;
import org.schema.SchemaObject;

/**
 * A technical article - Example: How-to (task) topics, step-by-step, procedural troubleshooting, specifications, etc.
 */
public interface TechArticle extends Article, SchemaObject {

  /**
   * Get a single dependencies property value for this TechArticle object.
   *
   * @return The first dependencies property value.
   */
  public String getDependencies();
  
  /**
   * Get a single proficiencyLevel property value for this TechArticle object.
   *
   * @return The first proficiencyLevel property value.
   */
  public String getProficiencyLevel();
  
  /**
   * Get all the dependencies property values for this TechArticle object.
   *
   * @return A list of dependencies property values.
   */
  public List<String> getDependenciess();
  
  /**
   * Get all the proficiencyLevel property values for this TechArticle object.
   *
   * @return A list of proficiencyLevel property values.
   */
  public List<String> getProficiencyLevels();
  
  /**
   * Set the dependencies property value for this TechArticle object; overwriting any existing values.
   *
   * @param dependencies The value to set.
   */
  public void setDependencies(String dependencies);
  
  /**
   * Set the proficiencyLevel property value for this TechArticle object; overwriting any existing values.
   *
   * @param proficiencyLevel The value to set.
   */
  public void setProficiencyLevel(String proficiencyLevel);
  
  /**
   * Set the dependencies property values for this TechArticle object; overwriting any existing values.
   *
   * @param dependenciess The list of values to set.
   */
  public void setDependenciess(List<String> dependenciess);
  
  /**
   * Set the proficiencyLevel property values for this TechArticle object; overwriting any existing values.
   *
   * @param proficiencyLevels The list of values to set.
   */
  public void setProficiencyLevels(List<String> proficiencyLevels);
  
  /**
   * Adds a dependencies property value for this TechArticle object; appending it to the list of existing values.
   *
   * @param dependencies The value to add.
   */
  public void addDependencies(String dependencies);
  
  /**
   * Adds a proficiencyLevel property value for this TechArticle object; appending it to the list of existing values.
   *
   * @param proficiencyLevel The value to add.
   */
  public void addProficiencyLevel(String proficiencyLevel);
  
}