package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.List;
import org.schema.SchemaObject;

/**
 * The most generic type of item.
 */
public interface Thing extends SchemaObject {

  /**
   * Get a single additionalType property value for this Thing object.
   *
   * @return The first additionalType property value.
   */
  public URL getAdditionalType();
  
  /**
   * Get a single alternateName property value for this Thing object.
   *
   * @return The first alternateName property value.
   */
  public String getAlternateName();
  
  /**
   * Get a single description property value for this Thing object.
   *
   * @return The first description property value.
   */
  public String getDescription();
  
  /**
   * Get a single image property value for this Thing object.
   *
   * @return The first image property value.
   */
  public URL getImage();
  
  /**
   * Get a single name property value for this Thing object.
   *
   * @return The first name property value.
   */
  public String getName();
  
  /**
   * Get a single sameAs property value for this Thing object.
   *
   * @return The first sameAs property value.
   */
  public URL getSameAs();
  
  /**
   * Get a single url property value for this Thing object.
   *
   * @return The first url property value.
   */
  public URL getUrl();
  
  /**
   * Get all the additionalType property values for this Thing object.
   *
   * @return A list of additionalType property values.
   */
  public List<URL> getAdditionalTypes();
  
  /**
   * Get all the alternateName property values for this Thing object.
   *
   * @return A list of alternateName property values.
   */
  public List<String> getAlternateNames();
  
  /**
   * Get all the description property values for this Thing object.
   *
   * @return A list of description property values.
   */
  public List<String> getDescriptions();
  
  /**
   * Get all the image property values for this Thing object.
   *
   * @return A list of image property values.
   */
  public List<URL> getImages();
  
  /**
   * Get all the name property values for this Thing object.
   *
   * @return A list of name property values.
   */
  public List<String> getNames();
  
  /**
   * Get all the sameAs property values for this Thing object.
   *
   * @return A list of sameAs property values.
   */
  public List<URL> getSameAss();
  
  /**
   * Get all the url property values for this Thing object.
   *
   * @return A list of url property values.
   */
  public List<URL> getUrls();
  
  /**
   * Set the additionalType property value for this Thing object; overwriting any existing values.
   *
   * @param additionalType The value to set.
   */
  public void setAdditionalType(URL additionalType);
  
  /**
   * Set the alternateName property value for this Thing object; overwriting any existing values.
   *
   * @param alternateName The value to set.
   */
  public void setAlternateName(String alternateName);
  
  /**
   * Set the description property value for this Thing object; overwriting any existing values.
   *
   * @param description The value to set.
   */
  public void setDescription(String description);
  
  /**
   * Set the image property value for this Thing object; overwriting any existing values.
   *
   * @param image The value to set.
   */
  public void setImage(URL image);
  
  /**
   * Set the name property value for this Thing object; overwriting any existing values.
   *
   * @param name The value to set.
   */
  public void setName(String name);
  
  /**
   * Set the sameAs property value for this Thing object; overwriting any existing values.
   *
   * @param sameAs The value to set.
   */
  public void setSameAs(URL sameAs);
  
  /**
   * Set the url property value for this Thing object; overwriting any existing values.
   *
   * @param url The value to set.
   */
  public void setUrl(URL url);
  
  /**
   * Set the additionalType property values for this Thing object; overwriting any existing values.
   *
   * @param additionalTypes The list of values to set.
   */
  public void setAdditionalTypes(List<URL> additionalTypes);
  
  /**
   * Set the alternateName property values for this Thing object; overwriting any existing values.
   *
   * @param alternateNames The list of values to set.
   */
  public void setAlternateNames(List<String> alternateNames);
  
  /**
   * Set the description property values for this Thing object; overwriting any existing values.
   *
   * @param descriptions The list of values to set.
   */
  public void setDescriptions(List<String> descriptions);
  
  /**
   * Set the image property values for this Thing object; overwriting any existing values.
   *
   * @param images The list of values to set.
   */
  public void setImages(List<URL> images);
  
  /**
   * Set the name property values for this Thing object; overwriting any existing values.
   *
   * @param names The list of values to set.
   */
  public void setNames(List<String> names);
  
  /**
   * Set the sameAs property values for this Thing object; overwriting any existing values.
   *
   * @param sameAss The list of values to set.
   */
  public void setSameAss(List<URL> sameAss);
  
  /**
   * Set the url property values for this Thing object; overwriting any existing values.
   *
   * @param urls The list of values to set.
   */
  public void setUrls(List<URL> urls);
  
  /**
   * Adds a additionalType property value for this Thing object; appending it to the list of existing values.
   *
   * @param additionalType The value to add.
   */
  public void addAdditionalType(URL additionalType);
  
  /**
   * Adds a alternateName property value for this Thing object; appending it to the list of existing values.
   *
   * @param alternateName The value to add.
   */
  public void addAlternateName(String alternateName);
  
  /**
   * Adds a description property value for this Thing object; appending it to the list of existing values.
   *
   * @param description The value to add.
   */
  public void addDescription(String description);
  
  /**
   * Adds a image property value for this Thing object; appending it to the list of existing values.
   *
   * @param image The value to add.
   */
  public void addImage(URL image);
  
  /**
   * Adds a name property value for this Thing object; appending it to the list of existing values.
   *
   * @param name The value to add.
   */
  public void addName(String name);
  
  /**
   * Adds a sameAs property value for this Thing object; appending it to the list of existing values.
   *
   * @param sameAs The value to add.
   */
  public void addSameAs(URL sameAs);
  
  /**
   * Adds a url property value for this Thing object; appending it to the list of existing values.
   *
   * @param url The value to add.
   */
  public void addUrl(URL url);
  
}