package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Intangible;
import org.schema.Organization;
import org.schema.SchemaObject;
import org.schema.Seat;
import org.schema.Thing;

/**
 * Used to describe a ticket to an event, a flight, a bus ride, etc.
 */
public interface Ticket extends Intangible, SchemaObject {

  /**
   * Get a single dateIssued property value for this Ticket object.
   *
   * @return The first dateIssued property value.
   */
  public Date getDateIssued();
  
  /**
   * Get a single issuedBy property value for this Ticket object.
   *
   * @return The first issuedBy property value.
   */
  public Organization getIssuedBy();
  
  /**
   * Get a single priceCurrency property value for this Ticket object.
   *
   * @return The first priceCurrency property value.
   */
  public String getPriceCurrency();
  
  /**
   * Get a single ticketNumber property value for this Ticket object.
   *
   * @return The first ticketNumber property value.
   */
  public String getTicketNumber();
  
  /**
   * Get a single ticketToken property value for this Ticket object.
   *
   * @return The first ticketToken property value.
   */
  public Thing getTicketToken();
  
  /**
   * Get a single ticketedSeat property value for this Ticket object.
   *
   * @return The first ticketedSeat property value.
   */
  public Seat getTicketedSeat();
  
  /**
   * Get a single totalPrice property value for this Ticket object.
   *
   * @return The first totalPrice property value.
   */
  public Thing getTotalPrice();
  
  /**
   * Get a single underName property value for this Ticket object.
   *
   * @return The first underName property value.
   */
  public Thing getUnderName();
  
  /**
   * Get all the dateIssued property values for this Ticket object.
   *
   * @return A list of dateIssued property values.
   */
  public List<Date> getDateIssueds();
  
  /**
   * Get all the issuedBy property values for this Ticket object.
   *
   * @return A list of issuedBy property values.
   */
  public List<Organization> getIssuedBies();
  
  /**
   * Get all the priceCurrency property values for this Ticket object.
   *
   * @return A list of priceCurrency property values.
   */
  public List<String> getPriceCurrencies();
  
  /**
   * Get all the ticketNumber property values for this Ticket object.
   *
   * @return A list of ticketNumber property values.
   */
  public List<String> getTicketNumbers();
  
  /**
   * Get all the ticketToken property values for this Ticket object.
   *
   * @return A list of ticketToken property values.
   */
  public List<Thing> getTicketTokens();
  
  /**
   * Get all the ticketedSeat property values for this Ticket object.
   *
   * @return A list of ticketedSeat property values.
   */
  public List<Seat> getTicketedSeats();
  
  /**
   * Get all the totalPrice property values for this Ticket object.
   *
   * @return A list of totalPrice property values.
   */
  public List<Thing> getTotalPrices();
  
  /**
   * Get all the underName property values for this Ticket object.
   *
   * @return A list of underName property values.
   */
  public List<Thing> getUnderNames();
  
  /**
   * Set the dateIssued property value for this Ticket object; overwriting any existing values.
   *
   * @param dateIssued The value to set.
   */
  public void setDateIssued(Date dateIssued);
  
  /**
   * Set the issuedBy property value for this Ticket object; overwriting any existing values.
   *
   * @param issuedBy The value to set.
   */
  public void setIssuedBy(Organization issuedBy);
  
  /**
   * Set the priceCurrency property value for this Ticket object; overwriting any existing values.
   *
   * @param priceCurrency The value to set.
   */
  public void setPriceCurrency(String priceCurrency);
  
  /**
   * Set the ticketNumber property value for this Ticket object; overwriting any existing values.
   *
   * @param ticketNumber The value to set.
   */
  public void setTicketNumber(String ticketNumber);
  
  /**
   * Set the ticketToken property value for this Ticket object; overwriting any existing values.
   *
   * @param ticketToken The value to set.
   */
  public void setTicketToken(Thing ticketToken);
  
  /**
   * Set the ticketedSeat property value for this Ticket object; overwriting any existing values.
   *
   * @param ticketedSeat The value to set.
   */
  public void setTicketedSeat(Seat ticketedSeat);
  
  /**
   * Set the totalPrice property value for this Ticket object; overwriting any existing values.
   *
   * @param totalPrice The value to set.
   */
  public void setTotalPrice(Thing totalPrice);
  
  /**
   * Set the underName property value for this Ticket object; overwriting any existing values.
   *
   * @param underName The value to set.
   */
  public void setUnderName(Thing underName);
  
  /**
   * Set the dateIssued property values for this Ticket object; overwriting any existing values.
   *
   * @param dateIssueds The list of values to set.
   */
  public void setDateIssueds(List<Date> dateIssueds);
  
  /**
   * Set the issuedBy property values for this Ticket object; overwriting any existing values.
   *
   * @param issuedBies The list of values to set.
   */
  public void setIssuedBies(List<Organization> issuedBies);
  
  /**
   * Set the priceCurrency property values for this Ticket object; overwriting any existing values.
   *
   * @param priceCurrencies The list of values to set.
   */
  public void setPriceCurrencies(List<String> priceCurrencies);
  
  /**
   * Set the ticketNumber property values for this Ticket object; overwriting any existing values.
   *
   * @param ticketNumbers The list of values to set.
   */
  public void setTicketNumbers(List<String> ticketNumbers);
  
  /**
   * Set the ticketToken property values for this Ticket object; overwriting any existing values.
   *
   * @param ticketTokens The list of values to set.
   */
  public void setTicketTokens(List<Thing> ticketTokens);
  
  /**
   * Set the ticketedSeat property values for this Ticket object; overwriting any existing values.
   *
   * @param ticketedSeats The list of values to set.
   */
  public void setTicketedSeats(List<Seat> ticketedSeats);
  
  /**
   * Set the totalPrice property values for this Ticket object; overwriting any existing values.
   *
   * @param totalPrices The list of values to set.
   */
  public void setTotalPrices(List<Thing> totalPrices);
  
  /**
   * Set the underName property values for this Ticket object; overwriting any existing values.
   *
   * @param underNames The list of values to set.
   */
  public void setUnderNames(List<Thing> underNames);
  
  /**
   * Adds a dateIssued property value for this Ticket object; appending it to the list of existing values.
   *
   * @param dateIssued The value to add.
   */
  public void addDateIssued(Date dateIssued);
  
  /**
   * Adds a issuedBy property value for this Ticket object; appending it to the list of existing values.
   *
   * @param issuedBy The value to add.
   */
  public void addIssuedBy(Organization issuedBy);
  
  /**
   * Adds a priceCurrency property value for this Ticket object; appending it to the list of existing values.
   *
   * @param priceCurrency The value to add.
   */
  public void addPriceCurrency(String priceCurrency);
  
  /**
   * Adds a ticketNumber property value for this Ticket object; appending it to the list of existing values.
   *
   * @param ticketNumber The value to add.
   */
  public void addTicketNumber(String ticketNumber);
  
  /**
   * Adds a ticketToken property value for this Ticket object; appending it to the list of existing values.
   *
   * @param ticketToken The value to add.
   */
  public void addTicketToken(Thing ticketToken);
  
  /**
   * Adds a ticketedSeat property value for this Ticket object; appending it to the list of existing values.
   *
   * @param ticketedSeat The value to add.
   */
  public void addTicketedSeat(Seat ticketedSeat);
  
  /**
   * Adds a totalPrice property value for this Ticket object; appending it to the list of existing values.
   *
   * @param totalPrice The value to add.
   */
  public void addTotalPrice(Thing totalPrice);
  
  /**
   * Adds a underName property value for this Ticket object; appending it to the list of existing values.
   *
   * @param underName The value to add.
   */
  public void addUnderName(Thing underName);
  
}