package org.schema;

import java.util.List;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TradeAction;

/**
 * The act of giving money voluntarily to a beneficiary in recognition of services rendered.
 */
public interface TipAction extends TradeAction, SchemaObject {

  /**
   * Get a single recipient property value for this TipAction object.
   *
   * @return The first recipient property value.
   */
  public Thing getRecipient();
  
  /**
   * Get all the recipient property values for this TipAction object.
   *
   * @return A list of recipient property values.
   */
  public List<Thing> getRecipients();
  
  /**
   * Set the recipient property value for this TipAction object; overwriting any existing values.
   *
   * @param recipient The value to set.
   */
  public void setRecipient(Thing recipient);
  
  /**
   * Set the recipient property values for this TipAction object; overwriting any existing values.
   *
   * @param recipients The list of values to set.
   */
  public void setRecipients(List<Thing> recipients);
  
  /**
   * Adds a recipient property value for this TipAction object; appending it to the list of existing values.
   *
   * @param recipient The value to add.
   */
  public void addRecipient(Thing recipient);
  
}