package org.schema;

import java.util.List;
import org.schema.Action;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of participating in an exchange of goods and services for monetary compensation. An agent trades an object, product or service with a participant in exchange for a one time or periodic payment.
 */
public interface TradeAction extends Action, SchemaObject {

  /**
   * Get a single price property value for this TradeAction object.
   *
   * @return The first price property value.
   */
  public Thing getPrice();
  
  /**
   * Get all the price property values for this TradeAction object.
   *
   * @return A list of price property values.
   */
  public List<Thing> getPrices();
  
  /**
   * Set the price property value for this TradeAction object; overwriting any existing values.
   *
   * @param price The value to set.
   */
  public void setPrice(Thing price);
  
  /**
   * Set the price property values for this TradeAction object; overwriting any existing values.
   *
   * @param prices The list of values to set.
   */
  public void setPrices(List<Thing> prices);
  
  /**
   * Adds a price property value for this TradeAction object; appending it to the list of existing values.
   *
   * @param price The value to add.
   */
  public void addPrice(Thing price);
  
}