package org.schema;

import java.lang.String;
import java.util.Date;
import java.util.List;
import org.schema.Intangible;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.TrainStation;

/**
 * A trip on a commercial train line.
 */
public interface TrainTrip extends Intangible, SchemaObject {

  /**
   * Get a single arrivalPlatform property value for this TrainTrip object.
   *
   * @return The first arrivalPlatform property value.
   */
  public String getArrivalPlatform();
  
  /**
   * Get a single arrivalStation property value for this TrainTrip object.
   *
   * @return The first arrivalStation property value.
   */
  public TrainStation getArrivalStation();
  
  /**
   * Get a single arrivalTime property value for this TrainTrip object.
   *
   * @return The first arrivalTime property value.
   */
  public Date getArrivalTime();
  
  /**
   * Get a single departurePlatform property value for this TrainTrip object.
   *
   * @return The first departurePlatform property value.
   */
  public String getDeparturePlatform();
  
  /**
   * Get a single departureStation property value for this TrainTrip object.
   *
   * @return The first departureStation property value.
   */
  public TrainStation getDepartureStation();
  
  /**
   * Get a single departureTime property value for this TrainTrip object.
   *
   * @return The first departureTime property value.
   */
  public Date getDepartureTime();
  
  /**
   * Get a single provider property value for this TrainTrip object.
   *
   * @return The first provider property value.
   */
  public Thing getProvider();
  
  /**
   * Get a single trainName property value for this TrainTrip object.
   *
   * @return The first trainName property value.
   */
  public String getTrainName();
  
  /**
   * Get a single trainNumber property value for this TrainTrip object.
   *
   * @return The first trainNumber property value.
   */
  public String getTrainNumber();
  
  /**
   * Get all the arrivalPlatform property values for this TrainTrip object.
   *
   * @return A list of arrivalPlatform property values.
   */
  public List<String> getArrivalPlatforms();
  
  /**
   * Get all the arrivalStation property values for this TrainTrip object.
   *
   * @return A list of arrivalStation property values.
   */
  public List<TrainStation> getArrivalStations();
  
  /**
   * Get all the arrivalTime property values for this TrainTrip object.
   *
   * @return A list of arrivalTime property values.
   */
  public List<Date> getArrivalTimes();
  
  /**
   * Get all the departurePlatform property values for this TrainTrip object.
   *
   * @return A list of departurePlatform property values.
   */
  public List<String> getDeparturePlatforms();
  
  /**
   * Get all the departureStation property values for this TrainTrip object.
   *
   * @return A list of departureStation property values.
   */
  public List<TrainStation> getDepartureStations();
  
  /**
   * Get all the departureTime property values for this TrainTrip object.
   *
   * @return A list of departureTime property values.
   */
  public List<Date> getDepartureTimes();
  
  /**
   * Get all the provider property values for this TrainTrip object.
   *
   * @return A list of provider property values.
   */
  public List<Thing> getProviders();
  
  /**
   * Get all the trainName property values for this TrainTrip object.
   *
   * @return A list of trainName property values.
   */
  public List<String> getTrainNames();
  
  /**
   * Get all the trainNumber property values for this TrainTrip object.
   *
   * @return A list of trainNumber property values.
   */
  public List<String> getTrainNumbers();
  
  /**
   * Set the arrivalPlatform property value for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalPlatform The value to set.
   */
  public void setArrivalPlatform(String arrivalPlatform);
  
  /**
   * Set the arrivalStation property value for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalStation The value to set.
   */
  public void setArrivalStation(TrainStation arrivalStation);
  
  /**
   * Set the arrivalTime property value for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalTime The value to set.
   */
  public void setArrivalTime(Date arrivalTime);
  
  /**
   * Set the departurePlatform property value for this TrainTrip object; overwriting any existing values.
   *
   * @param departurePlatform The value to set.
   */
  public void setDeparturePlatform(String departurePlatform);
  
  /**
   * Set the departureStation property value for this TrainTrip object; overwriting any existing values.
   *
   * @param departureStation The value to set.
   */
  public void setDepartureStation(TrainStation departureStation);
  
  /**
   * Set the departureTime property value for this TrainTrip object; overwriting any existing values.
   *
   * @param departureTime The value to set.
   */
  public void setDepartureTime(Date departureTime);
  
  /**
   * Set the provider property value for this TrainTrip object; overwriting any existing values.
   *
   * @param provider The value to set.
   */
  public void setProvider(Thing provider);
  
  /**
   * Set the trainName property value for this TrainTrip object; overwriting any existing values.
   *
   * @param trainName The value to set.
   */
  public void setTrainName(String trainName);
  
  /**
   * Set the trainNumber property value for this TrainTrip object; overwriting any existing values.
   *
   * @param trainNumber The value to set.
   */
  public void setTrainNumber(String trainNumber);
  
  /**
   * Set the arrivalPlatform property values for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalPlatforms The list of values to set.
   */
  public void setArrivalPlatforms(List<String> arrivalPlatforms);
  
  /**
   * Set the arrivalStation property values for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalStations The list of values to set.
   */
  public void setArrivalStations(List<TrainStation> arrivalStations);
  
  /**
   * Set the arrivalTime property values for this TrainTrip object; overwriting any existing values.
   *
   * @param arrivalTimes The list of values to set.
   */
  public void setArrivalTimes(List<Date> arrivalTimes);
  
  /**
   * Set the departurePlatform property values for this TrainTrip object; overwriting any existing values.
   *
   * @param departurePlatforms The list of values to set.
   */
  public void setDeparturePlatforms(List<String> departurePlatforms);
  
  /**
   * Set the departureStation property values for this TrainTrip object; overwriting any existing values.
   *
   * @param departureStations The list of values to set.
   */
  public void setDepartureStations(List<TrainStation> departureStations);
  
  /**
   * Set the departureTime property values for this TrainTrip object; overwriting any existing values.
   *
   * @param departureTimes The list of values to set.
   */
  public void setDepartureTimes(List<Date> departureTimes);
  
  /**
   * Set the provider property values for this TrainTrip object; overwriting any existing values.
   *
   * @param providers The list of values to set.
   */
  public void setProviders(List<Thing> providers);
  
  /**
   * Set the trainName property values for this TrainTrip object; overwriting any existing values.
   *
   * @param trainNames The list of values to set.
   */
  public void setTrainNames(List<String> trainNames);
  
  /**
   * Set the trainNumber property values for this TrainTrip object; overwriting any existing values.
   *
   * @param trainNumbers The list of values to set.
   */
  public void setTrainNumbers(List<String> trainNumbers);
  
  /**
   * Adds a arrivalPlatform property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param arrivalPlatform The value to add.
   */
  public void addArrivalPlatform(String arrivalPlatform);
  
  /**
   * Adds a arrivalStation property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param arrivalStation The value to add.
   */
  public void addArrivalStation(TrainStation arrivalStation);
  
  /**
   * Adds a arrivalTime property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param arrivalTime The value to add.
   */
  public void addArrivalTime(Date arrivalTime);
  
  /**
   * Adds a departurePlatform property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param departurePlatform The value to add.
   */
  public void addDeparturePlatform(String departurePlatform);
  
  /**
   * Adds a departureStation property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param departureStation The value to add.
   */
  public void addDepartureStation(TrainStation departureStation);
  
  /**
   * Adds a departureTime property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param departureTime The value to add.
   */
  public void addDepartureTime(Date departureTime);
  
  /**
   * Adds a provider property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param provider The value to add.
   */
  public void addProvider(Thing provider);
  
  /**
   * Adds a trainName property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param trainName The value to add.
   */
  public void addTrainName(String trainName);
  
  /**
   * Adds a trainNumber property value for this TrainTrip object; appending it to the list of existing values.
   *
   * @param trainNumber The value to add.
   */
  public void addTrainNumber(String trainNumber);
  
}