package org.schema;

import java.util.List;
import org.schema.Distance;
import org.schema.MoveAction;
import org.schema.SchemaObject;

/**
 * The act of traveling from an fromLocation to a destination by a specified mode of transport, optionally with participants.
 */
public interface TravelAction extends MoveAction, SchemaObject {

  /**
   * Get a single distance property value for this TravelAction object.
   *
   * @return The first distance property value.
   */
  public Distance getDistance();
  
  /**
   * Get all the distance property values for this TravelAction object.
   *
   * @return A list of distance property values.
   */
  public List<Distance> getDistances();
  
  /**
   * Set the distance property value for this TravelAction object; overwriting any existing values.
   *
   * @param distance The value to set.
   */
  public void setDistance(Distance distance);
  
  /**
   * Set the distance property values for this TravelAction object; overwriting any existing values.
   *
   * @param distances The list of values to set.
   */
  public void setDistances(List<Distance> distances);
  
  /**
   * Adds a distance property value for this TravelAction object; appending it to the list of existing values.
   *
   * @param distance The value to add.
   */
  public void addDistance(Distance distance);
  
}