package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.BusinessFunction;
import org.schema.Number;
import org.schema.Product;
import org.schema.SchemaObject;
import org.schema.StructuredValue;

/**
 * A structured value indicating the quantity, unit of measurement, and business function of goods included in a bundle offer.
 */
public interface TypeAndQuantityNode extends StructuredValue, SchemaObject {

  /**
   * Get a single amountOfThisGood property value for this TypeAndQuantityNode object.
   *
   * @return The first amountOfThisGood property value.
   */
  public Number getAmountOfThisGood();
  
  /**
   * Get a single businessFunction property value for this TypeAndQuantityNode object.
   *
   * @return The first businessFunction property value.
   */
  public BusinessFunction getBusinessFunction();
  
  /**
   * Get a single typeOfGood property value for this TypeAndQuantityNode object.
   *
   * @return The first typeOfGood property value.
   */
  public Product getTypeOfGood();
  
  /**
   * Get a single unitCode property value for this TypeAndQuantityNode object.
   *
   * @return The first unitCode property value.
   */
  public String getUnitCode();
  
  /**
   * Get all the amountOfThisGood property values for this TypeAndQuantityNode object.
   *
   * @return A list of amountOfThisGood property values.
   */
  public List<Number> getAmountOfThisGoods();
  
  /**
   * Get all the businessFunction property values for this TypeAndQuantityNode object.
   *
   * @return A list of businessFunction property values.
   */
  public List<BusinessFunction> getBusinessFunctions();
  
  /**
   * Get all the typeOfGood property values for this TypeAndQuantityNode object.
   *
   * @return A list of typeOfGood property values.
   */
  public List<Product> getTypeOfGoods();
  
  /**
   * Get all the unitCode property values for this TypeAndQuantityNode object.
   *
   * @return A list of unitCode property values.
   */
  public List<String> getUnitCodes();
  
  /**
   * Set the amountOfThisGood property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param amountOfThisGood The value to set.
   */
  public void setAmountOfThisGood(Number amountOfThisGood);
  
  /**
   * Set the businessFunction property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param businessFunction The value to set.
   */
  public void setBusinessFunction(BusinessFunction businessFunction);
  
  /**
   * Set the typeOfGood property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param typeOfGood The value to set.
   */
  public void setTypeOfGood(Product typeOfGood);
  
  /**
   * Set the unitCode property value for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param unitCode The value to set.
   */
  public void setUnitCode(String unitCode);
  
  /**
   * Set the amountOfThisGood property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param amountOfThisGoods The list of values to set.
   */
  public void setAmountOfThisGoods(List<Number> amountOfThisGoods);
  
  /**
   * Set the businessFunction property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param businessFunctions The list of values to set.
   */
  public void setBusinessFunctions(List<BusinessFunction> businessFunctions);
  
  /**
   * Set the typeOfGood property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param typeOfGoods The list of values to set.
   */
  public void setTypeOfGoods(List<Product> typeOfGoods);
  
  /**
   * Set the unitCode property values for this TypeAndQuantityNode object; overwriting any existing values.
   *
   * @param unitCodes The list of values to set.
   */
  public void setUnitCodes(List<String> unitCodes);
  
  /**
   * Adds a amountOfThisGood property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param amountOfThisGood The value to add.
   */
  public void addAmountOfThisGood(Number amountOfThisGood);
  
  /**
   * Adds a businessFunction property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param businessFunction The value to add.
   */
  public void addBusinessFunction(BusinessFunction businessFunction);
  
  /**
   * Adds a typeOfGood property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param typeOfGood The value to add.
   */
  public void addTypeOfGood(Product typeOfGood);
  
  /**
   * Adds a unitCode property value for this TypeAndQuantityNode object; appending it to the list of existing values.
   *
   * @param unitCode The value to add.
   */
  public void addUnitCode(String unitCode);
  
}