package org.schema;

import java.util.List;
import org.schema.Action;
import org.schema.SchemaObject;
import org.schema.Thing;

/**
 * The act of managing by changing/editing the state of the object.
 */
public interface UpdateAction extends Action, SchemaObject {

  /**
   * Get a single collection property value for this UpdateAction object.
   *
   * @return The first collection property value.
   */
  public Thing getCollection();
  
  /**
   * Get all the collection property values for this UpdateAction object.
   *
   * @return A list of collection property values.
   */
  public List<Thing> getCollections();
  
  /**
   * Set the collection property value for this UpdateAction object; overwriting any existing values.
   *
   * @param collection The value to set.
   */
  public void setCollection(Thing collection);
  
  /**
   * Set the collection property values for this UpdateAction object; overwriting any existing values.
   *
   * @param collections The list of values to set.
   */
  public void setCollections(List<Thing> collections);
  
  /**
   * Adds a collection property value for this UpdateAction object; appending it to the list of existing values.
   *
   * @param collection The value to add.
   */
  public void addCollection(Thing collection);
  
}