package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.CreativeWork;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.UserInteraction;

/**
 * The UserInteraction event in which a user comments on an item.
 */
public interface UserComments extends UserInteraction, SchemaObject {

  /**
   * Get a single commentText property value for this UserComments object.
   *
   * @return The first commentText property value.
   */
  public String getCommentText();
  
  /**
   * Get a single commentTime property value for this UserComments object.
   *
   * @return The first commentTime property value.
   */
  public Date getCommentTime();
  
  /**
   * Get a single creator property value for this UserComments object.
   *
   * @return The first creator property value.
   */
  public Thing getCreator();
  
  /**
   * Get a single discusses property value for this UserComments object.
   *
   * @return The first discusses property value.
   */
  public CreativeWork getDiscusses();
  
  /**
   * Get a single replyToUrl property value for this UserComments object.
   *
   * @return The first replyToUrl property value.
   */
  public URL getReplyToUrl();
  
  /**
   * Get all the commentText property values for this UserComments object.
   *
   * @return A list of commentText property values.
   */
  public List<String> getCommentTexts();
  
  /**
   * Get all the commentTime property values for this UserComments object.
   *
   * @return A list of commentTime property values.
   */
  public List<Date> getCommentTimes();
  
  /**
   * Get all the creator property values for this UserComments object.
   *
   * @return A list of creator property values.
   */
  public List<Thing> getCreators();
  
  /**
   * Get all the discusses property values for this UserComments object.
   *
   * @return A list of discusses property values.
   */
  public List<CreativeWork> getDiscussess();
  
  /**
   * Get all the replyToUrl property values for this UserComments object.
   *
   * @return A list of replyToUrl property values.
   */
  public List<URL> getReplyToUrls();
  
  /**
   * Set the commentText property value for this UserComments object; overwriting any existing values.
   *
   * @param commentText The value to set.
   */
  public void setCommentText(String commentText);
  
  /**
   * Set the commentTime property value for this UserComments object; overwriting any existing values.
   *
   * @param commentTime The value to set.
   */
  public void setCommentTime(Date commentTime);
  
  /**
   * Set the creator property value for this UserComments object; overwriting any existing values.
   *
   * @param creator The value to set.
   */
  public void setCreator(Thing creator);
  
  /**
   * Set the discusses property value for this UserComments object; overwriting any existing values.
   *
   * @param discusses The value to set.
   */
  public void setDiscusses(CreativeWork discusses);
  
  /**
   * Set the replyToUrl property value for this UserComments object; overwriting any existing values.
   *
   * @param replyToUrl The value to set.
   */
  public void setReplyToUrl(URL replyToUrl);
  
  /**
   * Set the commentText property values for this UserComments object; overwriting any existing values.
   *
   * @param commentTexts The list of values to set.
   */
  public void setCommentTexts(List<String> commentTexts);
  
  /**
   * Set the commentTime property values for this UserComments object; overwriting any existing values.
   *
   * @param commentTimes The list of values to set.
   */
  public void setCommentTimes(List<Date> commentTimes);
  
  /**
   * Set the creator property values for this UserComments object; overwriting any existing values.
   *
   * @param creators The list of values to set.
   */
  public void setCreators(List<Thing> creators);
  
  /**
   * Set the discusses property values for this UserComments object; overwriting any existing values.
   *
   * @param discussess The list of values to set.
   */
  public void setDiscussess(List<CreativeWork> discussess);
  
  /**
   * Set the replyToUrl property values for this UserComments object; overwriting any existing values.
   *
   * @param replyToUrls The list of values to set.
   */
  public void setReplyToUrls(List<URL> replyToUrls);
  
  /**
   * Adds a commentText property value for this UserComments object; appending it to the list of existing values.
   *
   * @param commentText The value to add.
   */
  public void addCommentText(String commentText);
  
  /**
   * Adds a commentTime property value for this UserComments object; appending it to the list of existing values.
   *
   * @param commentTime The value to add.
   */
  public void addCommentTime(Date commentTime);
  
  /**
   * Adds a creator property value for this UserComments object; appending it to the list of existing values.
   *
   * @param creator The value to add.
   */
  public void addCreator(Thing creator);
  
  /**
   * Adds a discusses property value for this UserComments object; appending it to the list of existing values.
   *
   * @param discusses The value to add.
   */
  public void addDiscusses(CreativeWork discusses);
  
  /**
   * Adds a replyToUrl property value for this UserComments object; appending it to the list of existing values.
   *
   * @param replyToUrl The value to add.
   */
  public void addReplyToUrl(URL replyToUrl);
  
}