package org.schema;

import java.util.List;
import org.schema.AnatomicalStructure;
import org.schema.SchemaObject;
import org.schema.Thing;
import org.schema.Vessel;

/**
 * A type of blood vessel that specifically carries blood to the heart.
 */
public interface Vein extends Vessel, SchemaObject {

  /**
   * Get a single drainsTo property value for this Vein object.
   *
   * @return The first drainsTo property value.
   */
  public Vessel getDrainsTo();
  
  /**
   * Get a single regionDrained property value for this Vein object.
   *
   * @return The first regionDrained property value.
   */
  public Thing getRegionDrained();
  
  /**
   * Get a single tributary property value for this Vein object.
   *
   * @return The first tributary property value.
   */
  public AnatomicalStructure getTributary();
  
  /**
   * Get all the drainsTo property values for this Vein object.
   *
   * @return A list of drainsTo property values.
   */
  public List<Vessel> getDrainsToes();
  
  /**
   * Get all the regionDrained property values for this Vein object.
   *
   * @return A list of regionDrained property values.
   */
  public List<Thing> getRegionDraineds();
  
  /**
   * Get all the tributary property values for this Vein object.
   *
   * @return A list of tributary property values.
   */
  public List<AnatomicalStructure> getTributaries();
  
  /**
   * Set the drainsTo property value for this Vein object; overwriting any existing values.
   *
   * @param drainsTo The value to set.
   */
  public void setDrainsTo(Vessel drainsTo);
  
  /**
   * Set the regionDrained property value for this Vein object; overwriting any existing values.
   *
   * @param regionDrained The value to set.
   */
  public void setRegionDrained(Thing regionDrained);
  
  /**
   * Set the tributary property value for this Vein object; overwriting any existing values.
   *
   * @param tributary The value to set.
   */
  public void setTributary(AnatomicalStructure tributary);
  
  /**
   * Set the drainsTo property values for this Vein object; overwriting any existing values.
   *
   * @param drainsToes The list of values to set.
   */
  public void setDrainsToes(List<Vessel> drainsToes);
  
  /**
   * Set the regionDrained property values for this Vein object; overwriting any existing values.
   *
   * @param regionDraineds The list of values to set.
   */
  public void setRegionDraineds(List<Thing> regionDraineds);
  
  /**
   * Set the tributary property values for this Vein object; overwriting any existing values.
   *
   * @param tributaries The list of values to set.
   */
  public void setTributaries(List<AnatomicalStructure> tributaries);
  
  /**
   * Adds a drainsTo property value for this Vein object; appending it to the list of existing values.
   *
   * @param drainsTo The value to add.
   */
  public void addDrainsTo(Vessel drainsTo);
  
  /**
   * Adds a regionDrained property value for this Vein object; appending it to the list of existing values.
   *
   * @param regionDrained The value to add.
   */
  public void addRegionDrained(Thing regionDrained);
  
  /**
   * Adds a tributary property value for this Vein object; appending it to the list of existing values.
   *
   * @param tributary The value to add.
   */
  public void addTributary(AnatomicalStructure tributary);
  
}