package org.schema;

import java.lang.String;
import java.util.List;
import org.schema.ImageObject;
import org.schema.MediaObject;
import org.schema.Organization;
import org.schema.SchemaObject;

/**
 * A video file.
 */
public interface VideoObject extends MediaObject, SchemaObject {

  /**
   * Get a single caption property value for this VideoObject object.
   *
   * @return The first caption property value.
   */
  public String getCaption();
  
  /**
   * Get a single productionCompany property value for this VideoObject object.
   *
   * @return The first productionCompany property value.
   */
  public Organization getProductionCompany();
  
  /**
   * Get a single thumbnail property value for this VideoObject object.
   *
   * @return The first thumbnail property value.
   */
  public ImageObject getThumbnail();
  
  /**
   * Get a single transcript property value for this VideoObject object.
   *
   * @return The first transcript property value.
   */
  public String getTranscript();
  
  /**
   * Get a single videoFrameSize property value for this VideoObject object.
   *
   * @return The first videoFrameSize property value.
   */
  public String getVideoFrameSize();
  
  /**
   * Get a single videoQuality property value for this VideoObject object.
   *
   * @return The first videoQuality property value.
   */
  public String getVideoQuality();
  
  /**
   * Get all the caption property values for this VideoObject object.
   *
   * @return A list of caption property values.
   */
  public List<String> getCaptions();
  
  /**
   * Get all the productionCompany property values for this VideoObject object.
   *
   * @return A list of productionCompany property values.
   */
  public List<Organization> getProductionCompanies();
  
  /**
   * Get all the thumbnail property values for this VideoObject object.
   *
   * @return A list of thumbnail property values.
   */
  public List<ImageObject> getThumbnails();
  
  /**
   * Get all the transcript property values for this VideoObject object.
   *
   * @return A list of transcript property values.
   */
  public List<String> getTranscripts();
  
  /**
   * Get all the videoFrameSize property values for this VideoObject object.
   *
   * @return A list of videoFrameSize property values.
   */
  public List<String> getVideoFrameSizes();
  
  /**
   * Get all the videoQuality property values for this VideoObject object.
   *
   * @return A list of videoQuality property values.
   */
  public List<String> getVideoQualities();
  
  /**
   * Set the caption property value for this VideoObject object; overwriting any existing values.
   *
   * @param caption The value to set.
   */
  public void setCaption(String caption);
  
  /**
   * Set the productionCompany property value for this VideoObject object; overwriting any existing values.
   *
   * @param productionCompany The value to set.
   */
  public void setProductionCompany(Organization productionCompany);
  
  /**
   * Set the thumbnail property value for this VideoObject object; overwriting any existing values.
   *
   * @param thumbnail The value to set.
   */
  public void setThumbnail(ImageObject thumbnail);
  
  /**
   * Set the transcript property value for this VideoObject object; overwriting any existing values.
   *
   * @param transcript The value to set.
   */
  public void setTranscript(String transcript);
  
  /**
   * Set the videoFrameSize property value for this VideoObject object; overwriting any existing values.
   *
   * @param videoFrameSize The value to set.
   */
  public void setVideoFrameSize(String videoFrameSize);
  
  /**
   * Set the videoQuality property value for this VideoObject object; overwriting any existing values.
   *
   * @param videoQuality The value to set.
   */
  public void setVideoQuality(String videoQuality);
  
  /**
   * Set the caption property values for this VideoObject object; overwriting any existing values.
   *
   * @param captions The list of values to set.
   */
  public void setCaptions(List<String> captions);
  
  /**
   * Set the productionCompany property values for this VideoObject object; overwriting any existing values.
   *
   * @param productionCompanies The list of values to set.
   */
  public void setProductionCompanies(List<Organization> productionCompanies);
  
  /**
   * Set the thumbnail property values for this VideoObject object; overwriting any existing values.
   *
   * @param thumbnails The list of values to set.
   */
  public void setThumbnails(List<ImageObject> thumbnails);
  
  /**
   * Set the transcript property values for this VideoObject object; overwriting any existing values.
   *
   * @param transcripts The list of values to set.
   */
  public void setTranscripts(List<String> transcripts);
  
  /**
   * Set the videoFrameSize property values for this VideoObject object; overwriting any existing values.
   *
   * @param videoFrameSizes The list of values to set.
   */
  public void setVideoFrameSizes(List<String> videoFrameSizes);
  
  /**
   * Set the videoQuality property values for this VideoObject object; overwriting any existing values.
   *
   * @param videoQualities The list of values to set.
   */
  public void setVideoQualities(List<String> videoQualities);
  
  /**
   * Adds a caption property value for this VideoObject object; appending it to the list of existing values.
   *
   * @param caption The value to add.
   */
  public void addCaption(String caption);
  
  /**
   * Adds a productionCompany property value for this VideoObject object; appending it to the list of existing values.
   *
   * @param productionCompany The value to add.
   */
  public void addProductionCompany(Organization productionCompany);
  
  /**
   * Adds a thumbnail property value for this VideoObject object; appending it to the list of existing values.
   *
   * @param thumbnail The value to add.
   */
  public void addThumbnail(ImageObject thumbnail);
  
  /**
   * Adds a transcript property value for this VideoObject object; appending it to the list of existing values.
   *
   * @param transcript The value to add.
   */
  public void addTranscript(String transcript);
  
  /**
   * Adds a videoFrameSize property value for this VideoObject object; appending it to the list of existing values.
   *
   * @param videoFrameSize The value to add.
   */
  public void addVideoFrameSize(String videoFrameSize);
  
  /**
   * Adds a videoQuality property value for this VideoObject object; appending it to the list of existing values.
   *
   * @param videoQuality The value to add.
   */
  public void addVideoQuality(String videoQuality);
  
}