package org.schema;

import java.util.List;
import org.schema.ChooseAction;
import org.schema.Person;
import org.schema.SchemaObject;

/**
 * The act of expressing a preference from a fixed/finite/structured set of choices/options.
 */
public interface VoteAction extends ChooseAction, SchemaObject {

  /**
   * Get a single candidate property value for this VoteAction object.
   *
   * @return The first candidate property value.
   */
  public Person getCandidate();
  
  /**
   * Get all the candidate property values for this VoteAction object.
   *
   * @return A list of candidate property values.
   */
  public List<Person> getCandidates();
  
  /**
   * Set the candidate property value for this VoteAction object; overwriting any existing values.
   *
   * @param candidate The value to set.
   */
  public void setCandidate(Person candidate);
  
  /**
   * Set the candidate property values for this VoteAction object; overwriting any existing values.
   *
   * @param candidates The list of values to set.
   */
  public void setCandidates(List<Person> candidates);
  
  /**
   * Adds a candidate property value for this VoteAction object; appending it to the list of existing values.
   *
   * @param candidate The value to add.
   */
  public void addCandidate(Person candidate);
  
}