package org.schema;

import java.util.List;
import org.schema.QuantitativeValue;
import org.schema.SchemaObject;
import org.schema.StructuredValue;
import org.schema.WarrantyScope;

/**
 * A structured value representing the duration and scope of services that will be provided to a customer free of charge in case of a defect or malfunction of a product.
 */
public interface WarrantyPromise extends StructuredValue, SchemaObject {

  /**
   * Get a single durationOfWarranty property value for this WarrantyPromise object.
   *
   * @return The first durationOfWarranty property value.
   */
  public QuantitativeValue getDurationOfWarranty();
  
  /**
   * Get a single warrantyScope property value for this WarrantyPromise object.
   *
   * @return The first warrantyScope property value.
   */
  public WarrantyScope getWarrantyScope();
  
  /**
   * Get all the durationOfWarranty property values for this WarrantyPromise object.
   *
   * @return A list of durationOfWarranty property values.
   */
  public List<QuantitativeValue> getDurationOfWarranties();
  
  /**
   * Get all the warrantyScope property values for this WarrantyPromise object.
   *
   * @return A list of warrantyScope property values.
   */
  public List<WarrantyScope> getWarrantyScopes();
  
  /**
   * Set the durationOfWarranty property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param durationOfWarranty The value to set.
   */
  public void setDurationOfWarranty(QuantitativeValue durationOfWarranty);
  
  /**
   * Set the warrantyScope property value for this WarrantyPromise object; overwriting any existing values.
   *
   * @param warrantyScope The value to set.
   */
  public void setWarrantyScope(WarrantyScope warrantyScope);
  
  /**
   * Set the durationOfWarranty property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param durationOfWarranties The list of values to set.
   */
  public void setDurationOfWarranties(List<QuantitativeValue> durationOfWarranties);
  
  /**
   * Set the warrantyScope property values for this WarrantyPromise object; overwriting any existing values.
   *
   * @param warrantyScopes The list of values to set.
   */
  public void setWarrantyScopes(List<WarrantyScope> warrantyScopes);
  
  /**
   * Adds a durationOfWarranty property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param durationOfWarranty The value to add.
   */
  public void addDurationOfWarranty(QuantitativeValue durationOfWarranty);
  
  /**
   * Adds a warrantyScope property value for this WarrantyPromise object; appending it to the list of existing values.
   *
   * @param warrantyScope The value to add.
   */
  public void addWarrantyScope(WarrantyScope warrantyScope);
  
}