package org.schema;

import java.lang.String;
import java.net.URL;
import java.util.Date;
import java.util.List;
import org.schema.CollectionPage;
import org.schema.CreativeWork;
import org.schema.ImageObject;
import org.schema.SchemaObject;
import org.schema.Specialty;
import org.schema.Thing;
import org.schema.WebPageElement;

/**
 * A web page. Every web page is implicitly assumed to be declared to be of type WebPage, so the various properties about that webpage, such as <code>breadcrumb</code> may be used. We recommend explicit declaration if these properties are specified, but if they are found outside of an itemscope, they will be assumed to be about the page
 */
public interface WebPage extends CreativeWork, SchemaObject {

  /**
   * Get a single breadcrumb property value for this WebPage object.
   *
   * @return The first breadcrumb property value.
   */
  public String getBreadcrumb();
  
  /**
   * Get a single isPartOf property value for this WebPage object.
   *
   * @return The first isPartOf property value.
   */
  public CollectionPage getIsPartOf();
  
  /**
   * Get a single lastReviewed property value for this WebPage object.
   *
   * @return The first lastReviewed property value.
   */
  public Date getLastReviewed();
  
  /**
   * Get a single mainContentOfPage property value for this WebPage object.
   *
   * @return The first mainContentOfPage property value.
   */
  public WebPageElement getMainContentOfPage();
  
  /**
   * Get a single primaryImageOfPage property value for this WebPage object.
   *
   * @return The first primaryImageOfPage property value.
   */
  public ImageObject getPrimaryImageOfPage();
  
  /**
   * Get a single relatedLink property value for this WebPage object.
   *
   * @return The first relatedLink property value.
   */
  public URL getRelatedLink();
  
  /**
   * Get a single reviewedBy property value for this WebPage object.
   *
   * @return The first reviewedBy property value.
   */
  public Thing getReviewedBy();
  
  /**
   * Get a single significantLink property value for this WebPage object.
   *
   * @return The first significantLink property value.
   */
  public URL getSignificantLink();
  
  /**
   * Get a single specialty property value for this WebPage object.
   *
   * @return The first specialty property value.
   */
  public Specialty getSpecialty();
  
  /**
   * Get all the breadcrumb property values for this WebPage object.
   *
   * @return A list of breadcrumb property values.
   */
  public List<String> getBreadcrumbs();
  
  /**
   * Get all the isPartOf property values for this WebPage object.
   *
   * @return A list of isPartOf property values.
   */
  public List<CollectionPage> getIsPartsOf();
  
  /**
   * Get all the lastReviewed property values for this WebPage object.
   *
   * @return A list of lastReviewed property values.
   */
  public List<Date> getLastRevieweds();
  
  /**
   * Get all the mainContentOfPage property values for this WebPage object.
   *
   * @return A list of mainContentOfPage property values.
   */
  public List<WebPageElement> getMainContentOfPages();
  
  /**
   * Get all the primaryImageOfPage property values for this WebPage object.
   *
   * @return A list of primaryImageOfPage property values.
   */
  public List<ImageObject> getPrimaryImageOfPages();
  
  /**
   * Get all the relatedLink property values for this WebPage object.
   *
   * @return A list of relatedLink property values.
   */
  public List<URL> getRelatedLinks();
  
  /**
   * Get all the reviewedBy property values for this WebPage object.
   *
   * @return A list of reviewedBy property values.
   */
  public List<Thing> getReviewedBies();
  
  /**
   * Get all the significantLink property values for this WebPage object.
   *
   * @return A list of significantLink property values.
   */
  public List<URL> getSignificantLinks();
  
  /**
   * Get all the specialty property values for this WebPage object.
   *
   * @return A list of specialty property values.
   */
  public List<Specialty> getSpecialties();
  
  /**
   * Set the breadcrumb property value for this WebPage object; overwriting any existing values.
   *
   * @param breadcrumb The value to set.
   */
  public void setBreadcrumb(String breadcrumb);
  
  /**
   * Set the isPartOf property value for this WebPage object; overwriting any existing values.
   *
   * @param isPartOf The value to set.
   */
  public void setIsPartOf(CollectionPage isPartOf);
  
  /**
   * Set the lastReviewed property value for this WebPage object; overwriting any existing values.
   *
   * @param lastReviewed The value to set.
   */
  public void setLastReviewed(Date lastReviewed);
  
  /**
   * Set the mainContentOfPage property value for this WebPage object; overwriting any existing values.
   *
   * @param mainContentOfPage The value to set.
   */
  public void setMainContentOfPage(WebPageElement mainContentOfPage);
  
  /**
   * Set the primaryImageOfPage property value for this WebPage object; overwriting any existing values.
   *
   * @param primaryImageOfPage The value to set.
   */
  public void setPrimaryImageOfPage(ImageObject primaryImageOfPage);
  
  /**
   * Set the relatedLink property value for this WebPage object; overwriting any existing values.
   *
   * @param relatedLink The value to set.
   */
  public void setRelatedLink(URL relatedLink);
  
  /**
   * Set the reviewedBy property value for this WebPage object; overwriting any existing values.
   *
   * @param reviewedBy The value to set.
   */
  public void setReviewedBy(Thing reviewedBy);
  
  /**
   * Set the significantLink property value for this WebPage object; overwriting any existing values.
   *
   * @param significantLink The value to set.
   */
  public void setSignificantLink(URL significantLink);
  
  /**
   * Set the specialty property value for this WebPage object; overwriting any existing values.
   *
   * @param specialty The value to set.
   */
  public void setSpecialty(Specialty specialty);
  
  /**
   * Set the breadcrumb property values for this WebPage object; overwriting any existing values.
   *
   * @param breadcrumbs The list of values to set.
   */
  public void setBreadcrumbs(List<String> breadcrumbs);
  
  /**
   * Set the isPartOf property values for this WebPage object; overwriting any existing values.
   *
   * @param isPartsOf The list of values to set.
   */
  public void setIsPartsOf(List<CollectionPage> isPartsOf);
  
  /**
   * Set the lastReviewed property values for this WebPage object; overwriting any existing values.
   *
   * @param lastRevieweds The list of values to set.
   */
  public void setLastRevieweds(List<Date> lastRevieweds);
  
  /**
   * Set the mainContentOfPage property values for this WebPage object; overwriting any existing values.
   *
   * @param mainContentOfPages The list of values to set.
   */
  public void setMainContentOfPages(List<WebPageElement> mainContentOfPages);
  
  /**
   * Set the primaryImageOfPage property values for this WebPage object; overwriting any existing values.
   *
   * @param primaryImageOfPages The list of values to set.
   */
  public void setPrimaryImageOfPages(List<ImageObject> primaryImageOfPages);
  
  /**
   * Set the relatedLink property values for this WebPage object; overwriting any existing values.
   *
   * @param relatedLinks The list of values to set.
   */
  public void setRelatedLinks(List<URL> relatedLinks);
  
  /**
   * Set the reviewedBy property values for this WebPage object; overwriting any existing values.
   *
   * @param reviewedBies The list of values to set.
   */
  public void setReviewedBies(List<Thing> reviewedBies);
  
  /**
   * Set the significantLink property values for this WebPage object; overwriting any existing values.
   *
   * @param significantLinks The list of values to set.
   */
  public void setSignificantLinks(List<URL> significantLinks);
  
  /**
   * Set the specialty property values for this WebPage object; overwriting any existing values.
   *
   * @param specialties The list of values to set.
   */
  public void setSpecialties(List<Specialty> specialties);
  
  /**
   * Adds a breadcrumb property value for this WebPage object; appending it to the list of existing values.
   *
   * @param breadcrumb The value to add.
   */
  public void addBreadcrumb(String breadcrumb);
  
  /**
   * Adds a isPartOf property value for this WebPage object; appending it to the list of existing values.
   *
   * @param isPartOf The value to add.
   */
  public void addIsPartOf(CollectionPage isPartOf);
  
  /**
   * Adds a lastReviewed property value for this WebPage object; appending it to the list of existing values.
   *
   * @param lastReviewed The value to add.
   */
  public void addLastReviewed(Date lastReviewed);
  
  /**
   * Adds a mainContentOfPage property value for this WebPage object; appending it to the list of existing values.
   *
   * @param mainContentOfPage The value to add.
   */
  public void addMainContentOfPage(WebPageElement mainContentOfPage);
  
  /**
   * Adds a primaryImageOfPage property value for this WebPage object; appending it to the list of existing values.
   *
   * @param primaryImageOfPage The value to add.
   */
  public void addPrimaryImageOfPage(ImageObject primaryImageOfPage);
  
  /**
   * Adds a relatedLink property value for this WebPage object; appending it to the list of existing values.
   *
   * @param relatedLink The value to add.
   */
  public void addRelatedLink(URL relatedLink);
  
  /**
   * Adds a reviewedBy property value for this WebPage object; appending it to the list of existing values.
   *
   * @param reviewedBy The value to add.
   */
  public void addReviewedBy(Thing reviewedBy);
  
  /**
   * Adds a significantLink property value for this WebPage object; appending it to the list of existing values.
   *
   * @param significantLink The value to add.
   */
  public void addSignificantLink(URL significantLink);
  
  /**
   * Adds a specialty property value for this WebPage object; appending it to the list of existing values.
   *
   * @param specialty The value to add.
   */
  public void addSpecialty(Specialty specialty);
  
}