package org.schema;

import java.util.List;
import org.schema.CreateAction;
import org.schema.Language;
import org.schema.SchemaObject;

/**
 * The act of authoring written creative content.
 */
public interface WriteAction extends CreateAction, SchemaObject {

  /**
   * Get a single language property value for this WriteAction object.
   *
   * @return The first language property value.
   */
  public Language getLanguage();
  
  /**
   * Get all the language property values for this WriteAction object.
   *
   * @return A list of language property values.
   */
  public List<Language> getLanguages();
  
  /**
   * Set the language property value for this WriteAction object; overwriting any existing values.
   *
   * @param language The value to set.
   */
  public void setLanguage(Language language);
  
  /**
   * Set the language property values for this WriteAction object; overwriting any existing values.
   *
   * @param languages The list of values to set.
   */
  public void setLanguages(List<Language> languages);
  
  /**
   * Adds a language property value for this WriteAction object; appending it to the list of existing values.
   *
   * @param language The value to add.
   */
  public void addLanguage(Language language);
  
}